@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -22,8 +22,8 @@ from E5Gui.E5ProgressDialog import E5ProgressDialog
 from .Ui_PyCoverageDialog import Ui_PyCoverageDialog
 
 import Utilities
-from DebugClients.Python3.coverage import coverage
-from DebugClients.Python3.coverage.misc import CoverageException
+from coverage import Coverage
+from coverage.misc import CoverageException
 
 
 class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
@@ -168,8 +168,7 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
             self.path = os.path.dirname(cfn)
         files.sort()
         
-        cover = coverage(data_file=self.cfn)
-        cover.use_cache(True)
+        cover = Coverage(data_file=self.cfn)
         cover.load()
         
         # set the exclude pattern
@@ -199,8 +198,8 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
                 try:
                     statements, excluded, missing, readable = \
                         cover.analysis2(file)[1:]
-                    readableEx = (excluded and self.__format_lines(excluded)
-                                  or '')
+                    readableEx = (excluded and self.__format_lines(excluded) or
+                                  '')
                     n = len(statements)
                     m = n - len(missing)
                     if n > 0:
@@ -316,8 +315,7 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         itm = self.resultList.currentItem()
         fn = itm.text(0)
         
-        cover = coverage(data_file=self.cfn)
-        cover.use_cache(True)
+        cover = Coverage(data_file=self.cfn)
         cover.exclude(self.excludeList[0])
         cover.load()
         cover.annotate([fn], None, True)
@@ -339,8 +337,7 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
             itm = self.resultList.topLevelItem(index)
             files.append(itm.text(0))
         
-        cover = coverage(data_file=self.cfn)
-        cover.use_cache(True)
+        cover = Coverage(data_file=self.cfn)
         cover.exclude(self.excludeList[0])
         cover.load()
         
@@ -368,8 +365,7 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         This method erases the collected coverage data that is
         stored in the .coverage file.
         """
-        cover = coverage(data_file=self.cfn)
-        cover.use_cache(True)
+        cover = Coverage(data_file=self.cfn)
         cover.load()
         cover.erase()
         
