@@ -65,6 +65,9 @@ class DebugBase(object):
 
     # cache for fixed file names
     _fnCache = {}
+    
+    # Stop all timers, when greenlets are used
+    pollTimerEnabled = True
 
     def __init__(self, dbgClient):
         """
@@ -92,7 +95,6 @@ class DebugBase(object):
         self.currentFrame = None
         
         # frames, where we want to stop or release debugger
-        self.botframe = None
         self.stopframe = None
         self.returnframe = None
         self.stop_everywhere = False
@@ -113,9 +115,11 @@ class DebugBase(object):
         """
         Private method to set a flag every 0.5 s to check for new messages.
         """
-        while True:
+        while DebugBase.pollTimerEnabled:
             time.sleep(0.5)
             self.eventPollFlag = True
+        
+        self.eventPollFlag = False
     
     def getCurrentFrame(self):
         """
@@ -308,39 +312,28 @@ class DebugBase(object):
         
         if event == 'line':
             if self.stop_here(frame) or self.break_here(frame):
-                self.user_line(frame)
+                if (self.stop_everywhere and frame.f_back and
+                        frame.f_back.f_code.co_name == "prepareJsonCommand"):
+                    # Just stepped into print statement, so skip these frames
+                    self._set_stopinfo(None, frame.f_back)
+                else:
+                    self.user_line(frame)
             return self.trace_dispatch
         
         if event == 'call':
-            if self.botframe is None and frame.f_lineno > 1:
-                self.botframe = frame
-                frame.f_trace = self.trace_dispatch
-                
-                self.user_line(frame)
-                return self.trace_dispatch
-            
-            if not (self.stop_here(frame) or
+            if (self.stop_here(frame) or
                     self.__checkBreakInFrame(frame) or
                     Watch.watches != []):
+                return self.trace_dispatch
+            else:
                 # No need to trace this function
                 return
-            return self.trace_dispatch
         
         if event == 'return':
-            if self.stop_here(frame) or frame == self.botframe:
-                # Ignore return events in generator except when stepping.
-                if self.stopframe and frame.f_code.co_flags & CO_GENERATOR:
-                    return
-                # The program has finished if we have just left the first frame
-                if frame == self.botframe:
-                    if self.isMainThread:
-                        atexit._run_exitfuncs()
-                        self._dbgClient.progTerminated(arg)
-                    else:
-                        self._dbgClient.threadTerminated(self.id)
-                
-                if self.quitting and not self._dbgClient.passive:
-                    raise SystemExit
+            if frame == self.returnframe:
+                # Only true if we didn't stopped in this frame, because it's
+                # belonging to the eric debugger.
+                self._set_stopinfo(None, frame.f_back)
             return
         
         if event == 'exception':
@@ -351,7 +344,7 @@ class DebugBase(object):
                 # statement.
                 if not (frame.f_code.co_flags & CO_GENERATOR and
                         arg[0] is StopIteration and arg[2] is None):
-                    self.user_exception(frame, arg)
+                    self.user_exception(arg)
             # Stop at the StopIteration or GeneratorExit exception when the
             # user has set stopframe in a generator by issuing a return
             # command, or a next/until command at the last statement in the
@@ -359,7 +352,7 @@ class DebugBase(object):
             elif (self.stopframe and frame is not self.stopframe and
                     self.stopframe.f_code.co_flags & CO_GENERATOR and
                     arg[0] in (StopIteration, GeneratorExit)):
-                self.user_exception(frame, arg)
+                self.user_exception(arg)
             return
 
         if event == 'c_call':
@@ -369,7 +362,7 @@ class DebugBase(object):
         if event == 'c_return':
             return
         
-        print('DebugBase.trace_dispatch:'       # __IGNORE_WARNING__
+        print('DebugBase.trace_dispatch:'       # __IGNORE_WARNING_M801__
               ' unknown debugging event: ',
               repr(event))
         return self.trace_dispatch
@@ -398,7 +391,6 @@ class DebugBase(object):
             # stop at erics debugger frame or a threading bootstrap
             if (frame.f_back.f_code == stopOnHandleLine):
                 frame.f_trace = self.trace_dispatch
-                self.botframe = frame
                 break
             
             frame = frame.f_back
@@ -422,50 +414,60 @@ class DebugBase(object):
         @type dict
         """
         try:
-            frame = sys._getframe()
-            self.botframe = frame
-            # First time the dispach function is called, a "base debug"
-            # function has to be returned, which is called at every user code
-            # function call. Because of setting botframe manually, the
-            # specific branch returning the trace_dispatch itself is skipped.
-            # Because the next step is always in threading.py and we assume
-            # that there is no breakpoint in it, it's save to return
-            # trace_dispatch unconditionally.
-            sys.settrace(lambda frame, event, arg: self.trace_dispatch)
-            frame.f_trace = self.trace_dispatch
+            # Because in the initial run method the "base debug" function is
+            # set up, it's also valid for the threads afterwards.
+            sys.settrace(self.trace_dispatch)
             
             target(*args, **kwargs)
-        except SystemExit:
-            pass
+        except Exception:
+            excinfo = sys.exc_info()
+            self.user_exception(excinfo, True)
         finally:
+            sys.settrace(None)
             sys.setprofile(None)
     
-    def run(self, cmd, globals=None, locals=None):
+    def run(self, cmd, globalsDict=None, localsDict=None, debug=True):
         """
         Public method to start a given command under debugger control.
         
         @param cmd command / code to execute under debugger control
         @type str or CodeType
-        @keyparam globals dictionary of global variables for cmd
+        @keyparam globalsDict dictionary of global variables for cmd
         @type dict
-        @keyparam locals  dictionary of local variables for cmd
+        @keyparam localsDict dictionary of local variables for cmd
         @type dict
+        @keyparam debug flag if command should run under debugger control
+        @type bool
         """
-        if globals is None:
+        if globalsDict is None:
             import __main__
-            globals = __main__.__dict__
+            globalsDict = __main__.__dict__
         
-        if locals is None:
-            locals = globals
+        if localsDict is None:
+            localsDict = globalsDict
         
-        sys.settrace(self.trace_dispatch)
         if not isinstance(cmd, types.CodeType):
             cmd = compile(cmd, "<string>", "exec")
         
+        if debug:
+            # First time the trace_dispatch function is called, a "base debug"
+            # function has to be returned, which is called at every user code
+            # function call. This is ensured by setting stop_everywhere.
+            self.stop_everywhere = True
+            sys.settrace(self.trace_dispatch)
+        
         try:
-            exec(cmd, globals, locals)
+            exec(cmd, globalsDict, localsDict)
+            atexit._run_exitfuncs()
+            self._dbgClient.progTerminated(0)
         except SystemExit:
-            pass
+            atexit._run_exitfuncs()
+            excinfo = sys.exc_info()
+            exitcode, message = self.__extractSystemExitMessage(excinfo)
+            self._dbgClient.progTerminated(exitcode, message)
+        except Exception:
+            excinfo = sys.exc_info()
+            self.user_exception(excinfo, True)
         finally:
             self.quitting = True
             sys.settrace(None)
@@ -481,6 +483,9 @@ class DebugBase(object):
         """
         self.stopframe = stopframe
         self.returnframe = returnframe
+        if returnframe is not None:
+            # Ensure to be able to stop on the return frame
+            returnframe.f_trace = self.trace_dispatch
         self.stop_everywhere = False
 
     def set_continue(self, special):
@@ -514,7 +519,6 @@ class DebugBase(object):
         @type frame object
         """
         self._set_stopinfo(frame, frame.f_back)
-        frame.f_back.f_trace = self.trace_dispatch
         frame.f_trace = self.trace_dispatch
 
     def set_return(self, frame):
@@ -525,6 +529,20 @@ class DebugBase(object):
         @type frame object
         """
         self._set_stopinfo(None, frame.f_back)
+    
+    def move_instruction_pointer(self, lineno):
+        """
+        Public methode to move the instruction pointer to another line.
+        
+        @param lineno new line number
+        @type int
+        """
+        try:
+            self.currentFrame.f_lineno = lineno
+            stack = self.getStack(self.currentFrame)
+            self._dbgClient.sendResponseLine(stack)
+        except Exception as e:
+            printerr(e)
 
     def set_quit(self):
         """
@@ -563,16 +581,16 @@ class DebugBase(object):
         try:
             return self._fnCache[fn]
         except KeyError:
-            if fn and fn != frame.f_code.co_filename:
-                absFilename = os.path.abspath(fn)
-                if absFilename.endswith(('.pyc', '.pyo')):
-                    fixedName = absFilename[:-1]
-                    if not os.path.exists(fixedName):
-                        fixedName = absFilename
-                else:
+            if fn is None:
+                return frame.f_code.co_filename
+            
+            absFilename = os.path.abspath(fn)
+            if absFilename.endswith(('.pyc', '.pyo')):
+                fixedName = absFilename[:-1]
+                if not os.path.exists(fixedName):
                     fixedName = absFilename
             else:
-                fixedName = frame.f_code.co_filename
+                fixedName = absFilename
             # update cache
             self._fnCache[fn] = fixedName
             return fixedName
@@ -753,10 +771,10 @@ class DebugBase(object):
         if frame.f_lineno == 0:
             return
         
+        self.isBroken = True
         self.currentFrame = frame
         stack = self.getStack(frame, applyTrace=True)
         
-        self.isBroken = True
         self._dbgClient.lockClient()
         self._dbgClient.currentThread = self
         self._dbgClient.currentThreadExec = self
@@ -767,12 +785,10 @@ class DebugBase(object):
         self.isBroken = False
         self._dbgClient.unlockClient()
         
-    def user_exception(self, frame, excinfo, unhandled=False):
+    def user_exception(self, excinfo, unhandled=False):
         """
         Public method reimplemented to report an exception to the debug server.
         
-        @param frame the frame object
-        @type frame object
         @param excinfo details about the exception
         @type tuple(Exception, excval object, traceback frame object)
         @keyparam unhandled flag indicating an uncaught exception
@@ -780,44 +796,12 @@ class DebugBase(object):
         """
         exctype, excval, exctb = excinfo
         
-        if exctype in [GeneratorExit, StopIteration]:
+        if ((exctype in [GeneratorExit, StopIteration] and
+             unhandled is False) or
+                exctype == SystemExit):
             # ignore these
             return
         
-        if exctype == SystemExit:
-            atexit._run_exitfuncs()
-            if excval is None:
-                exitcode = 0
-                message = ""
-            elif isinstance(excval, basestring):
-                exitcode = 1
-                message = excval
-            elif isinstance(excval, bytes):
-                exitcode = 1
-                message = excval.decode()
-            elif isinstance(excval, int):
-                exitcode = excval
-                message = ""
-            elif isinstance(excval, SystemExit):
-                code = excval.code
-                if isinstance(code, basestring):
-                    exitcode = 1
-                    message = code
-                elif isinstance(code, bytes):
-                    exitcode = 1
-                    message = code.decode()
-                elif isinstance(code, int):
-                    exitcode = code
-                    message = ""
-                else:
-                    exitcode = 1
-                    message = str(code)
-            else:
-                exitcode = 1
-                message = str(excval)
-            self._dbgClient.progTerminated(exitcode, message)
-            return
-        
         if exctype in [SyntaxError, IndentationError]:
             try:
                 # tuple could only occure on Python 2, but not always!
@@ -829,12 +813,16 @@ class DebugBase(object):
                     filename = excval.filename
                     lineno = excval.lineno
                     charno = excval.offset
-
-                if charno is None:
-                    charno = 0
                 
-                filename = os.path.abspath(filename)
-                realSyntaxError = os.path.exists(filename)
+                if filename is None:
+                    realSyntaxError = False
+                else:
+                    if charno is None:
+                        charno = 0
+                    
+                    filename = os.path.abspath(filename)
+                    realSyntaxError = os.path.exists(filename)
+                
             except (AttributeError, ValueError):
                 message = ""
                 filename = ""
@@ -885,23 +873,40 @@ class DebugBase(object):
         else:
             excvaltxt = str(excval)
         
+        # Don't step into libraries, which are used by our debugger methods
+        if exctb is not None:
+            self.stop_everywhere = False
+        
+        self.isBroken = True
+        
         stack = []
         if exctb:
             frlist = self.__extract_stack(exctb)
             frlist.reverse()
             
             self.currentFrame = frlist[0]
-            
             stack = self.getStack(frlist[self.skipFrames:])
         
+        self._dbgClient.lockClient()
+        self._dbgClient.currentThread = self
+        self._dbgClient.currentThreadExec = self
         self._dbgClient.sendException(exctypetxt, excvaltxt, stack)
+        self._dbgClient.dumpThreadList()
         
-        if exctb is None:
-            return
+        if exctb is not None:
+            # When polling kept enabled, it isn't possible to resume after an
+            # unhandled exception without further user interaction.
+            self._dbgClient.eventLoop(True)
         
-        self._dbgClient.eventLoop()
         self.skipFrames = 0
         
+        self.isBroken = False
+        stop_everywhere = self.stop_everywhere
+        self.stop_everywhere = False
+        self.eventPollFlag = False
+        self._dbgClient.unlockClient()
+        self.stop_everywhere = stop_everywhere
+    
     def __extractExceptionName(self, exctype):
         """
         Private method to extract the exception name given the exception
@@ -934,6 +939,48 @@ class DebugBase(object):
         tb = None
         return stack
 
+    def __extractSystemExitMessage(self, excinfo):
+        """
+        Private method to get the SystemExit code and message.
+        
+        @param excinfo details about the SystemExit exception
+        @type tuple(Exception, excval object, traceback frame object)
+        @return SystemExit code and message
+        @rtype int, str
+        """
+        exctype, excval, exctb = excinfo
+        if excval is None:
+            exitcode = 0
+            message = ""
+        elif isinstance(excval, basestring):
+            exitcode = 1
+            message = excval
+        elif isinstance(excval, bytes):
+            exitcode = 1
+            message = excval.decode()
+        elif isinstance(excval, int):
+            exitcode = excval
+            message = ""
+        elif isinstance(excval, SystemExit):
+            code = excval.code
+            if isinstance(code, basestring):
+                exitcode = 1
+                message = code
+            elif isinstance(code, bytes):
+                exitcode = 1
+                message = code.decode()
+            elif isinstance(code, int):
+                exitcode = code
+                message = ""
+            else:
+                exitcode = 1
+                message = str(code)
+        else:
+            exitcode = 1
+            message = str(excval)
+        
+        return exitcode, message
+
     def stop_here(self, frame):
         """
         Public method reimplemented to filter out debugger files.
@@ -971,7 +1018,7 @@ class DebugBase(object):
                         "dist-packages")) and not x.startswith(self.lib)]
             pathsToSkip.extend(localLib)
         
-        self.pathsToSkip = tuple(pathsToSkip)
+        self.pathsToSkip = tuple(set(pathsToSkip))
 
     def __skipFrame(self, frame):
         """
