@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -19,7 +19,6 @@ import imp
 import re
 import atexit
 import signal
-import time
 
 
 import DebugClientCapabilities
@@ -188,6 +187,7 @@ class DebugClientBase(object):
         """
         self.breakpoints = {}
         self.redirect = True
+        self.__receiveBuffer = ""
         
         # special objects representing the main scripts thread and frame
         self.mainThread = self
@@ -355,6 +355,23 @@ class DebugClientBase(object):
         
         return code
     
+    def handleLine(self, line):
+        """
+        Public method to handle the receipt of a complete line.
+
+        It first looks for a valid protocol token at the start of the line.
+        Thereafter it trys to execute the lines accumulated so far.
+        
+        @param line the received line
+        """
+        # Remove any newline.
+        if line[-1] == '\n':
+            line = line[:-1]
+
+##        printerr(line)          ##debug
+        
+        self.handleJsonCommand(line)
+    
     def handleJsonCommand(self, jsonStr):
         """
         Public method to handle a command serialized as a JSON string.
@@ -362,12 +379,9 @@ class DebugClientBase(object):
         @param jsonStr string containing the command received from the IDE
         @type str
         """
-##        printerr(jsonStr)          ##debug
-        
         try:
             commandDict = json.loads(jsonStr.strip())
         except (TypeError, ValueError) as err:
-            printerr("Error handling command: " + jsonStr)
             printerr(str(err))
             return
         
@@ -379,14 +393,12 @@ class DebugClientBase(object):
         
         if method == "RequestVariables":
             self.__dumpVariables(
-                params["frameNumber"], params["scope"], params["filters"],
-                params["maxSize"])
+                params["frameNumber"], params["scope"], params["filters"])
         
         elif method == "RequestVariable":
             self.__dumpVariable(
                 params["variable"], params["frameNumber"],
-                params["scope"], params["filters"],
-                params["maxSize"])
+                params["scope"], params["filters"])
         
         elif method == "RequestThreadList":
             self.dumpThreadList()
@@ -582,7 +594,7 @@ class DebugClientBase(object):
                 with codecs.open(sys.argv[0], encoding=self.__coding) as fp:
                     script = fp.read()
                 if script and not script.endswith('\n'):
-                    script += '\n'
+                        script += '\n'
             
             if script:
                 self.running = sys.argv[0]
@@ -801,57 +813,10 @@ class DebugClientBase(object):
         elif method == "RequestCompletion":
             self.__completionList(params["text"])
         
-        elif method == "RequestUTDiscover":
-            if params["syspath"]:
-                sys.path = params["syspath"] + sys.path
-            
-            discoveryStart = params["discoverystart"]
-            if not discoveryStart:
-                discoveryStart = params["workdir"]
-            
-            os.chdir(params["discoverystart"])
-            
-            # set the system exception handling function to ensure, that
-            # we report on all unhandled exceptions
-            sys.excepthook = self.__unhandled_exception
-            self.__interceptSignals()
-            
-            try:
-                import unittest
-                testLoader = unittest.TestLoader()
-                test = testLoader.discover(discoveryStart)
-                if hasattr(testLoader, "errors") and \
-                   bool(testLoader.errors):
-                    self.sendJsonCommand("ResponseUTDiscover", {
-                        "testCasesList": [],
-                        "exception": "DiscoveryError",
-                        "message": "\n\n".join(testLoader.errors),
-                    })
-                else:
-                    testsList = self.__assembleTestCasesList(test,
-                                                             discoveryStart)
-                    self.sendJsonCommand("ResponseUTDiscover", {
-                        "testCasesList": testsList,
-                        "exception": "",
-                        "message": "",
-                    })
-            except Exception:
-                exc_type, exc_value, exc_tb = sys.exc_info()
-                self.sendJsonCommand("ResponseUTDiscover", {
-                    "testCasesList": [],
-                    "exception": exc_type.__name__,
-                    "message": str(exc_value),
-                })
-        
         elif method == "RequestUTPrepare":
-            if params["syspath"]:
-                sys.path = params["syspath"] + sys.path
             sys.path.insert(
                 0, os.path.dirname(os.path.abspath(params["filename"])))
-            if params["workdir"]:
-                os.chdir(params["workdir"])
-            else:
-                os.chdir(sys.path[0])
+            os.chdir(sys.path[0])
             
             # set the system exception handling function to ensure, that
             # we report on all unhandled exceptions
@@ -860,33 +825,19 @@ class DebugClientBase(object):
             
             try:
                 import unittest
-                testLoader = unittest.TestLoader()
-                if params["discover"]:
-                    discoveryStart = params["discoverystart"]
-                    if not discoveryStart:
-                        discoveryStart = params["workdir"]
-                    if params["testcases"]:
-                        self.test = testLoader.loadTestsFromNames(
-                            params["testcases"])
-                    else:
-                        self.test = testLoader.discover(discoveryStart)
-                else:
-                    if params["filename"]:
-                        utModule = imp.load_source(
-                            params["testname"], params["filename"])
-                    else:
-                        utModule = None
+                utModule = imp.load_source(
+                    params["testname"], params["filename"])
+                try:
                     if params["failed"]:
-                        if utModule:
-                            failed = [t.split(".", 1)[1]
-                                      for t in params["failed"]]
-                        else:
-                            failed = params["failed"][:]
-                        self.test = testLoader.loadTestsFromNames(
-                            failed, utModule)
+                        self.test = unittest.defaultTestLoader\
+                            .loadTestsFromNames(params["failed"], utModule)
                     else:
-                        self.test = testLoader.loadTestsFromName(
-                            params["testfunctionname"], utModule)
+                        self.test = unittest.defaultTestLoader\
+                            .loadTestsFromName(params["testfunctionname"],
+                                               utModule)
+                except AttributeError:
+                    self.test = unittest.defaultTestLoader\
+                        .loadTestsFromModule(utModule)
             except Exception:
                 exc_type, exc_value, exc_tb = sys.exc_info()
                 self.sendJsonCommand("ResponseUTPrepared", {
@@ -908,10 +859,6 @@ class DebugClientBase(object):
             else:
                 self.cover = None
             
-            if params["debug"]:
-                Breakpoint.clear_all_breaks()
-                Watch.clear_all_watches()
-            
             self.sendJsonCommand("ResponseUTPrepared", {
                 "count": self.test.countTestCases(),
                 "exception": "",
@@ -920,27 +867,14 @@ class DebugClientBase(object):
         
         elif method == "RequestUTRun":
             from DCTestResult import DCTestResult
-            self.testResult = DCTestResult(self, params["failfast"])
+            self.testResult = DCTestResult(self)
             if self.cover:
                 self.cover.start()
-            self.debugging = params["debug"]
-            if params["debug"]:
-                locals_ = locals()
-                self.threads.clear()
-                self.attachThread(mainThread=True)
-                sys.setprofile(None)
-                self.mainThread.run(
-                    "result = self.test.run(self.testResult)\n",
-                    localsDict=locals_)
-                result = locals_["result"]
-            else:
-                result = self.test.run(self.testResult)
+            self.test.run(self.testResult)
             if self.cover:
                 self.cover.stop()
                 self.cover.save()
-            self.sendJsonCommand("ResponseUTFinished", {
-                "status": 0 if result.wasSuccessful() else 1,
-            })
+            self.sendJsonCommand("ResponseUTFinished", {})
         
         elif method == "RequestUTStop":
             self.testResult.stop()
@@ -950,37 +884,6 @@ class DebugClientBase(object):
             self.fork_child = (params["target"] == 'child')
             self.eventExit = True
     
-    def __assembleTestCasesList(self, suite, start):
-        """
-        Private method to assemble a list of test cases included in a test
-        suite.
-        
-        @param suite test suite to be inspected
-        @type unittest.TestSuite
-        @param start name of directory discovery was started at
-        @type str
-        @return list of tuples containing the test case ID, a short description
-            and the path of the test file name
-        @rtype list of tuples of (str, str, str)
-        """
-        import unittest
-        testCases = []
-        for test in suite:
-            if isinstance(test, unittest.TestSuite):
-                testCases.extend(self.__assembleTestCasesList(test, start))
-            else:
-                testId = test.id()
-                if "ModuleImportFailure" not in testId and \
-                   "LoadTestsFailure" not in testId and \
-                   "_FailedTest" not in testId:
-                    filename = os.path.join(
-                        start,
-                        test.__module__.replace(".", os.sep) + ".py")
-                    testCases.append(
-                        (test.id(), test.shortDescription(), filename)
-                    )
-        return testCases
-    
     def sendJsonCommand(self, method, params):
         """
         Public method to send a single command or response to the IDE.
@@ -1124,25 +1027,25 @@ class DebugClientBase(object):
         Public method called when there is data ready to be read.
         
         @param stream file like object that has data to be written
-        @return flag indicating an error condition
-        @rtype bool
         """
-        error = False
-        
-        self.lockClient()
         try:
-            command = stream.readCommand()
+            got = stream.readline_p()
         except Exception:
-            error = True
-            command = ""
-        self.unlockClient()
+            return
 
-        if error or len(command) == 0:
+        if len(got) == 0:
             self.sessionClose()
-        else:
-            self.handleJsonCommand(command)
-        
-        return error
+            return
+
+        self.__receiveBuffer = self.__receiveBuffer + got
+
+        # Call handleLine for the line if it is complete.
+        eol = self.__receiveBuffer.find('\n')
+        while eol >= 0:
+            line = self.__receiveBuffer[:eol + 1]
+            self.__receiveBuffer = self.__receiveBuffer[eol + 1:]
+            self.handleLine(line)
+            eol = self.__receiveBuffer.find('\n')
 
     def writeReady(self, stream):
         """
@@ -1173,11 +1076,10 @@ class DebugClientBase(object):
         @param disablePolling flag indicating to enter an event loop with
             polling disabled (boolean)
         """
-        self.eventExit = False
+        self.eventExit = None
         self.pollingDisabled = disablePolling
-        selectErrors = 0
 
-        while not self.eventExit:
+        while self.eventExit is None:
             wrdy = []
 
             if self.writestream.nWriteErrors > self.writestream.maxtries:
@@ -1192,21 +1094,11 @@ class DebugClientBase(object):
             try:
                 rrdy, wrdy, xrdy = select.select([self.readstream], wrdy, [])
             except (select.error, KeyboardInterrupt, socket.error):
-                selectErrors += 1
-                if selectErrors <= 10:      # arbitrarily selected
-                    # just carry on
-                    continue
-                else:
-                    # give up for too many errors
-                    break
-            
-            # reset the select error counter
-            selectErrors = 0
-            
+                # just carry on
+                continue
+
             if self.readstream in rrdy:
-                error = self.readReady(self.readstream)
-                if error:
-                    break
+                self.readReady(self.readstream)
 
             if self.writestream in wrdy:
                 self.writeReady(self.writestream)
@@ -1214,7 +1106,7 @@ class DebugClientBase(object):
             if self.errorstream in wrdy:
                 self.writeReady(self.errorstream)
 
-        self.eventExit = False
+        self.eventExit = None
         self.pollingDisabled = False
 
     def eventPoll(self):
@@ -1429,20 +1321,15 @@ class DebugClientBase(object):
         # reset coding
         self.__coding = self.defaultCoding
 
-    def __dumpVariables(self, frmnr, scope, filterList, maxSize):
+    def __dumpVariables(self, frmnr, scope, filterList):
         """
         Private method to return the variables of a frame to the debug server.
         
         @param frmnr distance of frame reported on. 0 is the current frame
-        @type int
-        @param scope 1 to report global variables, 0 for local variables
-        @type int
+            (int)
+        @param scope 1 to report global variables, 0 for local variables (int)
         @param filterList the indices of variable types to be filtered
-        @type list of int
-        @param maxSize maximum size the formatted value of a variable will
-            be shown. If it is bigger than that, a 'too big' indication will
-            be given.
-        @type int
+            (list of int)
         """
         if self.currentThread is None:
             return
@@ -1465,7 +1352,7 @@ class DebugClientBase(object):
         elif scope:
             varDict = f.f_globals
         elif f.f_globals is f.f_locals:
-            scope = -1
+                scope = -1
         else:
             varDict = f.f_locals
             
@@ -1475,7 +1362,7 @@ class DebugClientBase(object):
             keylist = varDict.keys()
             
             vlist = self.__formatVariablesList(
-                keylist, varDict, scope, filterList, maxSize=maxSize)
+                keylist, varDict, scope, filterList)
             varlist.extend(vlist)
         
         self.sendJsonCommand("ResponseVariables", {
@@ -1483,21 +1370,17 @@ class DebugClientBase(object):
             "variables": varlist,
         })
     
-    def __dumpVariable(self, var, frmnr, scope, filterList, maxSize):
+    def __dumpVariable(self, var, frmnr, scope, filterList):
         """
         Private method to return the variables of a frame to the debug server.
         
         @param var list encoded name of the requested variable
-        @type list of strings
+            (list of strings)
         @param frmnr distance of frame reported on. 0 is the current frame
-        @type int
+            (int)
         @param scope 1 to report global variables, 0 for local variables (int)
         @param filterList the indices of variable types to be filtered
-        @type list of int
-        @param maxSize maximum size the formatted value of a variable will
-            be shown. If it is bigger than that, a 'too big' indication will
-            be given.
-        @type int
+            (list of int)
         """
         if self.currentThread is None:
             return
@@ -1517,7 +1400,7 @@ class DebugClientBase(object):
         elif scope:
             varDict = f.f_globals
         elif f.f_globals is f.f_locals:
-            scope = -1
+                scope = -1
         else:
             varDict = f.f_locals
         
@@ -1546,8 +1429,7 @@ class DebugClientBase(object):
                 elif resolver:
                     varDict = resolver.getDictionary(variable)
                     vlist = self.__formatVariablesList(
-                        list(varDict.keys()), varDict, scope, filterList,
-                        maxSize=maxSize)
+                        list(varDict.keys()), varDict, scope, filterList)
                     varlist.extend(vlist)
         
         self.sendJsonCommand("ResponseVariable", {
@@ -1718,7 +1600,7 @@ class DebugClientBase(object):
         return varlist
     
     def __formatVariablesList(self, keylist, dict_, scope, filterList=None,
-                              formatSequences=False, maxSize=0):
+                              formatSequences=False):
         """
         Private method to produce a formated variables list.
         
@@ -1728,31 +1610,21 @@ class DebugClientBase(object):
         expressions. The formated variables list (a list of tuples of 3
         values) is returned.
         
-        @param keylist keys of the dictionary to be formatted
-        @type list of str
+        @param keylist keys of the dictionary
         @param dict_ the dictionary to be scanned
-        @type dict
         @param scope 1 to filter using the globals filter, 0 using the locals
-            filter.
+            filter (int).
             Variables are only added to the list, if their name do not match
             any of the filter expressions.
-        @type int
         @param filterList the indices of variable types to be filtered.
             Variables are only added to the list, if their type is not
             contained in the filter list.
-        @type list of int
         @param formatSequences flag indicating, that sequence or dictionary
             variables should be formatted. If it is 0 (or false), just the
-            number of items contained in these variables is returned.
-        @type bool
-        @param maxSize maximum size the formatted value of a variable will
-            be shown. If it is bigger than that, a 'too big' indication will
-            be placed in the value field.
-        @type int
+            number of items contained in these variables is returned. (boolean)
         @return A tuple consisting of a list of formatted variables. Each
             variable entry is a tuple of three elements, the variable name,
             its type and value.
-        @rtype list of tuple of (str, str, str)
         """
         filterList = [] if filterList is None else filterList[:]
         
@@ -1852,8 +1724,6 @@ class DebugClientBase(object):
                         if valtype.startswith('class') and \
                            rvalue[0] in ['{', '(', '[']:
                             rvalue = ""
-                        elif maxSize and len(rvalue) > maxSize:
-                            rvalue = "@@TOO_BIG_TO_SHOW@@"
                 except Exception:
                     rvalue = ''
             
@@ -2097,17 +1967,8 @@ class DebugClientBase(object):
             family = socket.AF_INET
         else:
             family = socket.AF_INET6
-        
-        retryCount = 0
-        while retryCount < 10:
-            try:
-                addrinfo = socket.getaddrinfo(
-                    host, None, family, socket.SOCK_STREAM)
-                return addrinfo[0][4][0]
-            except Exception:
-                retryCount += 1
-                time.sleep(3)
-        return None
+        return socket.getaddrinfo(host, None, family,
+                                  socket.SOCK_STREAM)[0][4][0]
     
     def main(self):
         """
@@ -2186,21 +2047,22 @@ class DebugClientBase(object):
                 redirect = True
             elif sys.argv[2] == "False":
                 redirect = False
-            else:
+            else: 
                 try:
                     redirect = int(sys.argv[2])
                 except (ValueError, IndexError):
                     redirect = True
             
-            ipOrHost = sys.argv[3]
-            if ':' in ipOrHost:
-                # IPv6 address
-                remoteAddress = ipOrHost
-            elif ipOrHost[0] in '0123456789':
-                # IPv4 address
-                remoteAddress = ipOrHost
-            else:
-                remoteAddress = self.__resolveHost(ipOrHost)
+            try:
+                ipOrHost = sys.argv[3]
+                if ':' in ipOrHost:
+                    remoteAddress = ipOrHost
+                elif ipOrHost[0] in '0123456789':
+                    remoteAddress = ipOrHost
+                else:
+                    remoteAddress = self.__resolveHost(ipOrHost)
+            except Exception:
+                remoteAddress = None
             
             sys.argv = ['']
             if '' not in sys.path:
