@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -30,12 +30,10 @@ import Preferences
 import Utilities
 
 
-DebuggerInterfaces = [
-    "DebuggerInterfacePython",
-    "DebuggerInterfacePython3",
-    "DebuggerInterfaceRuby",
-    "DebuggerInterfaceNone",
-]
+DebuggerInterfaces = {
+    "Python": "DebuggerInterfacePython",
+    "None": "DebuggerInterfaceNone",
+}
 
 
 class DebugServer(QTcpServer):
@@ -68,6 +66,8 @@ class DebugServer(QTcpServer):
         the client side
     @signal clientSyntaxError(exception) emitted after a syntax error has been
         detected on the client side
+    @signal clientSignal(signal) emitted after a signal has been generated on
+        the client side
     @signal clientExit(int) emitted with the exit status after the client has
         exited
     @signal clientClearBreak(filename, lineno) emitted after the debug client
@@ -131,7 +131,8 @@ class DebugServer(QTcpServer):
     clientStatement = pyqtSignal(bool)
     clientException = pyqtSignal(str, str, list)
     clientSyntaxError = pyqtSignal(str, str, int, int)
-    clientExit = pyqtSignal(int)
+    clientSignal = pyqtSignal(str, str, int, str, str)
+    clientExit = pyqtSignal(int, str)
     clientBreakConditionError = pyqtSignal(str, int)
     clientWatchConditionError = pyqtSignal(str)
     clientRawInput = pyqtSignal(str, bool)
@@ -152,12 +153,25 @@ class DebugServer(QTcpServer):
     callTraceInfo = pyqtSignal(bool, str, str, str, str, str, str)
     appendStdout = pyqtSignal(str)
     
-    def __init__(self):
+    def __init__(self, preventPassiveDebugging=False):
         """
         Constructor
+        
+        @param preventPassiveDebugging flag overriding the PassiveDbgEnabled
+            setting (boolean)
         """
         super(DebugServer, self).__init__()
         
+        self.__debuggerInterfaces = {}
+        # the interface name is the key, a function to get the
+        # registration data is the value
+        self.__debuggerInterfaceRegistry = {}
+        # the client language is the key, a list containing the client
+        # capabilities, a list of associated file extensions, a
+        # function reference to create the debugger interface (see
+        # __createDebuggerInterface() below) and the interface name is
+        # the value
+        
         # create our models
         self.breakpointModel = BreakPointModel(self)
         self.watchpointModel = WatchPointModel(self)
@@ -176,7 +190,8 @@ class DebugServer(QTcpServer):
         self.networkInterfaceName, self.networkInterfaceIndex = \
             self.__getNetworkInterfaceAndIndex(self.networkInterface)
         
-        if Preferences.getDebugger("PassiveDbgEnabled"):
+        if not preventPassiveDebugging and \
+           Preferences.getDebugger("PassiveDbgEnabled"):
             sock = Preferences.getDebugger("PassiveDbgPort")  # default: 42424
             self.listen(hostAddress, sock)
             self.passive = True
@@ -279,29 +294,90 @@ class DebugServer(QTcpServer):
         """
         Public slot to handle the preferencesChanged signal.
         """
-        self.__registerDebuggerInterfaces()
+        registeredInterfaces = {}
+        for interfaceName in self.__debuggerInterfaces:
+            registeredInterfaces[interfaceName] = \
+                self.__debuggerInterfaces[interfaceName]
+        
+        self.__debuggerInterfaces = {}
+        self.__debuggerInterfaceRegistry = {}
+        for interfaceName, getRegistryData in registeredInterfaces.items():
+            self.registerDebuggerInterface(interfaceName, getRegistryData)
+        
+    def registerDebuggerInterface(self, interfaceName, getRegistryData):
+        """
+        Public method to register a debugger interface.
+        
+        @param interfaceName name of the debugger interface
+        @type str
+        @param getRegistryData reference to a function to be called
+            to get the debugger interface details. This method shall
+            return the client language, the client capabilities, the
+            list of associated file extensions and a function reference
+            to create the debugger interface (see __createDebuggerInterface())
+        @type function
+        """
+        if interfaceName in self.__debuggerInterfaces:
+            E5MessageBox.warning(
+                None,
+                self.tr("Register Debugger Interface"),
+                self.tr("""<p>The debugger interface <b>{0}</b> has already"""
+                        """ been registered. Ignoring this request.</p>"""))
+            return
+        
+        registryDataList = getRegistryData()
+        if registryDataList:
+            self.__debuggerInterfaces[interfaceName] = getRegistryData
+            for clientLanguage, clientCapabilities, clientExtensions, \
+                    interfaceCreator in registryDataList:
+                self.__debuggerInterfaceRegistry[clientLanguage] = [
+                    clientCapabilities, clientExtensions, interfaceCreator,
+                    interfaceName]
+        
+    def unregisterDebuggerInterface(self, interfaceName):
+        """
+        Public method to unregister a debugger interface.
+        
+        @param interfaceName interfaceName of the debugger interface
+        @type str
+        """
+        if interfaceName in self.__debuggerInterfaces:
+            clientLanguages = []
+            for clientLanguage, registryData in \
+                    self.__debuggerInterfaceRegistry.items():
+                if interfaceName == registryData[-1]:
+                    clientLanguages.append(clientLanguage)
+            for clientLanguage in clientLanguages:
+                del self.__debuggerInterfaceRegistry[clientLanguage]
+            del self.__debuggerInterfaces[interfaceName]
+        
+    def __findLanguageForExtension(self, ext):
+        """
+        Private method to get the language associated with a file extension.
+        
+        @param ext file extension
+        @type str
+        @return associated language
+        @rtype str
+        """
+        for language in self.__debuggerInterfaceRegistry:
+            if ext in self.__debuggerInterfaceRegistry[language][1]:
+                return language
+        
+        return ""
         
     def __registerDebuggerInterfaces(self):
         """
-        Private method to register the available debugger interface modules.
+        Private method to register the available internal debugger interfaces.
         """
-        self.__clientCapabilities = {}
-        self.__clientAssociations = {}
-        
-        for interface in DebuggerInterfaces:
+        for name, interface in DebuggerInterfaces.items():
             modName = "Debugger.{0}".format(interface)
             mod = __import__(modName)
             components = modName.split('.')
             for comp in components[1:]:
                 mod = getattr(mod, comp)
             
-            clientLanguage, clientCapabilities, clientExtensions = \
-                mod.getRegistryData()
-            if clientLanguage:
-                self.__clientCapabilities[clientLanguage] = clientCapabilities
-                for extension in clientExtensions:
-                    if extension not in self.__clientAssociations:
-                        self.__clientAssociations[extension] = clientLanguage
+            self.registerDebuggerInterface(name, mod.getRegistryData)
         
     def getSupportedLanguages(self, shellOnly=False):
         """
@@ -311,16 +387,16 @@ class DebugServer(QTcpServer):
             interactive shell should be returned
         @return list of supported languages (list of strings)
         """
-        languages = list(self.__clientCapabilities.keys())
+        languages = list(self.__debuggerInterfaceRegistry.keys())
         try:
-            del languages[languages.index("None")]
+            languages.remove("None")
         except ValueError:
             pass    # it is not in the list
         
         if shellOnly:
             languages = \
                 [lang for lang in languages
-                 if self.__clientCapabilities[lang] &
+                 if self.__debuggerInterfaceRegistry[lang][0] &
                     DebugClientCapabilities.HasShell]
         
         return languages[:]
@@ -333,12 +409,10 @@ class DebugServer(QTcpServer):
         @return tuple of extensions associated with the language
             (tuple of strings)
         """
-        extensions = []
-        for ext, lang in list(self.__clientAssociations.items()):
-            if lang == language:
-                extensions.append(ext)
-        
-        return tuple(extensions)
+        if language in self.__debuggerInterfaceRegistry:
+            return tuple(self.__debuggerInterfaceRegistry[language][1])
+        else:
+            return tuple()
         
     def __createDebuggerInterface(self, clientType=None):
         """
@@ -349,26 +423,14 @@ class DebugServer(QTcpServer):
         if self.lastClientType != self.clientType or clientType is not None:
             if clientType is None:
                 clientType = self.clientType
-            if clientType == "Python2":
-                from .DebuggerInterfacePython import DebuggerInterfacePython
-                self.debuggerInterface = DebuggerInterfacePython(
-                    self, self.passive)
-            elif clientType == "Python3":
-                from .DebuggerInterfacePython3 import DebuggerInterfacePython3
-                self.debuggerInterface = DebuggerInterfacePython3(
-                    self, self.passive)
-            elif clientType == "Ruby":
-                from .DebuggerInterfaceRuby import DebuggerInterfaceRuby
-                self.debuggerInterface = DebuggerInterfaceRuby(
-                    self, self.passive)
-            elif clientType == "None":
-                from .DebuggerInterfaceNone import DebuggerInterfaceNone
-                self.debuggerInterface = DebuggerInterfaceNone(
-                    self, self.passive)
+            if clientType in self.__debuggerInterfaceRegistry:
+                self.debuggerInterface = \
+                    self.__debuggerInterfaceRegistry[clientType][2](
+                        self, self.passive)
             else:
-                from .DebuggerInterfaceNone import DebuggerInterfaceNone
-                self.debuggerInterface = DebuggerInterfaceNone(
-                    self, self.passive)
+                self.debuggerInterface = \
+                    self.__debuggerInterfaceRegistry["None"][2](
+                        self, self.passive)
                 self.clientType = "None"
         
     def __setClientType(self, clType):
@@ -383,7 +445,7 @@ class DebugServer(QTcpServer):
                 'DebugClient/Type', self.clientType)
         
     def startClient(self, unplanned=True, clType=None, forProject=False,
-                    runInConsole=False):
+                    runInConsole=False, interpreter=""):
         """
         Public method to start a debug client.
         
@@ -392,6 +454,8 @@ class DebugServer(QTcpServer):
         @keyparam forProject flag indicating a project related action (boolean)
         @keyparam runInConsole flag indicating to start the debugger in a
             console window (boolean)
+        @keyparam interpreter interpreter to be used to execute the remote
+            side (string)
         """
         self.running = False
         
@@ -416,16 +480,16 @@ class DebugServer(QTcpServer):
                 project = e5App().getObject("Project")
                 if not project.isDebugPropertiesLoaded():
                     self.clientProcess, isNetworked, clientInterpreter = \
-                        self.debuggerInterface.startRemote(self.serverPort(),
-                                                           runInConsole)
+                        self.debuggerInterface.startRemote(
+                            self.serverPort(), runInConsole, interpreter)
                 else:
                     self.clientProcess, isNetworked, clientInterpreter = \
                         self.debuggerInterface.startRemoteForProject(
-                            self.serverPort(), runInConsole)
+                            self.serverPort(), runInConsole, interpreter)
             else:
                 self.clientProcess, isNetworked, clientInterpreter = \
                     self.debuggerInterface.startRemote(
-                        self.serverPort(), runInConsole)
+                        self.serverPort(), runInConsole, interpreter)
             
             if self.clientProcess:
                 self.clientProcess.readyReadStandardError.connect(
@@ -646,15 +710,15 @@ class DebugServer(QTcpServer):
             self.__addWatchPoints(
                 QModelIndex(), startIndex.row(), endIndex.row())
         
-    def getClientCapabilities(self, type):
+    def getClientCapabilities(self, clientType):
         """
         Public method to retrieve the debug clients capabilities.
         
-        @param type debug client type (string)
+        @param clientType debug client type (string)
         @return debug client capabilities (integer)
         """
         try:
-            return self.__clientCapabilities[type]
+            return self.__debuggerInterfaceRegistry[clientType][0]
         except KeyError:
             return 0    # no capabilities
         
@@ -736,13 +800,15 @@ class DebugServer(QTcpServer):
                 pass
         self.debuggerInterface.remoteEnvironment(envdict)
         
-    def remoteLoad(self, fn, argv, wd, env, autoClearShell=True,
+    def remoteLoad(self, interpreter, fn, argv, wd, env, autoClearShell=True,
                    tracePython=False, autoContinue=True, forProject=False,
                    runInConsole=False, autoFork=False, forkChild=False,
                    clientType="", enableCallTrace=False):
         """
         Public method to load a new program to debug.
         
+        @param interpreter interpreter to be used to execute the remote
+            side (string)
         @param fn the filename to debug (string)
         @param argv the commandline arguments to pass to the program (string)
         @param wd the working directory for the program (string)
@@ -772,11 +838,11 @@ class DebugServer(QTcpServer):
                 self.__setClientType(clientType)
             else:
                 self.__setClientType(
-                    self.__clientAssociations[os.path.splitext(fn)[1]])
+                    self.__findLanguageForExtension(os.path.splitext(fn)[1]))
         except KeyError:
             self.__setClientType('Python3')    # assume it is a Python3 file
         self.startClient(False, forProject=forProject,
-                         runInConsole=runInConsole)
+                         runInConsole=runInConsole, interpreter=interpreter)
         
         self.setCallTraceEnabled(enableCallTrace)
         self.remoteEnvironment(env)
@@ -788,13 +854,14 @@ class DebugServer(QTcpServer):
         self.__restoreBreakpoints()
         self.__restoreWatchpoints()
 
-    def remoteRun(self, fn, argv, wd, env, autoClearShell=True,
-                  forProject=False, runInConsole=False,
-                  autoFork=False, forkChild=False,
-                  clientType=""):
+    def remoteRun(self, interpreter, fn, argv, wd, env, autoClearShell=True,
+                  forProject=False, runInConsole=False, autoFork=False,
+                  forkChild=False, clientType=""):
         """
         Public method to load a new program to run.
         
+        @param interpreter interpreter to be used to execute the remote
+            side (string)
         @param fn the filename to run (string)
         @param argv the commandline arguments to pass to the program (string)
         @param wd the working directory for the program (string)
@@ -817,11 +884,11 @@ class DebugServer(QTcpServer):
                 self.__setClientType(clientType)
             else:
                 self.__setClientType(
-                    self.__clientAssociations[os.path.splitext(fn)[1]])
+                    self.__findLanguageForExtension(os.path.splitext(fn)[1]))
         except KeyError:
             self.__setClientType('Python3')    # assume it is a Python3 file
         self.startClient(False, forProject=forProject,
-                         runInConsole=runInConsole)
+                         runInConsole=runInConsole, interpreter=interpreter)
         
         self.remoteEnvironment(env)
         
@@ -829,12 +896,14 @@ class DebugServer(QTcpServer):
         self.debugging = False
         self.running = True
 
-    def remoteCoverage(self, fn, argv, wd, env, autoClearShell=True,
-                       erase=False, forProject=False, runInConsole=False,
-                       clientType=""):
+    def remoteCoverage(self, interpreter, fn, argv, wd, env,
+                       autoClearShell=True, erase=False, forProject=False,
+                       runInConsole=False, clientType=""):
         """
         Public method to load a new program to collect coverage data.
         
+        @param interpreter interpreter to be used to execute the remote
+            side (string)
         @param fn the filename to run (string)
         @param argv the commandline arguments to pass to the program (string)
         @param wd the working directory for the program (string)
@@ -856,11 +925,11 @@ class DebugServer(QTcpServer):
                 self.__setClientType(clientType)
             else:
                 self.__setClientType(
-                    self.__clientAssociations[os.path.splitext(fn)[1]])
+                    self.__findLanguageForExtension(os.path.splitext(fn)[1]))
         except KeyError:
             self.__setClientType('Python3')    # assume it is a Python3 file
         self.startClient(False, forProject=forProject,
-                         runInConsole=runInConsole)
+                         runInConsole=runInConsole, interpreter=interpreter)
         
         self.remoteEnvironment(env)
         
@@ -868,13 +937,14 @@ class DebugServer(QTcpServer):
         self.debugging = False
         self.running = True
 
-    def remoteProfile(self, fn, argv, wd, env, autoClearShell=True,
-                      erase=False, forProject=False,
-                      runInConsole=False,
-                      clientType=""):
+    def remoteProfile(self, interpreter, fn, argv, wd, env,
+                      autoClearShell=True, erase=False, forProject=False,
+                      runInConsole=False, clientType=""):
         """
         Public method to load a new program to collect profiling data.
         
+        @param interpreter interpreter to be used to execute the remote
+            side (string)
         @param fn the filename to run (string)
         @param argv the commandline arguments to pass to the program (string)
         @param wd the working directory for the program (string)
@@ -896,11 +966,11 @@ class DebugServer(QTcpServer):
                 self.__setClientType(clientType)
             else:
                 self.__setClientType(
-                    self.__clientAssociations[os.path.splitext(fn)[1]])
+                    self.__findLanguageForExtension(os.path.splitext(fn)[1]))
         except KeyError:
             self.__setClientType('Python3')    # assume it is a Python3 file
         self.startClient(False, forProject=forProject,
-                         runInConsole=runInConsole)
+                         runInConsole=runInConsole, interpreter=interpreter)
         
         self.remoteEnvironment(env)
         
@@ -949,17 +1019,27 @@ class DebugServer(QTcpServer):
         """
         self.debuggerInterface.remoteContinue(special)
 
-    def remoteBreakpoint(self, fn, line, set, cond=None, temp=False):
+    def remoteMoveIP(self, line):
+        """
+        Public method to move the instruction pointer to a different line.
+        
+        @param line the new line, where execution should be continued
+        """
+        self.debuggerInterface.remoteMoveIP(line)
+
+    def remoteBreakpoint(self, fn, line, setBreakpoint, cond=None, temp=False):
         """
         Public method to set or clear a breakpoint.
         
         @param fn filename the breakpoint belongs to (string)
         @param line linenumber of the breakpoint (int)
-        @param set flag indicating setting or resetting a breakpoint (boolean)
+        @param setBreakpoint flag indicating setting or resetting a breakpoint
+            (boolean)
         @param cond condition of the breakpoint (string)
         @param temp flag indicating a temporary breakpoint (boolean)
         """
-        self.debuggerInterface.remoteBreakpoint(fn, line, set, cond, temp)
+        self.debuggerInterface.remoteBreakpoint(fn, line, setBreakpoint, cond,
+                                                temp)
         
     def __remoteBreakpointEnable(self, fn, line, enable):
         """
@@ -982,17 +1062,17 @@ class DebugServer(QTcpServer):
         """
         self.debuggerInterface.remoteBreakpointIgnore(fn, line, count)
         
-    def __remoteWatchpoint(self, cond, set, temp=False):
+    def __remoteWatchpoint(self, cond, setWatch, temp=False):
         """
         Private method to set or clear a watch expression.
         
         @param cond expression of the watch expression (string)
-        @param set flag indicating setting or resetting a watch expression
+        @param setWatch flag indicating setting or resetting a watch expression
             (boolean)
         @param temp flag indicating a temporary watch expression (boolean)
         """
         # cond is combination of cond and special (s. watch expression viewer)
-        self.debuggerInterface.remoteWatchpoint(cond, set, temp)
+        self.debuggerInterface.remoteWatchpoint(cond, setWatch, temp)
     
     def __remoteWatchpointEnable(self, cond, enable):
         """
@@ -1039,36 +1119,38 @@ class DebugServer(QTcpServer):
         """
         self.debuggerInterface.remoteSetThread(tid)
         
-    def remoteClientVariables(self, scope, filter, framenr=0):
+    def remoteClientVariables(self, scope, filterList, framenr=0):
         """
         Public method to request the variables of the debugged program.
         
         @param scope the scope of the variables (0 = local, 1 = global)
-        @param filter list of variable types to filter out (list of int)
+        @param filterList list of variable types to filter out (list of int)
         @param framenr framenumber of the variables to retrieve (int)
         """
-        self.debuggerInterface.remoteClientVariables(scope, filter, framenr)
+        self.debuggerInterface.remoteClientVariables(scope, filterList,
+                                                     framenr)
         
-    def remoteClientVariable(self, scope, filter, var, framenr=0):
+    def remoteClientVariable(self, scope, filterList, var, framenr=0):
         """
         Public method to request the variables of the debugged program.
         
         @param scope the scope of the variables (0 = local, 1 = global)
-        @param filter list of variable types to filter out (list of int)
+        @param filterList list of variable types to filter out (list of int)
         @param var list encoded name of variable to retrieve (string)
         @param framenr framenumber of the variables to retrieve (int)
         """
         self.debuggerInterface.remoteClientVariable(
-            scope, filter, var, framenr)
+            scope, filterList, var, framenr)
         
-    def remoteClientSetFilter(self, scope, filter):
+    def remoteClientSetFilter(self, scope, filterStr):
         """
         Public method to set a variables filter list.
         
         @param scope the scope of the variables (0 = local, 1 = global)
-        @param filter regexp string for variable names to filter out (string)
+        @param filterStr regexp string for variable names to filter out
+            (string)
         """
-        self.debuggerInterface.remoteClientSetFilter(scope, filter)
+        self.debuggerInterface.remoteClientSetFilter(scope, filterStr)
         
     def setCallTraceEnabled(self, on):
         """
@@ -1078,24 +1160,6 @@ class DebugServer(QTcpServer):
         """
         self.debuggerInterface.setCallTraceEnabled(on)
         
-    def remoteEval(self, arg):
-        """
-        Public method to evaluate arg in the current context of the debugged
-        program.
-        
-        @param arg the arguments to evaluate (string)
-        """
-        self.debuggerInterface.remoteEval(arg)
-        
-    def remoteExec(self, stmt):
-        """
-        Public method to execute stmt in the current context of the debugged
-        program.
-        
-        @param stmt statement to execute (string)
-        """
-        self.debuggerInterface.remoteExec(stmt)
-        
     def remoteBanner(self):
         """
         Public slot to get the banner info of the remote client.
@@ -1141,7 +1205,7 @@ class DebugServer(QTcpServer):
                 self.__setClientType(clientType)
             else:
                 self.__setClientType(
-                    self.__clientAssociations[os.path.splitext(fn)[1]])
+                    self.__findLanguageForExtension(os.path.splitext(fn)[1]))
         except KeyError:
             self.__setClientType('Python3')    # assume it is a Python3 file
         self.startClient(False)
@@ -1263,16 +1327,40 @@ class DebugServer(QTcpServer):
         if self.running:
             self.clientSyntaxError.emit(message, filename, lineNo, characterNo)
         
-    def signalClientExit(self, status):
+    def signalClientSignal(self, message, filename, lineNo,
+                           funcName, funcArgs):
+        """
+        Public method to process a signal generated on the client side.
+        
+        @param message message of the syntax error
+        @type str
+        @param filename translated filename of the syntax error position
+        @type str
+        @param lineNo line number of the syntax error position
+        @type int
+        @param funcName name of the function causing the signal
+        @type str
+        @param funcArgs function arguments
+        @type str
+        """
+        if self.running:
+            self.clientSignal.emit(message, filename, lineNo,
+                                   funcName, funcArgs)
+        
+    def signalClientExit(self, status, message=""):
         """
         Public method to process the client exit status.
         
-        @param status exit code as a string (string)
+        @param status exit code
+        @type int
+        @param message message sent with the exit
+        @type str
         """
         if self.passive:
             self.__passiveShutDown()
-        self.clientExit.emit(int(status))
-        if Preferences.getDebugger("AutomaticReset"):
+        self.clientExit.emit(int(status), message)
+        if Preferences.getDebugger("AutomaticReset") or (self.running and
+                                                         not self.debugging):
             self.startClient(False)
         if self.passive:
             self.__createDebuggerInterface("None")
@@ -1340,7 +1428,7 @@ class DebugServer(QTcpServer):
         @param capabilities bitmaks with the client capabilities (integer)
         @param clientType type of the debug client (string)
         """
-        self.__clientCapabilities[clientType] = capabilities
+        self.__debuggerInterfaceRegistry[clientType][0] = capabilities
         self.clientCapabilities.emit(capabilities, clientType)
         
     def signalClientCompletionList(self, completionList, text):
@@ -1394,54 +1482,54 @@ class DebugServer(QTcpServer):
         """
         self.utStopTest.emit()
         
-    def clientUtTestFailed(self, testname, traceback, id):
+    def clientUtTestFailed(self, testname, traceback, testId):
         """
         Public method to process the client test failed info.
         
         @param testname name of the test (string)
         @param traceback lines of traceback info (list of strings)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestFailed.emit(testname, traceback, id)
+        self.utTestFailed.emit(testname, traceback, testId)
         
-    def clientUtTestErrored(self, testname, traceback, id):
+    def clientUtTestErrored(self, testname, traceback, testId):
         """
         Public method to process the client test errored info.
         
         @param testname name of the test (string)
         @param traceback lines of traceback info (list of strings)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestErrored.emit(testname, traceback, id)
+        self.utTestErrored.emit(testname, traceback, testId)
         
-    def clientUtTestSkipped(self, testname, reason, id):
+    def clientUtTestSkipped(self, testname, reason, testId):
         """
         Public method to process the client test skipped info.
         
         @param testname name of the test (string)
         @param reason reason for skipping the test (string)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestSkipped.emit(testname, reason, id)
+        self.utTestSkipped.emit(testname, reason, testId)
         
-    def clientUtTestFailedExpected(self, testname, traceback, id):
+    def clientUtTestFailedExpected(self, testname, traceback, testId):
         """
         Public method to process the client test failed expected info.
         
         @param testname name of the test (string)
         @param traceback lines of traceback info (list of strings)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestFailedExpected.emit(testname, traceback, id)
+        self.utTestFailedExpected.emit(testname, traceback, testId)
         
-    def clientUtTestSucceededUnexpected(self, testname, id):
+    def clientUtTestSucceededUnexpected(self, testname, testId):
         """
         Public method to process the client test succeeded unexpected info.
         
         @param testname name of the test (string)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestSucceededUnexpected.emit(testname, id)
+        self.utTestSucceededUnexpected.emit(testname, testId)
         
     def clientUtFinished(self):
         """
