@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,16 +17,6 @@ ClientDefaultCapabilities = 0
 ClientTypeAssociations = []
 
 
-def getRegistryData():
-    """
-    Module functionto get characterising data for the debugger interface.
-    
-    @return list of the following data. Client type (string), client
-        capabilities (integer), client type association (list of strings)
-    """
-    return ["None", ClientDefaultCapabilities, ClientTypeAssociations]
-
-
 class DebuggerInterfaceNone(QObject):
     """
     Class implementing a dummy debugger interface for the debug server.
@@ -48,26 +38,30 @@ class DebuggerInterfaceNone(QObject):
         # set default values for capabilities of clients
         self.clientCapabilities = ClientDefaultCapabilities
         
-    def startRemote(self, port, runInConsole):
+    def startRemote(self, port, runInConsole, interpreter):
         """
         Public method to start a remote Python interpreter.
         
-        @param port portnumber the debug server is listening on (integer)
+        @param port port number the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
+        @param interpreter interpreter to be used to execute the remote
+            side (string)
         @return client process object (QProcess), a flag to indicate
             a network connection (boolean) and the name of the interpreter
             in case of a local execution (string)
         """
         return None, True, ""
 
-    def startRemoteForProject(self, port, runInConsole):
+    def startRemoteForProject(self, port, runInConsole, interpreter):
         """
         Public method to start a remote Python interpreter for a project.
         
-        @param port portnumber the debug server is listening on (integer)
+        @param port port number the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
+        @param interpreter interpreter to be used to execute the remote
+            side (string)
         @return client process object (QProcess), a flag to indicate
             a network connection (boolean) and the name of the interpreter
             in case of a local execution (string)
@@ -220,13 +214,22 @@ class DebuggerInterfaceNone(QObject):
         """
         return
 
-    def remoteBreakpoint(self, fn, line, set, cond=None, temp=False):
+    def remoteMoveIP(self, line):
+        """
+        Public method to move the instruction pointer to a different line.
+        
+        @param line the new line, where execution should be continued
+        """
+        return
+
+    def remoteBreakpoint(self, fn, line, setBreakpoint, cond=None, temp=False):
         """
         Public method to set or clear a breakpoint.
         
         @param fn filename the breakpoint belongs to (string)
         @param line linenumber of the breakpoint (int)
-        @param set flag indicating setting or resetting a breakpoint (boolean)
+        @param setBreakpoint flag indicating setting or resetting a
+            breakpoint (boolean)
         @param cond condition of the breakpoint (string)
         @param temp flag indicating a temporary breakpoint (boolean)
         """
@@ -253,12 +256,12 @@ class DebuggerInterfaceNone(QObject):
         """
         return
         
-    def remoteWatchpoint(self, cond, set, temp=False):
+    def remoteWatchpoint(self, cond, setWatch, temp=False):
         """
         Public method to set or clear a watch expression.
         
         @param cond expression of the watch expression (string)
-        @param set flag indicating setting or resetting a watch expression
+        @param setWatch flag indicating setting or resetting a watch expression
             (boolean)
         @param temp flag indicating a temporary watch expression (boolean)
         """
@@ -306,33 +309,34 @@ class DebuggerInterfaceNone(QObject):
         """
         return
         
-    def remoteClientVariables(self, scope, filter, framenr=0):
+    def remoteClientVariables(self, scope, filterList, framenr=0):
         """
         Public method to request the variables of the debugged program.
         
         @param scope the scope of the variables (0 = local, 1 = global)
-        @param filter list of variable types to filter out (list of int)
+        @param filterList list of variable types to filter out (list of int)
         @param framenr framenumber of the variables to retrieve (int)
         """
         return
         
-    def remoteClientVariable(self, scope, filter, var, framenr=0):
+    def remoteClientVariable(self, scope, filterList, var, framenr=0):
         """
         Public method to request the variables of the debugged program.
         
         @param scope the scope of the variables (0 = local, 1 = global)
-        @param filter list of variable types to filter out (list of int)
+        @param filterList list of variable types to filter out (list of int)
         @param var list encoded name of variable to retrieve (string)
         @param framenr framenumber of the variables to retrieve (int)
         """
         return
         
-    def remoteClientSetFilter(self, scope, filter):
+    def remoteClientSetFilter(self, scope, filterStr):
         """
         Public method to set a variables filter list.
         
         @param scope the scope of the variables (0 = local, 1 = global)
-        @param filter regexp string for variable names to filter out (string)
+        @param filterStr regexp string for variable names to filter out
+            (string)
         """
         return
         
@@ -353,22 +357,6 @@ class DebuggerInterfaceNone(QObject):
         """
         return
         
-    def remoteExec(self, stmt):
-        """
-        Public method to execute stmt in the current context of the debugged
-        program.
-        
-        @param stmt statement to execute (string)
-        """
-        return
-        
-    def remoteBanner(self):
-        """
-        Public slot to get the banner info of the remote client.
-        """
-        self.debugServer.signalClientBanner("No backend", "", "")
-        return
-        
     def remoteCapabilities(self):
         """
         Public slot to get the debug clients capabilities.
@@ -413,3 +401,31 @@ class DebuggerInterfaceNone(QObject):
         public method to stop a unittest run.
         """
         return
+    
+
+def createDebuggerInterfaceNone(debugServer, passive):
+    """
+    Module function to create a debugger interface instance.
+    
+        
+    @param debugServer reference to the debug server
+    @type DebugServer
+    @param passive flag indicating passive connection mode
+    @type bool
+    @return instantiated debugger interface
+    @rtype DebuggerInterfaceNone
+    """
+    return DebuggerInterfaceNone(debugServer, passive)
+
+
+def getRegistryData():
+    """
+    Module function to get characterizing data for the debugger interface.
+    
+    @return list of tuples containing the client type, the client capabilities,
+        the client file type associations and a reference to the creation
+        function
+    @rtype list of tuple of (str, int, list of str, function)
+    """
+    return [("None", ClientDefaultCapabilities, ClientTypeAssociations,
+            createDebuggerInterfaceNone)]
