@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,15 +9,11 @@ Module implementing the Start Program dialog.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSlot
-from PyQt5.QtWidgets import QDialog, QDialogButtonBox
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QComboBox, QInputDialog
 
-from E5Gui.E5Completers import E5DirCompleter
-from E5Gui import E5FileDialog
+from E5Gui.E5PathPicker import E5PathPickerModes
 
-import Utilities
 import Preferences
-import UI.PixmapCache
 
 
 class StartDialog(QDialog):
@@ -29,20 +25,22 @@ class StartDialog(QDialog):
     the commandline parameters, the working directory and
     whether exception reporting should be disabled.
     """
-    def __init__(self, caption, argvList, wdList, envList, exceptions,
-                 parent=None, type=0, modfuncList=None, tracePython=False,
-                 autoClearShell=True, autoContinue=True, autoFork=False,
-                 forkChild=False):
+    def __init__(self, caption, interpreterList, argvList, wdList, envList,
+                 exceptions,
+                 parent=None, dialogType=0, modfuncList=None,
+                 tracePython=False, autoClearShell=True, autoContinue=True,
+                 autoFork=False, forkChild=False):
         """
         Constructor
         
         @param caption the caption to be displayed (string)
+        @param interpreterList list of interpreters (list of string)
         @param argvList history list of commandline arguments (list of strings)
         @param wdList history list of working directories (list of strings)
         @param envList history list of environment settings (list of strings)
         @param exceptions exception reporting flag (boolean)
         @param parent parent widget of this dialog (QWidget)
-        @param type type of the start dialog
+        @param dialogType type of the start dialog
                 <ul>
                 <li>0 = start debug dialog</li>
                 <li>1 = start run dialog</li>
@@ -64,36 +62,47 @@ class StartDialog(QDialog):
         super(StartDialog, self).__init__(parent)
         self.setModal(True)
         
-        self.type = type
-        if type == 0:
+        self.dialogType = dialogType
+        if dialogType == 0:
             from .Ui_StartDebugDialog import Ui_StartDebugDialog
             self.ui = Ui_StartDebugDialog()
-        elif type == 1:
+        elif dialogType == 1:
             from .Ui_StartRunDialog import Ui_StartRunDialog
             self.ui = Ui_StartRunDialog()
-        elif type == 2:
+        elif dialogType == 2:
             from .Ui_StartCoverageDialog import Ui_StartCoverageDialog
             self.ui = Ui_StartCoverageDialog()
-        elif type == 3:
+        elif dialogType == 3:
             from .Ui_StartProfileDialog import Ui_StartProfileDialog
             self.ui = Ui_StartProfileDialog()
         self.ui.setupUi(self)
-        self.ui.dirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
+        self.ui.interpreterPicker.setMode(E5PathPickerModes.OpenFileMode)
+        self.ui.interpreterPicker.setInsertPolicy(QComboBox.InsertAtTop)
+        self.ui.interpreterPicker.setSizeAdjustPolicy(
+            QComboBox.AdjustToMinimumContentsLength)
+        
+        self.ui.workdirPicker.setMode(E5PathPickerModes.DirectoryMode)
+        self.ui.workdirPicker.setDefaultDirectory(
+            Preferences.getMultiProject("Workspace"))
+        self.ui.workdirPicker.setInsertPolicy(QComboBox.InsertAtTop)
+        self.ui.workdirPicker.setSizeAdjustPolicy(
+            QComboBox.AdjustToMinimumContentsLength)
         
         self.clearButton = self.ui.buttonBox.addButton(
             self.tr("Clear Histories"), QDialogButtonBox.ActionRole)
-        
-        self.workdirCompleter = E5DirCompleter(self.ui.workdirCombo)
+        self.editButton = self.ui.buttonBox.addButton(
+            self.tr("Edit History"), QDialogButtonBox.ActionRole)
         
         self.setWindowTitle(caption)
         self.ui.cmdlineCombo.clear()
         self.ui.cmdlineCombo.addItems(argvList)
         if len(argvList) > 0:
             self.ui.cmdlineCombo.setCurrentIndex(0)
-        self.ui.workdirCombo.clear()
-        self.ui.workdirCombo.addItems(wdList)
+        self.ui.workdirPicker.clear()
+        self.ui.workdirPicker.addItems(wdList)
         if len(wdList) > 0:
-            self.ui.workdirCombo.setCurrentIndex(0)
+            self.ui.workdirPicker.setCurrentIndex(0)
         self.ui.environmentCombo.clear()
         self.ui.environmentCombo.addItems(envList)
         self.ui.exceptionCheckBox.setChecked(exceptions)
@@ -101,41 +110,31 @@ class StartDialog(QDialog):
         self.ui.consoleCheckBox.setEnabled(
             Preferences.getDebugger("ConsoleDbgCommand") != "")
         self.ui.consoleCheckBox.setChecked(False)
+        self.ui.interpreterPicker.clear()
+        self.ui.interpreterPicker.addItems(interpreterList)
+        if len(interpreterList) > 0:
+            self.ui.interpreterPicker.setCurrentIndex(0)
         
-        if type == 0:        # start debug dialog
+        if dialogType == 0:        # start debug dialog
             self.ui.tracePythonCheckBox.setChecked(tracePython)
             self.ui.tracePythonCheckBox.show()
             self.ui.autoContinueCheckBox.setChecked(autoContinue)
             self.ui.forkModeCheckBox.setChecked(autoFork)
             self.ui.forkChildCheckBox.setChecked(forkChild)
         
-        if type == 1:       # start run dialog
+        if dialogType == 1:       # start run dialog
             self.ui.forkModeCheckBox.setChecked(autoFork)
             self.ui.forkChildCheckBox.setChecked(forkChild)
         
-        if type == 3:       # start coverage or profile dialog
+        if dialogType == 3:       # start coverage or profile dialog
             self.ui.eraseCheckBox.setChecked(True)
         
         self.__clearHistoryLists = False
+        self.__historiesModified = False
         
         msh = self.minimumSizeHint()
         self.resize(max(self.width(), msh.width()), msh.height())
         
-    @pyqtSlot()
-    def on_dirButton_clicked(self):
-        """
-        Private method used to open a directory selection dialog.
-        """
-        cwd = self.ui.workdirCombo.currentText()
-        d = E5FileDialog.getExistingDirectory(
-            self,
-            self.tr("Working directory"),
-            cwd,
-            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
-            
-        if d:
-            self.ui.workdirCombo.setEditText(Utilities.toNativeSeparators(d))
-        
     def on_modFuncCombo_editTextChanged(self):
         """
         Private slot to enable/disable the OK button.
@@ -147,22 +146,23 @@ class StartDialog(QDialog):
         """
         Public method to retrieve the data entered into this dialog.
         
-        @return a tuple of argv (string), workdir (string), environment
-            (string), exceptions flag (boolean), clear interpreter flag
-            (boolean), clear histories flag (boolean) and run in console
-            flag (boolean)
+        @return a tuple of interpreter (string), argv (string), workdir
+            (string), environment (string), exceptions flag (boolean),
+            clear interpreter flag (boolean) and run in console flag (boolean)
         """
         cmdLine = self.ui.cmdlineCombo.currentText()
-        workdir = self.ui.workdirCombo.currentText()
+        workdir = self.ui.workdirPicker.currentText()
         environment = self.ui.environmentCombo.currentText()
+        interpreter = self.ui.interpreterPicker.currentText()
         
-        return (cmdLine,
+        return (interpreter,
+                cmdLine,
                 workdir,
                 environment,
                 self.ui.exceptionCheckBox.isChecked(),
                 self.ui.clearShellCheckBox.isChecked(),
-                self.__clearHistoryLists,
-                self.ui.consoleCheckBox.isChecked())
+                self.ui.consoleCheckBox.isChecked(),
+                )
         
     def getDebugData(self):
         """
@@ -176,7 +176,7 @@ class StartDialog(QDialog):
             indicating, that the debugger should debug the child process after
             forking automatically (boolean)
         """
-        if self.type == 0:
+        if self.dialogType == 0:
             return (self.ui.tracePythonCheckBox.isChecked(),
                     self.ui.autoContinueCheckBox.isChecked(),
                     self.ui.forkModeCheckBox.isChecked(),
@@ -192,7 +192,7 @@ class StartDialog(QDialog):
             should debug the child process after forking automatically
             (boolean)
         """
-        if self.type == 1:
+        if self.dialogType == 1:
             return (self.ui.forkModeCheckBox.isChecked(),
                     self.ui.forkChildCheckBox.isChecked())
         
@@ -203,7 +203,7 @@ class StartDialog(QDialog):
         
         @return flag indicating erasure of coverage info (boolean)
         """
-        if self.type == 2:
+        if self.dialogType == 2:
             return self.ui.eraseCheckBox.isChecked()
         
     def getProfilingData(self):
@@ -213,7 +213,7 @@ class StartDialog(QDialog):
         
         @return flag indicating erasure of profiling info (boolean)
         """
-        if self.type == 3:
+        if self.dialogType == 3:
             return self.ui.eraseCheckBox.isChecked()
         
     def __clearHistories(self):
@@ -222,19 +222,107 @@ class StartDialog(QDialog):
         clear the lists.
         """
         self.__clearHistoryLists = True
+        self.__historiesModified = False    # clear catches it all
         
         cmdLine = self.ui.cmdlineCombo.currentText()
-        workdir = self.ui.workdirCombo.currentText()
+        workdir = self.ui.workdirPicker.currentText()
         environment = self.ui.environmentCombo.currentText()
+        interpreter = self.ui.interpreterPicker.currentText()
         
         self.ui.cmdlineCombo.clear()
-        self.ui.workdirCombo.clear()
+        self.ui.workdirPicker.clear()
         self.ui.environmentCombo.clear()
+        self.ui.interpreterPicker.clear()
         
         self.ui.cmdlineCombo.addItem(cmdLine)
-        self.ui.workdirCombo.addItem(workdir)
+        self.ui.workdirPicker.addItem(workdir)
         self.ui.environmentCombo.addItem(environment)
+        self.ui.interpreterPicker.addItem(interpreter)
+    
+    def __editHistory(self):
+        """
+        Private slot to edit a history list.
+        """
+        histories = [
+            "",
+            self.tr("Interpreter"),
+            self.tr("Command Line"),
+            self.tr("Working Directory"),
+            self.tr("Environment"),
+        ]
+        historyKind, ok = QInputDialog.getItem(
+            self,
+            self.tr("Edit History"),
+            self.tr("Select the history list to be edited:"),
+            histories,
+            0, False)
+        if ok and historyKind:
+            historiesIndex = histories.index(historyKind)
+            if historiesIndex == 3:
+                history = self.ui.workdirPicker.getPathItems()
+            elif historiesIndex == 1:
+                history = self.ui.interpreterPicker.getPathItems()
+            else:
+                history = []
+                if historiesIndex == 2:
+                    combo = self.ui.cmdlineCombo
+                else:
+                    combo = self.ui.environmentCombo
+                for index in range(combo.count()):
+                    history.append(combo.itemText(index))
+            
+            from .StartHistoryEditDialog import StartHistoryEditDialog
+            dlg = StartHistoryEditDialog(history, self)
+            if dlg.exec_() == QDialog.Accepted:
+                history = dlg.getHistory()
+                if historiesIndex == 1:
+                    combo = self.ui.interpreterPicker
+                elif historiesIndex == 2:
+                    combo = self.ui.cmdlineCombo
+                elif historiesIndex == 3:
+                    combo = self.ui.workdirPicker
+                else:
+                    combo = self.ui.environmentCombo
+                combo.clear()
+                combo.addItems(history)
+                
+                self.__historiesModified = True
+    
+    def historiesModified(self):
+        """
+        Public method to test for modified histories.
         
+        @return flag indicating modified histories
+        @rtype bool
+        """
+        return self.__historiesModified
+    
+    def clearHistories(self):
+        """
+        Public method to test, if histories shall be cleared.
+        
+        @return flag indicating histories shall be cleared
+        @rtype bool
+        """
+        return self.__clearHistoryLists
+    
+    def getHistories(self):
+        """
+        Public method to get the lists of histories.
+        
+        @return tuple containing the histories of command line arguments,
+            working directories, environment settings and interpreters
+        @rtype tuple of four list of str
+        """
+        return (
+            [self.ui.cmdlineCombo.itemText(index) for index in range(
+                self.ui.cmdlineCombo.count())],
+            self.ui.workdirPicker.getPathItems(),
+            [self.ui.environmentCombo.itemText(index) for index in range(
+                self.ui.environmentCombo.count())],
+            self.ui.interpreterPicker.getPathItems(),
+        )
+    
     def on_buttonBox_clicked(self, button):
         """
         Private slot called by a button of the button box clicked.
@@ -243,3 +331,5 @@ class StartDialog(QDialog):
         """
         if button == self.clearButton:
             self.__clearHistories()
+        elif button == self.editButton:
+            self.__editHistory()
