@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the variables filter dialog.
 """
 
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
 
-from Debugger.Config import ConfigVarTypeDispStrings
+from PyQt5.QtCore import Qt
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QListWidgetItem
+
+from Debugger.Config import ConfigVarTypeDispStrings, ConfigVarTypeFilters
 import Preferences
 
 from .Ui_VariablesFilterDialog import Ui_VariablesFilterDialog
@@ -30,28 +33,26 @@ class VariablesFilterDialog(QDialog, Ui_VariablesFilterDialog):
         @param name name of this dialog (string)
         @param modal flag to indicate a modal dialog (boolean)
         """
-        super().__init__(parent)
+        super(VariablesFilterDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setModal(modal)
         self.setupUi(self)
 
         self.defaultButton = self.buttonBox.addButton(
-            self.trUtf8("Save Default"), QDialogButtonBox.ActionRole)
+            self.tr("Save Default"), QDialogButtonBox.ActionRole)
+        
+        #populate the list widgets and set the default selection
+        for widget in self.localsList, self.globalsList:
+            for varType, varTypeStr in ConfigVarTypeDispStrings.items():
+                itm = QListWidgetItem(self.tr(varTypeStr), widget)
+                itm.setData(Qt.UserRole, ConfigVarTypeFilters[varType])
+                itm.setFlags(Qt.ItemIsEnabled | Qt.ItemIsUserCheckable)
+                itm.setCheckState(Qt.Unchecked)
+                widget.addItem(itm)
         
         lDefaultFilter, gDefaultFilter = Preferences.getVarFilters()
-        
-        #populate the listboxes and set the default selection
-        for lb in self.localsList, self.globalsList:
-            for ts in ConfigVarTypeDispStrings:
-                lb.addItem(self.trUtf8(ts))
-                
-        for filterIndex in lDefaultFilter:
-            itm = self.localsList.item(filterIndex)
-            self.localsList.setItemSelected(itm, True)
-        for filterIndex in gDefaultFilter:
-            itm = self.globalsList.item(filterIndex)
-            self.globalsList.setItemSelected(itm, True)
+        self.setSelection(lDefaultFilter, gDefaultFilter)
 
     def getSelection(self):
         """
@@ -61,17 +62,18 @@ class VariablesFilterDialog(QDialog, Ui_VariablesFilterDialog):
             locals variables filter, the second the globals variables filter.
         """
         lList = []
-        gList = []
-        for i in range(self.localsList.count()):
-            itm = self.localsList.item(i)
-            if self.localsList.isItemSelected(itm):
-                lList.append(i)
-        for i in range(self.globalsList.count()):
-            itm = self.globalsList.item(i)
-            if self.globalsList.isItemSelected(itm):
-                gList.append(i)
-        return (lList, gList)
+        for row in range(self.localsList.count()):
+            itm = self.localsList.item(row)
+            if itm.checkState() == Qt.Unchecked:
+                lList.append(itm.data(Qt.UserRole))
         
+        gList = []
+        for row in range(self.globalsList.count()):
+            itm = self.globalsList.item(row)
+            if itm.checkState() == Qt.Unchecked:
+                gList.append(itm.data(Qt.UserRole))
+        return (lList, gList)
+    
     def setSelection(self, lList, gList):
         """
         Public slot to set the current selection.
@@ -79,12 +81,19 @@ class VariablesFilterDialog(QDialog, Ui_VariablesFilterDialog):
         @param lList local variables filter (list of int)
         @param gList global variables filter (list of int)
         """
-        for filterIndex in lList:
-            itm = self.localsList.item(filterIndex)
-            self.localsList.setItemSelected(itm, True)
-        for filterIndex in gList:
-            itm = self.globalsList.item(filterIndex)
-            self.globalsList.setItemSelected(itm, True)
+        for row in range(self.localsList.count()):
+            itm = self.localsList.item(row)
+            if itm.data(Qt.UserRole) in lList:
+                itm.setCheckState(Qt.Unchecked)
+            else:
+                itm.setCheckState(Qt.Checked)
+        
+        for row in range(self.globalsList.count()):
+            itm = self.globalsList.item(row)
+            if itm.data(Qt.UserRole) in gList:
+                itm.setCheckState(Qt.Unchecked)
+            else:
+                itm.setCheckState(Qt.Checked)
 
     def on_buttonBox_clicked(self, button):
         """
