@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,25 +13,33 @@ try:
 except NameError:
     pass
 
-from PyQt5.QtCore import Qt, QRegExp, qVersion, QCoreApplication
+from PyQt5.QtCore import Qt, QRegExp, QCoreApplication
 from PyQt5.QtWidgets import QTreeWidget, QTreeWidgetItem, QAbstractItemView, \
     QMenu
-from PyQt5.QtGui import QTextDocument   # __IGNORE_WARNING__
 
 from E5Gui.E5Application import e5App
 
-from DebugClients.Python3.DebugConfig import ConfigVarTypeStrings
-    
 from .Config import ConfigVarTypeDispStrings
 
 import Preferences
 import Utilities
+from Globals import qVersionTuple
 
 
 class VariableItem(QTreeWidgetItem):
     """
     Class implementing the data structure for variable items.
     """
+    Indicators = ("()", "[]", "{:}", "{}")      # __IGNORE_WARNING_M613__
+    Type2Indicators = {
+        # Python types
+        'list': '[]',
+        'tuple': '()',
+        'dict': '{:}',                          # __IGNORE_WARNING_M613__
+        'set': '{}',                            # __IGNORE_WARNING_M613__
+        'frozenset': '{}',                      # __IGNORE_WARNING_M613__
+    }
+    
     def __init__(self, parent, dvar, dvalue, dtype):
         """
         Constructor
@@ -41,6 +49,8 @@ class VariableItem(QTreeWidgetItem):
         @param dvalue value string (string)
         @param dtype type string (string)
         """
+        dvar, self.__varID = VariableItem.extractId(dvar)
+        
         self.__value = dvalue
         if len(dvalue) > 2048:     # 1024 * 2
             dvalue = QCoreApplication.translate(
@@ -77,7 +87,71 @@ class VariableItem(QTreeWidgetItem):
         @return value of the item (string)
         """
         return self.__value
+    
+    def getId(self):
+        """
+        Public method to get the ID string.
         
+        @return ID string
+        @rtype str
+        """
+        return self.__varID
+    
+    @classmethod
+    def extractId(cls, var):
+        """
+        Class method to extract the ID string from a variable text.
+        
+        @param var variable text
+        @type str
+        @return tuple containing the variable text without ID and the ID string
+        @rtype tuple of two str
+        """
+        if " (ID:" in var:
+            dvar, varID = var.rsplit(None, 1)
+            if varID.endswith(VariableItem.Indicators):
+                varID, indicators = VariableItem.extractIndicators(varID)
+                dvar += indicators
+        else:
+            dvar = var
+            varID = None
+        
+        return dvar, varID
+    
+    @classmethod
+    def extractIndicators(cls, var):
+        """
+        Class method to extract the indicator string from a variable text.
+        
+        @param var variable text
+        @type str
+        @return tuple containing the variable text without indicators and the
+            indicator string
+        @rtype tuple of two str
+        """
+        for indicator in VariableItem.Indicators:
+            if var.endswith(indicator):
+                return var[:-len(indicator)], indicator
+        
+        return var, ""
+    
+    def _buildKey(self):
+        """
+        Protected method to build the access key for the variable.
+        
+        @return access key
+        @rtype str
+        """
+        indicators = ""
+        txt = self.text(0)
+        if txt.endswith(VariableItem.Indicators):
+            txt, indicators = VariableItem.extractIndicators(txt)
+        if self.__varID:
+            txt = "{0} {1}{2}".format(txt, self.__varID, indicators)
+        else:
+            txt = "{0}{1}".format(txt, indicators)
+        return txt
+    
     def data(self, column, role):
         """
         Public method to return the data for the requested role.
@@ -106,25 +180,6 @@ class VariableItem(QTreeWidgetItem):
         for itm in self.takeChildren():
             del itm
         
-    def key(self, column):
-        """
-        Public method generating the key for this item.
-        
-        @param column the column to sort on (integer)
-        @return text of the column (string)
-        """
-        return self.text(column)
-        
-    def __lt__(self, other):
-        """
-        Special method to check, if the item is less than the other one.
-        
-        @param other reference to item to compare against (QTreeWidgetItem)
-        @return true, if this item is less than other (boolean)
-        """
-        column = self.treeWidget().sortColumn()
-        return self.key(column) < other.key(column)
-        
     def expand(self):
         """
         Public method to expand the item.
@@ -149,7 +204,7 @@ class SpecialVarItem(VariableItem):
     These special variable nodes are generated for classes, lists,
     tuples and dictionaries.
     """
-    def __init__(self, parent, dvar, dvalue, dtype, frmnr, scope):
+    def __init__(self, parent, dvar, dvalue, dtype, frmnr, globalScope):
         """
         Constructor
         
@@ -158,14 +213,15 @@ class SpecialVarItem(VariableItem):
         @param dvalue value string (string)
         @param dtype type string (string)
         @param frmnr frame number (0 is the current frame) (int)
-        @param scope flag indicating global (1) or local (0) variables
+        @param globalScope flag indicating global (True) or local (False)
+            variables
         """
         VariableItem.__init__(self, parent, dvar, dvalue, dtype)
         self.attachDummy()
         self.populated = False
         
         self.framenr = frmnr
-        self.scope = scope
+        self.globalScope = globalScope
 
     def expand(self):
         """
@@ -174,18 +230,19 @@ class SpecialVarItem(VariableItem):
         self.deleteChildren()
         self.populated = True
         
-        pathlist = [self.text(0)]
+        pathlist = [self._buildKey()]
         par = self.parent()
         
         # step 1: get a pathlist up to the requested variable
         while par is not None:
-            pathlist.insert(0, par.text(0))
+            pathlist.insert(0, par._buildKey())
             par = par.parent()
         
         # step 2: request the variable from the debugger
-        filter = e5App().getObject("DebugUI").variablesFilter(self.scope)
+        variablesFilter = e5App().getObject("DebugUI").variablesFilter(
+            self.globalScope)
         e5App().getObject("DebugServer").remoteClientVariable(
-            self.scope, filter, pathlist, self.framenr)
+            self.globalScope, variablesFilter, pathlist, self.framenr)
 
 
 class ArrayElementVarItem(VariableItem):
@@ -209,20 +266,8 @@ class ArrayElementVarItem(VariableItem):
         element 2 will have a key of '000002' and appear before
         element 10 with a key of '000010'
         """
-        keyStr = self.text(0)
-        self.arrayElementKey = "{0:6d}".format(int(keyStr))
-
-    def key(self, column):
-        """
-        Public method generating the key for this item.
-        
-        @param column the column to sort on (integer)
-        @return key of the item (string)
-        """
-        if column == 0:
-            return self.arrayElementKey
-        else:
-            return VariableItem.key(self, column)
+        col0Str = self.text(0)
+        self.setText(0, "{0:6d}".format(int(col0Str)))
 
 
 class SpecialArrayElementVarItem(SpecialVarItem):
@@ -230,7 +275,7 @@ class SpecialArrayElementVarItem(SpecialVarItem):
     Class implementing a QTreeWidgetItem that represents a special array
     variable node.
     """
-    def __init__(self, parent, dvar, dvalue, dtype, frmnr, scope):
+    def __init__(self, parent, dvar, dvalue, dtype, frmnr, globalScope):
         """
         Constructor
         
@@ -239,10 +284,11 @@ class SpecialArrayElementVarItem(SpecialVarItem):
         @param dvalue value string (string)
         @param dtype type string (string)
         @param frmnr frame number (0 is the current frame) (int)
-        @param scope flag indicating global (1) or local (0) variables
+        @param globalScope flag indicating global (True) or local (False)
+            variables
         """
         SpecialVarItem.__init__(self, parent, dvar, dvalue, dtype, frmnr,
-                                scope)
+                                globalScope)
         
         """
         Array elements have numbers as names, but the key must be
@@ -250,20 +296,9 @@ class SpecialArrayElementVarItem(SpecialVarItem):
         element 2 will have a key of '000002' and appear before
         element 10 with a key of '000010'
         """
-        keyStr = self.text(0)[:-2]  # strip off [], () or {}
-        self.arrayElementKey = "{0:6d}".format(int(keyStr))
-
-    def key(self, column):
-        """
-        Public method generating the key for this item.
-        
-        @param column the column to sort on (integer)
-        @return key of the item (string)
-        """
-        if column == 0:
-            return self.arrayElementKey
-        else:
-            return SpecialVarItem.key(self, column)
+        # strip off [], () or {}
+        col0Str, indicators = VariableItem.extractIndicators(self.text(0))
+        self.setText(0, "{0:6d}{1}".format(int(col0Str), indicators))
 
 
 class VariablesViewer(QTreeWidget):
@@ -280,29 +315,32 @@ class VariablesViewer(QTreeWidget):
     This widget has two modes for displaying the global and the local
     variables.
     """
-    def __init__(self, parent=None, scope=1):
+    def __init__(self, viewer, globalScope, parent=None):
         """
         Constructor
         
+        @param viewer reference to the debug viewer object (DebugViewer)
+        @param globalScope flag indicating global (True) or local (False)
+            variables
         @param parent the parent (QWidget)
-        @param scope flag indicating global (1) or local (0) variables
         """
         super(VariablesViewer, self).__init__(parent)
         
-        self.indicators = {'list': '[]', 'tuple': '()', 'dict': '{}',
-                           # Python types
-                           'Array': '[]', 'Hash': '{}'
-                           # Ruby types
-                           }
+        self.__debugViewer = viewer
+        self.__globalScope = globalScope
         
+        indicatorPattern = "|".join([QRegExp.escape(indicator)
+                                     for indicator in VariableItem.Indicators])
         self.rx_class = QRegExp('<.*(instance|object) at 0x.*>')
         self.rx_class2 = QRegExp('class .*')
         self.rx_class3 = QRegExp('<class .* at 0x.*>')
         self.dvar_rx_class1 = QRegExp(
-            r'<.*(instance|object) at 0x.*>(\[\]|\{\}|\(\))')
-        self.dvar_rx_class2 = QRegExp(r'<class .* at 0x.*>(\[\]|\{\}|\(\))')
+            r'<.*(instance|object) at 0x.*>({0})'.format(indicatorPattern))
+        self.dvar_rx_class2 = QRegExp(
+            r'<class .* at 0x.*>({0})'.format(indicatorPattern))
         self.dvar_rx_array_element = QRegExp(r'^\d+$')
-        self.dvar_rx_special_array_element = QRegExp(r'^\d+(\[\]|\{\}|\(\))$')
+        self.dvar_rx_special_array_element = QRegExp(
+            r'^\d+({0})$'.format(indicatorPattern))
         self.rx_nonprintable = QRegExp(r"""(\\x\d\d)+""")
         
         self.framenr = 0
@@ -315,8 +353,7 @@ class VariablesViewer(QTreeWidget):
         self.setAlternatingRowColors(True)
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
         
-        self.scope = scope
-        if scope:
+        if self.__globalScope:
             self.setWindowTitle(self.tr("Global Variables"))
             self.setHeaderLabels([
                 self.tr("Globals"),
@@ -342,10 +379,11 @@ class VariablesViewer(QTreeWidget):
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
         header.setSortIndicatorShown(True)
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             header.setSectionsClickable(True)
         else:
             header.setClickable(True)
+        header.sectionClicked.connect(self.__sectionClicked)
         header.resizeSection(0, 120)    # variable column
         header.resizeSection(1, 150)    # value column
         
@@ -364,10 +402,13 @@ class VariablesViewer(QTreeWidget):
         """
         self.menu = QMenu()
         self.menu.addAction(self.tr("Show Details..."), self.__showDetails)
+        self.menu.addAction(self.tr("Refresh"), self.__refreshView)
         self.menu.addSeparator()
         self.menu.addAction(self.tr("Configure..."), self.__configure)
         
         self.backMenu = QMenu()
+        self.backMenu.addAction(self.tr("Refresh"), self.__refreshView)
+        self.backMenu.addSeparator()
         self.backMenu.addAction(self.tr("Configure..."), self.__configure)
         
     def __showContextMenu(self, coord):
@@ -400,12 +441,17 @@ class VariablesViewer(QTreeWidget):
         else:
             count = node.childCount()
         
+        if column == 0:
+            searchStr = VariableItem.extractId(slist[0])[0]
+        else:
+            searchStr = slist[0]
+        
         for index in range(count):
             if node is None:
                 itm = self.topLevelItem(index)
             else:
                 itm = node.child(index)
-            if itm.text(column) == slist[0]:
+            if itm.text(column) == searchStr:
                 if len(slist) > 1:
                     itm = self.__findItem(slist[1:], column, itm)
                 return itm
@@ -437,7 +483,7 @@ class VariablesViewer(QTreeWidget):
             for (var, vtype, value) in vlist:
                 self.__addItem(None, vtype, var, value)
             
-            # reexpand tree
+            # re-expand tree
             openItems = sorted(self.openItems[:])
             self.openItems = []
             for itemPath in openItems:
@@ -484,7 +530,7 @@ class VariablesViewer(QTreeWidget):
             for var, vtype, value in vlist[1:]:
                 self.__addItem(itm, vtype, var, value)
 
-        # reexpand tree
+        # re-expand tree
         openItems = sorted(self.openItems[:])
         self.openItems = []
         for itemPath in openItems:
@@ -534,18 +580,25 @@ class VariablesViewer(QTreeWidget):
             isSpecial = False
         
         if self.rx_class2.exactMatch(dtype):
-            return SpecialVarItem(parent, dvar, dvalue, dtype[7:-1],
-                                  self.framenr, self.scope)
+            return SpecialVarItem(
+                parent, dvar, dvalue, dtype[7:-1], self.framenr,
+                self.__globalScope)
         elif dtype != "void *" and \
             (self.rx_class.exactMatch(dvalue) or
              self.rx_class3.exactMatch(dvalue) or
              isSpecial):
             if self.dvar_rx_special_array_element.exactMatch(dvar):
-                return SpecialArrayElementVarItem(parent, dvar, dvalue, dtype,
-                                                  self.framenr, self.scope)
+                return SpecialArrayElementVarItem(
+                    parent, dvar, dvalue, dtype, self.framenr,
+                    self.__globalScope)
             else:
                 return SpecialVarItem(parent, dvar, dvalue, dtype,
-                                      self.framenr, self.scope)
+                                      self.framenr, self.__globalScope)
+        elif dtype in ["numpy.ndarray", "django.MultiValueDict",
+                       "array.array"]:
+            return SpecialVarItem(
+                parent, dvar, self.tr("{0} items").format(dvalue), dtype,
+                self.framenr, self.__globalScope)
         else:
             if self.dvar_rx_array_element.exactMatch(dvar):
                 return ArrayElementVarItem(parent, dvar, dvalue, dtype)
@@ -570,12 +623,12 @@ class VariablesViewer(QTreeWidget):
         if parent is None:
             parent = self
         try:
-            dvar = '{0}{1}'.format(var, self.indicators[vtype])
+            dvar = '{0}{1}'.format(var, VariableItem.Type2Indicators[vtype])
         except KeyError:
             dvar = var
         dvtype = self.__getDispType(vtype)
         
-        if vtype in ['list', 'Array', 'tuple', 'dict', 'Hash']:
+        if vtype in ['list', 'tuple', 'dict', 'set', 'frozenset']:
             itm = self.__generateItem(parent, dvar,
                                       self.tr("{0} items").format(value),
                                       dvtype, True)
@@ -585,7 +638,7 @@ class VariablesViewer(QTreeWidget):
             else:
                 try:
                     sval = eval(value)
-                except:
+                except Exception:
                     sval = value
             itm = self.__generateItem(parent, dvar, str(sval), dvtype)
         
@@ -603,16 +656,23 @@ class VariablesViewer(QTreeWidget):
         @return displaystring (string)
         """
         try:
-            i = ConfigVarTypeStrings.index(vtype)
-            dvtype = self.tr(ConfigVarTypeDispStrings[i])
-        except ValueError:
+            dvtype = self.tr(ConfigVarTypeDispStrings[vtype])
+        except KeyError:
             if vtype == 'classobj':
-                dvtype = self.tr(ConfigVarTypeDispStrings[
-                    ConfigVarTypeStrings.index('instance')])
+                dvtype = self.tr(ConfigVarTypeDispStrings['instance'])
             else:
                 dvtype = vtype
         return dvtype
-
+    
+    def __refreshView(self):
+        """
+        Private slot to refresh the view.
+        """
+        if self.__globalScope:
+            self.__debugViewer.setGlobalsFilter()
+        else:
+            self.__debugViewer.setLocalsFilter()
+    
     def mouseDoubleClickEvent(self, mouseEvent):
         """
         Protected method of QAbstractItemView.
@@ -647,23 +707,37 @@ class VariablesViewer(QTreeWidget):
             return  # do not display anything, if the variable has no value
             
         vtype = itm.text(2)
-        name = itm.text(0)
-        if name[-2:] in ['[]', '{}', '()']:
-            name = name[:-2]
+        name = VariableItem.extractIndicators(itm.text(0).strip())[0]
         
         par = itm.parent()
-        nlist = [name]
+        if name.startswith("["):    # numpy.ndarray, array.array
+            nlist = []
+        else:
+            nlist = [name]
+        
         # build up the fully qualified name
         while par is not None:
-            pname = par.text(0)
-            if pname[-2:] in ['[]', '{}', '()']:
+            pname, indicators = VariableItem.extractIndicators(
+                par.text(0).strip())
+            if indicators:
                 if nlist[0].endswith("."):
                     nlist[0] = '[{0}].'.format(nlist[0][:-1])
                 else:
                     nlist[0] = '[{0}]'.format(nlist[0])
-                nlist.insert(0, pname[:-2])
+                if not pname.startswith("["):   # numpy.ndarray, array.array
+                    nlist.insert(0, pname)
             else:
-                nlist.insert(0, '{0}.'.format(pname))
+                if par.text(2) == "django.MultiValueDict":
+                    nlist[0] = 'getlist({0})'.format(nlist[0])
+                elif par.text(2) == "numpy.ndarray":
+                    if nlist[0][0].isalpha():
+                        if nlist[0] in ["min", "max", "mean"]:
+                            nlist[0] = ".{0}()".format(nlist[0])
+                        else:
+                            nlist[0] = ".{0}".format(nlist[0])
+                    nlist.insert(0, pname)
+                else:
+                    nlist.insert(0, '{0}.'.format(pname))
             par = par.parent()
             
         name = ''.join(nlist)
@@ -715,7 +789,6 @@ class VariablesViewer(QTreeWidget):
         
         try:
             parentItem.expand()
-            self.__resort()
         except AttributeError:
             super(VariablesViewer, self).expandItem(parentItem)
 
@@ -733,14 +806,27 @@ class VariablesViewer(QTreeWidget):
             parentItem.collapse()
         except AttributeError:
             super(VariablesViewer, self).collapseItem(parentItem)
-
-    def __resort(self):
+    
+    def __sectionClicked(self):
+        """
+        Private method handling a click onto a header section.
+        """
+        self.__resort()
+    
+    def __resort(self, parent=None):
         """
         Private method to resort the tree.
+        
+        @param parent reference to a parent item
+        @type QTreeWidgetItem
         """
         if self.resortEnabled:
-            self.sortItems(self.sortColumn(),
-                           self.header().sortIndicatorOrder())
+            if parent is not None:
+                parent.sortChildren(self.sortColumn(),
+                                    self.header().sortIndicatorOrder())
+            else:
+                self.sortItems(self.sortColumn(),
+                               self.header().sortIndicatorOrder())
     
     def handleResetUI(self):
         """
