@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,6 +15,9 @@ from PyQt5.QtCore import pyqtSignal, Qt, QAbstractItemModel, QModelIndex
 class WatchPointModel(QAbstractItemModel):
     """
     Class implementing a custom model for watch expressions.
+    
+    @signal dataAboutToBeChanged(QModelIndex, QModelIndex) emitted to indicate
+        a change of the data
     """
     dataAboutToBeChanged = pyqtSignal(QModelIndex, QModelIndex)
     
@@ -41,16 +44,16 @@ class WatchPointModel(QAbstractItemModel):
                            Qt.Alignment(Qt.AlignRight),
                            ]
         
-    def columnCount(self, parent=QModelIndex()):
+    def columnCount(self, parent=None):
         """
         Public method to get the current column count.
         
-        @param parent index of the parent item (QModelIndex)
+        @param parent index of the parent item (QModelIndex) (Unused)
         @return column count (integer)
         """
         return len(self.header)
     
-    def rowCount(self, parent=QModelIndex()):
+    def rowCount(self, parent=None):
         """
         Public method to get the current row count.
         
@@ -58,7 +61,7 @@ class WatchPointModel(QAbstractItemModel):
         @return row count (integer)
         """
         # we do not have a tree, parent should always be invalid
-        if not parent.isValid():
+        if parent is None or not parent.isValid():
             return len(self.watchpoints)
         else:
             return 0
@@ -121,7 +124,7 @@ class WatchPointModel(QAbstractItemModel):
         
         return None
     
-    def index(self, row, column, parent=QModelIndex()):
+    def index(self, row, column, parent=None):
         """
         Public method to create an index.
         
@@ -130,7 +133,7 @@ class WatchPointModel(QAbstractItemModel):
         @param parent index of the parent item (QModelIndex)
         @return requested index (QModelIndex)
         """
-        if parent.isValid() or \
+        if (parent and parent.isValid()) or \
            row < 0 or row >= len(self.watchpoints) or \
            column < 0 or column >= len(self.header):
             return QModelIndex()
@@ -146,14 +149,14 @@ class WatchPointModel(QAbstractItemModel):
         """
         return QModelIndex()
     
-    def hasChildren(self, parent=QModelIndex()):
+    def hasChildren(self, parent=None):
         """
         Public method to check for the presence of child items.
         
         @param parent index of parent item (QModelIndex)
         @return flag indicating the presence of child items (boolean)
         """
-        if not parent.isValid():
+        if parent is None or not parent.isValid():
             return len(self.watchpoints) > 0
         else:
             return False
