@@ -84,8 +84,8 @@ class IndexGenerator(object):
             file = file.replace(basename, "")
             
         if "__init__" in file:
-            dir = os.path.dirname(file)
-            udir = os.path.dirname(dir)
+            dirName = os.path.dirname(file)
+            udir = os.path.dirname(dirName)
             if udir:
                 upackage = udir.replace(os.sep, ".")
                 try:
@@ -94,7 +94,7 @@ class IndexGenerator(object):
                     elt = self.packages["00index"]
             else:
                 elt = self.packages["00index"]
-            package = dir.replace(os.sep, ".")
+            package = dirName.replace(os.sep, ".")
             elt["subpackages"][package] = moduleDocument.shortDescription()
                 
             self.packages[package] = {
