@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -159,6 +159,12 @@ parametersListEntryTemplate = \
 {Description}
 </dd>'''
 
+parameterTypesListEntryTemplate = \
+'''<dt><i>{Name}</i> ({Type})</dt>
+<dd>
+{Description}
+</dd>'''
+
 returnsTemplate = \
 '''<dl>
 <dt>Returns:</dt>
@@ -167,6 +173,14 @@ returnsTemplate = \
 </dd>
 </dl>'''
 
+returnTypesTemplate = \
+'''<dl>
+<dt>Return Type:</dt>
+<dd>
+{0}
+</dd>
+</dl>'''
+
 exceptionsListTemplate = \
 '''<dl>
 {Exceptions}
@@ -259,3 +273,6 @@ indexListEntryTemplate = \
 <td><a href="{Link}">{Name}</a></td>
 <td>{Description}</td>
 </tr>'''
+
+#
+# eflag: noqa = E122
