@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -27,50 +27,52 @@ HideNameFilterDetails = QFileDialog.HideNameFilterDetails
 DontUseSheet = QFileDialog.DontUseSheet
 
 
-def __reorderFilter(filter, initialFilter=""):
+def __reorderFilter(filterStr, initialFilter=""):
     """
     Private function to reorder the file filter to cope with a KDE issue
     introduced by distributor's usage of KDE file dialogs.
     
-    @param filter Qt file filter (string)
+    @param filterStr Qt file filter (string)
     @param initialFilter initial filter (string)
     @return the rearranged Qt file filter (string)
     """
     if initialFilter and not Globals.isMacPlatform():
-        fileFilters = filter.split(';;')
+        fileFilters = filterStr.split(';;')
         if len(fileFilters) < 10 and initialFilter in fileFilters:
             fileFilters.remove(initialFilter)
         fileFilters.insert(0, initialFilter)
         return ";;".join(fileFilters)
     else:
-        return filter
+        return filterStr
 
 
 def getOpenFileName(parent=None, caption="", directory="",
-                    filter="", options=QFileDialog.Options()):
+                    filterStr="", options=None):
     """
     Module function to get the name of a file for opening it.
     
     @param parent parent widget of the dialog (QWidget)
     @param caption window title of the dialog (string)
     @param directory working directory of the dialog (string)
-    @param filter filter string for the dialog (string)
+    @param filterStr filter string for the dialog (string)
     @param options various options for the dialog (QFileDialog.Options)
     @return name of file to be opened (string)
     """
+    if options is None:
+        options = QFileDialog.Options()
     if Globals.isLinuxPlatform():
         options |= QFileDialog.DontUseNativeDialog
     if PYQT_VERSION_STR >= "5.0.0":
         return QFileDialog.getOpenFileName(
-            parent, caption, directory, filter, "", options)[0]
+            parent, caption, directory, filterStr, "", options)[0]
     else:
         return QFileDialog.getOpenFileName(
-            parent, caption, directory, filter, options)
+            parent, caption, directory, filterStr, options)
 
 
 def getOpenFileNameAndFilter(parent=None, caption="", directory="",
-                             filter="", initialFilter="",
-                             options=QFileDialog.Options()):
+                             filterStr="", initialFilter="",
+                             options=None):
     """
     Module function to get the name of a file for opening it and the selected
     file name filter.
@@ -78,14 +80,16 @@ def getOpenFileNameAndFilter(parent=None, caption="", directory="",
     @param parent parent widget of the dialog (QWidget)
     @param caption window title of the dialog (string)
     @param directory working directory of the dialog (string)
-    @param filter filter string for the dialog (string)
+    @param filterStr filter string for the dialog (string)
     @param initialFilter initial filter for the dialog (string)
     @param options various options for the dialog (QFileDialog.Options)
     @return name of file to be opened and selected filter (string, string)
     """
+    if options is None:
+        options = QFileDialog.Options()
     if Globals.isLinuxPlatform():
         options |= QFileDialog.DontUseNativeDialog
-    newfilter = __reorderFilter(filter, initialFilter)
+    newfilter = __reorderFilter(filterStr, initialFilter)
     if PYQT_VERSION_STR >= "5.0.0":
         return QFileDialog.getOpenFileName(
             parent, caption, directory, newfilter, initialFilter, options)
@@ -95,30 +99,32 @@ def getOpenFileNameAndFilter(parent=None, caption="", directory="",
 
 
 def getOpenFileNames(parent=None, caption="", directory="",
-                     filter="", options=QFileDialog.Options()):
+                     filterStr="", options=None):
     """
     Module function to get a list of names of files for opening.
     
     @param parent parent widget of the dialog (QWidget)
     @param caption window title of the dialog (string)
     @param directory working directory of the dialog (string)
-    @param filter filter string for the dialog (string)
+    @param filterStr filter string for the dialog (string)
     @param options various options for the dialog (QFileDialog.Options)
     @return list of file names to be opened (list of string)
     """
+    if options is None:
+        options = QFileDialog.Options()
     if Globals.isLinuxPlatform():
         options |= QFileDialog.DontUseNativeDialog
     if PYQT_VERSION_STR >= "5.0.0":
         return QFileDialog.getOpenFileNames(
-            parent, caption, directory, filter, "", options)[0]
+            parent, caption, directory, filterStr, "", options)[0]
     else:
         return QFileDialog.getOpenFileNames(
-            parent, caption, directory, filter, options)
+            parent, caption, directory, filterStr, options)
 
 
 def getOpenFileNamesAndFilter(parent=None, caption="", directory="",
-                              filter="", initialFilter="",
-                              options=QFileDialog.Options()):
+                              filterStr="", initialFilter="",
+                              options=None):
     """
     Module function to get a list of names of files for opening and the
     selected file name filter.
@@ -126,15 +132,17 @@ def getOpenFileNamesAndFilter(parent=None, caption="", directory="",
     @param parent parent widget of the dialog (QWidget)
     @param caption window title of the dialog (string)
     @param directory working directory of the dialog (string)
-    @param filter filter string for the dialog (string)
+    @param filterStr filter string for the dialog (string)
     @param initialFilter initial filter for the dialog (string)
     @param options various options for the dialog (QFileDialog.Options)
     @return list of file names to be opened and selected filter
         (list of string, string)
     """
+    if options is None:
+        options = QFileDialog.Options()
     if Globals.isLinuxPlatform():
         options |= QFileDialog.DontUseNativeDialog
-    newfilter = __reorderFilter(filter, initialFilter)
+    newfilter = __reorderFilter(filterStr, initialFilter)
     if PYQT_VERSION_STR >= "5.0.0":
         return QFileDialog.getOpenFileNames(
             parent, caption, directory, newfilter, initialFilter, options)
@@ -144,30 +152,32 @@ def getOpenFileNamesAndFilter(parent=None, caption="", directory="",
 
 
 def getSaveFileName(parent=None, caption="", directory="",
-                    filter="", options=QFileDialog.Options()):
+                    filterStr="", options=None):
     """
     Module function to get the name of a file for saving it.
     
     @param parent parent widget of the dialog (QWidget)
     @param caption window title of the dialog (string)
     @param directory working directory of the dialog (string)
-    @param filter filter string for the dialog (string)
+    @param filterStr filter string for the dialog (string)
     @param options various options for the dialog (QFileDialog.Options)
     @return name of file to be saved (string)
     """
+    if options is None:
+        options = QFileDialog.Options()
     if Globals.isLinuxPlatform():
         options |= QFileDialog.DontUseNativeDialog
     if PYQT_VERSION_STR >= "5.0.0":
         return QFileDialog.getSaveFileName(
-            parent, caption, directory, filter, "", options)[0]
+            parent, caption, directory, filterStr, "", options)[0]
     else:
         return QFileDialog.getSaveFileName(
-            parent, caption, directory, filter, options)
+            parent, caption, directory, filterStr, options)
 
 
 def getSaveFileNameAndFilter(parent=None, caption="", directory="",
-                             filter="", initialFilter="",
-                             options=QFileDialog.Options()):
+                             filterStr="", initialFilter="",
+                             options=None):
     """
     Module function to get the name of a file for saving it and the selected
     file name filter.
@@ -175,14 +185,16 @@ def getSaveFileNameAndFilter(parent=None, caption="", directory="",
     @param parent parent widget of the dialog (QWidget)
     @param caption window title of the dialog (string)
     @param directory working directory of the dialog (string)
-    @param filter filter string for the dialog (string)
+    @param filterStr filter string for the dialog (string)
     @param initialFilter initial filter for the dialog (string)
     @param options various options for the dialog (QFileDialog.Options)
     @return name of file to be saved and selected filter (string, string)
     """
+    if options is None:
+        options = QFileDialog.Options()
     if Globals.isLinuxPlatform():
         options |= QFileDialog.DontUseNativeDialog
-    newfilter = __reorderFilter(filter, initialFilter)
+    newfilter = __reorderFilter(filterStr, initialFilter)
     if PYQT_VERSION_STR >= "5.0.0":
         return QFileDialog.getSaveFileName(
             parent, caption, directory, newfilter, initialFilter, options)
