@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,11 +9,12 @@ Module implementing a menu populated from a QAbstractItemModel.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSignal, qVersion, Qt, QModelIndex, QPoint
+from PyQt5.QtCore import pyqtSignal, Qt, QModelIndex, QPoint
 from PyQt5.QtGui import QFontMetrics, QDrag, QPixmap
 from PyQt5.QtWidgets import QMenu, QAction, QApplication
 
 import UI.PixmapCache
+from Globals import qVersionTuple
 
 
 class E5ModelMenu(QMenu):
@@ -48,6 +49,9 @@ class E5ModelMenu(QMenu):
         self.__dropRow = -1
         self.__dropIndex = None
         
+        # This is to ensure it will be shown on Mac OS X
+        self.addAction("--not populated--")
+        
         self.aboutToShow.connect(self.__aboutToShow)
         self.triggered.connect(self.__actionTriggered)
     
@@ -275,6 +279,7 @@ class E5ModelMenu(QMenu):
         """
         idx = self.index(action)
         if idx.isValid():
+            self._keyboardModifiers = QApplication.keyboardModifiers()
             self.activated[QModelIndex].emit(idx)
     
     def index(self, action):
@@ -384,7 +389,7 @@ class E5ModelMenu(QMenu):
         drag = QDrag(self)
         drag.setMimeData(self.__model.mimeData([idx]))
         actionRect = self.actionGeometry(act)
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             drag.setPixmap(self.grab(actionRect))
         else:
             drag.setPixmap(QPixmap.grabWidget(self, actionRect))
