@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,13 +10,14 @@ Module implementing a sidebar class.
 from __future__ import unicode_literals
 
 from PyQt5.QtCore import QEvent, QSize, Qt, QByteArray, QDataStream, \
-    QIODevice, QTimer, qVersion
+    QIODevice, QTimer
 from PyQt5.QtWidgets import QTabBar, QWidget, QStackedWidget, QBoxLayout, \
     QToolButton, QSizePolicy
 
 from E5Gui.E5Application import e5App
 
 import UI.PixmapCache
+from Globals import qVersionTuple
 
 
 class E5SideBar(QWidget):
@@ -96,7 +97,7 @@ class E5SideBar(QWidget):
         
         self.__tabBar.currentChanged[int].connect(
             self.__stackedWidget.setCurrentIndex)
-        e5App().focusChanged[QWidget, QWidget].connect(self.__appFocusChanged)
+        e5App().focusChanged.connect(self.__appFocusChanged)
         self.__autoHideButton.toggled[bool].connect(self.__autoHideToggled)
     
     def setSplitter(self, splitter):
@@ -254,7 +255,7 @@ class E5SideBar(QWidget):
                 elif self.isMinimized():
                     self.expand()
             elif evt.type() == QEvent.Wheel:
-                if qVersion() >= "5.0.0":
+                if qVersionTuple() >= (5, 0, 0):
                     delta = evt.angleDelta().y()
                 else:
                     delta = evt.delta()
@@ -653,11 +654,13 @@ class E5SideBar(QWidget):
         @param old reference to the widget, that lost focus (QWidget or None)
         @param now reference to the widget having the focus (QWidget or None)
         """
-        self.__hasFocus = self.isAncestorOf(now)
-        if self.__autoHide and not self.__hasFocus and not self.isMinimized():
-            self.shrink()
-        elif self.__autoHide and self.__hasFocus and self.isMinimized():
-            self.expand()
+        if isinstance(now, QWidget):
+            self.__hasFocus = self.isAncestorOf(now)
+            if self.__autoHide and not self.__hasFocus and \
+                    not self.isMinimized():
+                self.shrink()
+            elif self.__autoHide and self.__hasFocus and self.isMinimized():
+                self.expand()
     
     def enterEvent(self, event):
         """
@@ -689,5 +692,4 @@ class E5SideBar(QWidget):
         properly. It disconnects from the focusChanged signal in order to
         avoid trouble later on.
         """
-        e5App().focusChanged[QWidget, QWidget].disconnect(
-            self.__appFocusChanged)
+        e5App().focusChanged.disconnect(self.__appFocusChanged)
