@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -44,12 +44,14 @@ class E5TreeSortFilterProxyModel(QSortFilterProxyModel):
         return QSortFilterProxyModel.filterAcceptsRow(
             self, sourceRow, sourceParent)
     
-    def hasChildren(self, parent=QModelIndex()):
+    def hasChildren(self, parent=None):
         """
         Public method to check, if a parent node has some children.
         
         @param parent index of the parent node (QModelIndex)
         @return flag indicating the presence of children (boolean)
         """
+        if parent is None:
+            parent = QModelIndex()
         sindex = self.mapToSource(parent)
         return self.sourceModel().hasChildren(sindex)
