@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -188,17 +188,17 @@ class E5TreeWidget(QTreeWidget):
         for item in items:
             self.deleteItem(item)
     
-    def filterString(self, filter):
+    def filterString(self, filterStr):
         """
         Public slot to set a new filter.
         
-        @param filter filter to be set (string)
+        @param filterStr filter to be set (string)
         """
         self.expandAll()
         allItems = self.allItems()
         
-        if filter:
-            lFilter = filter.lower()
+        if filterStr:
+            lFilter = filterStr.lower()
             for itm in allItems:
                 itm.setHidden(lFilter not in itm.text(0).lower())
                 itm.setExpanded(True)
