@@ -10,7 +10,7 @@ Module implementing a dialog to show and edit all certificates.
 from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSlot, Qt, QByteArray, QFile, QFileInfo, \
-    QIODevice, qVersion
+    QIODevice
 from PyQt5.QtWidgets import QDialog, QTreeWidgetItem
 try:
     from PyQt5.QtNetwork import QSslCertificate, QSslSocket, \
@@ -26,6 +26,7 @@ import Preferences
 import Utilities
 import UI.PixmapCache
 import Globals
+from Globals import qVersionTuple
 
 
 class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
@@ -86,7 +87,7 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         @param cert certificate to insert (QSslCertificate)
         """
         # step 1: extract the info to be shown
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             organisation = Utilities.decodeString(
                 ", ".join(cert.subjectInfo(QSslCertificate.Organization)))
             commonName = Utilities.decodeString(
@@ -213,7 +214,7 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
             pems = QByteArray()
             for cert in certs:
                 if cert in sCerts:
-                    if qVersion() >= "5.0.0":
+                    if qVersionTuple() >= (5, 0, 0):
                         commonStr = ", ".join(
                             cert.subjectInfo(QSslCertificate.CommonName))
                     else:
@@ -297,7 +298,7 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         @param cert certificate to insert (QSslCertificate)
         """
         # step 1: extract the info to be shown
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             organisation = Utilities.decodeString(
                 ", ".join(cert.subjectInfo(QSslCertificate.Organization)))
             commonName = Utilities.decodeString(
@@ -403,7 +404,7 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
             caCerts = self.__getSystemCaCertificates()
             for cert in certs:
                 if cert in caCerts:
-                    if qVersion() >= "5.0.0":
+                    if qVersionTuple() >= (5, 0, 0):
                         commonStr = ", ".join(
                             cert.subjectInfo(QSslCertificate.CommonName))
                     else:
