@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -48,14 +48,12 @@ class UserProjectReader(XMLStreamReaderBase):
                     if self.version not in self.supportedVersions:
                         self.raiseUnsupportedFormatVersion(self.version)
                 elif self.name() == "VcsType":
-                    self.project.pudata["VCSOVERRIDE"] = [
-                        self.readElementText()]
+                    self.project.pudata["VCSOVERRIDE"] = self.readElementText()
                 elif self.name() == "VcsStatusMonitorInterval":
                     interval = int(self.attribute(
                         "value",
                         Preferences.getVCS("StatusMonitorInterval")))
-                    self.project.pudata["VCSSTATUSMONITORINTERVAL"] = [
-                        interval]
+                    self.project.pudata["VCSSTATUSMONITORINTERVAL"] = interval
                 else:
                     self.raiseUnexpectedStartTag(self.name())
         
