@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -50,13 +50,21 @@ class XMLStreamReaderBase(QXmlStreamReader):
         Public method to show an error message.
         """
         if self.hasError():
-            msg = QCoreApplication.translate(
-                "XMLStreamReaderBase",
-                "<p>XML parse error in file <b>{0}</b>, line {1},"
-                " column {2}</p><p>Error: {3}</p>").format(
-                self.device().fileName(),
-                self.lineNumber(), self.columnNumber(),
-                self.errorString())
+            if self.device() is not None:
+                msg = QCoreApplication.translate(
+                    "XMLStreamReaderBase",
+                    "<p>XML parse error in file <b>{0}</b>, line {1},"
+                    " column {2}</p><p>Error: {3}</p>").format(
+                    self.device().fileName(),
+                    self.lineNumber(), self.columnNumber(),
+                    self.errorString())
+            else:
+                msg = QCoreApplication.translate(
+                    "XMLStreamReaderBase",
+                    "<p>XML parse error (line {0},"
+                    " column {1})</p><p>Error: {2}</p>").format(
+                    self.lineNumber(), self.columnNumber(),
+                    self.errorString())
             E5MessageBox.warning(
                 None,
                 QCoreApplication.translate(
