@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,7 +9,7 @@ Module implementing a dialog showing a pixmap.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import Qt, QSize, QEvent, qVersion
+from PyQt5.QtCore import Qt, QSize, QEvent
 from PyQt5.QtGui import QPalette, QImage, QPixmap, QPainter, QFont, QColor
 from PyQt5.QtWidgets import QLabel, QSizePolicy, QScrollArea, QAction, QMenu, \
     QToolBar
@@ -22,6 +22,7 @@ from E5Gui.E5ZoomWidget import E5ZoomWidget
 import UI.Config
 
 import Preferences
+from Globals import qVersionTuple
 
 
 class PixmapDiagram(E5MainWindow):
@@ -187,7 +188,7 @@ class PixmapDiagram(E5MainWindow):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 delta = evt.angleDelta().y()
             else:
                 delta = evt.delta()
@@ -222,9 +223,9 @@ class PixmapDiagram(E5MainWindow):
         pinch = evt.gesture(Qt.PinchGesture)
         if pinch:
             if pinch.state() == Qt.GestureStarted:
-                pinch.setScaleFactor(self.__zoom() / 100)
-            else:
-                self.__doZoom(int(pinch.scaleFactor() * 100))
+                pinch.setTotalScaleFactor(self.__zoom() / 100)
+            elif pinch.state() == Qt.GestureUpdated:
+                self.__doZoom(int(pinch.totalScaleFactor() * 100))
             evt.accept()
     
     ###########################################################################
@@ -238,8 +239,8 @@ class PixmapDiagram(E5MainWindow):
         @param scrollBar reference to the scrollbar object (QScrollBar)
         @param factor factor to adjust by (float)
         """
-        scrollBar.setValue(int(factor * scrollBar.value()
-                           + ((factor - 1) * scrollBar.pageStep() / 2)))
+        scrollBar.setValue(int(factor * scrollBar.value() +
+                           ((factor - 1) * scrollBar.pageStep() / 2)))
         
     def __levelForZoom(self, zoom):
         """
