@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,7 +9,7 @@ Module implementing a dialog showing a SVG graphic.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import Qt, QSize, QEvent, qVersion
+from PyQt5.QtCore import Qt, QSize, QEvent
 from PyQt5.QtGui import QPalette, QPainter, QFont, QColor
 from PyQt5.QtWidgets import QSizePolicy, QScrollArea, QAction, QMenu, QToolBar
 from PyQt5.QtPrintSupport import QPrinter, QPrintDialog
@@ -21,6 +21,7 @@ from E5Gui.E5ZoomWidget import E5ZoomWidget
 import UI.Config
 
 import Preferences
+from Globals import qVersionTuple
 
 
 class SvgDiagram(E5MainWindow):
@@ -157,7 +158,7 @@ class SvgDiagram(E5MainWindow):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 delta = evt.angleDelta().y()
             else:
                 delta = evt.delta()
@@ -192,9 +193,9 @@ class SvgDiagram(E5MainWindow):
         pinch = evt.gesture(Qt.PinchGesture)
         if pinch:
             if pinch.state() == Qt.GestureStarted:
-                pinch.setScaleFactor(self.__zoom() / 100)
-            else:
-                self.__doZoom(int(pinch.scaleFactor() * 100))
+                pinch.setTotalScaleFactor(self.__zoom() / 100)
+            elif pinch.state() == Qt.GestureUpdated:
+                self.__doZoom(int(pinch.totalScaleFactor() * 100))
             evt.accept()
     
     ###########################################################################
