@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,7 +10,7 @@ Module implementing a subclass of E5GraphicsView for our diagrams.
 from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSignal, Qt, QSignalMapper, QFileInfo, QEvent, \
-    QRectF, qVersion
+    QRectF
 from PyQt5.QtWidgets import QGraphicsView, QAction, QToolBar, QDialog
 from PyQt5.QtPrintSupport import QPrinter, QPrintDialog
 
@@ -25,6 +25,7 @@ import UI.Config
 import UI.PixmapCache
 
 import Preferences
+from Globals import qVersionTuple
 
 
 class UMLGraphicsView(E5GraphicsView):
@@ -601,7 +602,7 @@ class UMLGraphicsView(E5GraphicsView):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 delta = evt.angleDelta().y()
             else:
                 delta = evt.delta()
@@ -636,9 +637,9 @@ class UMLGraphicsView(E5GraphicsView):
         pinch = evt.gesture(Qt.PinchGesture)
         if pinch:
             if pinch.state() == Qt.GestureStarted:
-                pinch.setScaleFactor(self.zoom() / 100.0)
-            else:
-                self.setZoom(int(pinch.scaleFactor() * 100))
+                pinch.setTotalScaleFactor(self.zoom() / 100.0)
+            elif pinch.state() == Qt.GestureUpdated:
+                self.setZoom(int(pinch.totalScaleFactor() * 100))
             evt.accept()
     
     def getItemId(self):
@@ -650,16 +651,16 @@ class UMLGraphicsView(E5GraphicsView):
         self.__itemId += 1
         return self.__itemId
 
-    def findItem(self, id):
+    def findItem(self, itemId):
         """
         Public method to find an UML item based on the ID.
         
-        @param id of the item to search for (integer)
+        @param itemId of the item to search for (integer)
         @return item found (UMLItem) or None
         """
         for item in self.scene().items():
             try:
-                if item.getId() == id:
+                if item.getId() == itemId:
                     return item
             except AttributeError:
                 continue
@@ -732,9 +733,9 @@ class UMLGraphicsView(E5GraphicsView):
             
             key, value = line.split(": ", 1)
             if key == "item":
-                id, x, y, itemType, itemData = value.split(", ", 4)
+                itemId, x, y, itemType, itemData = value.split(", ", 4)
                 try:
-                    id = int(id.split("=", 1)[1].strip())
+                    itemId = int(itemId.split("=", 1)[1].strip())
                     x = float(x.split("=", 1)[1].strip())
                     y = float(y.split("=", 1)[1].strip())
                     itemType = itemType.split("=", 1)[1].strip()
@@ -744,8 +745,8 @@ class UMLGraphicsView(E5GraphicsView):
                         itm = ModuleItem(x=x, y=y, scene=self.scene())
                     elif itemType == PackageItem.ItemType:
                         itm = PackageItem(x=x, y=y, scene=self.scene())
-                    itm.setId(id)
-                    umlItems[id] = itm
+                    itm.setId(itemId)
+                    umlItems[itemId] = itm
                     if not itm.parseItemDataString(version, itemData):
                         return False, linenum
                 except ValueError:
