@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the AdBlock manager.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSignal, QObject, QUrl, QFile
+from PyQt5.QtCore import pyqtSignal, QObject, QUrl, QFile
 
 from .AdBlockSubscription import AdBlockSubscription
 
@@ -23,6 +25,8 @@ class AdBlockManager(QObject):
     Class implementing the AdBlock manager.
     
     @signal rulesChanged() emitted after some rule has changed
+    @signal requiredSubscriptionLoaded(subscription) emitted to indicate
+        loading of a required subscription is finished (AdBlockSubscription)
     """
     rulesChanged = pyqtSignal()
     requiredSubscriptionLoaded = pyqtSignal(AdBlockSubscription)
@@ -33,7 +37,7 @@ class AdBlockManager(QObject):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(AdBlockManager, self).__init__(parent)
         
         self.__loaded = False
         self.__subscriptionsLoaded = False
@@ -137,7 +141,7 @@ class AdBlockManager(QObject):
         location = self.__customSubscriptionLocation()
         encodedUrl = bytes(location.toEncoded()).decode()
         url = QUrl("abp:subscribe?location={0}&title={1}".format(
-            encodedUrl, self.trUtf8("Custom Rules")))
+            encodedUrl, self.tr("Custom Rules")))
         return url
     
     def customRules(self):
@@ -244,8 +248,8 @@ class AdBlockManager(QObject):
         Preferences.setHelp("AdBlockEnabled", self.__enabled)
         if self.__subscriptionsLoaded:
             subscriptions = []
-            requiresSubscriptions = []  # intermediate store for
-                                       # subscription requiring others
+            requiresSubscriptions = []
+            # intermediate store for subscription requiring others
             for subscription in self.__subscriptions:
                 if subscription is None:
                     continue
@@ -296,7 +300,7 @@ class AdBlockManager(QObject):
             subscriptions = [self.__defaultSubscriptionUrlString,
                              self.__customSubscriptionUrlString]
         for subscription in subscriptions:
-            url = QUrl.fromEncoded(subscription.encode())
+            url = QUrl.fromEncoded(subscription.encode("utf-8"))
             adBlockSubscription = AdBlockSubscription(
                 url,
                 subscription.startswith(self.__customSubscriptionUrlString),
@@ -325,7 +329,7 @@ class AdBlockManager(QObject):
                 return
         
         # Step 2: if it is not, get it
-        url = QUrl.fromEncoded(urlString.encode())
+        url = QUrl.fromEncoded(urlString.encode("utf-8"))
         adBlockSubscription = AdBlockSubscription(url, False, self)
         self.addSubscription(adBlockSubscription)
         self.requiredSubscriptionLoaded.emit(adBlockSubscription)
