@@ -1,16 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the AdBlock rule class.
 """
 
+from __future__ import unicode_literals
+
 import re
 
-from PyQt4.QtCore import Qt, QRegExp, QUrl, qVersion
-from PyQt4.QtNetwork import QNetworkRequest
+from PyQt5.QtCore import Qt, QRegExp, QUrl
+from PyQt5.QtNetwork import QNetworkRequest
+
+from Globals import qVersionTuple
 
 
 # Qt version < 4.8 has an issue; it will wrongly
@@ -22,7 +26,7 @@ def toSecondLevelDomain(url):
     @param url URL to extract domain from (QUrl)
     @return name of second level domain (string)
     """
-    if qVersion() >= "4.8.0":
+    if qVersionTuple() >= (4, 8, 0):
         topLevelDomain = url.topLevelDomain()
         urlHost = url.host()
         
@@ -53,11 +57,11 @@ class AdBlockRule(object):
     """
     Class implementing the AdBlock rule.
     """
-    def __init__(self, filter="", subscription=None):
+    def __init__(self, filterRule="", subscription=None):
         """
         Constructor
         
-        @param filter filter string of the rule (string)
+        @param filterRule filter string of the rule (string)
         @param subscription reference to the subscription object
             (AdBlockSubscription)
         """
@@ -88,7 +92,7 @@ class AdBlockRule(object):
         self.__elemhide = False
         self.__caseSensitivity = Qt.CaseInsensitive
         
-        self.setFilter(filter)
+        self.setFilter(filterRule)
     
     def subscription(self):
         """
@@ -106,13 +110,13 @@ class AdBlockRule(object):
         """
         return self.__filter
     
-    def setFilter(self, filter):
+    def setFilter(self, filterRule):
         """
         Public method to set the rule filter string.
         
-        @param filter rule filter string (string)
+        @param filterRule rule filter string (string)
         """
-        self.__filter = filter
+        self.__filter = filterRule
         self.__parseFilter()
     
     def __parseFilter(self):
@@ -363,7 +367,8 @@ class AdBlockRule(object):
         @param req request object to check (QNetworkRequest)
         @return flag indicating a match (boolean)
         """
-        referer = bytes(req.attribute(QNetworkRequest.User + 200, "")).decode()
+        referer = \
+            bytes(req.attribute(QNetworkRequest.User + 200, b"")).decode()
         if referer == "":
             return False
         
@@ -421,7 +426,7 @@ class AdBlockRule(object):
         @param req request object to check (QNetworkRequest)
         @return flag indicating a match (boolean)
         """
-        match = req.rawHeader("X-Request-With") == "XMLHttpRequest"
+        match = req.rawHeader(b"X-Request-With") == "XMLHttpRequest"
         
         if self.__xmlhttprequestException:
             return not match
