@@ -1,14 +1,20 @@
 # -*- coding: utf-8 -*-
 
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+#
+
 """
 Module implementing the download manager class.
 """
 
-from PyQt4.QtCore import pyqtSlot, Qt, QModelIndex, QFileInfo
-from PyQt4.QtGui import QDialog, QStyle, QFileIconProvider, QMenu, QCursor, \
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot, Qt, QModelIndex, QFileInfo
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QDialog, QStyle, QFileIconProvider, QMenu, \
     QApplication
-from PyQt4.QtNetwork import QNetworkRequest
-from PyQt4.QtWebKit import QWebSettings
+from PyQt5.QtNetwork import QNetworkRequest
+from PyQt5.QtWebKit import QWebSettings
 
 from E5Gui import E5MessageBox
 
@@ -37,8 +43,9 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(DownloadManager, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.__saveTimer = AutoSaver(self, self.save)
         
@@ -51,6 +58,8 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         self.__downloadDirectory = ""
         self.__loaded = False
         
+        self.__rowHeightMultiplier = 1.1
+        
         self.setDownloadDirectory(Preferences.getUI("DownloadPath"))
         
         self.downloadsView.setShowGrid(False)
@@ -82,29 +91,29 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             if itm.downloadCanceled():
                 menu.addAction(
                     UI.PixmapCache.getIcon("restart.png"),
-                    self.trUtf8("Retry"), self.__contextMenuRetry)
+                    self.tr("Retry"), self.__contextMenuRetry)
             else:
                 if itm.downloadedSuccessfully():
                     menu.addAction(
                         UI.PixmapCache.getIcon("open.png"),
-                        self.trUtf8("Open"), self.__contextMenuOpen)
+                        self.tr("Open"), self.__contextMenuOpen)
                 elif itm.downloading():
                     menu.addAction(
                         UI.PixmapCache.getIcon("stopLoading.png"),
-                        self.trUtf8("Cancel"), self.__contextMenuCancel)
+                        self.tr("Cancel"), self.__contextMenuCancel)
                     menu.addSeparator()
                 menu.addAction(
-                    self.trUtf8("Open Containing Folder"),
+                    self.tr("Open Containing Folder"),
                     self.__contextMenuOpenFolder)
             menu.addSeparator()
             menu.addAction(
-                self.trUtf8("Go to Download Page"),
+                self.tr("Go to Download Page"),
                 self.__contextMenuGotoPage)
             menu.addAction(
-                self.trUtf8("Copy Download Link"),
+                self.tr("Copy Download Link"),
                 self.__contextMenuCopyLink)
             menu.addSeparator()
-        menu.addAction(self.trUtf8("Select All"), self.__contextMenuSelectAll)
+        menu.addAction(self.tr("Select All"), self.__contextMenuSelectAll)
         if selectedRowsCount > 1 or \
            (selectedRowsCount == 1 and
             not self.__downloads[
@@ -112,7 +121,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
                 .downloading()):
             menu.addSeparator()
             menu.addAction(
-                self.trUtf8("Remove From List"),
+                self.tr("Remove From List"),
                 self.__contextMenuRemoveSelected)
         
         menu.exec_(QCursor.pos())
@@ -147,10 +156,10 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         if self.activeDownloads() > 0:
             res = E5MessageBox.yesNo(
                 self,
-                self.trUtf8(""),
-                self.trUtf8("""There are %n downloads in progress.\n"""
-                            """Do you want to quit anyway?""", "",
-                            self.activeDownloads()),
+                self.tr(""),
+                self.tr("""There are %n downloads in progress.\n"""
+                        """Do you want to quit anyway?""", "",
+                        self.activeDownloads()),
                 icon=E5MessageBox.Warning)
             if not res:
                 self.show()
@@ -213,24 +222,35 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         self.activateWindow()
         self.raise_()
     
-    def __addItem(self, itm):
+    def __addItem(self, itm, append=False):
         """
         Private method to add a download to the list of downloads.
         
-        @param itm reference to the download item (DownloadItem)
+        @param itm reference to the download item
+        @type DownloadItem
+        @param append flag indicating to append the item
+        @type bool
         """
         itm.statusChanged.connect(self.__updateRow)
         itm.downloadFinished.connect(self.__finished)
         
-        row = len(self.__downloads)
+        # insert at top of window
+        if append:
+            row = len(self.__downloads)
+        else:
+            row = 0
         self.__model.beginInsertRows(QModelIndex(), row, row)
-        self.__downloads.append(itm)
+        if append:
+            self.__downloads.append(itm)
+        else:
+            self.__downloads.insert(0, itm)
         self.__model.endInsertRows()
         
         self.downloadsView.setIndexWidget(self.__model.index(row, 0), itm)
         icon = self.style().standardIcon(QStyle.SP_FileIcon)
         itm.setIcon(icon)
-        self.downloadsView.setRowHeight(row, itm.sizeHint().height() * 1.5)
+        self.downloadsView.setRowHeight(
+            row, itm.sizeHint().height() * self.__rowHeightMultiplier)
         # just in case the download finished before the constructor returned
         self.__updateRow(itm)
         self.changeOccurred()
@@ -258,10 +278,9 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             icon = self.style().standardIcon(QStyle.SP_FileIcon)
         itm.setIcon(icon)
         
-        oldHeight = self.downloadsView.rowHeight(row)
         self.downloadsView.setRowHeight(
             row,
-            max(oldHeight, itm.minimumSizeHint().height() * 1.5))
+            itm.minimumSizeHint().height() * self.__rowHeightMultiplier)
         
         remove = False
         globalSettings = QWebSettings.globalSettings()
@@ -344,7 +363,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
                 from .DownloadItem import DownloadItem
                 itm = DownloadItem(parent=self)
                 itm.setData(download)
-                self.__addItem(itm)
+                self.__addItem(itm, append=True)
         self.cleanupButton.setEnabled(
             (len(self.__downloads) - self.activeDownloads()) > 0)
         
@@ -378,7 +397,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         Private method to update the count label.
         """
         count = len(self.__downloads)
-        self.countLabel.setText(self.trUtf8("%n Download(s)", "", count))
+        self.countLabel.setText(self.tr("%n Download(s)", "", count))
     
     def __updateActiveItemCount(self):
         """
@@ -387,9 +406,9 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         count = self.activeDownloads()
         if count > 0:
             self.setWindowTitle(
-                self.trUtf8("Downloading %n file(s)", "", count))
+                self.tr("Downloading %n file(s)", "", count))
         else:
-            self.setWindowTitle(self.trUtf8("Downloads"))
+            self.setWindowTitle(self.tr("Downloads"))
     
     def __finished(self):
         """
