@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -10,13 +10,15 @@ Module implementing the helpbrowser using QWebView.
 
 from __future__ import unicode_literals
 try:
-    str = unicode
+    str = unicode       # __IGNORE_EXCEPTION__
 except NameError:
     pass
 
+import os
+
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, QObject, QT_TRANSLATE_NOOP, \
     QUrl, QBuffer, QIODevice, QFileInfo, Qt, QTimer, QEvent, \
-    QRect, QFile, QPoint, QByteArray, qVersion
+    QRect, QFile, QPoint, QByteArray
 from PyQt5.QtGui import QDesktopServices, QClipboard, QMouseEvent, QColor, \
     QPalette
 from PyQt5.QtWidgets import qApp, QStyle, QMenu, QApplication, QInputDialog, \
@@ -33,9 +35,13 @@ import sip
 
 from E5Gui import E5MessageBox, E5FileDialog
 
+import Helpviewer
+
 import Preferences
 import UI.PixmapCache
 import Globals
+from Globals import qVersionTuple
+import Utilities
 
 try:
     from PyQt5.QtNetwork import QSslCertificate
@@ -188,6 +194,11 @@ class HelpWebPage(QWebPage):
         
         self.__adBlockedEntries = []
         self.loadStarted.connect(self.__loadStarted)
+        
+        self.saveFrameStateRequested.connect(
+            self.__saveFrameStateRequested)
+        self.restoreFrameStateRequested.connect(
+            self.__restoreFrameStateRequested)
     
     def acceptNavigationRequest(self, frame, request, type_):
         """
@@ -303,8 +314,23 @@ class HelpWebPage(QWebPage):
             urlString = bytes(info.url.toEncoded()).decode()
             errorPage.baseUrl = info.url
             if info.domain == QWebPage.QtNetwork and \
-               info.error == QNetworkReply.ContentAccessDenied and \
-               info.errorString.startswith("AdBlockRule:"):
+               info.error == QNetworkReply.ProtocolUnknownError:
+                url = QUrl(info.url)
+                res = E5MessageBox.yesNo(
+                    None,
+                    self.tr("Protocol Error"),
+                    self.tr("""Open external application for {0}-link?\n"""
+                            """URL: {1}""").format(
+                        url.scheme(), url.toString(
+                            QUrl.PrettyDecoded | QUrl.RemovePassword)),
+                    yesDefault=True)
+                
+                if res:
+                    QDesktopServices.openUrl(url)
+                return True
+            elif info.domain == QWebPage.QtNetwork and \
+                info.error == QNetworkReply.ContentAccessDenied and \
+                    info.errorString.startswith("AdBlockRule:"):
                 if info.frame != info.frame.page().mainFrame():
                     # content in <iframe>
                     docElement = info.frame.page().mainFrame()\
@@ -576,7 +602,7 @@ class HelpWebPage(QWebPage):
                 if cert in localCAList:
                     return True
         
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             for cert in certList:
                 if cert.isBlacklisted():
                     return False
@@ -617,6 +643,58 @@ class HelpWebPage(QWebPage):
             return super(HelpWebPage, self).event(fakeEvent)
         
         return super(HelpWebPage, self).event(evt)
+    
+    def __saveFrameStateRequested(self, frame, itm):
+        """
+        Private slot to save the page state (i.e. zoom level and scroll
+        position).
+        
+        Note: Code is based on qutebrowser.
+        
+        @param frame frame to be saved
+        @type QWebFrame
+        @param itm web history item to be saved
+        @type QWebHistoryItem
+        """
+        try:
+            if frame != self.mainFrame():
+                return
+        except RuntimeError:
+            # With Qt 5.2.1 (Ubuntu Trusty) we get this when closing a tab:
+            #     RuntimeError: wrapped C/C++ object of type BrowserPage has
+            #     been deleted
+            # Since the information here isn't that important for closing web
+            # views anyways, we ignore this error.
+            return
+        data = {
+            'zoom': frame.zoomFactor(),
+            'scrollPos': frame.scrollPosition(),
+        }
+        itm.setUserData(data)
+    
+    def __restoreFrameStateRequested(self, frame):
+        """
+        Private slot to restore scroll position and zoom level from
+        history.
+        
+        Note: Code is based on qutebrowser.
+        
+        @param frame frame to be restored
+        @type QWebFrame
+        """
+        if frame != self.mainFrame():
+            return
+        
+        data = self.history().currentItem().userData()
+        if data is None:
+            return
+        
+        if 'zoom' in data:
+            frame.page().view().setZoomValue(int(data['zoom'] * 100),
+                                             saveValue=False)
+        
+        if 'scrollPos' in data and frame.scrollPosition() == QPoint(0, 0):
+            frame.setScrollPosition(data['scrollPos'])
 
 ###############################################################################
 
@@ -697,6 +775,9 @@ class HelpBrowser(QWebView):
         self.page().setForwardUnsupportedContent(True)
         self.page().unsupportedContent.connect(self.__unsupportedContent)
         
+        self.page().featurePermissionRequested.connect(
+            self.__featurePermissionRequested)
+        
         self.page().downloadRequested.connect(self.__downloadRequested)
         self.page().frameCreated.connect(self.__addExternalBinding)
         self.__addExternalBinding(self.page().mainFrame())
@@ -723,6 +804,8 @@ class HelpBrowser(QWebView):
         self.mw.personalInformationManager().connectPage(self.page())
         self.mw.greaseMonkeyManager().connectPage(self.page())
         
+        self.__inspector = None
+        
         self.grabGesture(Qt.PinchGesture)
     
     def __addExternalBinding(self, frame=None):
@@ -786,7 +869,8 @@ class HelpBrowser(QWebView):
             resource = LinkedResource()
             resource.rel = rel
             resource.type_ = type_
-            resource.href = baseUrl.resolved(QUrl.fromEncoded(href))
+            resource.href = baseUrl.resolved(
+                QUrl.fromEncoded(href.encode("utf-8")))
             resource.title = title
             
             resources.append(resource)
@@ -821,7 +905,14 @@ class HelpBrowser(QWebView):
             return
         
         if not name.scheme():
-            name.setUrl(Preferences.getHelp("DefaultScheme") + name.toString())
+            if not os.path.exists(name.toString()):
+                name.setScheme(Preferences.getWebBrowser("DefaultScheme"))
+            else:
+                if Utilities.isWindowsPlatform():
+                    name.setUrl("file:///" + Utilities.fromNativeSeparators(
+                        name.toString()))
+                else:
+                    name.setUrl("file://" + name.toString())
         
         if len(name.scheme()) == 1 or \
            name.scheme() == "file":
@@ -977,17 +1068,24 @@ class HelpBrowser(QWebView):
         """
         self.setZoomValue(self.__currentZoom)
     
-    def setZoomValue(self, value):
+    def setZoomValue(self, value, saveValue=True):
         """
         Public method to set the zoom value.
         
         @param value zoom value (integer)
+        @keyparam saveValue flag indicating to save the zoom value with the
+            zoom manager
+        @type bool
         """
         if value != self.zoomValue():
             try:
                 self.setZoomFactor(value / 100.0)
             except AttributeError:
                 self.setTextSizeMultiplier(value / 100.0)
+            self.__currentZoom = value
+            if saveValue:
+                Helpviewer.HelpWindow.HelpWindow.zoomManager().setZoomValue(
+                    self.url(), value)
             self.zoomValueChanged.emit(value)
     
     def zoomValue(self):
@@ -1084,6 +1182,31 @@ class HelpBrowser(QWebView):
         from .UserAgent.UserAgentMenu import UserAgentMenu
         menu = QMenu(self)
         
+        if self.url().toString() == "eric:speeddial":
+            # special menu for the spedd dial page
+            menu.addAction(self.mw.newTabAct)
+            menu.addAction(self.mw.newAct)
+            menu.addSeparator()
+            menu.addAction(self.mw.backAct)
+            menu.addAction(self.mw.forwardAct)
+            menu.addSeparator()
+            menu.addAction(
+                UI.PixmapCache.getIcon("plus.png"),
+                self.tr("Add New Page"), self.__addSpeedDial)
+            menu.addAction(
+                UI.PixmapCache.getIcon("preferences-general.png"),
+                self.tr("Configure Speed Dial"), self.__configureSpeedDial)
+            menu.addSeparator()
+            menu.addAction(
+                UI.PixmapCache.getIcon("reload.png"),
+                self.tr("Reload All Dials"), self.__reloadAllSpeedDials)
+            menu.addSeparator()
+            menu.addAction(
+                self.tr("Reset to Default Dials"), self.__resetSpeedDials)
+            
+            menu.exec_(evt.globalPos())
+            return
+        
         frameAtPos = self.page().frameAt(evt.pos())
         hit = self.page().mainFrame().hitTestContent(evt.pos())
         if not hit.linkUrl().isEmpty():
@@ -1107,12 +1230,12 @@ class HelpBrowser(QWebView):
                 UI.PixmapCache.getIcon("mailSend.png"),
                 self.tr("Send Link"),
                 self.__sendLink).setData(hit.linkUrl())
-##            if Preferences.getHelp("VirusTotalEnabled") and \
-##               Preferences.getHelp("VirusTotalServiceKey") != "":
-##                menu.addAction(
-##                    UI.PixmapCache.getIcon("virustotal.png"),
-##                    self.tr("Scan Link with VirusTotal"),
-##                    self.__virusTotal).setData(hit.linkUrl())
+            if Preferences.getHelp("VirusTotalEnabled") and \
+               Preferences.getHelp("VirusTotalServiceKey") != "":
+                menu.addAction(
+                    UI.PixmapCache.getIcon("virustotal.png"),
+                    self.tr("Scan Link with VirusTotal"),
+                    self.__virusTotal).setData(hit.linkUrl())
         
         if not hit.imageUrl().isEmpty():
             if not menu.isEmpty():
@@ -1140,12 +1263,12 @@ class HelpBrowser(QWebView):
                 UI.PixmapCache.getIcon("adBlockPlus.png"),
                 self.tr("Block Image"), self.__blockImage)\
                 .setData(hit.imageUrl().toString())
-##            if Preferences.getHelp("VirusTotalEnabled") and \
-##               Preferences.getHelp("VirusTotalServiceKey") != "":
-##                menu.addAction(
-##                    UI.PixmapCache.getIcon("virustotal.png"),
-##                    self.tr("Scan Image with VirusTotal"),
-##                    self.__virusTotal).setData(hit.imageUrl())
+            if Preferences.getHelp("VirusTotalEnabled") and \
+               Preferences.getHelp("VirusTotalServiceKey") != "":
+                menu.addAction(
+                    UI.PixmapCache.getIcon("virustotal.png"),
+                    self.tr("Scan Image with VirusTotal"),
+                    self.__virusTotal).setData(hit.imageUrl())
         
         element = hit.element()
         if not element.isNull():
@@ -1477,14 +1600,14 @@ class HelpBrowser(QWebView):
         else:
             self.__clickedMediaElement.evaluateJavaScript("this.muted = true")
     
-##    def __virusTotal(self):
-##        """
-##        Private slot to scan the selected URL with VirusTotal.
-##        """
-##        act = self.sender()
-##        url = act.data()
-##        self.mw.requestVirusTotalScan(url)
-##    
+    def __virusTotal(self):
+        """
+        Private slot to scan the selected URL with VirusTotal.
+        """
+        act = self.sender()
+        url = act.data()
+        self.mw.requestVirusTotalScan(url)
+    
     def __searchRequested(self, act):
         """
         Private slot to search for some text with a selected search engine.
@@ -1530,10 +1653,10 @@ class HelpBrowser(QWebView):
         
         searchUrl = QUrl(self.page().mainFrame().baseUrl().resolved(
             QUrl(formElement.attribute("action"))))
-        if searchUrl.scheme() != "http":
-            return
+##        if searchUrl.scheme() != "http":
+##            return
         
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             from PyQt5.QtCore import QUrlQuery
             searchUrlQuery = QUrlQuery(searchUrl)
         searchEngines = {}
@@ -1548,18 +1671,18 @@ class HelpBrowser(QWebView):
             elif type_ == "text":
                 if inputField == element:
                     value = "{searchTerms}"
-                if qVersion() >= "5.0.0":
+                if qVersionTuple() >= (5, 0, 0):
                     searchUrlQuery.addQueryItem(name, value)
                 else:
                     searchUrl.addQueryItem(name, value)
             elif type_ == "checkbox" or type_ == "radio":
                 if inputField.evaluateJavaScript("this.checked"):
-                    if qVersion() >= "5.0.0":
+                    if qVersionTuple() >= (5, 0, 0):
                         searchUrlQuery.addQueryItem(name, value)
                     else:
                         searchUrl.addQueryItem(name, value)
             elif type_ == "hidden":
-                if qVersion() >= "5.0.0":
+                if qVersionTuple() >= (5, 0, 0):
                     searchUrlQuery.addQueryItem(name, value)
                 else:
                     searchUrl.addQueryItem(name, value)
@@ -1574,7 +1697,7 @@ class HelpBrowser(QWebView):
             
             options = selectField.findAll("option")
             value = options.at(selectedIndex).toPlainText()
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 searchUrlQuery.addQueryItem(name, value)
             else:
                 searchUrl.addQueryItem(name, value)
@@ -1591,7 +1714,7 @@ class HelpBrowser(QWebView):
                 return
             
             if searchEngines[searchEngine] != "":
-                if qVersion() >= "5.0.0":
+                if qVersionTuple() >= (5, 0, 0):
                     searchUrlQuery.addQueryItem(
                         searchEngines[searchEngine], searchEngine)
                 else:
@@ -1611,14 +1734,18 @@ class HelpBrowser(QWebView):
         if not ok:
             return
         
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             searchUrl.setQuery(searchUrlQuery)
         
         from .OpenSearch.OpenSearchEngine import OpenSearchEngine
         engine = OpenSearchEngine()
         engine.setName(engineName)
         engine.setDescription(engineName)
-        engine.setSearchUrlTemplate(searchUrl.toString())
+        if qVersionTuple() >= (5, 0, 0):
+            engine.setSearchUrlTemplate(
+                searchUrl.toDisplayString(QUrl.FullyDecoded))
+        else:
+            engine.setSearchUrlTemplate(searchUrl.toString())
         engine.setImage(self.icon().pixmap(16, 16).toImage())
         
         self.mw.openSearchManager().addEngine(engine)
@@ -1627,7 +1754,25 @@ class HelpBrowser(QWebView):
         """
         Private slot to show the web inspector window.
         """
-        self.triggerPageAction(QWebPage.InspectElement)
+        if self.__inspector is None:
+            from .HelpInspector import HelpInspector
+            self.__inspector = HelpInspector()
+            self.__inspector.setPage(self.page())
+            self.__inspector.show()
+        elif self.__inspector.isVisible():
+            self.__inspector.hide()
+        else:
+            self.__inspector.show()
+    
+    def closeWebInspector(self):
+        """
+        Public slot to close the web inspector.
+        """
+        if self.__inspector is not None:
+            if self.__inspector.isVisible():
+                self.__inspector.hide()
+            self.__inspector.deleteLater()
+            self.__inspector = None
     
     def addBookmark(self):
         """
@@ -1728,7 +1873,7 @@ class HelpBrowser(QWebView):
         
         @param evt reference to the wheel event (QWheelEvent)
         """
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             delta = evt.angleDelta().y()
         else:
             delta = evt.delta()
@@ -1821,9 +1966,9 @@ class HelpBrowser(QWebView):
         pinch = evt.gesture(Qt.PinchGesture)
         if pinch:
             if pinch.state() == Qt.GestureStarted:
-                pinch.setScaleFactor(self.__currentZoom / 100.0)
-            else:
-                scaleFactor = pinch.scaleFactor()
+                pinch.setTotalScaleFactor(self.__currentZoom / 100.0)
+            elif pinch.state() == Qt.GestureUpdated:
+                scaleFactor = pinch.totalScaleFactor()
                 self.__currentZoom = int(scaleFactor * 100)
                 self.__applyZoom()
             evt.accept()
@@ -1901,6 +2046,10 @@ class HelpBrowser(QWebView):
             self.zoomIn()
             self.zoomOut()
         
+        zoomValue = Helpviewer.HelpWindow.HelpWindow.zoomManager()\
+            .zoomValue(self.url())
+        self.setZoomValue(zoomValue)
+        
         if ok:
             self.mw.adBlockManager().page().hideBlockedPageEntries(self.page())
             self.mw.passwordManager().fill(self.page())
@@ -2018,6 +2167,18 @@ class HelpBrowser(QWebView):
         self.mw.historyManager().removeHistoryEntry(replyUrl, self.title())
         self.loadFinished.emit(False)
     
+    def __featurePermissionRequested(self, frame, feature):
+        """
+        Private slot handling a feature permission request.
+        
+        @param frame frame sending the request
+        @type QWebFrame
+        @param feature requested feature
+        @type QWebPage.Feature
+        """
+        manager = Helpviewer.HelpWindow.HelpWindow.featurePermissionManager()
+        manager.requestFeaturePermission(self.page(), frame, feature)
+    
     def __downloadRequested(self, request):
         """
         Private slot to handle a download request.
@@ -2477,6 +2638,34 @@ class HelpBrowser(QWebView):
         editor.setText(src, "Html")
         editor.setLanguage("dummy.html")
         editor.show()
+    
+    ###########################################################################
+    ## Speed Dial slots below
+    ###########################################################################
+    
+    def __addSpeedDial(self):
+        """
+        Private slot to add a new speed dial.
+        """
+        self.page().mainFrame().evaluateJavaScript("addSpeedDial();")
+    
+    def __configureSpeedDial(self):
+        """
+        Private slot to configure the speed dial.
+        """
+        self.page().mainFrame().evaluateJavaScript("configureSpeedDial();")
+    
+    def __reloadAllSpeedDials(self):
+        """
+        Private slot to reload all speed dials.
+        """
+        self.page().mainFrame().evaluateJavaScript("reloadAll();")
+    
+    def __resetSpeedDials(self):
+        """
+        Private slot to reset all speed dials to the default pages.
+        """
+        self.__speedDial.resetDials()
 
 
 def contentSniff(data):
