@@ -122,16 +122,16 @@ class HelpIndexWidget(QWidget):
             link = dlg.link()
         return link
     
-    def __filterIndices(self, filter):
+    def __filterIndices(self, filterStr):
         """
         Private slot to filter the indices according to the given filter.
         
-        @param filter filter to be used (string)
+        @param filterStr filter to be used (string)
         """
-        if '*' in filter:
-            self.__index.filterIndices(filter, filter)
+        if '*' in filterStr:
+            self.__index.filterIndices(filterStr, filterStr)
         else:
-            self.__index.filterIndices(filter)
+            self.__index.filterIndices(filterStr)
     
     def __enableSearchEdit(self):
         """
