@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -120,31 +120,37 @@ class HistoryModel(QAbstractTableModel):
         
         return None
     
-    def columnCount(self, parent=QModelIndex()):
+    def columnCount(self, parent=None):
         """
         Public method to get the number of columns.
         
         @param parent index of parent (QModelIndex)
         @return number of columns (integer)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         if parent.isValid():
             return 0
         else:
             return len(self.__headers)
     
-    def rowCount(self, parent=QModelIndex()):
+    def rowCount(self, parent=None):
         """
         Public method to determine the number of rows.
         
         @param parent index of parent (QModelIndex)
         @return number of rows (integer)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         if parent.isValid():
             return 0
         else:
             return len(self.__historyManager.history())
     
-    def removeRows(self, row, count, parent=QModelIndex()):
+    def removeRows(self, row, count, parent=None):
         """
         Public method to remove history entries from the model.
         
@@ -153,6 +159,9 @@ class HistoryModel(QAbstractTableModel):
         @param parent index of the parent entry (QModelIndex)
         @return flag indicating successful removal (boolean)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         if parent.isValid():
             return False
         
