@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -76,39 +76,43 @@ class EricAccessHandler(SchemeAccessHandler):
             htmlFile.open(QFile.ReadOnly)
             html = bytes(htmlFile.readAll()).decode()
             
-            html = (
-                html.replace("@FAVICON@", "qrc:icons/ericWeb16.png")
-                .replace("@IMG_PLUS@", "qrc:icons/plus.png")
-                .replace("@IMG_CLOSE@", "qrc:icons/close.png")
-                .replace("@IMG_EDIT@", "qrc:icons/edit.png")
-                .replace("@IMG_RELOAD@", "qrc:icons/reload.png")
-                .replace("@IMG_SETTINGS@", "qrc:icons/setting.png")
-                .replace("@LOADING-IMG@", "qrc:icons/loading.gif")
-                .replace("@BOX-BORDER@", "qrc:icons/box-border-small.png")
-                
-                .replace("@JQUERY@", "qrc:javascript/jquery.js")
-                .replace("@JQUERY-UI@", "qrc:javascript/jquery-ui.js")
-                
-                .replace("@SITE-TITLE@", self.tr("Speed Dial"))
-                .replace("@URL@", self.tr("URL"))
-                .replace("@TITLE@", self.tr("Title"))
-                .replace("@APPLY@", self.tr("Apply"))
-                .replace("@CLOSE@", self.tr("Close"))
-                .replace("@NEW-PAGE@", self.tr("New Page"))
-                .replace("@TITLE-EDIT@", self.tr("Edit"))
-                .replace("@TITLE-REMOVE@", self.tr("Remove"))
-                .replace("@TITLE-RELOAD@", self.tr("Reload"))
-                .replace("@TITLE-WARN@",
-                         self.tr("Are you sure to remove this speed dial?"))
-                .replace("@TITLE-FETCHTITLE@",
-                         self.tr("Load title from page"))
-                .replace("@SETTINGS-TITLE@",
-                         self.tr("Speed Dial Settings"))
-                .replace("@ADD-TITLE@", self.tr("Add New Page"))
-                .replace("@TXT_NRROWS@",
-                         self.tr("Maximum pages in a row:"))
-                .replace("@TXT_SDSIZE@", self.tr("Change size of pages:"))
-            )
+            html = html.replace("@FAVICON@", "qrc:icons/ericWeb16.png")
+            html = html.replace("@IMG_PLUS@", "qrc:icons/plus.png")
+            html = html.replace("@IMG_CLOSE@", "qrc:icons/close.png")
+            html = html.replace("@IMG_EDIT@", "qrc:icons/edit.png")
+            html = html.replace("@IMG_RELOAD@", "qrc:icons/reload.png")
+            html = html.replace("@IMG_SETTINGS@", "qrc:icons/setting.png")
+            html = html.replace("@LOADING-IMG@", "qrc:icons/loading.gif")
+            html = html.replace("@BOX-BORDER@",
+                                "qrc:icons/box-border-small.png")
+            
+            html = html.replace("@JQUERY@", "qrc:javascript/jquery.js")
+            html = html.replace("@JQUERY-UI@", "qrc:javascript/jquery-ui.js")
+            
+            html = html.replace("@SITE-TITLE@", self.tr("Speed Dial"))
+            html = html.replace("@URL@", self.tr("URL"))
+            html = html.replace("@TITLE@", self.tr("Title"))
+            html = html.replace("@APPLY@", self.tr("Apply"))
+            html = html.replace("@CLOSE@", self.tr("Close"))
+            html = html.replace("@NEW-PAGE@", self.tr("New Page"))
+            html = html.replace("@TITLE-EDIT@", self.tr("Edit"))
+            html = html.replace("@TITLE-REMOVE@", self.tr("Remove"))
+            html = html.replace("@TITLE-RELOAD@", self.tr("Reload"))
+            html = html.replace("@TITLE-WARN@",
+                                self.tr("Are you sure to remove this"
+                                        " speed dial?"))
+            html = html.replace("@TITLE-WARN-REL@",
+                                self.tr("Are you sure you want to reload"
+                                        " all speed dials?"))
+            html = html.replace("@TITLE-FETCHTITLE@",
+                                self.tr("Load title from page"))
+            html = html.replace("@SETTINGS-TITLE@",
+                                self.tr("Speed Dial Settings"))
+            html = html.replace("@ADD-TITLE@", self.tr("Add New Page"))
+            html = html.replace("@TXT_NRROWS@",
+                                self.tr("Maximum pages in a row:"))
+            html = html.replace("@TXT_SDSIZE@",
+                                self.tr("Change size of pages:"))
             
             self._speedDialPage = Utilities.html_uencode(html)
         
