@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -191,8 +191,8 @@ class FileReply(QNetworkReply):
         """
         Private slot loading the directory and preparing the listing page.
         """
-        dir = QDir(self.url().toLocalFile())
-        dirItems = dir.entryInfoList(
+        qdir = QDir(self.url().toLocalFile())
+        dirItems = qdir.entryInfoList(
             QDir.AllEntries | QDir.Hidden | QDir.NoDotAndDotDot,
             QDir.Name | QDir.DirsFirst)
         
