@@ -1,22 +1,29 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a network reply class for FTP resources.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
 import ftplib
 import socket
 import errno
 import mimetypes
 
-from PyQt4.QtCore import QByteArray, QIODevice, Qt, QUrl, QTimer, QBuffer, \
+from PyQt5.QtCore import QByteArray, QIODevice, Qt, QUrl, QTimer, QBuffer, \
     QCoreApplication
-from PyQt4.QtGui import QPixmap, QDialog
-from PyQt4.QtNetwork import QNetworkReply, QNetworkRequest, QAuthenticator
-from PyQt4.QtWebKit import QWebSettings
+from PyQt5.QtGui import QPixmap
+from PyQt5.QtWidgets import QDialog
+from PyQt5.QtNetwork import QNetworkReply, QNetworkRequest, QAuthenticator
+from PyQt5.QtWebKit import QWebSettings
 
 from E5Network.E5Ftp import E5Ftp, E5FtpProxyError, E5FtpProxyType
 
@@ -116,7 +123,7 @@ class FtpReply(QNetworkReply):
         @param accessHandler reference to the access handler (FtpAccessHandler)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(FtpReply, self).__init__(parent)
         
         self.__manager = parent
         self.__handler = accessHandler
@@ -177,7 +184,7 @@ class FtpReply(QNetworkReply):
     
     def readData(self, maxlen):
         """
-        Protected method to retrieve data from the reply object.
+        Public method to retrieve data from the reply object.
         
         @param maxlen maximum number of bytes to read (integer)
         @return string containing the data (bytes)
@@ -268,11 +275,11 @@ class FtpReply(QNetworkReply):
                         # found a not supported proxy
                         self.setError(
                             QNetworkReply.ProxyConnectionRefusedError,
-                            self.trUtf8("The proxy type seems to be wrong."
-                                        " If it is not in the list of"
-                                        " supported proxy types please report"
-                                        " it with the instructions given by"
-                                        " the proxy.\n{0}").format(
+                            self.tr("The proxy type seems to be wrong."
+                                    " If it is not in the list of"
+                                    " supported proxy types please report"
+                                    " it with the instructions given by"
+                                    " the proxy.\n{0}").format(
                                 "\n".join(lines[1:])))
                         self.error.emit(
                             QNetworkReply.ProxyConnectionRefusedError)
@@ -280,7 +287,7 @@ class FtpReply(QNetworkReply):
                     else:
                         from UI.AuthenticationDialog import \
                             AuthenticationDialog
-                        info = self.trUtf8(
+                        info = self.tr(
                             "<b>Connect to proxy '{0}' using:</b>")\
                             .format(Utilities.html_encode(
                                 Preferences.getUI("ProxyHost/Ftp")))
@@ -415,7 +422,7 @@ class FtpReply(QNetworkReply):
             icon = UI.PixmapCache.getIcon("up.png")
             linkClasses["link_parent"] = \
                 self.__cssLinkClass(icon, iconSize).format("link_parent")
-            parentStr = self.trUtf8(
+            parentStr = self.tr(
                 """  <p><a class="link_parent" href="{0}">"""
                 """Change to parent directory</a></p>"""
             ).format(parent.toString())
@@ -428,7 +435,7 @@ class FtpReply(QNetworkReply):
             """<td class="size">{4}</td>"""\
             """<td class="modified">{5}</td>"""\
             """</tr>\n"""
-        table = self.trUtf8(
+        table = self.tr(
             """    <tr>"""
             """<th align="left">Name</th>"""
             """<th>Size</th>"""
@@ -454,7 +461,7 @@ class FtpReply(QNetworkReply):
                     else:
                         break
                 
-                sizeStr = self.trUtf8("{0} {1}", "size unit")\
+                sizeStr = self.tr("{0} {1}", "size unit")\
                     .format(size, self.__units[unit])
                 linkClass = "link_file"
                 if linkClass not in linkClasses:
@@ -481,7 +488,7 @@ class FtpReply(QNetworkReply):
         content = ftpListPage_html.format(
             Utilities.html_encode(baseUrl),
             "".join(linkClasses.values()),
-            self.trUtf8("Listing of {0}").format(basePath),
+            self.tr("Listing of {0}").format(basePath),
             parentStr,
             table
         )
