@@ -1,23 +1,25 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a QNetworkAccessManager subclass.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSignal, QByteArray, qVersion
-from PyQt4.QtGui import QDialog
-from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
+from PyQt5.QtCore import pyqtSignal, QByteArray
+from PyQt5.QtWidgets import QDialog
+from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
     QNetworkReply
 
 from E5Network.E5NetworkProxyFactory import E5NetworkProxyFactory, \
     proxyAuthenticationRequired
 try:
-    from PyQt4.QtNetwork import QSslSocket
+    from PyQt5.QtNetwork import QSslSocket
     from E5Network.E5SslErrorHandler import E5SslErrorHandler
     SSL_AVAILABLE = True
 except ImportError:
@@ -25,6 +27,7 @@ except ImportError:
 
 import Preferences
 import Utilities
+from Globals import qVersionTuple
 
 
 class NetworkAccessManager(QNetworkAccessManager):
@@ -46,7 +49,7 @@ class NetworkAccessManager(QNetworkAccessManager):
         @param engine reference to the help engine (QHelpEngine)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(NetworkAccessManager, self).__init__(parent)
         
         self.__adblockNetwork = None
         
@@ -101,7 +104,7 @@ class NetworkAccessManager(QNetworkAccessManager):
     
     def createRequest(self, op, request, outgoingData=None):
         """
-        Protected method to create a request.
+        Public method to create a request.
         
         @param op the operation to be performed
             (QNetworkAccessManager.Operation)
@@ -139,18 +142,18 @@ class NetworkAccessManager(QNetworkAccessManager):
             return reply
         
         req = QNetworkRequest(request)
-        if req.rawHeader("X-Eric5-UserLoadAction") == QByteArray("1"):
-            req.setRawHeader("X-Eric5-UserLoadAction", QByteArray())
-            req.setAttribute(QNetworkRequest.User + 200, "")
+        if req.rawHeader(b"X-Eric6-UserLoadAction") == QByteArray(b"1"):
+            req.setRawHeader(b"X-Eric6-UserLoadAction", QByteArray())
+            req.setAttribute(QNetworkRequest.User + 200, b"")
         else:
             req.setAttribute(
-                QNetworkRequest.User + 200, req.rawHeader("Referer"))
+                QNetworkRequest.User + 200, req.rawHeader(b"Referer"))
         
         if hasattr(QNetworkRequest, 'HttpPipeliningAllowedAttribute'):
             req.setAttribute(
                 QNetworkRequest.HttpPipeliningAllowedAttribute, True)
         if not self.__acceptLanguage.isEmpty():
-            req.setRawHeader("Accept-Language", self.__acceptLanguage)
+            req.setRawHeader(b"Accept-Language", self.__acceptLanguage)
         
         # AdBlock code
         if op == QNetworkAccessManager.GetOperation:
@@ -182,12 +185,13 @@ class NetworkAccessManager(QNetworkAccessManager):
         
         # Do Not Track feature
         if self.__doNotTrack:
-            req.setRawHeader("DNT", "1")
+            req.setRawHeader(b"DNT", b"1")
+            req.setRawHeader(b"X-Do-Not-Track", b"1")
         
         # Send referer header?
         if not self.__sendReferer and \
            req.url().host() not in Preferences.getHelp("SendRefererWhitelist"):
-            req.setRawHeader("Referer", "")
+            req.setRawHeader(b"Referer", b"")
         
         reply = QNetworkAccessManager.createRequest(
             self, op, req, outgoingData)
@@ -208,10 +212,10 @@ class NetworkAccessManager(QNetworkAccessManager):
         if not realm and 'realm' in auth.options():
             realm = auth.option("realm")
         if realm:
-            info = self.trUtf8("<b>Enter username and password for '{0}', "
-                               "realm '{1}'</b>").format(urlRoot, realm)
+            info = self.tr("<b>Enter username and password for '{0}', "
+                           "realm '{1}'</b>").format(urlRoot, realm)
         else:
-            info = self.trUtf8("<b>Enter username and password for '{0}'</b>")\
+            info = self.tr("<b>Enter username and password for '{0}'</b>")\
                 .format(urlRoot)
         
         from UI.AuthenticationDialog import AuthenticationDialog
@@ -230,7 +234,7 @@ class NetworkAccessManager(QNetworkAccessManager):
             username, password = dlg.getData()
             auth.setUser(username)
             auth.setPassword(password)
-            if Preferences.getUser("SavePasswords"):
+            if Preferences.getUser("SavePasswords") and dlg.shallSave():
                 Helpviewer.HelpWindow.HelpWindow.passwordManager().setLogin(
                     reply.url(), realm, username, password)
     
@@ -259,12 +263,12 @@ class NetworkAccessManager(QNetworkAccessManager):
         Private method to set the disk cache.
         """
         if Preferences.getHelp("DiskCacheEnabled"):
-            from PyQt4.QtWebKit import qWebKitVersion
+            from PyQt5.QtWebKit import qWebKitVersion
             from .NetworkDiskCache import NetworkDiskCache
             diskCache = NetworkDiskCache(self)
             location = os.path.join(
                 Utilities.getConfigDir(), "browser", 'cache',
-                "{0}-Qt{1}".format(qWebKitVersion(), qVersion()))
+                "{0}-Qt{1}.{2}".format(qWebKitVersion(), *qVersionTuple()))
             size = Preferences.getHelp("DiskCacheSize") * 1024 * 1024
             diskCache.setCacheDirectory(location)
             diskCache.setMaximumCacheSize(size)
