@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,8 +8,10 @@ Module implementing a QNetworkReply subclass reporting an unknown protocol
 error.
 """
 
-from PyQt4.QtCore import QTimer
-from PyQt4.QtNetwork import QNetworkReply
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QTimer
+from PyQt5.QtNetwork import QNetworkReply
 
 
 class NetworkProtocolUnknownErrorReply(QNetworkReply):
@@ -24,10 +26,10 @@ class NetworkProtocolUnknownErrorReply(QNetworkReply):
         @param protocol protocol name (string)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(NetworkProtocolUnknownErrorReply, self).__init__(parent)
         self.setError(
             QNetworkReply.ProtocolUnknownError,
-            self.trUtf8("Protocol '{0}' not supported.").format(protocol))
+            self.tr("Protocol '{0}' not supported.").format(protocol))
         QTimer.singleShot(0, self.__fireSignals)
     
     def __fireSignals(self):
@@ -35,7 +37,7 @@ class NetworkProtocolUnknownErrorReply(QNetworkReply):
         Private method to send some signals to end the connection.
         """
         self.error.emit(QNetworkReply.ProtocolUnknownError)
-        self.finished[()].emit()
+        self.finished.emit()
     
     def abort(self):
         """
