@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a scheme access handler for QtHelp.
 """
 
+from __future__ import unicode_literals
+
 import mimetypes
 import os
 
-from PyQt4.QtCore import QByteArray
+from PyQt5.QtCore import QByteArray
 
 from .SchemeAccessHandler import SchemeAccessHandler
 
@@ -82,7 +84,7 @@ class QtHelpAccessHandler(SchemeAccessHandler):
     
     def createRequest(self, op, request, outgoingData=None):
         """
-        Protected method to create a request.
+        Public method to create a request.
         
         @param op the operation to be performed
             (QNetworkAccessManager.Operation)
@@ -115,7 +117,7 @@ class QtHelpAccessHandler(SchemeAccessHandler):
         if self.__engine.findFile(url).isValid():
             data = self.__engine.fileData(url)
         else:
-            data = QByteArray(self.trUtf8(
+            data = QByteArray(self.tr(
                 """<title>Error 404...</title>"""
                 """<div align="center"><br><br>"""
                 """<h1>The page could not be found</h1><br>"""
