@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,7 +13,7 @@ import re
 import json
 
 from PyQt5.QtCore import pyqtSignal, pyqtSlot, QLocale, QUrl, QByteArray, \
-    QBuffer, QIODevice, QObject, qVersion
+    QBuffer, QIODevice, QObject
 from PyQt5.QtGui import QImage
 from PyQt5.QtNetwork import QNetworkRequest, QNetworkAccessManager, \
     QNetworkReply
@@ -22,6 +22,7 @@ from UI.Info import Program
 
 import Preferences
 import Utilities
+from Globals import qVersionTuple
 
 
 class OpenSearchEngine(QObject):
@@ -136,6 +137,30 @@ class OpenSearchEngine(QObject):
         """
         Public method to set the engine search URL template.
         
+        The URL template is processed according to the specification:
+        <a
+          href="http://www.opensearch.org/Specifications/OpenSearch/1.1#OpenSearch_URL_template_syntax">
+        http://www.opensearch.org/Specifications/OpenSearch/1.1#OpenSearch_URL_template_syntax</a>
+
+        A list of template parameters currently supported and what they are
+        replaced with:
+        <table>
+        <tr><td><b>Parameter</b></td><td><b>Value</b></td></tr>
+        <tr><td>{count}</td><td>20</td></tr>
+        <tr><td>{startIndex}</td><td>0</td></tr>
+        <tr><td>{startPage}</td><td>0</td></tr>
+        <tr><td>{language}</td>
+          <td>the default language code (RFC 3066)</td></tr>
+        <tr><td>{country}</td>
+          <td>the default language code (RFC 3066) converted to lower
+              case</td></tr>
+        <tr><td>{inputEncoding}</td><td>UTF-8</td></tr>
+        <tr><td>{outputEncoding}</td><td>UTF-8</td></tr>
+        <tr><td>{searchTerms}</td><td>the string supplied by the user</td></tr>
+        <tr><td>{*:source}</td>
+          <td>application name, QCoreApplication::applicationName()</td></tr>
+        </table>
+        
         @param searchUrlTemplate search URL template of the engine (string)
         """
         self._searchUrlTemplate = searchUrlTemplate
@@ -155,7 +180,7 @@ class OpenSearchEngine(QObject):
             .encode("utf-8"))
         
         if self.__searchMethod != "post":
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 from PyQt5.QtCore import QUrlQuery
                 urlQuery = QUrlQuery(ret)
                 for parameter in self._searchParameters:
@@ -210,7 +235,7 @@ class OpenSearchEngine(QObject):
             searchTerm, self._suggestionsUrlTemplate).encode("utf-8")))
         
         if self.__searchMethod != "post":
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 from PyQt5.QtCore import QUrlQuery
                 urlQuery = QUrlQuery(ret)
                 for parameter in self._suggestionsParameters:
