@@ -279,17 +279,17 @@ class OpenSearchManager(QObject):
         
         @param dirName name of the directory to write the files to (string)
         """
-        dir = QDir()
-        if not dir.mkpath(dirName):
+        qdir = QDir()
+        if not qdir.mkpath(dirName):
             return
-        dir.setPath(dirName)
+        qdir.setPath(dirName)
         
         from .OpenSearchWriter import OpenSearchWriter
         writer = OpenSearchWriter()
         
         for engine in list(self.__engines.values()):
             name = self.generateEngineFileName(engine.name())
-            fileName = dir.filePath(name)
+            fileName = qdir.filePath(name)
             
             file = QFile(fileName)
             if not file.open(QIODevice.WriteOnly):
@@ -325,9 +325,9 @@ class OpenSearchManager(QObject):
         
         success = False
         
-        dir = QDir(dirName)
-        for name in dir.entryList(["*.xml"]):
-            fileName = dir.filePath(name)
+        qdir = QDir(dirName)
+        for name in qdir.entryList(["*.xml"]):
+            fileName = qdir.filePath(name)
             if self.__addEngineByFile(fileName):
                 success = True
         
@@ -359,7 +359,8 @@ class OpenSearchManager(QObject):
         Public method to restore the default search engines.
         """
         from .OpenSearchReader import OpenSearchReader
-        from .DefaultSearchEngines import DefaultSearchEngines_rc   # __IGNORE_WARNING__
+        from .DefaultSearchEngines import DefaultSearchEngines_rc
+        # __IGNORE_WARNING__
         
         defaultEngineFiles = ["Amazoncom.xml", "Bing.xml",
                               "DeEn_Beolingus.xml", "DuckDuckGo.xml",
