@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,7 @@ from __future__ import unicode_literals
 import os
 
 from PyQt5.QtCore import pyqtSignal, QObject, QByteArray, QUrl, \
-    QCoreApplication, QXmlStreamReader, qVersion
+    QCoreApplication, QXmlStreamReader
 from PyQt5.QtWidgets import QApplication
 from PyQt5.QtNetwork import QNetworkRequest
 from PyQt5.QtWebKit import QWebSettings
@@ -25,6 +25,7 @@ from Utilities.AutoSaver import AutoSaver
 import Utilities
 import Utilities.crypto
 import Preferences
+from Globals import qVersionTuple
 
 
 class PasswordManager(QObject):
@@ -437,7 +438,7 @@ class PasswordManager(QObject):
         @return stripped URL (QUrl)
         """
         cleanUrl = QUrl(url)
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             cleanUrl.setQuery("")
         else:
             cleanUrl.setQueryItems([])
@@ -466,7 +467,7 @@ class PasswordManager(QObject):
         if boundary is not None:
             args = self.__extractMultipartQueryItems(data, boundary)
         else:
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 from PyQt5.QtCore import QUrlQuery
                 argsUrl = QUrl.fromEncoded(
                     QByteArray(b"foo://bar.com/?" + QUrl.fromPercentEncoding(
@@ -486,13 +487,13 @@ class PasswordManager(QObject):
         # extract the forms
         from Helpviewer.JavaScriptResources import parseForms_js
         lst = webPage.mainFrame().evaluateJavaScript(parseForms_js)
-        for map in lst:
+        for formMap in lst:
             formHasPasswords = False
-            formName = map["name"]
-            formIndex = map["index"]
+            formName = formMap["name"]
+            formIndex = formMap["index"]
             if isinstance(formIndex, float) and formIndex.is_integer():
                 formIndex = int(formIndex)
-            elements = map["elements"]
+            elements = formMap["elements"]
             formElements = set()
             formElementTypes = {}
             deadElements = set()
@@ -637,9 +638,10 @@ class PasswordManager(QObject):
         for key in self.__logins:
             progress.setValue(count)
             QCoreApplication.processEvents()
-            username, hash = self.__logins[key]
-            hash = Utilities.crypto.pwRecode(hash, oldPassword, newPassword)
-            self.__logins[key] = (username, hash)
+            username, oldPwHash = self.__logins[key]
+            newPwHash = Utilities.crypto.pwRecode(oldPwHash, oldPassword,
+                                                  newPassword)
+            self.__logins[key] = (username, newPwHash)
             count += 1
         
         progress.setValue(len(self.__logins))
