@@ -85,8 +85,10 @@ class QtHelpDocumentationDialog(QDialog, Ui_QtHelpDocumentationDialog):
         """
         from .QtHelpDocumentationSelectionDialog import \
             QtHelpDocumentationSelectionDialog
-        dlg = QtHelpDocumentationSelectionDialog(self.__pluginHelpDocuments,
-                                                 self)
+        dlg = QtHelpDocumentationSelectionDialog(
+            self.__pluginHelpDocuments,
+            QtHelpDocumentationSelectionDialog.AddMode,
+            self)
         if dlg.exec_() == QDialog.Accepted:
             documents = dlg.getData()
             if not documents:
@@ -94,6 +96,19 @@ class QtHelpDocumentationDialog(QDialog, Ui_QtHelpDocumentationDialog):
             
             self.__registerDocumentations(documents)
     
+    @pyqtSlot()
+    def on_managePluginButton_clicked(self):
+        """
+        Private slot to manage the QtHelp documents provided by plug-ins.
+        """
+        from .QtHelpDocumentationSelectionDialog import \
+            QtHelpDocumentationSelectionDialog
+        dlg = QtHelpDocumentationSelectionDialog(
+            self.__pluginHelpDocuments,
+            QtHelpDocumentationSelectionDialog.ManageMode,
+            self)
+        dlg.exec_()
+    
     def __registerDocumentations(self, fileNames):
         """
         Private method to register a given list of documentations.
@@ -161,9 +176,9 @@ class QtHelpDocumentationDialog(QDialog, Ui_QtHelpDocumentationDialog):
                 if not res:
                     return
             self.__unregisteredDocs.append(ns)
-            for id in openedDocs:
-                if openedDocs[id] == ns and id not in self.__tabsToClose:
-                    self.__tabsToClose.append(id)
+            for docId in openedDocs:
+                if openedDocs[docId] == ns and docId not in self.__tabsToClose:
+                    self.__tabsToClose.append(docId)
             itm = self.documentsList.takeItem(self.documentsList.row(item))
             del itm
             
