@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,16 +9,13 @@ Module implementing the synchronization shared directory settings wizard page.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QWizardPage
 
-from E5Gui import E5FileDialog
+from E5Gui.E5PathPicker import E5PathPickerModes
 
 from .Ui_SyncDirectorySettingsPage import Ui_SyncDirectorySettingsPage
 
 import Preferences
-import Utilities
-import UI.PixmapCache
 
 
 class SyncDirectorySettingsPage(QWizardPage, Ui_SyncDirectorySettingsPage):
@@ -34,11 +31,10 @@ class SyncDirectorySettingsPage(QWizardPage, Ui_SyncDirectorySettingsPage):
         super(SyncDirectorySettingsPage, self).__init__(parent)
         self.setupUi(self)
         
-        self.directoryButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.directoryPicker.setMode(E5PathPickerModes.DirectoryMode)
+        self.directoryPicker.setText(Preferences.getHelp("SyncDirectoryPath"))
         
-        self.directoryEdit.setText(Preferences.getHelp("SyncDirectoryPath"))
-        
-        self.directoryEdit.textChanged.connect(self.completeChanged)
+        self.directoryPicker.textChanged.connect(self.completeChanged)
     
     def nextId(self):
         """
@@ -47,9 +43,7 @@ class SyncDirectorySettingsPage(QWizardPage, Ui_SyncDirectorySettingsPage):
         @return next wizard page ID (integer)
         """
         # save the settings
-        Preferences.setHelp(
-            "SyncDirectoryPath",
-            Utilities.toNativeSeparators(self.directoryEdit.text()))
+        Preferences.setHelp("SyncDirectoryPath", self.directoryPicker.text())
         
         from . import SyncGlobals
         return SyncGlobals.PageCheck
@@ -60,19 +54,4 @@ class SyncDirectorySettingsPage(QWizardPage, Ui_SyncDirectorySettingsPage):
         
         @return flag indicating completeness (boolean)
         """
-        return self.directoryEdit.text() != ""
-    
-    @pyqtSlot()
-    def on_directoryButton_clicked(self):
-        """
-        Private slot to select the shared directory via a directory selection
-        dialog.
-        """
-        directory = E5FileDialog.getExistingDirectory(
-            self,
-            self.tr("Shared Directory"),
-            self.directoryEdit.text(),
-            E5FileDialog.Options(E5FileDialog.Option(0)))
-        
-        if directory:
-            self.directoryEdit.setText(Utilities.toNativeSeparators(directory))
+        return self.directoryPicker.text() != ""
