@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -40,7 +40,7 @@ class UserAgentModel(QAbstractTableModel):
         self.beginResetModel()
         self.endResetModel()
     
-    def removeRows(self, row, count, parent=QModelIndex()):
+    def removeRows(self, row, count, parent=None):
         """
         Public method to remove entries from the model.
         
@@ -49,6 +49,9 @@ class UserAgentModel(QAbstractTableModel):
         @param parent parent index (QModelIndex)
         @return flag indicating success (boolean)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         if parent.isValid():
             return False
         
@@ -68,23 +71,26 @@ class UserAgentModel(QAbstractTableModel):
         
         return True
     
-    def rowCount(self, parent=QModelIndex()):
+    def rowCount(self, parent=None):
         """
         Public method to get the number of rows of the model.
         
         @param parent parent index (QModelIndex)
         @return number of rows (integer)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         if parent.isValid():
             return 0
         else:
             return self.__manager.hostsCount()
     
-    def columnCount(self, parent=QModelIndex()):
+    def columnCount(self, parent=None):
         """
         Public method to get the number of columns of the model.
         
-        @param parent parent index (QModelIndex)
+        @param parent parent index (QModelIndex) (Unused)
         @return number of columns (integer)
         """
         return len(self.__headers)
