@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -142,11 +142,11 @@ class ClickToFlash(QWidget, Ui_ClickToFlash):
         """
         self.__plugin.removeFromWhitelist(self.__url.host())
     
-    def __load(self, all=False):
+    def __load(self, allPlayers=False):
         """
         Private slot to load the flash content.
         
-        @param all flag indicating to load all flash players. (boolean)
+        @param allPlayers flag indicating to load all flash players (boolean)
         """
         self.__findElement()
         if not self.__element.isNull():
