@@ -12,7 +12,7 @@ from __future__ import unicode_literals
 import os
 
 from PyQt5.QtCore import pyqtSignal, Qt, QSize, QSignalMapper, QFileInfo, \
-    QFile, QEvent, qVersion
+    QFile, QEvent
 from PyQt5.QtGui import QPalette, QImage, QImageReader, QImageWriter, \
     QKeySequence
 from PyQt5.QtWidgets import QScrollArea, QLabel, QDockWidget, QWhatsThis
@@ -28,6 +28,7 @@ import UI.PixmapCache
 import UI.Config
 
 import Preferences
+from Globals import qVersionTuple
 
 
 class IconEditorWindow(E5MainWindow):
@@ -123,8 +124,12 @@ class IconEditorWindow(E5MainWindow):
         """
         filters = {
             'bmp': self.tr("Windows Bitmap File (*.bmp)"),
+            'cur': self.tr("Windows Cursor File (*.cur)"),
+            'dds': self.tr("DirectDraw-Surface File (*.dds)"),
             'gif': self.tr("Graphic Interchange Format File (*.gif)"),
+            'icns': self.tr("Apple Icon File (*.icns)"),
             'ico': self.tr("Windows Icon File (*.ico)"),
+            'jp2': self.tr("JPEG2000 File (*.jp2)"),
             'jpg': self.tr("JPEG File (*.jpg)"),
             'jpeg': self.tr("JPEG File (*.jpeg)"),
             'mng': self.tr("Multiple-Image Network Graphics File (*.mng)"),
@@ -141,6 +146,7 @@ class IconEditorWindow(E5MainWindow):
             'tif': self.tr("TIFF File (*.tif)"),
             'tiff': self.tr("TIFF File (*.tiff)"),
             'wbmp': self.tr("WAP Bitmap File (*.wbmp)"),
+            'webp': self.tr("WebP Image File (*.webp)"),
             'xbm': self.tr("X11 Bitmap File (*.xbm)"),
             'xpm': self.tr("X11 Pixmap File (*.xpm)"),
         }
@@ -1347,7 +1353,7 @@ class IconEditorWindow(E5MainWindow):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 delta = evt.angleDelta().y()
             else:
                 delta = evt.delta()
@@ -1382,8 +1388,9 @@ class IconEditorWindow(E5MainWindow):
         pinch = evt.gesture(Qt.PinchGesture)
         if pinch:
             if pinch.state() == Qt.GestureStarted:
-                pinch.setScaleFactor(self.__editor.zoomFactor() / 100.0)
-            else:
-                self.__editor.setZoomFactor(int(pinch.scaleFactor() * 100))
+                pinch.setTotalScaleFactor(self.__editor.zoomFactor() / 100.0)
+            elif pinch.state() == Qt.GestureUpdated:
+                self.__editor.setZoomFactor(
+                    int(pinch.totalScaleFactor() * 100))
                 self.__updateZoom()
             evt.accept()
