@@ -1,36 +1,50 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the multi project browser.
 """
 
-from PyQt4.QtCore import Qt
-from PyQt4.QtGui import QListWidget, QListWidgetItem, QDialog, QMenu
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import Qt
+from PyQt5.QtWidgets import QTreeWidget, QTreeWidgetItem, QDialog, QMenu
 
 from E5Gui.E5Application import e5App
 
 import UI.PixmapCache
 
 
-class MultiProjectBrowser(QListWidget):
+class MultiProjectBrowser(QTreeWidget):
     """
     Class implementing the multi project browser.
     """
-    def __init__(self, multiProject, parent=None):
+    ProjectFileNameRole = Qt.UserRole
+    ProjectUidRole = Qt.UserRole + 1
+    
+    def __init__(self, multiProject, project, parent=None):
         """
         Constructor
         
         @param multiProject reference to the multi project object
-        @param parent parent widget (QWidget)
+        @type MultiProject
+        @param project reference to the project object
+        @type Project
+        @param parent parent widget
+        @type QWidget
         """
-        super().__init__(parent)
+        super(MultiProjectBrowser, self).__init__(parent)
         self.multiProject = multiProject
+        self.project = project
         
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
         self.setAlternatingRowColors(True)
+        self.setHeaderHidden(True)
+        self.setItemsExpandable(False)
+        self.setRootIsDecorated(False)
+        self.setSortingEnabled(True)
         
         self.__openingProject = False
         
@@ -46,13 +60,16 @@ class MultiProjectBrowser(QListWidget):
             self.__projectAdded)
         self.multiProject.projectRemoved.connect(
             self.__projectRemoved)
-        self.multiProject.projectOpened.connect(
-            self.__projectOpened)
+        
+        self.project.projectOpened.connect(self.__projectOpened)
+        self.project.projectClosed.connect(self.__projectClosed)
         
         self.__createPopupMenu()
         self.setContextMenuPolicy(Qt.CustomContextMenu)
         self.customContextMenuRequested.connect(self.__contextMenuRequested)
         self.itemActivated.connect(self.__openItem)
+        
+        self.setEnabled(False)
     
     ###########################################################################
     ## Slot handling methods below
@@ -63,6 +80,7 @@ class MultiProjectBrowser(QListWidget):
         Private slot to handle the creation of a new multi project.
         """
         self.clear()
+        self.setEnabled(True)
     
     def __multiProjectOpened(self):
         """
@@ -71,13 +89,16 @@ class MultiProjectBrowser(QListWidget):
         for project in self.multiProject.getProjects():
             self.__addProject(project)
         
-        self.sortItems()
+        self.sortItems(0, Qt.AscendingOrder)
+        
+        self.setEnabled(True)
     
     def __multiProjectClosed(self):
         """
         Private slot to handle the closing of a multi project.
         """
         self.clear()
+        self.setEnabled(False)
     
     def __projectAdded(self, project):
         """
@@ -86,7 +107,7 @@ class MultiProjectBrowser(QListWidget):
         @param project reference to the project data dictionary
         """
         self.__addProject(project)
-        self.sortItems()
+        self.sortItems(0, Qt.AscendingOrder)
     
     def __projectRemoved(self, project):
         """
@@ -94,10 +115,15 @@ class MultiProjectBrowser(QListWidget):
         
         @param project reference to the project data dictionary
         """
-        row = self.__findProjectItem(project)
-        if row > -1:
-            itm = self.takeItem(row)
+        itm = self.__findProjectItem(project)
+        if itm:
+            parent = itm.parent()
+            parent.removeChild(itm)
             del itm
+            if parent.childCount() == 0:
+                top = self.takeTopLevelItem(self.indexOfTopLevelItem(parent))
+                # __IGNORE_WARNING__
+                del top
     
     def __projectDataChanged(self, project):
         """
@@ -105,27 +131,47 @@ class MultiProjectBrowser(QListWidget):
         
         @param project reference to the project data dictionary
         """
-        row = self.__findProjectItem(project)
-        if row > -1:
-            self.__setItemData(self.item(row), project)
+        itm = self.__findProjectItem(project)
+        if itm:
+            parent = itm.parent()
+            if parent.text(0) != project["category"]:
+                self.__projectRemoved(project)
+                self.__addProject(project)
+            else:
+                self.__setItemData(itm, project)
             
-            self.sortItems()
+        self.sortItems(0, Qt.AscendingOrder)
     
-    def __projectOpened(self, projectfile):
+    def __projectOpened(self):
         """
         Private slot to handle the opening of a project.
-        
-        @param projectfile file name of the opened project file (string)
         """
+        projectfile = self.project.getProjectFile()
         project = {
             'name': "",
             'file': projectfile,
             'master': False,
             'description': "",
+            'category': "",
+            'uid': "",
         }
-        row = self.__findProjectItem(project)
-        if row > -1:
-            self.item(row).setSelected(True)
+        itm = self.__findProjectItem(project)
+        if itm:
+            font = itm.font(0)
+            font.setBold(True)
+            itm.setFont(0, font)
+    
+    def __projectClosed(self):
+        """
+        Private slot to handle the closing of a project.
+        """
+        for topIndex in range(self.topLevelItemCount()):
+            topItem = self.topLevelItem(topIndex)
+            for childIndex in range(topItem.childCount()):
+                childItem = topItem.child(childIndex)
+                font = childItem.font(0)
+                font.setBold(False)
+                childItem.setFont(0, font)
     
     def __contextMenuRequested(self, coord):
         """
@@ -134,7 +180,7 @@ class MultiProjectBrowser(QListWidget):
         @param coord the position of the mouse pointer (QPoint)
         """
         itm = self.itemAt(coord)
-        if itm is None:
+        if itm is None or itm.parent() is None:
             self.__backMenu.popup(self.mapToGlobal(coord))
         else:
             self.__menu.popup(self.mapToGlobal(coord))
@@ -143,15 +189,15 @@ class MultiProjectBrowser(QListWidget):
         """
         Private slot to open a project.
         
-        @param itm reference to the project item to be opened (QListWidgetItem)
+        @param itm reference to the project item to be opened (QTreeWidgetItem)
         """
         if itm is None:
             itm = self.currentItem()
-            if itm is None:
+            if itm is None or itm.parent() is None:
                 return
         
         if not self.__openingProject:
-            filename = itm.data(Qt.UserRole)
+            filename = itm.data(0, MultiProjectBrowser.ProjectFileNameRole)
             if filename:
                 self.__openingProject = True
                 self.multiProject.openProject(filename)
@@ -161,76 +207,114 @@ class MultiProjectBrowser(QListWidget):
     ## Private methods below
     ###########################################################################
     
+    def __findCategoryItem(self, category):
+        """
+        Private method to find the item for a category.
+        
+        @param category category to search for (string)
+        @return reference to the category item or None, if there is
+            no such item (QTreeWidgetItem or None)
+        """
+        if category == "":
+            category = self.tr("Not categorized")
+        for index in range(self.topLevelItemCount()):
+            itm = self.topLevelItem(index)
+            if itm.text(0) == category:
+                return itm
+        
+        return None
+    
     def __addProject(self, project):
         """
         Private method to add a project to the list.
         
         @param project reference to the project data dictionary
         """
-        itm = QListWidgetItem(self)
+        parent = self.__findCategoryItem(project['category'])
+        if parent is None:
+            if project['category']:
+                parent = QTreeWidgetItem(self, [project['category']])
+            else:
+                parent = QTreeWidgetItem(self, [self.tr("Not categorized")])
+            parent.setExpanded(True)
+        itm = QTreeWidgetItem(parent)
         self.__setItemData(itm, project)
     
     def __setItemData(self, itm, project):
         """
         Private method to set the data of a project item.
         
-        @param itm reference to the item to be set (QListWidgetItem)
+        @param itm reference to the item to be set (QTreeWidgetItem)
         @param project reference to the project data dictionary
         """
-        itm.setText(project['name'])
+        itm.setText(0, project['name'])
         if project['master']:
-            itm.setIcon(UI.PixmapCache.getIcon("masterProject.png"))
+            itm.setIcon(0, UI.PixmapCache.getIcon("masterProject.png"))
         else:
-            itm.setIcon(UI.PixmapCache.getIcon("empty.png"))
-        itm.setToolTip(project['file'])
-        itm.setData(Qt.UserRole, project['file'])
+            itm.setIcon(0, UI.PixmapCache.getIcon("empty.png"))
+        itm.setToolTip(0, project['file'])
+        itm.setData(0, MultiProjectBrowser.ProjectFileNameRole,
+                    project['file'])
+        itm.setData(0, MultiProjectBrowser.ProjectUidRole, project['uid'])
     
     def __findProjectItem(self, project):
         """
         Private method to search a specific project item.
         
         @param project reference to the project data dictionary
-        @return row number of the project, -1 if not found (integer)
+        @return reference to the item (QTreeWidgetItem) or None
         """
-        row = 0
-        while row < self.count():
-            itm = self.item(row)
-            data = itm.data(Qt.UserRole)
-            if data == project['file']:
-                return row
-            row += 1
+        if project["uid"]:
+            compareData = project["uid"]
+            compareRole = MultiProjectBrowser.ProjectUidRole
+        else:
+            compareData = project["file"]
+            compareRole = MultiProjectBrowser.ProjectFileNameRole
         
-        return -1
+        for topIndex in range(self.topLevelItemCount()):
+            topItm = self.topLevelItem(topIndex)
+            for childIndex in range(topItm.childCount()):
+                itm = topItm.child(childIndex)
+                data = itm.data(0, compareRole)
+                if data == compareData:
+                    return itm
+        
+        return None
     
     def __removeProject(self):
         """
         Private method to handle the Remove context menu entry.
         """
         itm = self.currentItem()
-        if itm is not None:
-            filename = itm.data(Qt.UserRole)
-            if filename:
-                self.multiProject.removeProject(filename)
+        if itm is not None and itm.parent() is not None:
+            uid = itm.data(0, MultiProjectBrowser.ProjectUidRole)
+            if uid:
+                self.multiProject.removeProject(uid)
     
     def __showProjectProperties(self):
         """
         Private method to show the data of a project entry.
         """
         itm = self.currentItem()
-        if itm is not None:
-            filename = itm.data(Qt.UserRole)
-            if filename:
-                project = self.multiProject.getProject(filename)
+        if itm is not None and itm.parent() is not None:
+            uid = itm.data(0, MultiProjectBrowser.ProjectUidRole)
+            if uid:
+                project = self.multiProject.getProject(uid)
                 if project is not None:
                     from .AddProjectDialog import AddProjectDialog
-                    dlg = AddProjectDialog(self, project=project)
+                    dlg = AddProjectDialog(
+                        self, project=project,
+                        categories=self.multiProject.getCategories())
                     if dlg.exec_() == QDialog.Accepted:
-                        name, filename, isMaster, description = dlg.getData()
+                        (name, filename, isMaster, description, category,
+                         uid) = dlg.getData()
                         project = {
                             'name': name,
                             'file': filename,
                             'master': isMaster,
                             'description': description,
+                            'category': category,
+                            'uid': uid,
                         }
                         self.multiProject.changeProjectProperties(project)
     
@@ -238,28 +322,28 @@ class MultiProjectBrowser(QListWidget):
         """
         Private method to add a new project entry.
         """
-        self.multiProject.addProject()
+        self.multiProject.addNewProject()
     
     def __createPopupMenu(self):
         """
         Private method to create the popup menu.
         """
         self.__menu = QMenu(self)
-        self.__menu.addAction(self.trUtf8("Open"), self.__openItem)
-        self.__menu.addAction(self.trUtf8("Remove"), self.__removeProject)
-        self.__menu.addAction(self.trUtf8("Properties"),
+        self.__menu.addAction(self.tr("Open"), self.__openItem)
+        self.__menu.addAction(self.tr("Remove"), self.__removeProject)
+        self.__menu.addAction(self.tr("Properties"),
                               self.__showProjectProperties)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8("Add Project..."),
+        self.__menu.addAction(self.tr("Add Project..."),
                               self.__addNewProject)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.__menu.addAction(self.tr("Configure..."), self.__configure)
         
         self.__backMenu = QMenu(self)
-        self.__backMenu.addAction(self.trUtf8("Add Project..."),
+        self.__backMenu.addAction(self.tr("Add Project..."),
                                   self.__addNewProject)
         self.__backMenu.addSeparator()
-        self.__backMenu.addAction(self.trUtf8("Configure..."),
+        self.__backMenu.addAction(self.tr("Configure..."),
                                   self.__configure)
     
     def __configure(self):
