@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -21,6 +21,7 @@ from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
     QNetworkReply
 
 from E5Gui import E5MessageBox
+from E5Gui.E5Application import e5App
 
 from E5Network.E5NetworkProxyFactory import proxyAuthenticationRequired
 try:
@@ -81,6 +82,8 @@ class PluginManager(QObject):
         @keyparam develPlugin filename of a plugin to be loaded for
             development (string)
         @exception PluginPathError raised to indicate an invalid plug-in path
+        @exception PluginModulesError raised to indicate the absence of
+            plug-in modules
         """
         super(PluginManager, self).__init__(parent)
         
@@ -142,6 +145,12 @@ class PluginManager(QObject):
             self.__sslErrorHandler = E5SslErrorHandler(self)
             self.__networkManager.sslErrors.connect(self.__sslErrors)
         self.__replies = []
+        
+        try:
+            self.__ui.onlineStateChanged.connect(self.__onlineStateChanged)
+        except AttributeError:
+            # it was not called from eric
+            pass
     
     def finalizeSetup(self):
         """
@@ -189,33 +198,29 @@ class PluginManager(QObject):
                         self.tr("Could not create a package for {0}.")
                             .format(self.__develPluginFile))
         
-        if Preferences.getPluginManager("ActivateExternal"):
-            fname = os.path.join(self.pluginDirs["user"], "__init__.py")
-            if not os.path.exists(fname):
-                if not os.path.exists(self.pluginDirs["user"]):
-                    os.mkdir(self.pluginDirs["user"], 0o755)
-                try:
-                    f = open(fname, "w")
-                    f.close()
-                except IOError:
-                    del self.pluginDirs["user"]
-            
-            if not os.path.exists(self.pluginDirs["global"]) and \
-               os.access(Utilities.getPythonModulesDirectory(), os.W_OK):
-                # create the global plugins directory
-                os.mkdir(self.pluginDirs["global"], 0o755)
-                fname = os.path.join(self.pluginDirs["global"], "__init__.py")
-                f = open(fname, "w", encoding="utf-8")
-                f.write('# -*- coding: utf-8 -*-' + "\n")
-                f.write("\n")
-                f.write('"""' + "\n")
-                f.write('Package containing the global plugins.' + "\n")
-                f.write('"""' + "\n")
+        fname = os.path.join(self.pluginDirs["user"], "__init__.py")
+        if not os.path.exists(fname):
+            if not os.path.exists(self.pluginDirs["user"]):
+                os.mkdir(self.pluginDirs["user"], 0o755)
+            try:
+                f = open(fname, "w")
                 f.close()
-            if not os.path.exists(self.pluginDirs["global"]):
-                del self.pluginDirs["global"]
-        else:
-            del self.pluginDirs["user"]
+            except IOError:
+                del self.pluginDirs["user"]
+        
+        if not os.path.exists(self.pluginDirs["global"]) and \
+           os.access(Utilities.getPythonModulesDirectory(), os.W_OK):
+            # create the global plugins directory
+            os.mkdir(self.pluginDirs["global"], 0o755)
+            fname = os.path.join(self.pluginDirs["global"], "__init__.py")
+            f = open(fname, "w", encoding="utf-8")
+            f.write('# -*- coding: utf-8 -*-' + "\n")
+            f.write("\n")
+            f.write('"""' + "\n")
+            f.write('Package containing the global plugins.' + "\n")
+            f.write('"""' + "\n")
+            f.close()
+        if not os.path.exists(self.pluginDirs["global"]):
             del self.pluginDirs["global"]
         
         if not os.path.exists(self.pluginDirs["eric6"]):
@@ -239,12 +244,13 @@ class PluginManager(QObject):
         
         self.__foundCoreModules = self.getPluginModules(
             self.pluginDirs["eric6"])
-        if "global" in self.pluginDirs:
-            self.__foundGlobalModules = \
-                self.getPluginModules(self.pluginDirs["global"])
-        if "user" in self.pluginDirs:
-            self.__foundUserModules = \
-                self.getPluginModules(self.pluginDirs["user"])
+        if Preferences.getPluginManager("ActivateExternal"):
+            if "global" in self.pluginDirs:
+                self.__foundGlobalModules = \
+                    self.getPluginModules(self.pluginDirs["global"])
+            if "user" in self.pluginDirs:
+                self.__foundUserModules = \
+                    self.getPluginModules(self.pluginDirs["user"])
         
         return len(self.__foundCoreModules + self.__foundGlobalModules +
                    self.__foundUserModules) > 0
@@ -333,6 +339,8 @@ class PluginManager(QObject):
         @param reload_ flag indicating to reload the module (boolean)
         @exception PluginLoadError raised to indicate an issue loading
             the plug-in
+        @exception PluginPy2IncompatibleError raised to indicate the Python 2
+            incompatibility of a plug-in
         """
         try:
             fname = "{0}.py".format(os.path.join(directory, name))
@@ -374,6 +382,13 @@ class PluginManager(QObject):
             self.__modulesCount += 1
             if reload_:
                 imp.reload(module)
+                self.initOnDemandPlugin(name)
+                try:
+                    pluginObject = self.__onDemandInactivePlugins[name]
+                    pluginObject.initToolbar(
+                        self.__ui, e5App().getObject("ToolbarManager"))
+                except (KeyError, AttributeError):
+                    pass
         except PluginLoadError:
             print("Error loading plug-in module:", name)
         except PluginPy2IncompatibleError:
@@ -403,12 +418,22 @@ class PluginManager(QObject):
         
         if name in self.__inactiveModules:
             try:
+                pluginObject = self.__inactivePlugins[name]
+                try:
+                    pluginObject.prepareUnload()
+                except AttributeError:
+                    pass
                 del self.__inactivePlugins[name]
             except KeyError:
                 pass
             del self.__inactiveModules[name]
         elif name in self.__onDemandInactiveModules:
             try:
+                pluginObject = self.__onDemandInactivePlugins[name]
+                try:
+                    pluginObject.prepareUnload()
+                except AttributeError:
+                    pass
                 del self.__onDemandInactivePlugins[name]
             except KeyError:
                 pass
@@ -483,6 +508,21 @@ class PluginManager(QObject):
         except PluginActivationError:
             return
     
+    def initPluginToolbars(self, toolbarManager):
+        """
+        Public method to initialize plug-in toolbars.
+        
+        @param toolbarManager reference to the toolbar manager object
+            (E5ToolBarManager)
+        """
+        self.initOnDemandPlugins()
+        for pluginObject in self.__onDemandInactivePlugins.values():
+            try:
+                pluginObject.initToolbar(self.__ui, toolbarManager)
+            except AttributeError:
+                # ignore it
+                pass
+    
     def activatePlugins(self):
         """
         Public method to activate all plugins having the "autoactivate"
@@ -771,6 +811,9 @@ class PluginManager(QObject):
             module = self.__failedModules[name]
             autoactivate = False
             active = False
+        elif "_" in name:
+            # try stripping of a postfix
+            return self.getPluginDetails(name.rsplit("_", 1)[0])
         else:
             # should not happen
             return None
@@ -864,6 +907,23 @@ class PluginManager(QObject):
         
         return apis
         
+    def getPluginQtHelpFiles(self):
+        """
+        Public method to get the list of QtHelp documentation files provided
+        by a plug-in.
+        
+        @return dictionary with documentation type as key and list of files
+            as value
+        @rtype dict (key: str, value: list of str)
+        """
+        helpFiles = {}
+        for module in list(self.__activeModules.values()) + \
+                list(self.__onDemandActiveModules.values()):
+            if hasattr(module, "helpFiles"):
+                helpFiles.update(module.helpFiles())
+        
+        return helpFiles
+        
     def getPluginExeDisplayData(self):
         """
         Public method to get data to display information about a plugins
@@ -978,7 +1038,7 @@ class PluginManager(QObject):
             pluginName in self.__onDemandActiveModules
     
     ###########################################################################
-    ## Specialized plugin module handling methods below
+    ## Specialized plug-in module handling methods below
     ###########################################################################
     
     ###########################################################################
@@ -1022,7 +1082,7 @@ class PluginManager(QObject):
                 self.deactivatePlugin(name, True)
     
     ########################################################################
-    ## Methods creation of the plug-ins download directory
+    ## Methods for the creation of the plug-ins download directory
     ########################################################################
     
     def __checkPluginsDownloadDirectory(self):
@@ -1067,12 +1127,22 @@ class PluginManager(QObject):
     ## Methods for automatic plug-in update check below
     ########################################################################
     
+    def __onlineStateChanged(self, online):
+        """
+        Private slot handling changes in online state.
+        
+        @param online flag indicating the online state
+        @type bool
+        """
+        if online:
+            self.checkPluginUpdatesAvailable()
+    
     def checkPluginUpdatesAvailable(self):
         """
         Public method to check the availability of updates of plug-ins.
         """
         period = Preferences.getPluginManager("UpdatesCheckInterval")
-        if period == 0:
+        if period == 0 or not self.__ui.isOnline():
             return
         elif period in [1, 2, 3]:
             lastModified = QFileInfo(self.pluginRepositoryFile).lastModified()
@@ -1118,6 +1188,7 @@ class PluginManager(QObject):
                 ).format(Preferences.getUI("PluginRepositoryUrl6"),
                          reply.errorString())
             )
+            reply.deleteLater()
             return
         
         ioDevice = QFile(self.pluginRepositoryFile + ".tmp")
@@ -1127,6 +1198,7 @@ class PluginManager(QObject):
         if QFile.exists(self.pluginRepositoryFile):
             QFile.remove(self.pluginRepositoryFile)
         ioDevice.rename(self.pluginRepositoryFile)
+        reply.deleteLater()
         
         if os.path.exists(self.pluginRepositoryFile):
             f = QFile(self.pluginRepositoryFile)
@@ -1186,7 +1258,13 @@ class PluginManager(QObject):
                 self.__updateAvailable = True
             return
         
-        if pluginDetails["version"] < version:
+        if version.count(".") >= 3:
+            # cope for extended version numbers by ignoring
+            # the extension
+            checkVersion = ".".join(version.split(".", 3)[:3])
+        else:
+            checkVersion = version
+        if pluginDetails["version"] < checkVersion:
             self.__updateAvailable = True
             return
         
@@ -1203,12 +1281,12 @@ class PluginManager(QObject):
                 return
             
             # 3. Check the version of the archive file
-            zip = zipfile.ZipFile(archive, "r")
+            zipFile = zipfile.ZipFile(archive, "r")
             try:
-                aversion = zip.read("VERSION").decode("utf-8")
+                aversion = zipFile.read("VERSION").decode("utf-8")
             except KeyError:
                 aversion = ""
-            zip.close()
+            zipFile.close()
             
             if aversion != version:
                 self.__updateAvailable = True
@@ -1223,3 +1301,29 @@ class PluginManager(QObject):
         ignored = self.__sslErrorHandler.sslErrorsReply(reply, errors)[0]
         if ignored == E5SslErrorHandler.NotIgnored:
             self.__downloadCancelled = True
+    
+    ########################################################################
+    ## Methods to clear private data of plug-ins below
+    ########################################################################
+    
+    def clearPluginsPrivateData(self, type_):
+        """
+        Public method to clear the private data of plug-ins of a specified
+        type.
+        
+        Plugins supporting this functionality must support the module function
+        clearPrivateData() and have the module level attribute pluginType.
+        
+        @param type_ type of the plugin to clear private data for (string)
+        """
+        for name, module in \
+            list(self.__onDemandActiveModules.items()) + \
+            list(self.__onDemandInactiveModules.items()) + \
+            list(self.__activeModules.items()) + \
+                list(self.__inactiveModules.items()):
+            if getattr(module, "pluginType", "") == type_:
+                if hasattr(module, "clearPrivateData"):
+                    module.clearPrivateData()
+
+#
+# eflag: noqa = M801
