@@ -14,9 +14,10 @@ import sys
 import os
 import zipfile
 import glob
+import re
 
 from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QFile, QIODevice, QUrl, \
-    QProcess, QPoint
+    QProcess, QPoint, QCoreApplication
 from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QAbstractButton, \
     QTreeWidgetItem, QDialog, QVBoxLayout, QMenu
 from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
@@ -390,6 +391,10 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__unstableItem = None
         self.__unknownItem = None
         
+        self.__newItems = 0
+        self.__updateLocalItems = 0
+        self.__updateRemoteItems = 0
+        
         self.downloadProgress.setValue(0)
         self.__doneMethod = None
         
@@ -429,6 +434,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                     "No plugin repository file available.\nSelect Update.")
                  ])
             self.repositoryList.resizeColumnToContents(1)
+        
+        self.newLabel.setText(self.tr("New: <b>{0}</b>")
+                              .format(self.__newItems))
+        self.updateLocalLabel.setText(self.tr("Local Updates: <b>{0}</b>")
+                                      .format(self.__updateLocalItems))
+        self.updateRemoteLabel.setText(self.tr("Remote Updates: <b>{0}</b>")
+                                       .format(self.__updateRemoteItems))
     
     def __downloadFile(self, url, filename, doneMethod=None):
         """
@@ -471,12 +483,11 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
     def __downloadFileDone(self):
         """
         Private method called, after the file has been downloaded
-        from the internet.
+        from the Internet.
         """
         self.__updateButton.setEnabled(True)
         self.__downloadCancelButton.setEnabled(False)
-        self.__onlineStateChanged(
-            self.__isOnline())
+        self.__onlineStateChanged(self.__isOnline())
         
         ok = True
         reply = self.sender()
@@ -510,7 +521,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             return
         
         self.__downloadIODevice.open(QIODevice.WriteOnly)
-        self.__downloadIODevice.write(reply.readAll())
+        # read data in chunks
+        chunkSize = 64 * 1024 * 1024
+        while True:
+            data = reply.read(chunkSize)
+            if data is None or len(data) == 0:
+                break
+            self.__downloadIODevice.write(data)
         self.__downloadIODevice.close()
         if QFile.exists(self.__downloadFileName):
             QFile.remove(self.__downloadFileName)
@@ -596,16 +613,19 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         elif updateStatus == PluginRepositoryWidget.PluginStatusNew:
             itm.setIcon(1, UI.PixmapCache.getIcon("download.png"))
             itm.setToolTip(1, self.tr("new download available"))
+            self.__newItems += 1
         elif updateStatus == PluginRepositoryWidget.PluginStatusLocalUpdate:
             itm.setIcon(1, UI.PixmapCache.getIcon("updateLocal.png"))
             itm.setToolTip(1, self.tr("update installable"))
+            self.__updateLocalItems += 1
         elif updateStatus == PluginRepositoryWidget.PluginStatusRemoteUpdate:
             itm.setIcon(1, UI.PixmapCache.getIcon("updateRemote.png"))
             itm.setToolTip(1, self.tr("updated download available"))
+            self.__updateRemoteItems += 1
     
     def __updateStatus(self, filename, version):
         """
-        Private method to check, if the given archive update status.
+        Private method to check the given archive update status.
         
         @param filename data for the filename field (string)
         @param version data for the version field (string)
@@ -630,12 +650,12 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         if not zipfile.is_zipfile(archive):
             return PluginRepositoryWidget.PluginStatusRemoteUpdate
         
-        zip = zipfile.ZipFile(archive, "r")
+        zipFile = zipfile.ZipFile(archive, "r")
         try:
-            aversion = zip.read("VERSION").decode("utf-8")
+            aversion = zipFile.read("VERSION").decode("utf-8")
         except KeyError:
             aversion = ""
-        zip.close()
+        zipFile.close()
         
         if aversion == version:
             if not self.__external:
@@ -648,7 +668,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                 if version.count(".") >= 3:
                     # cope for extended version numbers by ignoring
                     # the extension
-                    version = ".".join(version.split(".",3)[:3])
+                    version = ".".join(version.split(".", 3)[:3])
                 if pluginDetails["version"] < version:
                     return PluginRepositoryWidget.PluginStatusLocalUpdate
             
@@ -749,39 +769,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         Private slot to cleanup the plug-in downloads area.
         """
-        downloadPath = Preferences.getPluginManager("DownloadPath")
-        downloads = {}  # plug-in name as key, file name as value
-        
-        # step 1: extract plug-ins and downloaded files
-        for pluginFile in os.listdir(downloadPath):
-            if not os.path.isfile(os.path.join(downloadPath, pluginFile)):
-                continue
-            
-            pluginName = pluginFile.rsplit("-", 1)[0]
-            if pluginName not in downloads:
-                downloads[pluginName] = []
-            downloads[pluginName].append(pluginFile)
-        
-        # step 2: delete old entries
-        for pluginName in downloads:
-            downloads[pluginName].sort()
-        
-            if pluginName in self.__hiddenPlugins and \
-                    not Preferences.getPluginManager("KeepHidden"):
-                removeFiles = downloads[pluginName]
-            else:
-                removeFiles = downloads[pluginName][
-                    :-Preferences.getPluginManager("KeepGenerations")]
-            for removeFile in removeFiles:
-                try:
-                    os.remove(os.path.join(downloadPath, removeFile))
-                except (IOError, OSError) as err:
-                    E5MessageBox.critical(
-                        self,
-                        self.tr("Cleanup of Plugin Downloads"),
-                        self.tr("""<p>The plugin download <b>{0}</b> could"""
-                                """ not be deleted.</p><p>Reason: {1}</p>""")
-                        .format(removeFile, str(err)))
+        PluginRepositoryDownloadCleanup()
 
 
 class PluginRepositoryDialog(QDialog):
@@ -873,3 +861,60 @@ class PluginRepositoryWindow(E5MainWindow):
                 self.tr('OK'))
         
         self.close()
+
+
+def PluginRepositoryDownloadCleanup(quiet=False):
+    """
+    Module function to clean up the plug-in downloads area.
+    
+    @param quiet flag indicating quiet operations
+    @type bool
+    """
+    downloadPath = Preferences.getPluginManager("DownloadPath")
+    downloads = {}  # plug-in name as key, file name as value
+    
+    # step 1: extract plug-ins and downloaded files
+    for pluginFile in os.listdir(downloadPath):
+        if not os.path.isfile(os.path.join(downloadPath, pluginFile)):
+            continue
+        
+        pluginName, pluginVersion = \
+            pluginFile.replace(".zip", "").rsplit("-", 1)
+        pluginVersionList = re.split("[._-]", pluginVersion)
+        for index in range(len(pluginVersionList)):
+            try:
+                pluginVersionList[index] = int(pluginVersionList[index])
+            except ValueError:
+                # use default of 0
+                pluginVersionList[index] = 0
+        
+        if pluginName not in downloads:
+            downloads[pluginName] = []
+        downloads[pluginName].append((pluginFile, tuple(pluginVersionList)))
+    
+    # step 2: delete old entries
+    hiddenPlugins = Preferences.getPluginManager("HiddenPlugins")
+    for pluginName in downloads:
+        downloads[pluginName].sort(key=lambda x: x[1])
+    
+        if pluginName in hiddenPlugins and \
+                not Preferences.getPluginManager("KeepHidden"):
+            removeFiles = downloads[pluginName][0]
+        else:
+            removeFiles = [f[0] for f in downloads[pluginName][
+                :-Preferences.getPluginManager("KeepGenerations")]]
+        for removeFile in removeFiles:
+            try:
+                os.remove(os.path.join(downloadPath, removeFile))
+            except (IOError, OSError) as err:
+                if not quiet:
+                    E5MessageBox.critical(
+                        None,
+                        QCoreApplication.translate(
+                            "PluginRepositoryWidget",
+                            "Cleanup of Plugin Downloads"),
+                        QCoreApplication.translate(
+                            "PluginRepositoryWidget",
+                            """<p>The plugin download <b>{0}</b> could"""
+                            """ not be deleted.</p><p>Reason: {1}</p>""")
+                        .format(removeFile, str(err)))
