@@ -15,7 +15,7 @@ import fnmatch
 from PyQt5.QtCore import pyqtSlot, Qt, QTimer
 from PyQt5.QtGui import QIcon
 from PyQt5.QtWidgets import QDialog, QTreeWidgetItem, QAbstractButton, \
-    QDialogButtonBox, QApplication, QHeaderView
+    QDialogButtonBox, QApplication, QHeaderView, QListWidgetItem
 
 from E5Gui.E5Application import e5App
 
@@ -65,6 +65,8 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.setupUi(self)
         self.setWindowFlags(Qt.Window)
         
+        self.optionsTabWidget.setCurrentIndex(0)
+        
         self.excludeMessagesSelectButton.setIcon(
             UI.PixmapCache.getIcon("select.png"))
         self.includeMessagesSelectButton.setIcon(
@@ -77,7 +79,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.docTypeComboBox.addItem(self.tr("PEP-257"), "pep257")
         self.docTypeComboBox.addItem(self.tr("Eric"), "eric")
         
-        self.futuresList.addItems(self.availableFutures)
+        for future in CodeStyleCheckerDialog.availableFutures:
+            itm = QListWidgetItem(future, self.futuresList)
+            itm.setFlags(itm.flags() | Qt.ItemIsUserCheckable)
+            itm.setCheckState(Qt.Unchecked)
         
         self.statisticsButton = self.buttonBox.addButton(
             self.tr("Statistics..."), QDialogButtonBox.ActionRole)
@@ -95,6 +100,9 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.resultList.headerItem().setText(self.resultList.columnCount(), "")
         self.resultList.header().setSortIndicator(0, Qt.AscendingOrder)
         
+        self.addBuiltinButton.setIcon(UI.PixmapCache.getIcon("plus.png"))
+        self.deleteBuiltinButton.setIcon(UI.PixmapCache.getIcon("minus.png"))
+        
         self.checkProgress.setVisible(False)
         self.checkProgressLabel.setVisible(False)
         self.checkProgressLabel.setMaximumWidth(600)
@@ -317,6 +325,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             self.__data["ShowIgnored"] = False
         if "MaxCodeComplexity" not in self.__data:
             self.__data["MaxCodeComplexity"] = 10
+        if "LineComplexity" not in self.__data:
+            self.__data["LineComplexity"] = 15
+        if "LineComplexityScore" not in self.__data:
+            self.__data["LineComplexityScore"] = 10
         if "ValidEncodings" not in self.__data:
             self.__data["ValidEncodings"] = "latin-1, utf-8"
         if "CopyrightMinFileSize" not in self.__data or \
@@ -325,6 +337,11 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             self.__data["CopyrightAuthor"] = ""
         if "FutureChecker" not in self.__data:
             self.__data["FutureChecker"] = ""
+        if "BuiltinsChecker" not in self.__data:
+            self.__data["BuiltinsChecker"] = {
+                "str": ["unicode", ],
+                "chr": ["unichr", ],
+            }
         
         self.excludeFilesEdit.setText(self.__data["ExcludeFiles"])
         self.excludeMessagesEdit.setText(self.__data["ExcludeMessages"])
@@ -339,11 +356,15 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.docTypeComboBox.setCurrentIndex(
             self.docTypeComboBox.findData(self.__data["DocstringType"]))
         self.complexitySpinBox.setValue(self.__data["MaxCodeComplexity"])
+        self.lineComplexitySpinBox.setValue(self.__data["LineComplexity"])
+        self.lineComplexityScoreSpinBox.setValue(
+            self.__data["LineComplexityScore"])
         self.encodingsEdit.setText(self.__data["ValidEncodings"])
         self.copyrightFileSizeSpinBox.setValue(
             self.__data["CopyrightMinFileSize"])
         self.copyrightAuthorEdit.setText(self.__data["CopyrightAuthor"])
         self.__initFuturesList(self.__data["FutureChecker"])
+        self.__initBuiltinsIgnoreList(self.__data["BuiltinsChecker"])
     
     def start(self, fn, save=False, repeat=None):
         """
@@ -392,10 +413,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             filterString = self.excludeFilesEdit.text()
             filterList = [f.strip() for f in filterString.split(",")
                           if f.strip()]
-            for filter in filterList:
+            for fileFilter in filterList:
                 self.files = \
                     [f for f in self.files
-                     if not fnmatch.fnmatch(f, filter.strip())]
+                     if not fnmatch.fnmatch(f, fileFilter.strip())]
 
         self.__errorItem = None
         self.__resetStatistics()
@@ -422,7 +443,11 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             hangClosing = self.hangClosingCheckBox.isChecked()
             docType = self.docTypeComboBox.itemData(
                 self.docTypeComboBox.currentIndex())
-            maxCodeComplexity = self.complexitySpinBox.value()
+            codeComplexityArgs = {
+                "McCabeComplexity": self.complexitySpinBox.value(),
+                "LineComplexity": self.lineComplexitySpinBox.value(),
+                "LineComplexityScore": self.lineComplexityScoreSpinBox.value(),
+            }
             miscellaneousArgs = {
                 "CodingChecker": self.encodingsEdit.text(),
                 "CopyrightChecker": {
@@ -430,11 +455,12 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                     "Author": self.copyrightAuthorEdit.text(),
                 },
                 "FutureChecker": self.__getSelectedFutureImports(),
+                "BuiltinsChecker": self.__getBuiltinsIgnoreList(),
             }
             
             self.__options = [excludeMessages, includeMessages, repeatMessages,
                               fixCodes, noFixCodes, fixIssues, maxLineLength,
-                              hangClosing, docType, maxCodeComplexity,
+                              hangClosing, docType, codeComplexityArgs,
                               miscellaneousArgs]
             
             # now go through all the files
@@ -751,10 +777,13 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 "DocstringType": self.docTypeComboBox.itemData(
                     self.docTypeComboBox.currentIndex()),
                 "MaxCodeComplexity": self.complexitySpinBox.value(),
+                "LineComplexity": self.lineComplexitySpinBox.value(),
+                "LineComplexityScore": self.lineComplexityScoreSpinBox.value(),
                 "ValidEncodings": self.encodingsEdit.text(),
                 "CopyrightMinFileSize": self.copyrightFileSizeSpinBox.value(),
                 "CopyrightAuthor": self.copyrightAuthorEdit.text(),
                 "FutureChecker": self.__getSelectedFutureImports(),
+                "BuiltinsChecker": self.__getBuiltinsIgnoreList(),
             }
             if data != self.__data:
                 self.__data = data
@@ -928,6 +957,12 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             Preferences.Prefs.settings.value("PEP8/DocstringType", "pep257")))
         self.complexitySpinBox.setValue(int(Preferences.Prefs.settings.value(
             "PEP8/MaxCodeComplexity", 10)))
+        self.lineComplexitySpinBox.setValue(
+            int(Preferences.Prefs.settings.value(
+                "PEP8/LineComplexity", 15)))
+        self.lineComplexityScoreSpinBox.setValue(
+            int(Preferences.Prefs.settings.value(
+                "PEP8/LineComplexityScore", 10)))
         self.encodingsEdit.setText(Preferences.Prefs.settings.value(
             "PEP8/ValidEncodings", "latin-1, utf-8"))
         self.copyrightFileSizeSpinBox.setValue(int(
@@ -936,6 +971,11 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             Preferences.Prefs.settings.value("PEP8/CopyrightAuthor", ""))
         self.__initFuturesList(
             Preferences.Prefs.settings.value("PEP8/FutureChecker", ""))
+        self.__initBuiltinsIgnoreList(Preferences.toDict(
+            Preferences.Prefs.settings.value("PEP8/BuiltinsChecker", {
+                "str": ["unicode", ],
+                "chr": ["unichr", ],
+            })))
     
     @pyqtSlot()
     def on_storeDefaultButton_clicked(self):
@@ -968,6 +1008,11 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 self.docTypeComboBox.currentIndex()))
         Preferences.Prefs.settings.setValue(
             "PEP8/MaxCodeComplexity", self.complexitySpinBox.value())
+        Preferences.Prefs.settings.setValue(
+            "PEP8/LineComplexity", self.lineComplexitySpinBox.value())
+        Preferences.Prefs.settings.setValue(
+            "PEP8/LineComplexityScore",
+            self.lineComplexityScoreSpinBox.value())
         Preferences.Prefs.settings.setValue(
             "PEP8/ValidEncodings", self.encodingsEdit.text())
         Preferences.Prefs.settings.setValue(
@@ -976,6 +1021,8 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             "PEP8/CopyrightAuthor", self.copyrightAuthorEdit.text())
         Preferences.Prefs.settings.setValue(
             "PEP8/FutureChecker", self.__getSelectedFutureImports())
+        Preferences.Prefs.settings.setValue(
+            "PEP8/BuiltinsChecker", self.__getBuiltinsIgnoreList())
     
     @pyqtSlot()
     def on_resetDefaultButton_clicked(self):
@@ -996,11 +1043,17 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         Preferences.Prefs.settings.setValue("PEP8/HangClosing", False)
         Preferences.Prefs.settings.setValue("PEP8/DocstringType", "pep257")
         Preferences.Prefs.settings.setValue("PEP8/MaxCodeComplexity", 10)
+        Preferences.Prefs.settings.setValue("PEP8/LineComplexity", 15)
+        Preferences.Prefs.settings.setValue("PEP8/LineComplexityScore", 10)
         Preferences.Prefs.settings.setValue(
             "PEP8/ValidEncodings", "latin-1, utf-8")
         Preferences.Prefs.settings.setValue("PEP8/CopyrightMinFileSize", 0)
         Preferences.Prefs.settings.setValue("PEP8/CopyrightAuthor", "")
         Preferences.Prefs.settings.setValue("PEP8/FutureChecker", "")
+        Preferences.Prefs.settings.setValue("PEP8/BuiltinsChecker", {
+            "str": ["unicode", ],
+            "chr": ["unichr", ],
+        })
     
     @pyqtSlot(QAbstractButton)
     def on_buttonBox_clicked(self, button):
@@ -1116,7 +1169,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             expectedImports = []
         for row in range(self.futuresList.count()):
             itm = self.futuresList.item(row)
-            itm.setSelected(itm.text() in expectedImports)
+            if itm.text() in expectedImports:
+                itm.setCheckState(Qt.Checked)
+            else:
+                itm.setCheckState(Qt.Unchecked)
     
     def __getSelectedFutureImports(self):
         """
@@ -1125,5 +1181,72 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         @return expected future imports as a comma separated string
         @rtype str
         """
-        selectedFutures = [i.text() for i in self.futuresList.selectedItems()]
+        selectedFutures = []
+        for row in range(self.futuresList.count()):
+            itm = self.futuresList.item(row)
+            if itm.checkState() == Qt.Checked:
+                selectedFutures.append(itm.text())
         return ", ".join(selectedFutures)
+    
+    def __initBuiltinsIgnoreList(self, builtinsIgnoreDict):
+        """
+        Private method to populate the list of shadowed builtins to be ignored.
+        
+        @param builtinsIgnoreDict dictionary containing the builtins
+            assignments to be ignored
+        @type dict of list of str
+        """
+        self.builtinsAssignmentList.clear()
+        for left, rightList in builtinsIgnoreDict.items():
+            for right in rightList:
+                QTreeWidgetItem(self.builtinsAssignmentList, [left, right])
+        
+        self.on_builtinsAssignmentList_itemSelectionChanged()
+    
+    def __getBuiltinsIgnoreList(self):
+        """
+        Private method to get a dictionary containing the builtins assignments
+        to be ignored.
+        
+        @return dictionary containing the builtins assignments to be ignored
+        @rtype dict of list of str
+        """
+        builtinsIgnoreDict = {}
+        for row in range(self.builtinsAssignmentList.topLevelItemCount()):
+            itm = self.builtinsAssignmentList.topLevelItem(row)
+            left, right = itm.text(0), itm.text(1)
+            if left not in builtinsIgnoreDict:
+                builtinsIgnoreDict[left] = []
+            builtinsIgnoreDict[left].append(right)
+        
+        return builtinsIgnoreDict
+    
+    @pyqtSlot()
+    def on_builtinsAssignmentList_itemSelectionChanged(self):
+        """
+        Private slot to react upon changes of the selected builtin assignments.
+        """
+        self.deleteBuiltinButton.setEnabled(
+            len(self.builtinsAssignmentList.selectedItems()) > 0)
+    
+    @pyqtSlot()
+    def on_addBuiltinButton_clicked(self):
+        """
+        Private slot to add a built-in assignment to be ignored.
+        """
+        from .CodeStyleAddBuiltinIgnoreDialog import \
+            CodeStyleAddBuiltinIgnoreDialog
+        dlg = CodeStyleAddBuiltinIgnoreDialog(self)
+        if dlg.exec_() == QDialog.Accepted:
+            left, right = dlg.getData()
+            QTreeWidgetItem(self.builtinsAssignmentList, [left, right])
+    
+    @pyqtSlot()
+    def on_deleteBuiltinButton_clicked(self):
+        """
+        Private slot to delete the selected items from the list.
+        """
+        for itm in self.builtinsAssignmentList.selectedItems():
+            index = self.builtinsAssignmentList.indexOfTopLevelItem(itm)
+            self.builtinsAssignmentList.takeTopLevelItem(index)
+            del itm
