@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -84,7 +84,7 @@ class CodeStyleStatisticsDialog(QDialog, Ui_CodeStyleStatisticsDialog):
         itm.setData(0, Qt.DisplayRole, count)
         itm.setData(1, Qt.DisplayRole, code)
         itm.setData(2, Qt.DisplayRole, message)
-        if code.startswith("W"):
+        if code.startswith(("W", "C", "M")):
             itm.setIcon(1, UI.PixmapCache.getIcon("warning.png"))
         elif code.startswith("E"):
             itm.setIcon(1, UI.PixmapCache.getIcon("syntaxError.png"))
