@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -22,6 +22,11 @@ import tokenize
 import ast
 import sys
 
+try:
+    ast.AsyncFunctionDef    # __IGNORE_EXCEPTION__
+except AttributeError:
+    ast.AsyncFunctionDef = ast.FunctionDef
+
 
 class DocStyleContext(object):
     """
@@ -35,13 +40,18 @@ class DocStyleContext(object):
         @param startLine line number the context starts in the source (integer)
         @param contextType type of the context object (string)
         """
-        if isinstance(source, str):
+        if sys.version_info[0] == 2:
+            stringTypes = (str, unicode)        # __IGNORE_WARNING__
+        else:
+            stringTypes = str
+        if isinstance(source, stringTypes):
             self.__source = source.splitlines(True)
         else:
             self.__source = source[:]
         self.__start = startLine
         self.__indent = ""
         self.__type = contextType
+        self.__special = ""
         
         # ensure first line is left justified
         if self.__source:
@@ -96,6 +106,24 @@ class DocStyleContext(object):
         @return context type (string)
         """
         return self.__type
+    
+    def setSpecial(self, special):
+        """
+        Public method to set a special attribute for the context.
+        
+        @param special attribute string
+        @type str
+        """
+        self.__special = special
+    
+    def special(self):
+        """
+        Public method to get the special context attribute string.
+        
+        @return attribute string
+        @rtype str
+        """
+        return self.__special
 
 
 class DocStyleChecker(object):
@@ -113,7 +141,8 @@ class DocStyleChecker(object):
         "D221", "D222",
         "D231", "D232", "D234", "D235", "D236", "D237", "D238", "D239",
         "D242", "D243", "D244", "D245", "D246", "D247",
-        "D250", "D251",
+        "D250", "D251", "D252", "D253",
+        "D260", "D261", "D262", "D263",
         
         "D901",
     ]
@@ -189,7 +218,7 @@ class DocStyleChecker(object):
                     (self.__checkUnicode, ("D113",)),
                     (self.__checkOneLiner, ("D121",)),
                     (self.__checkIndent, ("D122",)),
-                    (self.__checkSummary, ("D130")),
+                    (self.__checkSummary, ("D130",)),
                     (self.__checkEndsWithPeriod, ("D131",)),
                     (self.__checkBlankAfterSummary, ("D144",)),
                     (self.__checkBlankAfterLastParagraph, ("D145",)),
@@ -206,6 +235,7 @@ class DocStyleChecker(object):
                     (self.__checkClassDocstring, ("D104", "D205")),
                     (self.__checkEricNoBlankBeforeAndAfterClassOrFunction,
                      ("D242", "D243")),
+                    (self.__checkEricSignal, ("D260", "D261", "D262", "D263")),
                 ],
                 "methodDocstring": [
                     (self.__checkEricSummary, ("D232")),
@@ -219,14 +249,15 @@ class DocStyleChecker(object):
                      ("D236", "D237", "D238", "D239")),
                     (self.__checkEricNoBlankBeforeAndAfterClassOrFunction,
                      ("D244", "D245")),
-                    (self.__checkEricException, ("D250", "D251")),
+                    (self.__checkEricException,
+                     ("D250", "D251", "D252", "D253")),
                 ],
                 "docstring": [
                     (self.__checkTripleDoubleQuotes, ("D111",)),
                     (self.__checkBackslashes, ("D112",)),
                     (self.__checkUnicode, ("D113",)),
                     (self.__checkIndent, ("D122",)),
-                    (self.__checkSummary, ("D130")),
+                    (self.__checkSummary, ("D130",)),
                     (self.__checkEricEndsWithPeriod, ("D231",)),
                     (self.__checkEricBlankAfterSummary, ("D246",)),
                     (self.__checkEricNBlankAfterLastParagraph, ("D247",)),
@@ -323,8 +354,15 @@ class DocStyleChecker(object):
             # don't do anything, if no codes were selected
             return
         
+        source = "".join(self.__source)
+        # Check type for py2: if not str it's unicode
+        if sys.version_info[0] == 2:
+            try:
+                source = source.encode('utf-8')
+            except UnicodeError:
+                pass
         try:
-            compile(''.join(self.__source), '', 'exec', ast.PyCF_ONLY_AST)
+            compile(source, self.__filename, 'exec', ast.PyCF_ONLY_AST)
         except (SyntaxError, TypeError):
             self.__reportInvalidSyntax()
             return
@@ -600,9 +638,17 @@ class DocStyleChecker(object):
                         end = line - 1, char
                         startLine = classContext.start() + start[0]
                         endLine = classContext.start() + end[0]
-                        contexts.append(DocStyleContext(
+                        context = DocStyleContext(
                             self.__source[startLine:endLine],
-                            startLine, "def"))
+                            startLine, "def")
+                        if startLine > 0:
+                            if self.__source[startLine - 1].strip() == \
+                                    "@staticmethod":
+                                context.setSpecial("staticmethod")
+                            elif self.__source[startLine - 1].strip() == \
+                                    "@classmethod":
+                                context.setSpecial("classmethod")
+                        contexts.append(context)
                 except StopIteration:
                     pass
             self.__methodsCache = contexts
@@ -794,7 +840,7 @@ class DocStyleChecker(object):
         if not nonEmptyLines:
             return
         
-        indent = min([len(l) - len(l.strip()) for l in nonEmptyLines])
+        indent = min(len(l) - len(l.strip()) for l in nonEmptyLines)
         if context.contextType() == "module":
             expectedIndent = 0
         else:
@@ -881,8 +927,8 @@ class DocStyleChecker(object):
             return_ = [tokens[i + 1][0] for i, token in enumerate(tokens)
                        if token[1] == "return"]
             if (set(return_) -
-                    set([tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE]) !=
-                    set([])):
+                    {tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE} !=
+                    set()):
                 self.__error(docstringContext.end(), 0, "D134")
     
     def __checkNoBlankLineBefore(self, docstringContext, context):
@@ -1046,13 +1092,13 @@ class DocStyleChecker(object):
                    if token[1] in ("return", "yield")]
         if "@return" not in docstringContext.ssource():
             if (set(return_) -
-                    set([tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE]) !=
-                    set([])):
+                    {tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE} !=
+                    set()):
                 self.__error(docstringContext.end(), 0, "D234")
         else:
             if (set(return_) -
-                    set([tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE]) ==
-                    set([])):
+                    {tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE} ==
+                    set()):
                 self.__error(docstringContext.end(), 0, "D235")
     
     def __checkEricFunctionArguments(self, docstringContext, context):
@@ -1071,7 +1117,8 @@ class DocStyleChecker(object):
         except (SyntaxError, TypeError):
             return
         if (isinstance(tree, ast.Module) and len(tree.body) == 1 and
-                isinstance(tree.body[0], ast.FunctionDef)):
+                isinstance(tree.body[0],
+                           (ast.FunctionDef, ast.AsyncFunctionDef))):
             functionDef = tree.body[0]
             argNames, kwNames = self.__getArgNames(functionDef)
             if "self" in argNames:
@@ -1092,10 +1139,12 @@ class DocStyleChecker(object):
                 kwargs = []
                 for line in docstringContext.source():
                     if line.strip().startswith(("@param", "@keyparam")):
-                        at, name = line.strip().split(None, 2)[:2]
-                        if at == "@keyparam":
-                            kwargs.append(name.lstrip("*"))
-                        args.append(name.lstrip("*"))
+                        paramParts = line.strip().split(None, 2)
+                        if len(paramParts) >= 2:
+                            at, name = paramParts[:2]
+                            if at == "@keyparam":
+                                kwargs.append(name.lstrip("*"))
+                            args.append(name.lstrip("*"))
                 
                 # do the checks
                 for name in kwNames:
@@ -1110,6 +1159,10 @@ class DocStyleChecker(object):
         Private method to check, that docstrings contain an &#64;exception line
         if they raise an exception and don't otherwise.
         
+        Note: This method also checks the raised and documented exceptions for
+        completeness (i.e. raised exceptions that are not documented or
+        documented exceptions that are not raised)
+        
         @param docstringContext docstring context (DocStyleContext)
         @param context context of the docstring (DocStyleContext)
         """
@@ -1118,20 +1171,106 @@ class DocStyleChecker(object):
         
         tokens = list(
             tokenize.generate_tokens(StringIO(context.ssource()).readline))
-        exception = [tokens[i + 1][0] for i, token in enumerate(tokens)
-                     if token[1] == "raise"]
+        exceptions = set()
+        raisedExceptions = set()
+        tokensLen = len(tokens)
+        for i, token in enumerate(tokens):
+            if token[1] == "raise":
+                exceptions.add(tokens[i + 1][0])
+                if tokens[i + 1][0] == tokenize.NAME:
+                    if tokensLen > (i + 2) and \
+                       tokens[i + 2][1] == ".":
+                        raisedExceptions.add("{0}.{1}".format(
+                            tokens[i + 1][1], tokens[i + 3][1]))
+                    else:
+                        raisedExceptions.add(tokens[i + 1][1])
+        
         if "@exception" not in docstringContext.ssource() and \
                 "@throws" not in docstringContext.ssource() and \
                 "@raise" not in docstringContext.ssource():
-            if (set(exception) -
-                    set([tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE]) !=
-                    set([])):
+            if (exceptions -
+                    {tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE} !=
+                    set()):
                 self.__error(docstringContext.end(), 0, "D250")
         else:
-            if (set(exception) -
-                    set([tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE]) ==
-                    set([])):
+            if (exceptions -
+                    {tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE} ==
+                    set()):
                 self.__error(docstringContext.end(), 0, "D251")
+            else:
+                # step 1: extract documented exceptions
+                documentedExceptions = set()
+                for line in docstringContext.source():
+                    line = line.strip()
+                    if line.startswith(("@exception", "@throws", "@raise")):
+                        exceptionTokens = line.split(None, 2)
+                        if len(exceptionTokens) >= 2:
+                            documentedExceptions.add(exceptionTokens[1])
+                
+                # step 2: report undocumented exceptions
+                for exception in raisedExceptions:
+                    if exception not in documentedExceptions:
+                        self.__error(docstringContext.end(), 0, "D252",
+                                     exception)
+                
+                # step 3: report undefined signals
+                for exception in documentedExceptions:
+                    if exception not in raisedExceptions:
+                        self.__error(docstringContext.end(), 0, "D253",
+                                     exception)
+    
+    def __checkEricSignal(self, docstringContext, context):
+        """
+        Private method to check, that docstrings contain an &#64;signal line
+        if they define signals and don't otherwise.
+        
+        Note: This method also checks the defined and documented signals for
+        completeness (i.e. defined signals that are not documented or
+        documented signals that are not defined)
+        
+        @param docstringContext docstring context (DocStyleContext)
+        @param context context of the docstring (DocStyleContext)
+        """
+        if docstringContext is None:
+            return
+        
+        tokens = list(
+            tokenize.generate_tokens(StringIO(context.ssource()).readline))
+        definedSignals = set()
+        for i, token in enumerate(tokens):
+            if token[1] in ("pyqtSignal", "Signal"):
+                if tokens[i - 1][1] == "." and tokens[i - 2][1] == "QtCore":
+                    definedSignals.add(tokens[i - 4][1])
+                elif tokens[i - 1][1] == "=":
+                    definedSignals.add(tokens[i - 2][1])
+        
+        if "@signal" not in docstringContext.ssource() and definedSignals:
+            self.__error(docstringContext.end(), 0, "D260")
+        elif "@signal" in docstringContext.ssource():
+            if not definedSignals:
+                self.__error(docstringContext.end(), 0, "D261")
+            else:
+                # step 1: extract documented signals
+                documentedSignals = set()
+                for line in docstringContext.source():
+                    line = line.strip()
+                    if line.startswith("@signal"):
+                        signalTokens = line.split(None, 2)
+                        if len(signalTokens) >= 2:
+                            signal = signalTokens[1]
+                            if "(" in signal:
+                                signal = signal.split("(", 1)[0]
+                            documentedSignals.add(signal)
+                
+                # step 2: report undocumented signals
+                for signal in definedSignals:
+                    if signal not in documentedSignals:
+                        self.__error(docstringContext.end(), 0, "D262", signal)
+                
+                # step 3: report undefined signals
+                for signal in documentedSignals:
+                    if signal not in definedSignals:
+                        self.__error(docstringContext.end(), 0, "D263", signal)
     
     def __checkEricBlankAfterSummary(self, docstringContext, context):
         """
@@ -1246,6 +1385,45 @@ class DocStyleChecker(object):
                 if firstWord != 'special':
                     self.__error(docstringContext.start() + lineNumber, 0,
                                  "D232", 'special')
+            elif context.special() == "staticmethod":
+                secondWord = summary.strip().split(None, 2)[1].lower()
+                if firstWord != 'static' and secondWord != 'static':
+                    self.__error(docstringContext.start() + lineNumber, 0,
+                                 "D232", 'static')
+                elif secondWord == 'static':
+                    if functionName.startswith(('__', 'on_')):
+                        if firstWord != 'private':
+                            self.__error(docstringContext.start() + lineNumber,
+                                         0, "D232", 'private static')
+                    elif functionName.startswith('_') or \
+                            functionName.endswith('Event'):
+                        if firstWord != 'protected':
+                            self.__error(docstringContext.start() + lineNumber,
+                                         0, "D232", 'protected static')
+                    else:
+                        if firstWord != 'public':
+                            self.__error(docstringContext.start() + lineNumber,
+                                         0, "D232", 'public static')
+            elif arguments.startswith(('cls,', 'cls)')) or \
+                    context.special() == "classmethod":
+                secondWord = summary.strip().split(None, 2)[1].lower()
+                if firstWord != 'class' and secondWord != 'class':
+                    self.__error(docstringContext.start() + lineNumber, 0,
+                                 "D232", 'class')
+                elif secondWord == 'class':
+                    if functionName.startswith(('__', 'on_')):
+                        if firstWord != 'private':
+                            self.__error(docstringContext.start() + lineNumber,
+                                         0, "D232", 'private class')
+                    elif functionName.startswith('_') or \
+                            functionName.endswith('Event'):
+                        if firstWord != 'protected':
+                            self.__error(docstringContext.start() + lineNumber,
+                                         0, "D232", 'protected class')
+                    else:
+                        if firstWord != 'public':
+                            self.__error(docstringContext.start() + lineNumber,
+                                         0, "D232", 'public class')
             elif functionName.startswith(('__', 'on_')):
                 if firstWord != 'private':
                     self.__error(docstringContext.start() + lineNumber, 0,
@@ -1255,11 +1433,10 @@ class DocStyleChecker(object):
                 if firstWord != 'protected':
                     self.__error(docstringContext.start() + lineNumber, 0,
                                  "D232", 'protected')
-            elif arguments.startswith(('cls,', 'cls)')):
-                if firstWord != 'class':
-                    self.__error(docstringContext.start() + lineNumber, 0,
-                                 "D232", 'class')
             else:
                 if firstWord != 'public':
                     self.__error(docstringContext.start() + lineNumber, 0,
                                  "D232", 'public')
+
+#
+# eflag: noqa = M702
