@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,6 +13,11 @@ import re
 import os
 import sys
 
+try:
+    ast.AsyncFunctionDef    # __IGNORE_EXCEPTION__
+except AttributeError:
+    ast.AsyncFunctionDef = ast.FunctionDef
+
 
 class NamingStyleChecker(object):
     """
@@ -30,11 +35,11 @@ class NamingStyleChecker(object):
     
     def __init__(self, tree, filename, options):
         """
-        Constructor (according to 'extended' pep8.py API)
+        Constructor (according to 'extended' pycodestyle.py API)
         
         @param tree AST tree of the source file
         @param filename name of the source file (string)
-        @param options options as parsed by pep8.StyleGuide
+        @param options options as parsed by pycodestyle.StyleGuide
         """
         self.__parents = collections.deque()
         self.__tree = tree
@@ -46,7 +51,7 @@ class NamingStyleChecker(object):
                 (self.__checkNameToBeAvoided, ("N831",)),
             ],
             "functiondef": [
-                (self.__checkFuntionName, ("N802",)),
+                (self.__checkFunctionName, ("N802",)),
                 (self.__checkFunctionArgumentNames,
                     ("N803", "N804", "N805", "N806")),
                 (self.__checkNameToBeAvoided, ("N831",)),
@@ -74,7 +79,7 @@ class NamingStyleChecker(object):
 
     def run(self):
         """
-        Public method run by the pep8.py checker.
+        Public method run by the pycodestyle.py checker.
         
         @return tuple giving line number, offset within line, code and
             checker function
@@ -110,7 +115,7 @@ class NamingStyleChecker(object):
         """
         if isinstance(node, ast.ClassDef):
             self.__tagClassFunctions(node)
-        elif isinstance(node, ast.FunctionDef):
+        elif isinstance(node, (ast.FunctionDef, ast.AsyncFunctionDef)):
             self.__findGlobalDefs(node)
         
         checkerName = node.__class__.__name__.lower()
@@ -142,7 +147,7 @@ class NamingStyleChecker(object):
 
         # iterate over all functions and tag them
         for node in ast.iter_child_nodes(classNode):
-            if not isinstance(node, ast.FunctionDef):
+            if not isinstance(node, (ast.FunctionDef, ast.AsyncFunctionDef)):
                 continue
             
             node.function_type = 'method'
@@ -171,7 +176,8 @@ class NamingStyleChecker(object):
             if isinstance(node, ast.Global):
                 globalNames.update(node.names)
 
-            if not isinstance(node, (ast.FunctionDef, ast.ClassDef)):
+            if not isinstance(node, (ast.FunctionDef, ast.AsyncFunctionDef,
+                                     ast.ClassDef)):
                 nodesToCheck.extend(ast.iter_child_nodes(node))
         functionNode.global_names = globalNames
     
@@ -222,7 +228,7 @@ class NamingStyleChecker(object):
             if isinstance(node, ast.ClassDef):
                 lineno += len(node.decorator_list)
                 offset += 6
-            elif isinstance(node, ast.FunctionDef):
+            elif isinstance(node, (ast.FunctionDef, ast.AsyncFunctionDef)):
                 lineno += len(node.decorator_list)
                 offset += 4
         return (lineno, offset, code)
@@ -245,13 +251,14 @@ class NamingStyleChecker(object):
         @return tuple giving line number, offset within line and error code
             (integer, integer, string)
         """
-        if isinstance(node, (ast.ClassDef, ast.FunctionDef)):
+        if isinstance(node, (ast.ClassDef, ast.FunctionDef,
+                             ast.AsyncFunctionDef)):
             name = node.name
             if self.__isNameToBeAvoided(name):
                 yield self.__error(node, "N831")
                 return
         
-        if isinstance(node, ast.FunctionDef):
+        if isinstance(node, (ast.FunctionDef, ast.AsyncFunctionDef)):
             argNames = self.__getArgNames(node)
             for arg in argNames:
                 if self.__isNameToBeAvoided(arg):
@@ -260,13 +267,25 @@ class NamingStyleChecker(object):
         
         if isinstance(node, ast.Assign):
             for target in node.targets:
-                name = isinstance(target, ast.Name) and target.id
-                if not name:
-                    return
+                if isinstance(target, ast.Name):
+                    name = target.id
+                    if not name:
+                        return
+                    
+                    if self.__isNameToBeAvoided(name):
+                        yield self.__error(node, "N831")
+                        return
                 
-                if self.__isNameToBeAvoided(name):
-                    yield self.__error(node, "N831")
-                    return
+                elif isinstance(target, (ast.Tuple, ast.List)):
+                    for element in target.elts:
+                        if isinstance(element, ast.Name):
+                            name = element.id
+                            if not name:
+                                return
+                            
+                            if self.__isNameToBeAvoided(name):
+                                yield self.__error(node, "N831")
+                                return
     
     def __checkClassName(self, node, parents):
         """
@@ -284,7 +303,7 @@ class NamingStyleChecker(object):
         if not self.CamelcaseRegexp.match(node.name):
             yield self.__error(node, "N801")
     
-    def __checkFuntionName(self, node, parents):
+    def __checkFunctionName(self, node, parents):
         """
         Private class to check the given node for function name
         conventions (N802).
@@ -376,7 +395,7 @@ class NamingStyleChecker(object):
         for parentFunc in reversed(parents):
             if isinstance(parentFunc, ast.ClassDef):
                 return
-            if isinstance(parentFunc, ast.FunctionDef):
+            if isinstance(parentFunc, (ast.FunctionDef, ast.AsyncFunctionDef)):
                 break
         else:
             return
@@ -435,3 +454,6 @@ class NamingStyleChecker(object):
                 yield self.__error(node, "N813")
             elif self.UppercaseRegexp.match(name.asname):
                 yield self.__error(node, "N814")
+
+#
+# eflag: noqa = M702
