@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,201 +11,249 @@ from __future__ import unicode_literals
 
 from PyQt5.QtCore import QCoreApplication
 
+from Globals import translate
+
 __all__ = ["getTranslatedMessage"]
 
 _messages = {
     "E101": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "indentation contains mixed spaces and tabs"),
     "E111": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "indentation is not a multiple of four"),
     "E112": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "expected an indented block"),
     "E113": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "unexpected indentation"),
+    "E114": QCoreApplication.translate(
+        "pycodestyle",
+        "indentation is not a multiple of four (comment)"),
+    "E115": QCoreApplication.translate(
+        "pycodestyle",
+        "expected an indented block (comment)"),
+    "E116": QCoreApplication.translate(
+        "pycodestyle",
+        "unexpected indentation (comment)"),
     "E121": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line indentation is not a multiple of four"),
     "E122": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line missing indentation or outdented"),
     "E123": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "closing bracket does not match indentation of opening"
         " bracket's line"),
     "E124": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "closing bracket does not match visual indentation"),
     "E125": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line with same indent as next logical line"),
     "E126": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line over-indented for hanging indent"),
     "E127": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line over-indented for visual indent"),
     "E128": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line under-indented for visual indent"),
     "E129": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "visually indented line with same indent as next logical line"),
     "E131": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "continuation line unaligned for hanging indent"),
     "E133": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "closing bracket is missing indentation"),
     "W191": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "indentation contains tabs"),
     "E201": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "whitespace after '{0}'"),
     "E202": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "whitespace before '{0}'"),
     "E203": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "whitespace before '{0}'"),
     "E211": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "whitespace before '{0}'"),
     "E221": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces before operator"),
     "E222": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces after operator"),
     "E223": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab before operator"),
     "E224": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab after operator"),
     "E225": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace around operator"),
     "E226": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace around arithmetic operator"),
     "E227": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace around bitwise or shift operator"),
     "E228": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace around modulo operator"),
     "E231": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "missing whitespace after '{0}'"),
     "E241": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces after '{0}'"),
     "E242": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab after '{0}'"),
     "E251": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "unexpected spaces around keyword / parameter equals"),
     "E261": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "at least two spaces before inline comment"),
     "E262": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "inline comment should start with '# '"),
     "E265": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "block comment should start with '# '"),
+    "E266": QCoreApplication.translate(
+        "pycodestyle",
+        "too many leading '#' for block comment"),
     "E271": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces after keyword"),
     "E272": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple spaces before keyword"),
     "E273": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab after keyword"),
     "E274": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "tab before keyword"),
+    "E275": QCoreApplication.translate(
+        "pycodestyle",
+        "missing whitespace after keyword"),
     "W291": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "trailing whitespace"),
     "W292": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "no newline at end of file"),
     "W293": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "blank line contains whitespace"),
     "E301": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "expected 1 blank line, found 0"),
     "E302": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "expected 2 blank lines, found {0}"),
     "E303": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "too many blank lines ({0})"),
     "E304": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "blank lines found after function decorator"),
+    "E305": QCoreApplication.translate(
+        "pycodestyle",
+        "expected 2 blank lines after class or function definition,"
+        " found {0}"),
+    "E306": QCoreApplication.translate(
+        "pycodestyle",
+        "expected 1 blank line before a nested definition, found 0"),
     "W391": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "blank line at end of file"),
     "E401": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple imports on one line"),
+    "E402": QCoreApplication.translate(
+        "pycodestyle",
+        "module level import not at top of file"),
     "E501": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "line too long ({0} > {1} characters)"),
     "E502": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "the backslash is redundant between brackets"),
+    "W503": QCoreApplication.translate(
+        "pycodestyle",
+        "line break before binary operator"),
     "W601": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         ".has_key() is deprecated, use 'in'"),
     "W602": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "deprecated form of raising exception"),
     "W603": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "'<>' is deprecated, use '!='"),
     "W604": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "backticks are deprecated, use 'repr()'"),
     "E701": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple statements on one line (colon)"),
     "E702": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "multiple statements on one line (semicolon)"),
     "E703": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "statement ends with a semicolon"),
+    "E704": QCoreApplication.translate(
+        "pycodestyle",
+        "multiple statements on one line (def)"),
     "E711": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "comparison to {0} should be {1}"),
     "E712": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "comparison to {0} should be {1}"),
     "E713": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "test for membership should be 'not in'"),
     "E714": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "test for object identity should be 'is not'"),
     "E721": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "do not compare types, use 'isinstance()'"),
+    "E722": QCoreApplication.translate(
+        "pycodestyle",
+        "do not use bare except"),
+    "E731": QCoreApplication.translate(
+        "pycodestyle",
+        "do not assign a lambda expression, use a def"),
+    "E741": QCoreApplication.translate(
+        "pycodestyle",
+        "ambiguous variable name '{0}'"),
+    "E742": QCoreApplication.translate(
+        "pycodestyle",
+        "ambiguous class definition '{0}'"),
+    "E743": QCoreApplication.translate(
+        "pycodestyle",
+        "ambiguous function definition '{0}'"),
     "E901": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "{0}: {1}"),
     "E902": QCoreApplication.translate(
-        "pep8",
+        "pycodestyle",
         "{0}"),
 
     # DocStyleChecker messages
@@ -322,6 +370,24 @@ _messages = {
         "DocStyleChecker",
         "docstring contains a @exception line but function/method doesn't"
         " raise an exception"),
+    "D252": QCoreApplication.translate(
+        "DocStyleChecker",
+        "raised exception '{0}' is not documented in docstring"),
+    "D253": QCoreApplication.translate(
+        "DocStyleChecker",
+        "documented exception '{0}' is not raised"),
+    "D260": QCoreApplication.translate(
+        "DocStyleChecker",
+        "docstring does not contain a @signal line but class defines signals"),
+    "D261": QCoreApplication.translate(
+        "DocStyleChecker",
+        "docstring contains a @signal line but class doesn't define signals"),
+    "D262": QCoreApplication.translate(
+        "DocStyleChecker",
+        "defined signal '{0}' is not documented in docstring"),
+    "D263": QCoreApplication.translate(
+        "DocStyleChecker",
+        "documented signal '{0}' is not defined"),
     
     "D901": QCoreApplication.translate(
         "DocStyleChecker", "{0}: {1}"),
@@ -371,6 +437,117 @@ _messages = {
         "NamingStyleChecker",
         "names 'l', 'O' and 'I' should be avoided"),
 
+    # Code complexity messages
+    "C101": QCoreApplication.translate(
+        "ComplexityChecker", "'{0}' is too complex ({1})"),
+    "C111": QCoreApplication.translate(
+        "ComplexityChecker", "source code line is too complex ({0})"),
+    "C112": QCoreApplication.translate(
+        "ComplexityChecker",
+        "overall source code line complexity is too high ({0})"),
+    "C901": QCoreApplication.translate(
+        "ComplexityChecker", "{0}: {1}"),
+    
+    # Messages of the Miscellaneous Checker
+    "M101": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "coding magic comment not found"),
+    "M102": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "unknown encoding ({0}) found in coding magic comment"),
+    "M111": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "copyright notice not present"),
+    "M112": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "copyright notice contains invalid author"),
+    "M131": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        '"{0}" is a Python builtin and is being shadowed; '
+        'consider renaming the variable'),
+    "M132": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        '"{0}" is used as an argument and thus shadows a '
+        'Python builtin; consider renaming the argument'),
+    "M191": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary generator - rewrite as a list comprehension'),
+    "M192": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary generator - rewrite as a set comprehension'),
+    "M193": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary generator - rewrite as a dict comprehension'),
+    "M194": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list comprehension - rewrite as a set comprehension'),
+    "M195": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list comprehension - rewrite as a dict comprehension'),
+    "M196": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list literal - rewrite as a set literal'),
+    "M197": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list literal - rewrite as a dict literal'),
+    "M198": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list comprehension - "{0}" can take a generator'),
+    "M601": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "found {0} formatter"),
+    "M611": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "format string does contain unindexed parameters"),
+    "M612": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "docstring does contain unindexed parameters"),
+    "M613": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "other string does contain unindexed parameters"),
+    "M621": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "format call uses too large index ({0})"),
+    "M622": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "format call uses missing keyword ({0})"),
+    "M623": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "format call uses keyword arguments but no named entries"),
+    "M624": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "format call uses variable arguments but no numbered entries"),
+    "M625": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "format call uses implicit and explicit indexes together"),
+    "M631": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "format call provides unused index ({0})"),
+    "M632": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "format call provides unused keyword ({0})"),
+    "M701": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "expected these __future__ imports: {0}; but only got: {1}"),
+    "M702": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "expected these __future__ imports: {0}; but got none"),
+    "M801": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "print statement found"),
+    "M811": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "one element tuple found"),
+    "M821": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "mutable default argument of type {0}"),
+    "M822": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "mutable default argument of type {0}"),
+    "M901": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "{0}: {1}"),
+    
     # CodeStyleFixer messages
     "FD111": QCoreApplication.translate(
         'CodeStyleFixer',
@@ -469,10 +646,10 @@ _messages = {
         'CodeStyleFixer',
         "One blank line inserted."),
     
-    "FE302+": lambda n=1: QCoreApplication.translate(
+    "FE302+": lambda n=1: translate(
         'CodeStyleFixer',
         "%n blank line(s) inserted.", '', n),
-    "FE302-": lambda n=1: QCoreApplication.translate(
+    "FE302-": lambda n=1: translate(
         'CodeStyleFixer',
         "%n superfluous lines removed", '', n),
     
@@ -534,13 +711,39 @@ _messages_sample_args = {
     "E242": [",;:"],
     "E302": [1],
     "E303": [3],
+    "E305": [1],
     "E501": [85, 79],
     "E711": ["None", "'if cond is None:'"],
     "E712": ["True", "'if cond is True:' or 'if cond:'"],
+    "E741": ["l"],
+    "E742": ["l"],
+    "E743": ["l"],
     "E901": ["SyntaxError", "Invalid Syntax"],
     "E902": ["IOError"],
     "D232": ["public"],
+    "D252": ["RuntimeError"],
+    "D253": ["RuntimeError"],
+    "D262": ["buttonClicked"],
+    "D263": ["buttonClicked"],
     "D901": ["SyntaxError", "Invalid Syntax"],
+    "C101": ["foo.bar", "42"],
+    "C111": [42],
+    "C112": [12.0],
+    "C901": ["SyntaxError", "Invalid Syntax"],
+    "M102": ["enc42"],
+    "M131": ["list"],
+    "M132": ["list"],
+    "M198": ["sorted"],
+    "M601": ["%s"],
+    "M621": [5],
+    "M622": ["foo"],
+    "M631": [5],
+    "M632": ["foo"],
+    "M701": ["print_function, unicode_literals", "print_function"],
+    "M702": ["print_function, unicode_literals"],
+    "M821": ["Dict"],
+    "M822": ["Call"],
+    "M901": ["SyntaxError", "Invalid Syntax"],
     "FWRITE_ERROR": ["IOError"],
 }
 
