@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,12 +16,14 @@ from E5Gui.E5Application import e5App
 from E5Gui.E5Action import E5Action
 from E5Gui import E5MessageBox
 
+import UI.Info
+
 # Start-Of-Header
 name = "QFontDialog Wizard Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "6.0.0"
+version = UI.Info.VersionOnly
 className = "FontDialogWizard"
 packageName = "__core__"
 shortDescription = "Show the QFontDialog wizard."
