@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -24,6 +24,8 @@ from E5Gui import E5MessageBox
 
 from .Ui_HgGpgSignaturesDialog import Ui_HgGpgSignaturesDialog
 
+from Globals import strToQByteArray
+
 
 class HgGpgSignaturesDialog(QDialog, Ui_HgGpgSignaturesDialog):
     """
@@ -148,8 +150,6 @@ class HgGpgSignaturesDialog(QDialog, Ui_HgGpgSignaturesDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setFocus(
             Qt.OtherFocusReason)
         
-        self.process = None
-        
         if self.signaturesList.topLevelItemCount() == 0:
             # no patches present
             self.__generateItem("", "", self.tr("no signatures found"))
@@ -354,17 +354,17 @@ class HgGpgSignaturesDialog(QDialog, Ui_HgGpgSignaturesDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
