@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -256,11 +256,14 @@ class HgClient(QObject):
             
             # input channels
             if channel in inputChannels:
-                input = inputChannels[channel](data)
                 if channel == "L":
+                    inputData, isPassword = inputChannels[channel](data)
                     # echo the input to the output if it was a prompt
-                    outputChannels["o"](input)
-                self.__writeDataBlock(input)
+                    if not isPassword:
+                        outputChannels["o"](inputData)
+                else:
+                    inputData = inputChannels[channel](data)
+                self.__writeDataBlock(inputData)
             
             # output channels
             elif channel in outputChannels:
@@ -288,13 +291,15 @@ class HgClient(QObject):
         @return data entered by the user (string)
         """
         from .HgClientPromptDialog import HgClientPromptDialog
-        input = ""
+        inputData = ""
+        isPassword = False
         dlg = HgClientPromptDialog(size, message)
         if dlg.exec_() == QDialog.Accepted:
-            input = dlg.getInput() + '\n'
-        return input
+            inputData = dlg.getInput() + '\n'
+            isPassword = dlg.isPassword()
+        return inputData, isPassword
     
-    def runcommand(self, args, prompt=None, input=None, output=None,
+    def runcommand(self, args, prompt=None, inputData=None, output=None,
                    error=None):
         """
         Public method to execute a command via the command server.
@@ -303,8 +308,8 @@ class HgClient(QObject):
         @keyparam prompt function to reply to prompts by the server. It
             receives the max number of bytes to return and the contents
             of the output channel received so far.
-        @keyparam input function to reply to bulk data requests by the server.
-            It receives the max number of bytes to return.
+        @keyparam inputData function to reply to bulk data requests by the
+            server. It receives the max number of bytes to return.
         @keyparam output function receiving the data from the server (string).
             If a prompt function is given, this parameter will be ignored.
         @keyparam error function receiving error messages from the server
@@ -333,7 +338,7 @@ class HgClient(QObject):
         if prompt is not None:
             def func(size):
                 reply = prompt(size, outputBuffer.getvalue())
-                return reply
+                return reply, False
             inputChannels["L"] = func
         else:
             def myprompt(size):
@@ -341,11 +346,11 @@ class HgClient(QObject):
                     msg = self.tr("For message see output dialog.")
                 else:
                     msg = outputBuffer.getvalue()
-                reply = self.__prompt(size, msg)
-                return reply
+                reply, isPassword = self.__prompt(size, msg)
+                return reply, isPassword
             inputChannels["L"] = myprompt
-        if input is not None:
-            inputChannels["I"] = input
+        if inputData is not None:
+            inputChannels["I"] = inputData
         
         self.__cancel = False
         self.__runcommand(args, inputChannels, outputChannels)
@@ -384,3 +389,6 @@ class HgClient(QObject):
         @return flag indicating the execution of a command (boolean)
         """
         return self.__commandRunning
+
+#
+# eflag: noqa = M702
