@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,16 +16,22 @@ except NameError:
 
 import os
 
-from PyQt5.QtCore import pyqtSlot, Qt, QProcess, QTimer
+from PyQt5.QtCore import pyqtSlot, Qt, QProcess, QTimer, QSize
+from PyQt5.QtGui import QTextCursor, QCursor
 from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QMenu, QHeaderView, \
-    QTreeWidgetItem, QLineEdit
+    QTreeWidgetItem, QLineEdit, QToolTip
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
 
 from .Ui_HgStatusDialog import Ui_HgStatusDialog
 
+from .HgDiffHighlighter import HgDiffHighlighter
+from .HgDiffGenerator import HgDiffGenerator
+
 import Preferences
+import UI.PixmapCache
+from Globals import qVersionTuple, strToQByteArray
 
 
 class HgStatusDialog(QWidget, Ui_HgStatusDialog):
@@ -58,87 +64,31 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
         self.diff = None
-        self.process = None
         self.vcs = vcs
         self.vcs.committed.connect(self.__committed)
         self.__hgClient = self.vcs.getClient()
         self.__mq = mq
+        if self.__hgClient:
+            self.process = None
+        else:
+            self.process = QProcess()
+            self.process.finished.connect(self.__procFinished)
+            self.process.readyReadStandardOutput.connect(self.__readStdout)
+            self.process.readyReadStandardError.connect(self.__readStderr)
         
         self.statusList.headerItem().setText(self.__lastColumn, "")
         self.statusList.header().setSortIndicator(
             self.__pathColumn, Qt.AscendingOrder)
         
-        if mq:
-            self.buttonsLine.setVisible(False)
-            self.addButton.setVisible(False)
-            self.diffButton.setVisible(False)
-            self.sbsDiffButton.setVisible(False)
-            self.revertButton.setVisible(False)
-            self.forgetButton.setVisible(False)
-            self.restoreButton.setVisible(False)
+        font = Preferences.getEditorOtherFonts("MonospacedFont")
+        self.diffEdit.setFontFamily(font.family())
+        self.diffEdit.setFontPointSize(font.pointSize())
         
-        self.menuactions = []
-        self.lfActions = []
-        self.menu = QMenu()
-        if not mq:
-            self.__commitAct = self.menu.addAction(
-                self.tr("Commit changes to repository..."), self.__commit)
-            self.menuactions.append(self.__commitAct)
-            self.menuactions.append(self.menu.addAction(
-                self.tr("Select all for commit"), self.__commitSelectAll))
-            self.menuactions.append(self.menu.addAction(
-                self.tr("Deselect all from commit"),
-                self.__commitDeselectAll))
-            self.menu.addSeparator()
-            self.__addAct = self.menu.addAction(
-                self.tr("Add to repository"), self.__add)
-            self.menuactions.append(self.__addAct)
-            if self.vcs.version >= (2, 0):
-                self.lfActions.append(self.menu.addAction(
-                    self.tr("Add as Large File"),
-                    lambda: self.__lfAdd("large")))
-                self.lfActions.append(self.menu.addAction(
-                    self.tr("Add as Normal File"),
-                    lambda: self.__lfAdd("normal")))
-            self.__diffAct = self.menu.addAction(
-                self.tr("Show differences"), self.__diff)
-            self.menuactions.append(self.__diffAct)
-            self.__sbsDiffAct = self.menu.addAction(
-                self.tr("Show differences side-by-side"), self.__sbsDiff)
-            self.menuactions.append(self.__sbsDiffAct)
-            self.__revertAct = self.menu.addAction(
-                self.tr("Revert changes"), self.__revert)
-            self.menuactions.append(self.__revertAct)
-            self.__forgetAct = self.menu.addAction(
-                self.tr("Forget missing"), self.__forget)
-            self.menuactions.append(self.__forgetAct)
-            self.__restoreAct = self.menu.addAction(
-                self.tr("Restore missing"), self.__restoreMissing)
-            self.menuactions.append(self.__restoreAct)
-            self.menu.addSeparator()
-            self.menuactions.append(self.menu.addAction(
-                self.tr("Adjust column sizes"), self.__resizeColumns))
-            for act in self.menuactions:
-                act.setEnabled(False)
-            for act in self.lfActions:
-                act.setEnabled(False)
-            
-            self.statusList.setContextMenuPolicy(Qt.CustomContextMenu)
-            self.statusList.customContextMenuRequested.connect(
-                self.__showContextMenu)
+        self.diffHighlighter = HgDiffHighlighter(self.diffEdit.document())
+        self.__diffGenerator = HgDiffGenerator(vcs, self)
+        self.__diffGenerator.finished.connect(self.__generatorFinished)
         
-        if not mq and self.vcs.version >= (2, 0):
-            self.__lfAddActions = []
-            self.__addButtonMenu = QMenu()
-            self.__addButtonMenu.addAction(self.tr("Add"), self.__add)
-            self.__lfAddActions.append(
-                self.__addButtonMenu.addAction(self.tr("Add as Large File"),
-                                               lambda: self.__lfAdd("large")))
-            self.__lfAddActions.append(
-                self.__addButtonMenu.addAction(self.tr("Add as Normal File"),
-                                               lambda: self.__lfAdd("normal")))
-            self.addButton.setMenu(self.__addButtonMenu)
-            self.__addButtonMenu.aboutToShow.connect(self.__showAddMenu)
+        self.__selectedName = ""
         
         self.modifiedIndicators = [
             self.tr('added'),
@@ -163,6 +113,161 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             '?': self.tr('not tracked'),
             '!': self.tr('missing'),
         }
+        
+        self.__initActionsMenu()
+        
+        if mq:
+            self.diffLabel.setVisible(False)
+            self.diffEdit.setVisible(False)
+            self.actionsButton.setEnabled(False)
+            self.diffSplitter.setSizes([600, 0])
+        else:
+            self.diffSplitter.setSizes([300, 300])
+    
+    def __initActionsMenu(self):
+        """
+        Private method to initialize the actions menu.
+        """
+        self.__actionsMenu = QMenu()
+        self.__actionsMenu.setTearOffEnabled(True)
+        if qVersionTuple() >= (5, 1, 0):
+            self.__actionsMenu.setToolTipsVisible(True)
+        else:
+            self.__actionsMenu.hovered.connect(self.__actionsMenuHovered)
+        self.__actionsMenu.aboutToShow.connect(self.__showActionsMenu)
+        
+        self.__commitAct = self.__actionsMenu.addAction(
+            self.tr("Commit"), self.__commit)
+        self.__commitAct.setToolTip(self.tr("Commit the selected changes"))
+        self.__commitSelectAct = self.__actionsMenu.addAction(
+            self.tr("Select all for commit"), self.__commitSelectAll)
+        self.__commitDeselectAct = self.__actionsMenu.addAction(
+            self.tr("Unselect all from commit"), self.__commitDeselectAll)
+        
+        self.__actionsMenu.addSeparator()
+        
+        self.__addAct = self.__actionsMenu.addAction(
+            self.tr("Add"), self.__add)
+        self.__addAct.setToolTip(self.tr("Add the selected files"))
+        self.__lfAddLargeAct = self.__actionsMenu.addAction(
+            self.tr("Add as Large Files"), lambda: self.__lfAdd("large"))
+        self.__lfAddLargeAct.setToolTip(self.tr(
+            "Add the selected files as a large files using the 'Large Files'"
+            " extension"))
+        self.__lfAddNormalAct = self.__actionsMenu.addAction(
+            self.tr("Add as Normal Files"), lambda: self.__lfAdd("normal"))
+        self.__lfAddNormalAct.setToolTip(self.tr(
+            "Add the selected files as a normal files using the 'Large Files'"
+            " extension"))
+        
+        self.__actionsMenu.addSeparator()
+        
+        self.__diffAct = self.__actionsMenu.addAction(
+            self.tr("Differences"), self.__diff)
+        self.__diffAct.setToolTip(self.tr(
+            "Shows the differences of the selected entry in a"
+            " separate dialog"))
+        self.__sbsDiffAct = self.__actionsMenu.addAction(
+            self.tr("Differences Side-By-Side"), self.__sbsDiff)
+        self.__sbsDiffAct.setToolTip(self.tr(
+            "Shows the differences of the selected entry side-by-side in"
+            " a separate dialog"))
+        
+        self.__actionsMenu.addSeparator()
+        
+        self.__revertAct = self.__actionsMenu.addAction(
+            self.tr("Revert"), self.__revert)
+        self.__revertAct.setToolTip(self.tr(
+            "Reverts the changes of the selected files"))
+        
+        self.__actionsMenu.addSeparator()
+        
+        self.__forgetAct = self.__actionsMenu.addAction(
+            self.tr("Forget missing"), self.__forget)
+        self.__forgetAct.setToolTip(self.tr(
+            "Forgets about the selected missing files"))
+        self.__restoreAct = self.__actionsMenu.addAction(
+            self.tr("Restore missing"), self.__restoreMissing)
+        self.__restoreAct.setToolTip(self.tr(
+            "Restores the selected missing files"))
+        
+        self.__actionsMenu.addSeparator()
+        
+        act = self.__actionsMenu.addAction(
+            self.tr("Adjust column sizes"), self.__resizeColumns)
+        act.setToolTip(self.tr(
+            "Adjusts the width of all columns to their contents"))
+        
+        self.actionsButton.setIcon(
+            UI.PixmapCache.getIcon("actionsToolButton.png"))
+        self.actionsButton.setMenu(self.__actionsMenu)
+    
+    def __actionsMenuHovered(self, action):
+        """
+        Private slot to show the tooltip for an action menu entry.
+        
+        @param action action to show tooltip for
+        @type QAction
+        """
+        QToolTip.showText(
+            QCursor.pos(), action.toolTip(),
+            self.__actionsMenu, self.__actionsMenu.actionGeometry(action))
+    
+    def closeEvent(self, e):
+        """
+        Protected slot implementing a close event handler.
+        
+        @param e close event (QCloseEvent)
+        """
+        if self.__hgClient:
+            if self.__hgClient.isExecuting():
+                self.__hgClient.cancel()
+        else:
+            if self.process is not None and \
+               self.process.state() != QProcess.NotRunning:
+                self.process.terminate()
+                QTimer.singleShot(2000, self.process.kill)
+                self.process.waitForFinished(3000)
+        
+        if self.__mq:
+            self.vcs.getPlugin().setPreferences(
+                "MqStatusDialogGeometry", self.saveGeometry())
+            self.vcs.getPlugin().setPreferences(
+                "MqStatusDialogSplitterState", self.diffSplitter.saveState())
+        else:
+            self.vcs.getPlugin().setPreferences(
+                "StatusDialogGeometry", self.saveGeometry())
+            self.vcs.getPlugin().setPreferences(
+                "StatusDialogSplitterState", self.diffSplitter.saveState())
+        
+        e.accept()
+    
+    def show(self):
+        """
+        Public slot to show the dialog.
+        """
+        super(HgStatusDialog, self).show()
+        
+        if self.__mq:
+            geom = self.vcs.getPlugin().getPreferences(
+                "MqStatusDialogGeometry")
+        else:
+            geom = self.vcs.getPlugin().getPreferences(
+                "StatusDialogGeometry")
+        if geom.isEmpty():
+            s = QSize(800, 600)
+            self.resize(s)
+        else:
+            self.restoreGeometry(geom)
+        
+        if self.__mq:
+            diffSplitterState = self.vcs.getPlugin().getPreferences(
+                "MqStatusDialogSplitterState")
+        else:
+            diffSplitterState = self.vcs.getPlugin().getPreferences(
+                "StatusDialogSplitterState")
+        if diffSplitterState is not None:
+            self.diffSplitter.restoreState(diffSplitterState)
     
     def __resort(self):
         """
@@ -205,24 +310,6 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         if statusText not in self.__statusFilters:
             self.__statusFilters.append(statusText)
         
-    def closeEvent(self, e):
-        """
-        Protected slot implementing a close event handler.
-        
-        @param e close event (QCloseEvent)
-        """
-        if self.__hgClient:
-            if self.__hgClient.isExecuting():
-                self.__hgClient.cancel()
-        else:
-            if self.process is not None and \
-               self.process.state() != QProcess.NotRunning:
-                self.process.terminate()
-                QTimer.singleShot(2000, self.process.kill)
-                self.process.waitForFinished(3000)
-        
-        e.accept()
-    
     def start(self, fn):
         """
         Public slot to start the hg status command.
@@ -234,21 +321,11 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         self.intercept = False
         self.args = fn
         
-        for act in self.menuactions:
-            act.setEnabled(False)
-        for act in self.lfActions:
-            act.setEnabled(False)
-        
-        self.addButton.setEnabled(False)
-        self.commitButton.setEnabled(False)
-        self.diffButton.setEnabled(False)
-        self.sbsDiffButton.setEnabled(False)
-        self.revertButton.setEnabled(False)
-        self.forgetButton.setEnabled(False)
-        self.restoreButton.setEnabled(False)
+        self.actionsButton.setEnabled(False)
         
         self.statusFilterCombo.clear()
         self.__statusFilters = []
+        self.statusList.clear()
         
         if self.__mq:
             self.setWindowTitle(
@@ -284,6 +361,7 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         if self.__hgClient:
             self.inputGroup.setEnabled(False)
             self.inputGroup.hide()
+            self.refreshButton.setEnabled(False)
             
             out, err = self.__hgClient.runcommand(args)
             if err:
@@ -297,11 +375,6 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         else:
             if self.process:
                 self.process.kill()
-            else:
-                self.process = QProcess()
-                self.process.finished.connect(self.__procFinished)
-                self.process.readyReadStandardOutput.connect(self.__readStdout)
-                self.process.readyReadStandardError.connect(self.__readStderr)
             
             self.process.setWorkingDirectory(repodir)
             
@@ -318,8 +391,11 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
                         'Ensure, that it is in the search path.'
                     ).format('hg'))
             else:
-                self.inputGroup.setEnabled(True)
-                self.inputGroup.show()
+                self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
+                self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(True)
+                self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
+                
+                self.refreshButton.setEnabled(False)
     
     def __finish(self):
         """
@@ -346,16 +422,13 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         self.__statusFilters.insert(0, "<{0}>".format(self.tr("all")))
         self.statusFilterCombo.addItems(self.__statusFilters)
         
-        for act in self.menuactions:
-            act.setEnabled(True)
-        
-        self.process = None
+        if not self.__mq:
+            self.actionsButton.setEnabled(True)
         
         self.__resort()
         self.__resizeColumns()
         
-        self.__updateButtons()
-        self.__updateCommitButton()
+        self.__refreshDiff()
     
     def on_buttonBox_clicked(self, button):
         """
@@ -428,6 +501,11 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         self.errorGroup.show()
         self.errors.insertPlainText(out)
         self.errors.ensureCursorVisible()
+        
+        if not self.__hgClient:
+            # show input in case the process asked for some input
+            self.inputGroup.setEnabled(True)
+            self.inputGroup.show()
     
     def on_passwordCheckBox_toggled(self, isOn):
         """
@@ -445,17 +523,17 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -484,40 +562,14 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         """
         Private slot to refresh the status display.
         """
-        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
-        self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(True)
-        self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
-        
-        self.inputGroup.setEnabled(True)
-        self.inputGroup.show()
-        self.refreshButton.setEnabled(False)
-        
-        self.statusList.clear()
+        selectedItems = self.statusList.selectedItems()
+        if len(selectedItems) == 1:
+            self.__selectedName = selectedItems[0].text(self.__pathColumn)
+        else:
+            self.__selectedName = ""
         
         self.start(self.args)
     
-    def __updateButtons(self):
-        """
-        Private method to update the VCS buttons status.
-        """
-        modified = len(self.__getModifiedItems())
-        unversioned = len(self.__getUnversionedItems())
-        missing = len(self.__getMissingItems())
-
-        self.addButton.setEnabled(unversioned)
-        self.diffButton.setEnabled(modified)
-        self.sbsDiffButton.setEnabled(modified == 1)
-        self.revertButton.setEnabled(modified)
-        self.forgetButton.setEnabled(missing)
-        self.restoreButton.setEnabled(missing)
-    
-    def __updateCommitButton(self):
-        """
-        Private method to update the Commit button status.
-        """
-        commitable = len(self.__getCommitableItems())
-        self.commitButton.setEnabled(commitable)
-    
     @pyqtSlot(str)
     def on_statusFilterCombo_activated(self, txt):
         """
@@ -534,87 +586,26 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
                 topItem = self.statusList.topLevelItem(topIndex)
                 topItem.setHidden(topItem.text(self.__statusColumn) != txt)
     
-    @pyqtSlot(QTreeWidgetItem, int)
-    def on_statusList_itemChanged(self, item, column):
-        """
-        Private slot to act upon item changes.
-        
-        @param item reference to the changed item (QTreeWidgetItem)
-        @param column index of column that changed (integer)
-        """
-        if column == self.__toBeCommittedColumn:
-            self.__updateCommitButton()
-    
     @pyqtSlot()
     def on_statusList_itemSelectionChanged(self):
         """
         Private slot to act upon changes of selected items.
         """
-        self.__updateButtons()
-    
-    @pyqtSlot()
-    def on_commitButton_clicked(self):
-        """
-        Private slot to handle the press of the Commit button.
-        """
-        self.__commit()
-    
-    @pyqtSlot()
-    def on_addButton_clicked(self):
-        """
-        Private slot to handle the press of the Add button.
-        """
-        self.__add()
-    
-    @pyqtSlot()
-    def on_diffButton_clicked(self):
-        """
-        Private slot to handle the press of the Differences button.
-        """
-        self.__diff()
-    
-    @pyqtSlot()
-    def on_sbsDiffButton_clicked(self):
-        """
-        Private slot to handle the press of the Side-by-Side Diff button.
-        """
-        self.__sbsDiff()
-    
-    @pyqtSlot()
-    def on_revertButton_clicked(self):
-        """
-        Private slot to handle the press of the Revert button.
-        """
-        self.__revert()
-    
-    @pyqtSlot()
-    def on_forgetButton_clicked(self):
-        """
-        Private slot to handle the press of the Forget button.
-        """
-        self.__forget()
-    
-    @pyqtSlot()
-    def on_restoreButton_clicked(self):
-        """
-        Private slot to handle the press of the Restore button.
-        """
-        self.__restoreMissing()
+        self.__generateDiffs()
     
     ###########################################################################
-    ## Context menu handling methods
+    ## Menu handling methods
     ###########################################################################
     
-    def __showContextMenu(self, coord):
+    def __showActionsMenu(self):
         """
-        Private slot to show the context menu of the status list.
-        
-        @param coord the position of the mouse pointer (QPoint)
+        Private slot to prepare the actions button menu before it is shown.
         """
         modified = len(self.__getModifiedItems())
         unversioned = len(self.__getUnversionedItems())
         missing = len(self.__getMissingItems())
         commitable = len(self.__getCommitableItems())
+        commitableUnselected = len(self.__getCommitableUnselectedItems())
 
         self.__addAct.setEnabled(unversioned)
         self.__diffAct.setEnabled(modified)
@@ -623,22 +614,15 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
         self.__forgetAct.setEnabled(missing)
         self.__restoreAct.setEnabled(missing)
         self.__commitAct.setEnabled(commitable)
+        self.__commitSelectAct.setEnabled(commitableUnselected)
+        self.__commitDeselectAct.setEnabled(commitable)
         
         if self.vcs.isExtensionActive("largefiles"):
-            enable = len(self.__getUnversionedItems()) > 0
+            enable = bool(unversioned)
         else:
             enable = False
-        for act in self.lfActions:
-            act.setEnabled(enable)
-        self.menu.popup(self.statusList.mapToGlobal(coord))
-    
-    def __showAddMenu(self):
-        """
-        Private slot to prepare the Add button menu before it is shown.
-        """
-        enable = self.vcs.isExtensionActive("largefiles")
-        for act in self.__lfAddActions:
-            act.setEnabled(enable)
+        self.__lfAddLargeAct.setEnabled(enable)
+        self.__lfAddNormalAct.setEnabled(enable)
     
     def __commit(self):
         """
@@ -807,7 +791,7 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             from .HgDiffDialog import HgDiffDialog
             self.diff = HgDiffDialog(self.vcs)
         self.diff.show()
-        self.diff.start(names)
+        self.diff.start(names, refreshable=True)
     
     def __sbsDiff(self):
         """
@@ -845,6 +829,21 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
                 commitableItems.append(itm)
         return commitableItems
     
+    def __getCommitableUnselectedItems(self):
+        """
+        Private method to retrieve all entries the user may commit but hasn't
+        selected.
+        
+        @return list of all items, the user has checked
+        """
+        items = []
+        for index in range(self.statusList.topLevelItemCount()):
+            itm = self.statusList.topLevelItem(index)
+            if itm.flags() & Qt.ItemIsUserCheckable and \
+               itm.checkState(self.__toBeCommittedColumn) == Qt.Unchecked:
+                items.append(itm)
+        return items
+    
     def __getModifiedItems(self):
         """
         Private method to retrieve all entries, that have a modified status.
@@ -895,3 +894,53 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
                     itm.setCheckState(self.__toBeCommittedColumn, Qt.Checked)
                 else:
                     itm.setCheckState(self.__toBeCommittedColumn, Qt.Unchecked)
+    
+    ###########################################################################
+    ## Diff handling methods below
+    ###########################################################################
+    
+    def __generateDiffs(self):
+        """
+        Private slot to generate diff outputs for the selected item.
+        """
+        self.diffEdit.clear()
+        self.diffHighlighter.regenerateRules()
+        
+        if not self.__mq:
+            selectedItems = self.statusList.selectedItems()
+            if len(selectedItems) == 1:
+                fn = os.path.join(self.dname,
+                                  selectedItems[0].text(self.__pathColumn))
+                self.__diffGenerator.start(fn)
+    
+    def __generatorFinished(self):
+        """
+        Private slot connected to the finished signal of the diff generator.
+        """
+        diff = self.__diffGenerator.getResult()[0]
+        
+        if diff:
+            for line in diff[:]:
+                if line.startswith("@@ "):
+                    break
+                else:
+                    diff.pop(0)
+            self.diffEdit.setPlainText("".join(diff))
+        
+        tc = self.diffEdit.textCursor()
+        tc.movePosition(QTextCursor.Start)
+        self.diffEdit.setTextCursor(tc)
+        self.diffEdit.ensureCursorVisible()
+    
+    def __refreshDiff(self):
+        """
+        Private method to refresh the diff output after a refresh.
+        """
+        if self.__selectedName and not self.__mq:
+            for index in range(self.statusList.topLevelItemCount()):
+                itm = self.statusList.topLevelItem(index)
+                if itm.text(self.__pathColumn) == self.__selectedName:
+                    itm.setSelected(True)
+                    break
+        
+        self.__selectedName = ""
