@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,14 +15,19 @@ except NameError:
 
 import os
 
-from PyQt5.QtCore import pyqtSlot, QProcess, Qt, QTimer, QCoreApplication
+from PyQt5.QtCore import pyqtSlot, QProcess, Qt, QTimer, QCoreApplication, \
+    QPoint
 from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QHeaderView, \
-    QTreeWidgetItem, QLineEdit
+    QTreeWidgetItem, QLineEdit, QMenu
 
+from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
 
 from .Ui_HgTagBranchListDialog import Ui_HgTagBranchListDialog
 
+import UI.PixmapCache
+from Globals import strToQByteArray
+
 
 class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
     """
@@ -42,18 +47,28 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
-        self.process = QProcess()
+        self.refreshButton = self.buttonBox.addButton(
+            self.tr("&Refresh"), QDialogButtonBox.ActionRole)
+        self.refreshButton.setToolTip(
+            self.tr("Press to refresh the list"))
+        self.refreshButton.setEnabled(False)
+        
         self.vcs = vcs
         self.tagsList = None
         self.allTagsList = None
         self.__hgClient = vcs.getClient()
+        self.__currentRevision = ""
         
         self.tagList.headerItem().setText(self.tagList.columnCount(), "")
         self.tagList.header().setSortIndicator(3, Qt.AscendingOrder)
         
-        self.process.finished.connect(self.__procFinished)
-        self.process.readyReadStandardOutput.connect(self.__readStdout)
-        self.process.readyReadStandardError.connect(self.__readStderr)
+        if self.__hgClient:
+            self.process = None
+        else:
+            self.process = QProcess()
+            self.process.finished.connect(self.__procFinished)
+            self.process.readyReadStandardOutput.connect(self.__readStdout)
+            self.process.readyReadStandardError.connect(self.__readStderr)
         
         self.show()
         QCoreApplication.processEvents()
@@ -88,6 +103,7 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
         @param allTagsList reference to string list all tags (list of strings)
         """
         self.errorGroup.hide()
+        self.tagList.clear()
         
         self.intercept = False
         self.tagsMode = tags
@@ -106,6 +122,7 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
             repodir = os.path.dirname(repodir)
             if os.path.splitdrive(repodir)[1] == os.sep:
                 return
+        self.__repoDir = repodir
         
         if self.tagsMode:
             args = self.vcs.initCommand("tags")
@@ -160,6 +177,7 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
         
         self.inputGroup.setEnabled(False)
         self.inputGroup.hide()
+        self.refreshButton.setEnabled(True)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
@@ -167,10 +185,19 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setFocus(
             Qt.OtherFocusReason)
         
-        self.process = None
-        
+        if not self.tagsMode:
+            self.__highlightCurrentBranch()
         self.__resizeColumns()
         self.__resort()
+        
+        # restore current item
+        if self.__currentRevision:
+            items = self.tagList.findItems(
+                self.__currentRevision, Qt.MatchExactly, 0)
+            if items:
+                self.tagList.setCurrentItem(items[0])
+                self.__currentRevision = ""
+                self.tagList.setFocus(Qt.OtherFocusReason)
     
     def on_buttonBox_clicked(self, button):
         """
@@ -185,6 +212,8 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
                 self.__hgClient.cancel()
             else:
                 self.__finish()
+        elif button == self.refreshButton:
+            self.on_refreshButton_clicked()
     
     def __procFinished(self, exitCode, exitStatus):
         """
@@ -310,17 +339,17 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -343,3 +372,124 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
             evt.accept()
             return
         super(HgTagBranchListDialog, self).keyPressEvent(evt)
+    
+    def __highlightCurrentBranch(self):
+        """
+        Private method to highlight the current branch with a bold font.
+        """
+        currentBranch = self.vcs.hgGetCurrentBranch(self.__repoDir)
+        if currentBranch:
+            items = self.tagList.findItems(
+                currentBranch, Qt.MatchCaseSensitive, 3)
+            if len(items) == 1:
+                font = items[0].font(3)
+                font.setBold(True)
+                for column in range(4):
+                    items[0].setFont(column, font)
+    
+    @pyqtSlot()
+    def on_refreshButton_clicked(self):
+        """
+        Private slot to refresh the log.
+        """
+        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
+        self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(True)
+        self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
+        
+        if not self.__hgClient:
+            self.inputGroup.setEnabled(True)
+            self.inputGroup.show()
+        self.refreshButton.setEnabled(False)
+        
+        # save the current items commit ID
+        itm = self.tagList.currentItem()
+        if itm is not None:
+            self.__currentRevision = itm.text(0)
+        else:
+            self.__currentRevision = ""
+        
+        self.start(self.__repoDir, self.tagsMode, self.tagsList,
+                   self.allTagsList)
+    
+    @pyqtSlot(QPoint)
+    def on_tagList_customContextMenuRequested(self, pos):
+        """
+        Private slot to handle the context menu request.
+        
+        @param pos position the context menu was requested at
+        @type QPoint
+        """
+        itm = self.tagList.itemAt(pos)
+        if itm is not None:
+            menu = QMenu(self.tagList)
+            if self.tagsMode:
+                menu.addAction(
+                    UI.PixmapCache.getIcon("vcsSwitch.png"),
+                    self.tr("Switch to"), self.__switchTo)
+            else:
+                menu.addAction(
+                    UI.PixmapCache.getIcon("vcsSwitch.png"),
+                    self.tr("Switch to"), self.__switchTo)
+                menu.addSeparator()
+                act = menu.addAction(self.tr("Close Branch"),
+                                     self.__closeBranch)
+                act.setEnabled(itm.text(3) != "default")
+            menu.popup(self.tagList.mapToGlobal(pos))
+    
+    def __switchTo(self):
+        """
+        Private slot to switch the working directory to the selected revision.
+        """
+        itm = self.tagList.currentItem()
+        rev = itm.text(0).strip()
+        if rev:
+            shouldReopen = self.vcs.vcsUpdate(self.__repoDir, revision=rev)
+            if shouldReopen:
+                res = E5MessageBox.yesNo(
+                    None,
+                    self.tr("Switch"),
+                    self.tr(
+                        """The project should be reread. Do this now?"""),
+                    yesDefault=True)
+                if res:
+                    e5App().getObject("Project").reopenProject()
+                    return
+            
+            self.on_refreshButton_clicked()
+    
+    def __closeBranch(self):
+        """
+        Private slot to close the selected branch.
+        """
+        itm = self.tagList.currentItem()
+        branch = itm.text(3).strip()
+        if branch == "default":
+            E5MessageBox.warning(
+                self,
+                self.tr("Close Branch"),
+                self.tr("""The branch "default" cannot be closed."""
+                        """ Aborting..."""))
+            return
+        
+        yes = E5MessageBox.yesNo(
+            self,
+            self.tr("Close Branch"),
+            self.tr("""<p>Shall the branch <b>{0}</b> really be closed?"""
+                    """</p>""").format(branch))
+        if yes:
+            switched = False
+            currentBranch = self.vcs.hgGetCurrentBranch(self.__repoDir)
+            if currentBranch != branch:
+                # step 1: switch to branch to be closed
+                switched = True
+                self.vcs.vcsUpdate(self.__repoDir, noDialog=True,
+                                   revision=branch)
+            self.vcs.vcsCommit(self.__repoDir,
+                               "Branch <{0}> closed.".format(branch),
+                               noDialog=True,
+                               closeBranch=True)
+            if switched:
+                self.vcs.vcsUpdate(self.__repoDir, noDialog=True,
+                                   revision=currentBranch)
+            
+            self.on_refreshButton_clicked()
