@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,7 +11,7 @@ from __future__ import unicode_literals
 
 import os
 
-from PyQt5.QtWidgets import QMenu
+from PyQt5.QtWidgets import QMenu, QToolBar
 
 from E5Gui import E5MessageBox
 from E5Gui.E5Application import e5App
@@ -44,25 +44,29 @@ class HgProjectHelper(VcsProjectHelper):
         from .FetchExtension.ProjectHelper import FetchProjectHelper
         from .PurgeExtension.ProjectHelper import PurgeProjectHelper
         from .GpgExtension.ProjectHelper import GpgProjectHelper
-        from .TransplantExtension.ProjectHelper import TransplantProjectHelper
         from .RebaseExtension.ProjectHelper import RebaseProjectHelper
         from .ShelveExtension.ProjectHelper import ShelveProjectHelper
         from .LargefilesExtension.ProjectHelper import LargefilesProjectHelper
+        from .StripExtension.ProjectHelper import StripProjectHelper
+        from .HisteditExtension.ProjectHelper import HisteditProjectHelper
         self.__extensions = {
             "mq": QueuesProjectHelper(),
             "fetch": FetchProjectHelper(),
             "purge": PurgeProjectHelper(),
             "gpg": GpgProjectHelper(),
-            "transplant": TransplantProjectHelper(),
             "rebase": RebaseProjectHelper(),
             "shelve": ShelveProjectHelper(),
             "largefiles": LargefilesProjectHelper(),
+            "strip": StripProjectHelper(),
+            "histedit": HisteditProjectHelper(),
         }
         
         self.__extensionMenuTitles = {}
         for extension in self.__extensions:
             self.__extensionMenuTitles[
                 self.__extensions[extension].menuTitle()] = extension
+        
+        self.__toolbarManager = None
     
     def setObjects(self, vcsObject, projectObject):
         """
@@ -78,6 +82,17 @@ class HgProjectHelper(VcsProjectHelper):
             extension.setObjects(vcsObject, projectObject)
         
         self.vcs.iniFileChanged.connect(self.__checkActions)
+        
+        title = self.__toolbar.windowTitle()
+        if self.vcs.version >= (3, 9):
+            self.actions.append(self.hgBookmarkPullCurrentAct)
+            self.__toolbarManager.addAction(self.hgBookmarkPullCurrentAct,
+                                            title)
+        
+        if self.vcs.version >= (3, 8):
+            self.actions.append(self.hgBookmarkPushCurrentAct)
+            self.__toolbarManager.addAction(self.hgBookmarkPushCurrentAct,
+                                            title)
     
     def getProject(self):
         """
@@ -245,21 +260,6 @@ class HgProjectHelper(VcsProjectHelper):
         self.vcsExportAct.triggered.connect(self._vcsExport)
         self.actions.append(self.vcsExportAct)
         
-        self.vcsLogAct = E5Action(
-            self.tr('Show log'),
-            UI.PixmapCache.getIcon("vcsLog.png"),
-            self.tr('Show &log'),
-            0, 0, self, 'mercurial_log')
-        self.vcsLogAct.setStatusTip(self.tr(
-            'Show the log of the local project'
-        ))
-        self.vcsLogAct.setWhatsThis(self.tr(
-            """<b>Show log</b>"""
-            """<p>This shows the log of the local project.</p>"""
-        ))
-        self.vcsLogAct.triggered.connect(self._vcsLog)
-        self.actions.append(self.vcsLogAct)
-        
         self.hgLogBrowserAct = E5Action(
             self.tr('Show log browser'),
             UI.PixmapCache.getIcon("vcsLog.png"),
@@ -769,6 +769,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgBundleAct = E5Action(
             self.tr('Create changegroup'),
+            UI.PixmapCache.getIcon("vcsCreateChangegroup.png"),
             self.tr('Create changegroup...'),
             0, 0, self, 'mercurial_bundle')
         self.hgBundleAct.setStatusTip(self.tr(
@@ -784,6 +785,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgPreviewBundleAct = E5Action(
             self.tr('Preview changegroup'),
+            UI.PixmapCache.getIcon("vcsPreviewChangegroup.png"),
             self.tr('Preview changegroup...'),
             0, 0, self, 'mercurial_preview_bundle')
         self.hgPreviewBundleAct.setStatusTip(self.tr(
@@ -799,6 +801,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgUnbundleAct = E5Action(
             self.tr('Apply changegroups'),
+            UI.PixmapCache.getIcon("vcsApplyChangegroup.png"),
             self.tr('Apply changegroups...'),
             0, 0, self, 'mercurial_unbundle')
         self.hgUnbundleAct.setStatusTip(self.tr(
@@ -925,6 +928,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgImportAct = E5Action(
             self.tr('Import Patch'),
+            UI.PixmapCache.getIcon("vcsImportPatch.png"),
             self.tr('Import Patch...'),
             0, 0, self, 'mercurial_import')
         self.hgImportAct.setStatusTip(self.tr(
@@ -940,6 +944,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgExportAct = E5Action(
             self.tr('Export Patches'),
+            UI.PixmapCache.getIcon("vcsExportPatch.png"),
             self.tr('Export Patches...'),
             0, 0, self, 'mercurial_export')
         self.hgExportAct.setStatusTip(self.tr(
@@ -1154,6 +1159,22 @@ class HgProjectHelper(VcsProjectHelper):
         self.hgBookmarkPullAct.triggered.connect(self.__hgBookmarkPull)
         self.actions.append(self.hgBookmarkPullAct)
         
+        self.hgBookmarkPullCurrentAct = E5Action(
+            self.tr('Pull current bookmark'),
+            UI.PixmapCache.getIcon("pullBookmark.png"),
+            self.tr('Pull current bookmark'),
+            0, 0, self, 'mercurial_pull_current_bookmark')
+        self.hgBookmarkPullCurrentAct.setStatusTip(self.tr(
+            'Pull the current bookmark from a remote repository'
+        ))
+        self.hgBookmarkPullCurrentAct.setWhatsThis(self.tr(
+            """<b>Pull current bookmark</b>"""
+            """<p>This pulls the current bookmark from a remote"""
+            """ repository into the local repository.</p>"""
+        ))
+        self.hgBookmarkPullCurrentAct.triggered.connect(
+            self.__hgBookmarkPullCurrent)
+        
         self.hgBookmarkOutgoingAct = E5Action(
             self.tr('Show outgoing bookmarks'),
             UI.PixmapCache.getIcon("outgoingBookmark.png"),
@@ -1187,6 +1208,40 @@ class HgProjectHelper(VcsProjectHelper):
         self.hgBookmarkPushAct.triggered.connect(self.__hgBookmarkPush)
         self.actions.append(self.hgBookmarkPushAct)
     
+        self.hgBookmarkPushCurrentAct = E5Action(
+            self.tr('Push current bookmark'),
+            UI.PixmapCache.getIcon("pushBookmark.png"),
+            self.tr('Push current bookmark'),
+            0, 0, self, 'mercurial_push_current_bookmark')
+        self.hgBookmarkPushCurrentAct.setStatusTip(self.tr(
+            'Push the current bookmark to a remote repository'
+        ))
+        self.hgBookmarkPushCurrentAct.setWhatsThis(self.tr(
+            """<b>Push current bookmark</b>"""
+            """<p>This pushes the current bookmark from the local"""
+            """ repository to a remote repository.</p>"""
+        ))
+        self.hgBookmarkPushCurrentAct.triggered.connect(
+            self.__hgBookmarkPushCurrent)
+        self.actions.append(self.hgBookmarkPushCurrentAct)
+    
+        self.hgDeleteBackupsAct = E5Action(
+            self.tr('Delete all backups'),
+            UI.PixmapCache.getIcon("clearPrivateData.png"),
+            self.tr('Delete all backups'),
+            0, 0, self, 'mercurial_delete_all_backups')
+        self.hgDeleteBackupsAct.setStatusTip(self.tr(
+            'Delete all backup bundles stored in the backup area'
+        ))
+        self.hgDeleteBackupsAct.setWhatsThis(self.tr(
+            """<b>Delete all backups</b>"""
+            """<p>This deletes all backup bundles stored in the backup"""
+            """ area of the repository.</p>"""
+        ))
+        self.hgDeleteBackupsAct.triggered.connect(
+            self.__hgDeleteBackups)
+        self.actions.append(self.hgDeleteBackupsAct)
+    
     def __checkActions(self):
         """
         Private slot to set the enabled status of actions.
@@ -1195,6 +1250,8 @@ class HgProjectHelper(VcsProjectHelper):
         self.hgIncomingAct.setEnabled(self.vcs.canPull())
         self.hgBookmarkPullAct.setEnabled(self.vcs.canPull())
         self.hgBookmarkIncomingAct.setEnabled(self.vcs.canPull())
+        if self.vcs.version >= (3, 9):
+            self.hgBookmarkPullCurrentAct.setEnabled(self.vcs.canPull())
         
         self.hgPushAct.setEnabled(self.vcs.canPush())
         self.hgPushBranchAct.setEnabled(self.vcs.canPush())
@@ -1202,6 +1259,8 @@ class HgProjectHelper(VcsProjectHelper):
         self.hgOutgoingAct.setEnabled(self.vcs.canPush())
         self.hgBookmarkPushAct.setEnabled(self.vcs.canPush())
         self.hgBookmarkOutgoingAct.setEnabled(self.vcs.canPush())
+        if self.vcs.version >= (3, 8):
+            self.hgBookmarkPushCurrentAct.setEnabled(self.vcs.canPull())
     
     def initMenu(self, menu):
         """
@@ -1234,6 +1293,8 @@ class HgProjectHelper(VcsProjectHelper):
         adminMenu.addAction(self.hgRollbackAct)
         adminMenu.addSeparator()
         adminMenu.addAction(self.hgVerifyAct)
+        adminMenu.addSeparator()
+        adminMenu.addAction(self.hgDeleteBackupsAct)
         self.subMenus.append(adminMenu)
         
         specialsMenu = QMenu(self.tr("Specials"), menu)
@@ -1294,9 +1355,13 @@ class HgProjectHelper(VcsProjectHelper):
         bookmarksMenu.addSeparator()
         bookmarksMenu.addAction(self.hgBookmarkIncomingAct)
         bookmarksMenu.addAction(self.hgBookmarkPullAct)
+        if self.vcs.version >= (3, 9):
+            bookmarksMenu.addAction(self.hgBookmarkPullCurrentAct)
         bookmarksMenu.addSeparator()
         bookmarksMenu.addAction(self.hgBookmarkOutgoingAct)
         bookmarksMenu.addAction(self.hgBookmarkPushAct)
+        if self.vcs.version >= (3, 8):
+            bookmarksMenu.addAction(self.hgBookmarkPushCurrentAct)
         self.subMenus.append(bookmarksMenu)
         
         self.__extensionsMenu = QMenu(self.tr("Extensions"), menu)
@@ -1310,14 +1375,11 @@ class HgProjectHelper(VcsProjectHelper):
                     self.__extensionsMenu))
         self.vcs.activeExtensionsChanged.connect(self.__showExtensionMenu)
         
-        if self.vcs.version >= (2, 0):
-            graftMenu = QMenu(self.tr("Graft"), menu)
-            graftMenu.setIcon(UI.PixmapCache.getIcon("vcsGraft.png"))
-            graftMenu.setTearOffEnabled(True)
-            graftMenu.addAction(self.hgGraftAct)
-            graftMenu.addAction(self.hgGraftContinueAct)
-        else:
-            graftMenu = None
+        graftMenu = QMenu(self.tr("Graft"), menu)
+        graftMenu.setIcon(UI.PixmapCache.getIcon("vcsGraft.png"))
+        graftMenu.setTearOffEnabled(True)
+        graftMenu.addAction(self.hgGraftAct)
+        graftMenu.addAction(self.hgGraftContinueAct)
         
         subrepoMenu = QMenu(self.tr("Sub-Repository"), menu)
         subrepoMenu.setTearOffEnabled(True)
@@ -1327,12 +1389,15 @@ class HgProjectHelper(VcsProjectHelper):
         changesMenu = QMenu(self.tr("Manage Changes"), menu)
         changesMenu.setTearOffEnabled(True)
         changesMenu.addAction(self.vcsRevertAct)
+        changesMenu.addSeparator()
         changesMenu.addAction(self.vcsMergeAct)
         changesMenu.addAction(self.hgShowConflictsAct)
         changesMenu.addAction(self.vcsResolveAct)
         changesMenu.addAction(self.hgUnresolveAct)
         changesMenu.addAction(self.hgReMergeAct)
         changesMenu.addAction(self.hgCancelMergeAct)
+        changesMenu.addSeparator()
+        changesMenu.addAction(self.hgPhaseAct)
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
@@ -1352,22 +1417,18 @@ class HgProjectHelper(VcsProjectHelper):
         menu.addAction(self.hgOutgoingAct)
         menu.addAction(self.hgPushAct)
         menu.addSeparator()
+        menu.addMenu(changesMenu)
+        menu.addSeparator()
         if graftMenu is not None:
             menu.addMenu(graftMenu)
             menu.addSeparator()
         menu.addMenu(bundleMenu)
         menu.addMenu(patchMenu)
         menu.addSeparator()
-        menu.addMenu(self.__extensionsMenu)
-        menu.addSeparator()
-        menu.addAction(self.vcsNewAct)
-        menu.addAction(self.vcsExportAct)
-        menu.addSeparator()
         menu.addMenu(tagsMenu)
         menu.addMenu(branchesMenu)
         menu.addMenu(bookmarksMenu)
         menu.addSeparator()
-        menu.addAction(self.vcsLogAct)
         menu.addAction(self.hgLogBrowserAct)
         menu.addSeparator()
         menu.addAction(self.vcsStatusAct)
@@ -1376,10 +1437,7 @@ class HgProjectHelper(VcsProjectHelper):
         menu.addAction(self.vcsDiffAct)
         menu.addAction(self.hgExtDiffAct)
         menu.addSeparator()
-        if self.vcs.version >= (2, 1):
-            menu.addAction(self.hgPhaseAct)
-            menu.addSeparator()
-        menu.addMenu(changesMenu)
+        menu.addMenu(self.__extensionsMenu)
         menu.addSeparator()
         menu.addAction(self.vcsSwitchAct)
         menu.addSeparator()
@@ -1396,6 +1454,90 @@ class HgProjectHelper(VcsProjectHelper):
         menu.addSeparator()
         menu.addAction(self.hgEditUserConfigAct)
         menu.addAction(self.hgConfigAct)
+        menu.addSeparator()
+        menu.addAction(self.vcsNewAct)
+        menu.addAction(self.vcsExportAct)
+    
+    def initToolbar(self, ui, toolbarManager):
+        """
+        Public slot to initialize the VCS toolbar.
+        
+        @param ui reference to the main window (UserInterface)
+        @param toolbarManager reference to a toolbar manager object
+            (E5ToolBarManager)
+        """
+        self.__toolbarManager = toolbarManager
+        
+        self.__toolbar = QToolBar(self.tr("Mercurial"), ui)
+        self.__toolbar.setIconSize(UI.Config.ToolBarIconSize)
+        self.__toolbar.setObjectName("MercurialToolbar")
+        self.__toolbar.setToolTip(self.tr('Mercurial'))
+        
+        self.__toolbar.addAction(self.hgLogBrowserAct)
+        self.__toolbar.addAction(self.vcsStatusAct)
+        self.__toolbar.addSeparator()
+        self.__toolbar.addAction(self.vcsDiffAct)
+        self.__toolbar.addSeparator()
+        self.__toolbar.addAction(self.vcsNewAct)
+        self.__toolbar.addAction(self.vcsExportAct)
+        self.__toolbar.addSeparator()
+        
+        title = self.__toolbar.windowTitle()
+        toolbarManager.addToolBar(self.__toolbar, title)
+        toolbarManager.addAction(self.hgPullAct, title)
+        toolbarManager.addAction(self.vcsUpdateAct, title)
+        toolbarManager.addAction(self.vcsCommitAct, title)
+        toolbarManager.addAction(self.hgPushAct, title)
+        toolbarManager.addAction(self.hgPushForcedAct, title)
+        toolbarManager.addAction(self.hgExtDiffAct, title)
+        toolbarManager.addAction(self.hgSummaryAct, title)
+        toolbarManager.addAction(self.vcsRevertAct, title)
+        toolbarManager.addAction(self.vcsMergeAct, title)
+        toolbarManager.addAction(self.hgReMergeAct, title)
+        toolbarManager.addAction(self.vcsTagAct, title)
+        toolbarManager.addAction(self.hgBranchAct, title)
+        toolbarManager.addAction(self.vcsSwitchAct, title)
+        toolbarManager.addAction(self.hgGraftAct, title)
+        toolbarManager.addAction(self.hgAddSubrepoAct, title)
+        toolbarManager.addAction(self.hgRemoveSubreposAct, title)
+        toolbarManager.addAction(self.hgArchiveAct, title)
+        toolbarManager.addAction(self.hgBookmarksListAct, title)
+        toolbarManager.addAction(self.hgBookmarkDefineAct, title)
+        toolbarManager.addAction(self.hgBookmarkDeleteAct, title)
+        toolbarManager.addAction(self.hgBookmarkRenameAct, title)
+        toolbarManager.addAction(self.hgBookmarkMoveAct, title)
+        toolbarManager.addAction(self.hgBookmarkPullAct, title)
+        toolbarManager.addAction(self.hgBookmarkPushAct, title)
+        toolbarManager.addAction(self.hgImportAct, title)
+        toolbarManager.addAction(self.hgExportAct, title)
+        toolbarManager.addAction(self.hgBundleAct, title)
+        toolbarManager.addAction(self.hgPreviewBundleAct, title)
+        toolbarManager.addAction(self.hgUnbundleAct, title)
+        
+        self.__toolbar.setEnabled(False)
+        self.__toolbar.setVisible(False)
+        
+        ui.registerToolbar("mercurial", self.__toolbar.windowTitle(),
+                           self.__toolbar)
+        ui.addToolBar(self.__toolbar)
+    
+    def removeToolbar(self, ui, toolbarManager):
+        """
+        Public method to remove a toolbar created by initToolbar().
+        
+        @param ui reference to the main window (UserInterface)
+        @param toolbarManager reference to a toolbar manager object
+            (E5ToolBarManager)
+        """
+        ui.removeToolBar(self.__toolbar)
+        ui.unregisterToolbar("mercurial")
+        
+        title = self.__toolbar.windowTitle()
+        toolbarManager.removeCategoryActions(title)
+        toolbarManager.removeToolBar(self.__toolbar)
+        
+        self.__toolbar.deleteLater()
+        self.__toolbar = None
     
     def showMenu(self):
         """
@@ -1839,8 +1981,27 @@ class HgProjectHelper(VcsProjectHelper):
         """
         self.vcs.hgBookmarkPull(self.project.getProjectPath())
     
+    def __hgBookmarkPullCurrent(self):
+        """
+        Private slot used to pull the current bookmark from a remote
+        repository.
+        """
+        self.vcs.hgBookmarkPull(self.project.getProjectPath(), current=True)
+    
     def __hgBookmarkPush(self):
         """
         Private slot used to push a bookmark to a remote repository.
         """
         self.vcs.hgBookmarkPush(self.project.getProjectPath())
+    
+    def __hgBookmarkPushCurrent(self):
+        """
+        Private slot used to push the current bookmark to a remote repository.
+        """
+        self.vcs.hgBookmarkPush(self.project.getProjectPath(), current=True)
+    
+    def __hgDeleteBackups(self):
+        """
+        Private slot used to delete all backup bundles.
+        """
+        self.vcs.hgDeleteBackups()
