@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -22,6 +22,8 @@ from E5Gui import E5MessageBox
 
 from .Ui_HgQueuesHeaderDialog import Ui_HgQueuesHeaderDialog
 
+import Utilities
+
 
 class HgQueuesHeaderDialog(QDialog, Ui_HgQueuesHeaderDialog):
     """
@@ -41,13 +43,16 @@ class HgQueuesHeaderDialog(QDialog, Ui_HgQueuesHeaderDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
-        self.process = QProcess()
         self.vcs = vcs
         self.__hgClient = vcs.getClient()
         
-        self.process.finished.connect(self.__procFinished)
-        self.process.readyReadStandardOutput.connect(self.__readStdout)
-        self.process.readyReadStandardError.connect(self.__readStderr)
+        if self.__hgClient:
+            self.process = None
+        else:
+            self.process = QProcess()
+            self.process.finished.connect(self.__procFinished)
+            self.process.readyReadStandardOutput.connect(self.__readStdout)
+            self.process.readyReadStandardError.connect(self.__readStderr)
         
         self.show()
         QCoreApplication.processEvents()
@@ -128,8 +133,6 @@ class HgQueuesHeaderDialog(QDialog, Ui_HgQueuesHeaderDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         self.buttonBox.button(QDialogButtonBox.Close).setFocus(
             Qt.OtherFocusReason)
-        
-        self.process = None
     
     def on_buttonBox_clicked(self, button):
         """
@@ -172,7 +175,7 @@ class HgQueuesHeaderDialog(QDialog, Ui_HgQueuesHeaderDialog):
         
         @param out output to be shown (string)
         """
-        self.messageEdit.appendPlainText(out)
+        self.messageEdit.appendPlainText(Utilities.filterAnsiSequences(out))
     
     def __readStderr(self):
         """
@@ -193,4 +196,4 @@ class HgQueuesHeaderDialog(QDialog, Ui_HgQueuesHeaderDialog):
         @param out error to be shown (string)
         """
         self.messageEdit.appendPlainText(self.tr("Error: "))
-        self.messageEdit.appendPlainText(out)
+        self.messageEdit.appendPlainText(Utilities.filterAnsiSequences(out))
