@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -23,6 +23,8 @@ from E5Gui import E5MessageBox
 
 from .Ui_HgQueuesListDialog import Ui_HgQueuesListDialog
 
+from Globals import strToQByteArray
+
 
 class HgQueuesListDialog(QDialog, Ui_HgQueuesListDialog):
     """
@@ -43,15 +45,18 @@ class HgQueuesListDialog(QDialog, Ui_HgQueuesListDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
-        self.process = QProcess()
         self.vcs = vcs
         self.__hgClient = vcs.getClient()
         
         self.patchesList.header().setSortIndicator(0, Qt.AscendingOrder)
         
-        self.process.finished.connect(self.__procFinished)
-        self.process.readyReadStandardOutput.connect(self.__readStdout)
-        self.process.readyReadStandardError.connect(self.__readStderr)
+        if self.__hgClient:
+            self.process = None
+        else:
+            self.process = QProcess()
+            self.process.finished.connect(self.__procFinished)
+            self.process.readyReadStandardOutput.connect(self.__readStdout)
+            self.process.readyReadStandardError.connect(self.__readStderr)
         
         self.__statusDict = {
             "A": self.tr("applied"),
@@ -223,8 +228,6 @@ class HgQueuesListDialog(QDialog, Ui_HgQueuesListDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setFocus(
             Qt.OtherFocusReason)
         
-        self.process = None
-        
         if self.patchesList.topLevelItemCount() == 0:
             # no patches present
             self.__generateItem(
@@ -407,17 +410,17 @@ class HgQueuesListDialog(QDialog, Ui_HgQueuesListDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
