@@ -1,21 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Module defining configuration variables for the subversion package
+Module defining configuration variables for the subversion package.
 """
 
-from PyQt4.QtCore import QStringList
+from __future__ import unicode_literals
+
+# Available protocols for the repository URL
+ConfigSvnProtocols = [
+    'file://',
+    'http://',
+    'https://',
+    'svn://',
+    'svn+ssh://',
+]
 
-# Available protocols fpr the repository URL
-ConfigSvnProtocols = QStringList()
-ConfigSvnProtocols.append('file://')
-ConfigSvnProtocols.append('http://')
-ConfigSvnProtocols.append('https://')
-ConfigSvnProtocols.append('svn://')
-ConfigSvnProtocols.append('svn+ssh://')
 
 DefaultConfig = "\n".join([
     "### This file configures various client-side behaviors.",
@@ -117,7 +119,8 @@ DefaultConfig = "\n".join([
     "global-ignores = *.o *.lo *.la *.al .libs *.so *.so.[0-9]* *.a *.pyc",
     "  *.pyo .*.rej *.rej .*~ *~ #*# .#* .*.swp .DS_Store",
     "  *.orig *.bak cur tmp __pycache__ .directory",
-    "  .ropeproject .eric4project _ropeproject _eric4project",
+    "  .ropeproject .eric4project .eric5project .eric6project",
+    "  _ropeproject _eric4project _eric5project _eric5project",
     "### Set log-encoding to the default encoding for log messages",
     "# log-encoding = latin1",
     "### Set use-commit-times to make checkout/update/switch/revert",
@@ -180,6 +183,10 @@ DefaultIgnores = [
     ".directory",
     ".ropeproject",
     ".eric4project",
+    ".eric5project",
+    ".eric6project",
     "_ropeproject",
     "_eric4project",
+    "_eric5project",
+    "_eric6project",
 ]
