@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,11 +11,12 @@ from __future__ import unicode_literals
 
 import os
 
-from E5Gui.E5Application import e5App
+from PyQt5.QtWidgets import QToolBar
 
 from VCS.ProjectHelper import VcsProjectHelper
 
 from E5Gui.E5Action import E5Action
+from E5Gui.E5Application import e5App
 
 import UI.PixmapCache
 
@@ -95,21 +96,6 @@ class SvnProjectHelper(VcsProjectHelper):
         self.vcsCommitAct.triggered.connect(self._vcsCommit)
         self.actions.append(self.vcsCommitAct)
         
-        self.vcsLogAct = E5Action(
-            self.tr('Show log'),
-            UI.PixmapCache.getIcon("vcsLog.png"),
-            self.tr('Show &log'),
-            0, 0, self, 'subversion_log')
-        self.vcsLogAct.setStatusTip(self.tr(
-            'Show the log of the local project'
-        ))
-        self.vcsLogAct.setWhatsThis(self.tr(
-            """<b>Show log</b>"""
-            """<p>This shows the log of the local project.</p>"""
-        ))
-        self.vcsLogAct.triggered.connect(self._vcsLog)
-        self.actions.append(self.vcsLogAct)
-        
         self.svnLogBrowserAct = E5Action(
             self.tr('Show log browser'),
             UI.PixmapCache.getIcon("vcsLog.png"),
@@ -503,9 +489,6 @@ class SvnProjectHelper(VcsProjectHelper):
         menu.addAction(self.vcsUpdateAct)
         menu.addAction(self.vcsCommitAct)
         menu.addSeparator()
-        menu.addAction(self.vcsNewAct)
-        menu.addAction(self.vcsExportAct)
-        menu.addSeparator()
         menu.addAction(self.vcsTagAct)
         if self.vcs.otherData["standardLayout"]:
             menu.addAction(self.svnTagListAct)
@@ -513,7 +496,6 @@ class SvnProjectHelper(VcsProjectHelper):
         else:
             menu.addAction(self.svnListAct)
         menu.addSeparator()
-        menu.addAction(self.vcsLogAct)
         menu.addAction(self.svnLogBrowserAct)
         menu.addSeparator()
         menu.addAction(self.vcsStatusAct)
@@ -543,6 +525,70 @@ class SvnProjectHelper(VcsProjectHelper):
         menu.addAction(self.vcsPropsAct)
         menu.addSeparator()
         menu.addAction(self.svnConfigAct)
+        menu.addSeparator()
+        menu.addAction(self.vcsNewAct)
+        menu.addAction(self.vcsExportAct)
+    
+    def initToolbar(self, ui, toolbarManager):
+        """
+        Public slot to initialize the VCS toolbar.
+        
+        @param ui reference to the main window (UserInterface)
+        @param toolbarManager reference to a toolbar manager object
+            (E5ToolBarManager)
+        """
+        self.__toolbar = QToolBar(self.tr("Subversion (svn)"), ui)
+        self.__toolbar.setIconSize(UI.Config.ToolBarIconSize)
+        self.__toolbar.setObjectName("SubversionToolbar")
+        self.__toolbar.setToolTip(self.tr('Subversion (svn)'))
+        
+        self.__toolbar.addAction(self.svnLogBrowserAct)
+        self.__toolbar.addAction(self.vcsStatusAct)
+        self.__toolbar.addSeparator()
+        self.__toolbar.addAction(self.vcsDiffAct)
+        self.__toolbar.addSeparator()
+        self.__toolbar.addAction(self.svnRepoBrowserAct)
+        self.__toolbar.addAction(self.vcsNewAct)
+        self.__toolbar.addAction(self.vcsExportAct)
+        self.__toolbar.addSeparator()
+        
+        title = self.__toolbar.windowTitle()
+        toolbarManager.addToolBar(self.__toolbar, title)
+        toolbarManager.addAction(self.vcsUpdateAct, title)
+        toolbarManager.addAction(self.vcsCommitAct, title)
+        toolbarManager.addAction(self.svnExtDiffAct, title)
+        toolbarManager.addAction(self.svnUrlDiffAct, title)
+        toolbarManager.addAction(self.svnChangeListsAct, title)
+        toolbarManager.addAction(self.vcsTagAct, title)
+        toolbarManager.addAction(self.vcsRevertAct, title)
+        toolbarManager.addAction(self.vcsMergeAct, title)
+        toolbarManager.addAction(self.vcsSwitchAct, title)
+        toolbarManager.addAction(self.svnRelocateAct, title)
+        
+        self.__toolbar.setEnabled(False)
+        self.__toolbar.setVisible(False)
+        
+        ui.registerToolbar("subversion", self.__toolbar.windowTitle(),
+                           self.__toolbar)
+        ui.addToolBar(self.__toolbar)
+    
+    def removeToolbar(self, ui, toolbarManager):
+        """
+        Public method to remove a toolbar created by initToolbar().
+        
+        @param ui reference to the main window (UserInterface)
+        @param toolbarManager reference to a toolbar manager object
+            (E5ToolBarManager)
+        """
+        ui.removeToolBar(self.__toolbar)
+        ui.unregisterToolbar("subversion")
+        
+        title = self.__toolbar.windowTitle()
+        toolbarManager.removeCategoryActions(title)
+        toolbarManager.removeToolBar(self.__toolbar)
+        
+        self.__toolbar.deleteLater()
+        self.__toolbar = None
     
     def __svnResolve(self):
         """
