@@ -24,6 +24,7 @@ from E5Gui import E5MessageBox
 from .Ui_SvnBlameDialog import Ui_SvnBlameDialog
 
 import Preferences
+from Globals import strToQByteArray
 
 
 class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
@@ -224,17 +225,17 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
