@@ -1,22 +1,30 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to browse the change lists.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
 import os
 
-from PyQt4.QtCore import pyqtSlot, Qt, QProcess, QRegExp, QTimer
-from PyQt4.QtGui import QDialog, QDialogButtonBox, QListWidgetItem, QLineEdit
+from PyQt5.QtCore import pyqtSlot, Qt, QProcess, QRegExp, QTimer
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QListWidgetItem, \
+    QLineEdit
 
 from E5Gui import E5MessageBox
 
 from .Ui_SvnChangeListsDialog import Ui_SvnChangeListsDialog
 
 import Preferences
+from Globals import strToQByteArray
 
 
 class SvnChangeListsDialog(QDialog, Ui_SvnChangeListsDialog):
@@ -30,25 +38,30 @@ class SvnChangeListsDialog(QDialog, Ui_SvnChangeListsDialog):
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnChangeListsDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
-        self.process = None
         self.vcs = vcs
         
+        self.process = QProcess()
+        self.process.finished.connect(self.__procFinished)
+        self.process.readyReadStandardOutput.connect(self.__readStdout)
+        self.process.readyReadStandardError.connect(self.__readStderr)
+        
         self.rx_status = QRegExp(
             '(.{8,9})\\s+([0-9-]+)\\s+([0-9?]+)\\s+(\\S+)\\s+(.+)\\s*')
-            # flags (8 or 9 anything), revision, changed rev, author, path
+        # flags (8 or 9 anything), revision, changed rev, author, path
         self.rx_status2 = \
             QRegExp('(.{8,9})\\s+(.+)\\s*')
-            # flags (8 or 9 anything), path
+        # flags (8 or 9 anything), path
         self.rx_changelist = \
             QRegExp('--- \\S+ .([\\w\\s]+).:\\s+')
-            # three dashes, Changelist (translated), quote,
-            # changelist name, quote, :
+        # three dashes, Changelist (translated), quote,
+        # changelist name, quote, :
     
     @pyqtSlot(QListWidgetItem, QListWidgetItem)
     def on_changeLists_currentItemChanged(self, current, previous):
@@ -74,7 +87,7 @@ class SvnChangeListsDialog(QDialog, Ui_SvnChangeListsDialog):
         self.changeListsDict = {}
         
         self.filesLabel.setText(
-            self.trUtf8("Files (relative to {0}):").format(path))
+            self.tr("Files (relative to {0}):").format(path))
         
         self.errorGroup.hide()
         self.intercept = False
@@ -82,11 +95,6 @@ class SvnChangeListsDialog(QDialog, Ui_SvnChangeListsDialog):
         self.path = path
         self.currentChangelist = ""
         
-        self.process = QProcess()
-        self.process.finished.connect(self.__procFinished)
-        self.process.readyReadStandardOutput.connect(self.__readStdout)
-        self.process.readyReadStandardError.connect(self.__readStderr)
-        
         args = []
         args.append('status')
         self.vcs.addArguments(args, self.vcs.options['global'])
@@ -110,8 +118,8 @@ class SvnChangeListsDialog(QDialog, Ui_SvnChangeListsDialog):
             self.inputGroup.hide()
             E5MessageBox.critical(
                 self,
-                self.trUtf8('Process Generation Error'),
-                self.trUtf8(
+                self.tr('Process Generation Error'),
+                self.tr(
                     'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
                 ).format('svn'))
@@ -138,7 +146,7 @@ class SvnChangeListsDialog(QDialog, Ui_SvnChangeListsDialog):
         self.inputGroup.hide()
         
         if len(self.changeListsDict) == 0:
-            self.changeLists.addItem(self.trUtf8("No changelists found"))
+            self.changeLists.addItem(self.tr("No changelists found"))
             self.buttonBox.button(QDialogButtonBox.Close).setFocus(
                 Qt.OtherFocusReason)
         else:
@@ -232,17 +240,17 @@ class SvnChangeListsDialog(QDialog, Ui_SvnChangeListsDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -264,4 +272,4 @@ class SvnChangeListsDialog(QDialog, Ui_SvnChangeListsDialog):
             self.intercept = False
             evt.accept()
             return
-        super().keyPressEvent(evt)
+        super(SvnChangeListsDialog, self).keyPressEvent(evt)
