@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -23,6 +23,7 @@ from E5Gui import E5MessageBox
 from .Ui_SvnDialog import Ui_SvnDialog
 
 import Preferences
+from Globals import strToQByteArray
 
 
 class SvnDialog(QDialog, Ui_SvnDialog):
@@ -47,7 +48,7 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
-        self.proc = None
+        self.process = None
         self.username = ''
         self.password = ''
         
@@ -58,11 +59,11 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         Private slot called when the process finished or the user pressed the
         button.
         """
-        if self.proc is not None and \
-           self.proc.state() != QProcess.NotRunning:
-            self.proc.terminate()
-            QTimer.singleShot(2000, self.proc.kill)
-            self.proc.waitForFinished(3000)
+        if self.process is not None and \
+           self.process.state() != QProcess.NotRunning:
+            self.process.terminate()
+            QTimer.singleShot(2000, self.process.kill)
+            self.process.waitForFinished(3000)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
@@ -71,7 +72,7 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         self.inputGroup.setEnabled(False)
         self.inputGroup.hide()
         
-        self.proc = None
+        self.process = None
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
@@ -120,11 +121,11 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         
         self.__hasAddOrDelete = False
         
-        self.proc = QProcess()
+        self.process = QProcess()
         if setLanguage:
             env = QProcessEnvironment.systemEnvironment()
             env.insert("LANG", "C")
-            self.proc.setProcessEnvironment(env)
+            self.process.setProcessEnvironment(env)
         nargs = []
         lastWasPwd = False
         for arg in args:
@@ -139,14 +140,14 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         self.resultbox.append(' '.join(nargs))
         self.resultbox.append('')
         
-        self.proc.finished.connect(self.__procFinished)
-        self.proc.readyReadStandardOutput.connect(self.__readStdout)
-        self.proc.readyReadStandardError.connect(self.__readStderr)
+        self.process.finished.connect(self.__procFinished)
+        self.process.readyReadStandardOutput.connect(self.__readStdout)
+        self.process.readyReadStandardError.connect(self.__readStderr)
         
         if workingDir:
-            self.proc.setWorkingDirectory(workingDir)
-        self.proc.start('svn', args)
-        procStarted = self.proc.waitForStarted(5000)
+            self.process.setWorkingDirectory(workingDir)
+        self.process.start('svn', args)
+        procStarted = self.process.waitForStarted(5000)
         if not procStarted:
             self.buttonBox.setFocus()
             self.inputGroup.setEnabled(False)
@@ -178,8 +179,8 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         It reads the output of the process, formats it and inserts it into
         the contents pane.
         """
-        if self.proc is not None:
-            s = str(self.proc.readAllStandardOutput(),
+        if self.process is not None:
+            s = str(self.process.readAllStandardOutput(),
                     Preferences.getSystem("IOEncoding"),
                     'replace')
             self.resultbox.insertPlainText(s)
@@ -201,9 +202,9 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         It reads the error output of the process and inserts it into the
         error pane.
         """
-        if self.proc is not None:
+        if self.process is not None:
             self.errorGroup.show()
-            s = str(self.proc.readAllStandardError(),
+            s = str(self.process.readAllStandardError(),
                     Preferences.getSystem("IOEncoding"),
                     'replace')
             self.errors.insertPlainText(s)
@@ -225,17 +226,17 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.proc.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
