@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,16 +17,18 @@ except NameError:
 import os
 
 from PyQt5.QtCore import QTimer, QFileInfo, QProcess, pyqtSlot, Qt
-from PyQt5.QtGui import QColor, QBrush, QTextCursor
+from PyQt5.QtGui import QTextCursor
 from PyQt5.QtWidgets import QWidget, QLineEdit, QDialogButtonBox
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox, E5FileDialog
 
 from .Ui_SvnDiffDialog import Ui_SvnDiffDialog
+from .SvnDiffHighlighter import SvnDiffHighlighter
 
 import Utilities
 import Preferences
+from Globals import strToQByteArray
 
 
 class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
@@ -44,9 +46,16 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         super(SvnDiffDialog, self).__init__(parent)
         self.setupUi(self)
         
+        self.refreshButton = self.buttonBox.addButton(
+            self.tr("Refresh"), QDialogButtonBox.ActionRole)
+        self.refreshButton.setToolTip(
+            self.tr("Press to refresh the display"))
+        self.refreshButton.setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Save).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
+        self.searchWidget.attachTextEdit(self.contents)
+        
         self.process = QProcess()
         self.vcs = vcs
         
@@ -54,13 +63,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         self.contents.setFontFamily(font.family())
         self.contents.setFontPointSize(font.pointSize())
         
-        self.cNormalFormat = self.contents.currentCharFormat()
-        self.cAddedFormat = self.contents.currentCharFormat()
-        self.cAddedFormat.setBackground(QBrush(QColor(190, 237, 190)))
-        self.cRemovedFormat = self.contents.currentCharFormat()
-        self.cRemovedFormat.setBackground(QBrush(QColor(237, 190, 190)))
-        self.cLineNoFormat = self.contents.currentCharFormat()
-        self.cLineNoFormat.setBackground(QBrush(QColor(255, 220, 168)))
+        self.highlighter = SvnDiffHighlighter(self.contents.document())
         
         self.process.finished.connect(self.__procFinished)
         self.process.readyReadStandardOutput.connect(self.__readStdout)
@@ -92,7 +95,8 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         else:
             return str(version)
         
-    def start(self, fn, versions=None, urls=None, summary=False):
+    def start(self, fn, versions=None, urls=None, summary=False,
+              refreshable=False):
         """
         Public slot to start the svn diff command.
         
@@ -102,15 +106,20 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         @keyparam urls list of repository URLs (list of 2 strings)
         @keyparam summary flag indicating a summarizing diff
             (only valid for URL diffs) (boolean)
+        @keyparam refreshable flag indicating a refreshable diff (boolean)
         """
+        self.refreshButton.setVisible(refreshable)
+        
         self.errorGroup.hide()
         self.inputGroup.show()
+        self.inputGroup.setEnabled(True)
         self.intercept = False
         self.filename = fn
         
         self.process.kill()
         
         self.contents.clear()
+        self.highlighter.regenerateRules()
         self.paras = 0
         
         self.filesCombo.clear()
@@ -197,13 +206,13 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         """
         self.inputGroup.setEnabled(False)
         self.inputGroup.hide()
+        self.refreshButton.setEnabled(True)
         
         if self.paras == 0:
-            self.contents.setCurrentCharFormat(self.cNormalFormat)
-            self.contents.setPlainText(
-                self.tr('There is no difference.'))
+            self.contents.setPlainText(self.tr('There is no difference.'))
             
         self.buttonBox.button(QDialogButtonBox.Save).setEnabled(self.paras > 0)
+        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         self.buttonBox.button(QDialogButtonBox.Close).setFocus(
             Qt.OtherFocusReason)
@@ -222,17 +231,15 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             else:
                 self.filesCombo.addItem(oldFile, pos)
         
-    def __appendText(self, txt, format):
+    def __appendText(self, txt):
         """
         Private method to append text to the end of the contents pane.
         
         @param txt text to insert (string)
-        @param format text format to be used (QTextCharFormat)
         """
         tc = self.contents.textCursor()
         tc.movePosition(QTextCursor.End)
         self.contents.setTextCursor(tc)
-        self.contents.setCurrentCharFormat(format)
         self.contents.insertPlainText(txt)
         
     def __extractFileName(self, line):
@@ -279,17 +286,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             if line.startswith("--- ") or line.startswith("+++ "):
                     self.__processFileLine(line)
                 
-            if line.startswith('+') or line.startswith('>') or \
-                    line.startswith('A '):
-                format = self.cAddedFormat
-            elif line.startswith('-') or line.startswith('<') or \
-                    line.startswith('D '):
-                format = self.cRemovedFormat
-            elif line.startswith('@@'):
-                format = self.cLineNoFormat
-            else:
-                format = self.cNormalFormat
-            self.__appendText(line, format)
+            self.__appendText(line)
             self.paras += 1
         
     def __readStderr(self):
@@ -315,7 +312,9 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         """
         if button == self.buttonBox.button(QDialogButtonBox.Save):
             self.on_saveButton_clicked()
-        
+        elif button == self.refreshButton:
+            self.on_refreshButton_clicked()
+    
     @pyqtSlot(int)
     def on_filesCombo_activated(self, index):
         """
@@ -410,6 +409,18 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
                     '<br>Reason: {1}</p>')
                 .format(fname, str(why)))
         
+    @pyqtSlot()
+    def on_refreshButton_clicked(self):
+        """
+        Private slot to refresh the display.
+        """
+        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
+        
+        self.buttonBox.button(QDialogButtonBox.Save).setEnabled(False)
+        self.refreshButton.setEnabled(False)
+        
+        self.start(self.filename, refreshable=True)
+    
     def on_passwordCheckBox_toggled(self, isOn):
         """
         Private slot to handle the password checkbox toggled.
@@ -426,17 +437,17 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         """
         Private slot to send the input to the subversion process.
         """
-        input = self.input.text()
-        input += os.linesep
+        inputTxt = self.input.text()
+        inputTxt += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
             self.errors.ensureCursorVisible()
         else:
-            self.errors.insertPlainText(input)
+            self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
