@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data for a merge operation.
 """
 
-from PyQt4.QtCore import QRegExp
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QRegExp
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from .Ui_SvnMergeDialog import Ui_SvnMergeDialog
 
@@ -30,7 +32,7 @@ class SvnMergeDialog(QDialog, Ui_SvnMergeDialog):
         @param force flag indicating a forced merge (boolean)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnMergeDialog, self).__init__(parent)
         self.setupUi(self)
        
         self.forceCheckBox.setChecked(force)
@@ -48,6 +50,9 @@ class SvnMergeDialog(QDialog, Ui_SvnMergeDialog):
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
         self.okButton.setEnabled(False)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def __enableOkButton(self):
         """
         Private method used to enable/disable the OK-button.
