@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data for a switch operation.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_SvnSwitchDialog import Ui_SvnSwitchDialog
 
@@ -26,7 +28,7 @@ class SvnSwitchDialog(QDialog, Ui_SvnSwitchDialog):
             repository (boolean)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnSwitchDialog, self).__init__(parent)
         self.setupUi(self)
        
         self.tagCombo.clear()
@@ -38,6 +40,9 @@ class SvnSwitchDialog(QDialog, Ui_SvnSwitchDialog):
         if not standardLayout:
             self.TagTypeGroup.setEnabled(False)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def getParameters(self):
         """
         Public method to retrieve the tag data.
