@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data for a tagging operation.
 """
 
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from .Ui_SvnTagDialog import Ui_SvnTagDialog
 
@@ -26,14 +28,14 @@ class SvnTagDialog(QDialog, Ui_SvnTagDialog):
             repository (boolean)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnTagDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
         self.okButton.setEnabled(False)
        
         self.tagCombo.clear()
-        self.tagCombo.addItems(sorted(taglist))
+        self.tagCombo.addItems(sorted(taglist, reverse=True))
         
         if reposURL is not None and reposURL != "":
             self.tagCombo.setEditText(reposURL)
@@ -41,6 +43,9 @@ class SvnTagDialog(QDialog, Ui_SvnTagDialog):
         if not standardLayout:
             self.TagActionGroup.setEnabled(False)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def on_tagCombo_editTextChanged(self, text):
         """
         Private method used to enable/disable the OK-button.
