@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -69,7 +69,7 @@ class ColorDialogWizardDialog(QDialog, Ui_ColorDialogWizardDialog):
                     exec('from PyQt5.QtCore import Qt;'
                          ' QColorDialog.getColor({0}, None, "{1}")'.format(
                              coStr, self.eTitle.text()))
-                except:
+                except Exception:
                     E5MessageBox.critical(
                         self,
                         self.tr("QColorDialog Wizard Error"),
