@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+#
+
 """
 Module implementing the eric6 message box wizard dialog.
 """
@@ -427,8 +430,7 @@ class E5MessageBoxWizardDialog(QDialog, Ui_E5MessageBoxWizardDialog):
             btnCode = ',{0}{1}E5MessageBox.StandardButtons('.format(
                 os.linesep, istring)
         else:
-            btnCode = 'E5MessageBox.StandardButtons('.format(
-                os.linesep, istring)
+            btnCode = 'E5MessageBox.StandardButtons('
         btnCode += '{0}{1}{2})'.format(
             os.linesep, istring2, joinstring.join(buttons))
         
