@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -279,15 +279,15 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
             self.bTest.setDisabled(
                 self.cStartWith.isChecked() or self.cFilters.isChecked())
     
-    def __toggleInitialFilterAndResult(self, id):
+    def __toggleInitialFilterAndResult(self, checkedId):
         """
         Private slot to enable/disable the initial filter elements and the
         results entries.
         
-        @param id id of the clicked button (integer)
+        @param checkedId id of the clicked button (integer)
         """
-        if (self.__pyqtVariant == 4 and id in [11, 12, 13]) or \
-                (self.__pyqtVariant == 5 and id in [1, 2, 3]):
+        if (self.__pyqtVariant == 4 and checkedId in [11, 12, 13]) or \
+                (self.__pyqtVariant == 5 and checkedId in [1, 2, 3]):
             enable = True
         else:
             enable = False
@@ -346,6 +346,8 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 filterVariable = ", selectedFilter"
             else:
                 filterVariable = ""
+        else:
+            filterVariable = ", " + filterVariable
         
         code = '{0}{1} = QFileDialog.'.format(nameVariable, filterVariable)
         if self.rOpenFile.isChecked() or self.rfOpenFile.isChecked():
@@ -378,14 +380,14 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 code += fmt.format(self.eFilters.text())
             if self.rfOpenFile.isChecked() or self.__pyqtVariant == 5:
                 if self.eInitialFilter.text() == "":
-                    filter = "None"
+                    initialFilter = "None"
                 else:
                     if self.cInitialFilter.isChecked():
                         fmt = '{0}'
                     else:
                         fmt = 'self.tr("{0}")'
-                    filter = fmt.format(self.eInitialFilter.text())
-                code += ',{0}{1}{2}'.format(os.linesep, istring, filter)
+                    initialFilter = fmt.format(self.eInitialFilter.text())
+                code += ',{0}{1}{2}'.format(os.linesep, istring, initialFilter)
             if not self.cSymlinks.isChecked():
                 code += \
                     ',{0}{1}QFileDialog.Options(' \
@@ -422,14 +424,14 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 code += fmt.format(self.eFilters.text())
             if self.rfOpenFiles.isChecked() or self.__pyqtVariant == 5:
                 if self.eInitialFilter.text() == "":
-                    filter = "None"
+                    initialFilter = "None"
                 else:
                     if self.cInitialFilter.isChecked():
                         fmt = '{0}'
                     else:
                         fmt = 'self.tr("{0}")'
-                    filter = fmt.format(self.eInitialFilter.text())
-                code += ',{0}{1}{2}'.format(os.linesep, istring, filter)
+                    initialFilter = fmt.format(self.eInitialFilter.text())
+                code += ',{0}{1}{2}'.format(os.linesep, istring, initialFilter)
             if not self.cSymlinks.isChecked():
                 code += \
                     ',{0}{1}QFileDialog.Options(' \
@@ -466,14 +468,14 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 code += fmt.format(self.eFilters.text())
             if self.rfSaveFile.isChecked() or self.__pyqtVariant == 5:
                 if self.eInitialFilter.text() == "":
-                    filter = "None"
+                    initialFilter = "None"
                 else:
                     if self.cInitialFilter.isChecked():
                         fmt = '{0}'
                     else:
                         fmt = 'self.tr("{0}")'
-                    filter = fmt.format(self.eInitialFilter.text())
-                code += ',{0}{1}{2}'.format(os.linesep, istring, filter)
+                    initialFilter = fmt.format(self.eInitialFilter.text())
+                code += ',{0}{1}{2}'.format(os.linesep, istring, initialFilter)
             if (not self.cSymlinks.isChecked()) or \
                (not self.cConfirmOverwrite.isChecked()):
                 code += ',{0}{1}QFileDialog.Options('.format(
