@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the font dialog wizard dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox, QFontDialog
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QFontDialog
 
 from .Ui_FontDialogWizardDialog import Ui_FontDialogWizardDialog
 
@@ -28,14 +30,17 @@ class FontDialogWizardDialog(QDialog, Ui_FontDialogWizardDialog):
         
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(FontDialogWizardDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.bTest = self.buttonBox.addButton(
-            self.trUtf8("Test"), QDialogButtonBox.ActionRole)
+            self.tr("Test"), QDialogButtonBox.ActionRole)
         
         self.font = None
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def on_buttonBox_clicked(self, button):
         """
         Private slot called by a button of the button box clicked.
@@ -122,7 +127,7 @@ class FontDialogWizardDialog(QDialog, Ui_FontDialogWizardDialog):
             if title:
                 code += ',{0}{1}{2}'.format(
                     os.linesep, istring, parent)
-                code += ',{0}{1}self.trUtf8("{2}")'.format(
+                code += ',{0}{1}self.tr("{2}")'.format(
                     os.linesep, istring, title)
             elif parent != "None":
                 code += ',{0}{1}{2}'.format(
