@@ -27,6 +27,14 @@ class ApplicationPage(ConfigurationPageBase, Ui_ApplicationPage):
         self.setupUi(self)
         self.setObjectName("ApplicationPage")
         
+        self.backgroundServicesLabel.setText(self.tr(
+            "eric is using background services for certain things like"
+            " syntax checks or code style checks. Per default the number"
+            " of processes to use for these checks is determined"
+            " automatically based on the number of CPUs. Please note, that"
+            " this is an advanced setting."
+        ))
+        
         # set initial values
         self.singleApplicationCheckBox.setChecked(
             Preferences.getUI("SingleApplicationMode"))
@@ -70,6 +78,9 @@ class ApplicationPage(ConfigurationPageBase, Ui_ApplicationPage):
         self.intervalSpinBox.setValue(
             Preferences.getUI("KeyboardInputInterval"))
         
+        self.backgroundServicesSpinBox.setValue(
+            Preferences.getUI("BackgroundServiceProcesses"))
+    
     def save(self):
         """
         Public slot to save the Application configuration.
@@ -96,7 +107,7 @@ class ApplicationPage(ConfigurationPageBase, Ui_ApplicationPage):
             openOnStartup = 4
         Preferences.setUI("OpenOnStartup", openOnStartup)
         Preferences.setUI("OpenCrashSessionOnStartup",
-            self.openCrashSessionCheckBox.isChecked())
+                          self.openCrashSessionCheckBox.isChecked())
         
         if self.noCheckRadioButton.isChecked():
             period = 0
@@ -121,7 +132,11 @@ class ApplicationPage(ConfigurationPageBase, Ui_ApplicationPage):
         Preferences.setUI(
             "KeyboardInputInterval",
             self.intervalSpinBox.value())
-    
+        
+        Preferences.setUI(
+            "BackgroundServiceProcesses",
+            self.backgroundServicesSpinBox.value())
+
 
 def create(dlg):
     """
