@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,17 +9,12 @@ Module implementing the Debugger Python3 configuration page.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSlot
-
-from E5Gui.E5Completers import E5FileCompleter
-from E5Gui import E5FileDialog
+from E5Gui.E5PathPicker import E5PathPickerModes
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_DebuggerPython3Page import Ui_DebuggerPython3Page
 
 import Preferences
-import Utilities
-import UI.PixmapCache
 
 
 class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
@@ -34,24 +29,26 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         self.setupUi(self)
         self.setObjectName("DebuggerPython3Page")
         
-        self.interpreterButton.setIcon(UI.PixmapCache.getIcon("open.png"))
-        self.debugClientButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.interpreterPicker.setMode(E5PathPickerModes.OpenFileMode)
+        self.interpreterPicker.setToolTip(self.tr(
+            "Press to select the Python3 interpreter via a file selection"
+            " dialog"))
         
-        self.interpreterCompleter = E5FileCompleter(self.interpreterEdit)
-        self.debugClientCompleter = E5FileCompleter(self.debugClientEdit)
+        self.debugClientPicker.setMode(E5PathPickerModes.OpenFileMode)
+        self.debugClientPicker.setToolTip(self.tr(
+            "Press to select the Debug Client via a file selection dialog"))
+        self.debugClientPicker.setFilters(self.tr("Python Files (*.py *.py3)"))
         
         # set initial values
-        self.interpreterEdit.setText(
-            Preferences.getDebugger("Python3Interpreter"))
+        self.interpreterPicker.setText(
+            Preferences.getDebugger("Python3Interpreter"), toNative=False)
         dct = Preferences.getDebugger("DebugClientType3")
         if dct == "standard":
             self.standardButton.setChecked(True)
-        elif dct == "threaded":
-            self.threadedButton.setChecked(True)
         else:
             self.customButton.setChecked(True)
-        self.debugClientEdit.setText(
-            Preferences.getDebugger("DebugClient3"))
+        self.debugClientPicker.setText(
+            Preferences.getDebugger("DebugClient3"), toNative=False)
         self.pyRedirectCheckBox.setChecked(
             Preferences.getDebugger("Python3Redirect"))
         self.pyNoEncodingCheckBox.setChecked(
@@ -65,17 +62,15 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         """
         Preferences.setDebugger(
             "Python3Interpreter",
-            self.interpreterEdit.text())
+            self.interpreterPicker.text(toNative=False))
         if self.standardButton.isChecked():
             dct = "standard"
-        elif self.threadedButton.isChecked():
-            dct = "threaded"
         else:
             dct = "custom"
         Preferences.setDebugger("DebugClientType3", dct)
         Preferences.setDebugger(
             "DebugClient3",
-            self.debugClientEdit.text())
+            self.debugClientPicker.text(toNative=False))
         Preferences.setDebugger(
             "Python3Redirect",
             self.pyRedirectCheckBox.isChecked())
@@ -85,36 +80,6 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         Preferences.setDebugger(
             "Python3Extensions",
             self.sourceExtensionsEdit.text())
-        
-    @pyqtSlot()
-    def on_interpreterButton_clicked(self):
-        """
-        Private slot to handle the Python interpreter selection.
-        """
-        file = E5FileDialog.getOpenFileName(
-            self,
-            self.tr("Select Python interpreter for Debug Client"),
-            self.interpreterEdit.text(),
-            "")
-            
-        if file:
-            self.interpreterEdit.setText(
-                Utilities.toNativeSeparators(file))
-        
-    @pyqtSlot()
-    def on_debugClientButton_clicked(self):
-        """
-        Private slot to handle the Debug Client selection.
-        """
-        file = E5FileDialog.getOpenFileName(
-            None,
-            self.tr("Select Debug Client"),
-            self.debugClientEdit.text(),
-            self.tr("Python Files (*.py *.py3)"))
-            
-        if file:
-            self.debugClientEdit.setText(
-                Utilities.toNativeSeparators(file))
     
 
 def create(dlg):
