@@ -55,7 +55,9 @@ class EditorAPIsPage(ConfigurationPageBase, Ui_EditorAPIsPage):
         apiLanguages = sorted(
             [''] + list(QScintilla.Lexers.getSupportedApiLanguages()))
         for lang in apiLanguages:
-            self.apiLanguageComboBox.addItem(lang)
+            self.apiLanguageComboBox.addItem(
+                QScintilla.Lexers.getLanguageIcon(lang, False),
+                lang)
         apiProjectTypes = sorted(
             [("", "")] +
             [(trans, ptype) for ptype, trans in
