@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -29,14 +29,26 @@ class EditorAutocompletionPage(ConfigurationPageBase,
         self.setObjectName("EditorAutocompletionPage")
         
         # set initial values
-        self.acEnabledCheckBox.setChecked(
+        self.acEnabledGroupBox.setChecked(
             Preferences.getEditor("AutoCompletionEnabled"))
         self.acCaseSensitivityCheckBox.setChecked(
             Preferences.getEditor("AutoCompletionCaseSensitivity"))
+        self.acReversedCheckBox.setChecked(
+            Preferences.getEditor("AutoCompletionReversedList"))
         self.acReplaceWordCheckBox.setChecked(
             Preferences.getEditor("AutoCompletionReplaceWord"))
         self.acThresholdSlider.setValue(
             Preferences.getEditor("AutoCompletionThreshold"))
+        self.acScintillaCheckBox.setChecked(
+            Preferences.getEditor("AutoCompletionScintillaOnFail"))
+        self.acTimeoutSpinBox.setValue(
+            Preferences.getEditor("AutoCompletionTimeout"))
+        self.acCacheSizeSpinBox.setValue(
+            Preferences.getEditor("AutoCompletionCacheSize"))
+        self.acCacheTimeSpinBox.setValue(
+            Preferences.getEditor("AutoCompletionCacheTime"))
+        self.acWatchdogDoubleSpinBox.setValue(
+            Preferences.getEditor("AutoCompletionWatchdogTime") / 1000.0)
         
     def save(self):
         """
@@ -44,16 +56,35 @@ class EditorAutocompletionPage(ConfigurationPageBase,
         """
         Preferences.setEditor(
             "AutoCompletionEnabled",
-            self.acEnabledCheckBox.isChecked())
+            self.acEnabledGroupBox.isChecked())
         Preferences.setEditor(
             "AutoCompletionCaseSensitivity",
             self.acCaseSensitivityCheckBox.isChecked())
+            
+        Preferences.setEditor(
+            "AutoCompletionReversedList",
+            self.acReversedCheckBox.isChecked())
         Preferences.setEditor(
             "AutoCompletionReplaceWord",
             self.acReplaceWordCheckBox.isChecked())
         Preferences.setEditor(
             "AutoCompletionThreshold",
             self.acThresholdSlider.value())
+        Preferences.setEditor(
+            "AutoCompletionScintillaOnFail",
+            self.acScintillaCheckBox.isChecked())
+        Preferences.setEditor(
+            "AutoCompletionTimeout",
+            self.acTimeoutSpinBox.value())
+        Preferences.setEditor(
+            "AutoCompletionCacheSize",
+            self.acCacheSizeSpinBox.value())
+        Preferences.setEditor(
+            "AutoCompletionCacheTime",
+            self.acCacheTimeSpinBox.value())
+        Preferences.setEditor(
+            "AutoCompletionWatchdogTime",
+            self.acWatchdogDoubleSpinBox.value() * 1000)
     
 
 def create(dlg):
