@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -45,6 +45,11 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         
         self.defaultEncodingComboBox.addItems(sorted(supportedCodecs))
         
+        self.previewMarkdownHTMLFormatComboBox.addItems(
+            ["XHTML1", "HTML4", "HTML5"])
+        self.previewRestDocutilsHTMLFormatComboBox.addItems(
+            ["HTML4", "HTML5"])
+        
         # set initial values
         self.autosaveSlider.setValue(
             Preferences.getEditor("AutosaveInterval"))
@@ -89,6 +94,16 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
             " ".join(Preferences.getEditor("PreviewRestFileNameExtensions")))
         self.previewQssExtensionsEdit.setText(
             " ".join(Preferences.getEditor("PreviewQssFileNameExtensions")))
+        self.previewRestSphinxCheckBox.setChecked(
+            Preferences.getEditor("PreviewRestUseSphinx"))
+        self.previewMarkdownNLtoBreakCheckBox.setChecked(
+            Preferences.getEditor("PreviewMarkdownNLtoBR"))
+        index = self.previewMarkdownHTMLFormatComboBox.findText(
+            Preferences.getEditor("PreviewMarkdownHTMLFormat"))
+        self.previewMarkdownHTMLFormatComboBox.setCurrentIndex(index)
+        index = self.previewRestDocutilsHTMLFormatComboBox.findText(
+            Preferences.getEditor("PreviewRestDocutilsHTMLFormat"))
+        self.previewRestDocutilsHTMLFormatComboBox.setCurrentIndex(index)
         
     def save(self):
         """
@@ -156,6 +171,18 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
             "PreviewQssFileNameExtensions",
             [ext.strip() for ext in
              self.previewQssExtensionsEdit.text().split()])
+        Preferences.setEditor(
+            "PreviewRestUseSphinx",
+            self.previewRestSphinxCheckBox.isChecked())
+        Preferences.setEditor(
+            "PreviewMarkdownNLtoBR",
+            self.previewMarkdownNLtoBreakCheckBox.isChecked())
+        Preferences.setEditor(
+            "PreviewMarkdownHTMLFormat",
+            self.previewMarkdownHTMLFormatComboBox.currentText())
+        Preferences.setEditor(
+            "PreviewRestDocutilsHTMLFormat",
+            self.previewRestDocutilsHTMLFormatComboBox.currentText())
     
     def __setDefaultFiltersLists(self, keepSelection=False):
         """
@@ -198,24 +225,24 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         else:
             self.saveFileFilters = filters
     
-    def __checkFileFilter(self, filter):
+    def __checkFileFilter(self, fileFilter):
         """
         Private method to check a file filter for validity.
         
-        @param filter file filter pattern to check (string)
+        @param fileFilter file filter pattern to check (string)
         @return flag indicating validity (boolean)
         """
         if not self.__showsOpenFilters and \
-           filter.count("*") != 1:
+           fileFilter.count("*") != 1:
             E5MessageBox.critical(
                 self,
                 self.tr("Add File Filter"),
                 self.tr("""A Save File Filter must contain exactly one"""
                         """ wildcard pattern. Yours contains {0}.""")
-                .format(filter.count("*")))
+                .format(fileFilter.count("*")))
             return False
         
-        if filter.count("*") == 0:
+        if fileFilter.count("*") == 0:
             E5MessageBox.critical(
                 self,
                 self.tr("Add File Filter"),
@@ -230,14 +257,14 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         """
         Private slot to add a file filter to the list.
         """
-        filter, ok = QInputDialog.getText(
+        fileFilter, ok = QInputDialog.getText(
             self,
             self.tr("Add File Filter"),
             self.tr("Enter the file filter entry:"),
             QLineEdit.Normal)
-        if ok and filter:
-            if self.__checkFileFilter(filter):
-                self.fileFiltersList.addItem(filter)
+        if ok and fileFilter:
+            if self.__checkFileFilter(fileFilter):
+                self.fileFiltersList.addItem(fileFilter)
                 self.__extractFileFilters()
                 self.__setDefaultFiltersLists(keepSelection=True)
     
@@ -246,16 +273,16 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         """
         Private slot called to edit a file filter entry.
         """
-        filter = self.fileFiltersList.currentItem().text()
-        filter, ok = QInputDialog.getText(
+        fileFilter = self.fileFiltersList.currentItem().text()
+        fileFilter, ok = QInputDialog.getText(
             self,
             self.tr("Add File Filter"),
             self.tr("Enter the file filter entry:"),
             QLineEdit.Normal,
-            filter)
-        if ok and filter:
-            if self.__checkFileFilter(filter):
-                self.fileFiltersList.currentItem().setText(filter)
+            fileFilter)
+        if ok and fileFilter:
+            if self.__checkFileFilter(fileFilter):
+                self.fileFiltersList.currentItem().setText(fileFilter)
                 self.__extractFileFilters()
                 self.__setDefaultFiltersLists(keepSelection=True)
     
