@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -19,6 +19,13 @@ from .Ui_EditorHighlightingStylesPage import Ui_EditorHighlightingStylesPage
 from E5Gui import E5MessageBox, E5FileDialog
 
 import Preferences
+from Globals import qVersionTuple
+
+try:
+    MonospacedFontsOption = QFontDialog.MonospacedFonts
+except AttributeError:
+    MonospacedFontsOption = QFontDialog.FontDialogOptions(0x10)
+NoFontsOption = QFontDialog.FontDialogOptions(0)
 
 
 class EditorHighlightingStylesPage(ConfigurationPageBase,
@@ -41,6 +48,10 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
         self.setupUi(self)
         self.setObjectName("EditorHighlightingStylesPage")
         
+        if qVersionTuple() < (5, 0, 0):
+            self.monospacedButton.setChecked(False)
+            self.monospacedButton.hide()
+        
         self.__fontButtonMenu = QMenu()
         act = self.__fontButtonMenu.addAction(self.tr("Font"))
         act.setData(self.FONT)
@@ -74,8 +85,12 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
         self.lexers = lexers
         
         # set initial values
+        import QScintilla.Lexers
         languages = sorted([''] + list(self.lexers.keys()))
-        self.lexerLanguageComboBox.addItems(languages)
+        for language in languages:
+            self.lexerLanguageComboBox.addItem(
+                QScintilla.Lexers.getLanguageIcon(language, False),
+                language)
         self.on_lexerLanguageComboBox_activated("")
         
     def save(self):
@@ -264,7 +279,12 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
             else:
                 self.sampleText.setFont(font)
         
-        font, ok = QFontDialog.getFont(self.lexer.font(self.style))
+        if self.monospacedButton.isChecked():
+            options = MonospacedFontsOption
+        else:
+            options = NoFontsOption
+        font, ok = QFontDialog.getFont(self.lexer.font(self.style), self,
+                                       "", options)
         if ok:
             setSampleFont(font, familyOnly, sizeOnly)
             if doAll:
