@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor Properties configuration page.
 """
 
+from __future__ import unicode_literals
+
 from QScintilla.QsciScintillaCompat import QSCINTILLA_VERSION
 
 from .ConfigurationPageBase import ConfigurationPageBase
@@ -25,7 +27,7 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         
         @param lexers reference to the lexers dictionary
         """
-        super().__init__()
+        super(EditorPropertiesPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorPropertiesPage")
         
@@ -40,10 +42,6 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         self.foldBashCommentCheckBox.setChecked(
             Preferences.getEditor("BashFoldComment"))
         
-        # CMake
-        self.cmakeFoldAtElseCheckBox.setChecked(
-            Preferences.getEditor("CMakeFoldAtElse"))
-        
         # C++
         self.foldCppCommentCheckBox.setChecked(
             Preferences.getEditor("CppFoldComment"))
@@ -59,36 +57,44 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             Preferences.getEditor("CppCaseInsensitiveKeywords"))
         self.cppDollarAllowedCheckBox.setChecked(
             Preferences.getEditor("CppDollarsAllowed"))
-        if QSCINTILLA_VERSION() >= 0x020500:
-            self.cppStylePreprocessorCheckBox.setChecked(
-                Preferences.getEditor("CppStylePreprocessor"))
+        self.cppStylePreprocessorCheckBox.setChecked(
+            Preferences.getEditor("CppStylePreprocessor"))
+        self.cppHighlightTripleQuotedCheckBox.setChecked(
+            Preferences.getEditor("CppHighlightTripleQuotedStrings"))
+        self.cppHighlightHashQuotedCheckBox.setChecked(
+            Preferences.getEditor("CppHighlightHashQuotedStrings"))
+        self.cppHighlightBackQuotedCheckBox.setChecked(
+            Preferences.getEditor("CppHighlightBackQuotedStrings"))
+        self.cppHighlightEsacepSequencesCheckBox.setChecked(
+            Preferences.getEditor("CppHighlightEscapeSequences"))
+        self.cppVerbatimStringEscapeAllowedCheckBox.setChecked(
+            Preferences.getEditor(
+                "CppVerbatimStringEscapeSequencesAllowed"))
+        
+        # CMake
+        self.cmakeFoldAtElseCheckBox.setChecked(
+            Preferences.getEditor("CMakeFoldAtElse"))
+        
+        # CoffeeScript
+        if "CoffeeScript" in self.languages:
+            self.foldCoffeeScriptCommentCheckBox.setChecked(
+                Preferences.getEditor("CoffeScriptFoldComment"))
+            self.coffeeScriptDollarAllowedCheckBox.setChecked(
+                Preferences.getEditor("CoffeeScriptDollarsAllowed"))
+            self.coffeeScriptStylePreprocessorCheckBox.setChecked(
+                Preferences.getEditor("CoffeeScriptStylePreprocessor"))
         else:
-            self.cppStylePreprocessorCheckBox.setEnabled(False)
-        if QSCINTILLA_VERSION() >= 0x020600:
-            self.cppHighlightTripleQuotedCheckBox.setChecked(
-                Preferences.getEditor("CppHighlightTripleQuotedStrings"))
-        else:
-            self.cppHighlightTripleQuotedCheckBox.setEnabled(False)
-        if QSCINTILLA_VERSION() >= 0x020700:
-            self.cppHighlightHashQuotedCheckBox.setChecked(
-                Preferences.getEditor("CppHighlightHashQuotedStrings"))
-        else:
-            self.cppHighlightHashQuotedCheckBox.setEnabled(False)
+            self.coffeeScriptGroup.setEnabled(False)
         
         # CSS
         self.foldCssCommentCheckBox.setChecked(
             Preferences.getEditor("CssFoldComment"))
-        if QSCINTILLA_VERSION() >= 0x020700:
-            self.cssHssCheckBox.setChecked(
-                Preferences.getEditor("CssHssSupport"))
-            self.cssLessCheckBox.setChecked(
-                Preferences.getEditor("CssLessSupport"))
-            self.cssSassyCheckBox.setChecked(
-                Preferences.getEditor("CssSassySupport"))
-        else:
-            self.cssHssCheckBox.setEnabled(False)
-            self.cssLessCheckBox.setEnabled(False)
-            self.cssSassyCheckBox.setEnabled(False)
+        self.cssHssCheckBox.setChecked(
+            Preferences.getEditor("CssHssSupport"))
+        self.cssLessCheckBox.setChecked(
+            Preferences.getEditor("CssLessSupport"))
+        self.cssSassyCheckBox.setChecked(
+            Preferences.getEditor("CssSassySupport"))
         
         # D
         self.foldDCommentCheckBox.setChecked(
@@ -100,6 +106,13 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         self.dIndentClosingBraceCheckBox.setChecked(
             Preferences.getEditor("DIndentClosingBrace"))
         
+        # Gettext
+        if "Gettext" in self.languages:
+            self.foldPoCommentCheckBox.setChecked(
+                Preferences.getEditor("PoFoldComment"))
+        else:
+            self.gettextGroup.setEnabled(False)
+        
         # HTML
         self.foldHtmlPreprocessorCheckBox.setChecked(
             Preferences.getEditor("HtmlFoldPreprocessor"))
@@ -109,29 +122,28 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             Preferences.getEditor("HtmlFoldScriptComments"))
         self.foldHtmlScriptHereDocsCheckBox.setChecked(
             Preferences.getEditor("HtmlFoldScriptHeredocs"))
-        if QSCINTILLA_VERSION() >= 0x020500:
-            self.htmlDjangoCheckBox.setChecked(
-                Preferences.getEditor("HtmlDjangoTemplates"))
-            self.htmlMakoCheckBox.setChecked(
-                Preferences.getEditor("HtmlMakoTemplates"))
+        self.htmlDjangoCheckBox.setChecked(
+            Preferences.getEditor("HtmlDjangoTemplates"))
+        self.htmlMakoCheckBox.setChecked(
+            Preferences.getEditor("HtmlMakoTemplates"))
+        
+        # JSON
+        if "JSON" in self.languages:
+            self.jsonHighlightCommentsCheckBox.setChecked(
+                Preferences.getEditor("JSONHightlightComments"))
+            self.jsonHighlightEscapeCheckBox.setChecked(
+                Preferences.getEditor("JSONHighlightEscapeSequences"))
         else:
-            self.htmlDjangoCheckBox.setEnabled(False)
-            self.htmlMakoCheckBox.setEnabled(False)
+            self.jsonGroup.setEnabled(False)
         
         # Pascal
-        if "Pascal" in self.languages:
-            self.pascalGroup.setEnabled(True)
-            self.foldPascalCommentCheckBox.setChecked(
-                Preferences.getEditor("PascalFoldComment"))
-            self.foldPascalPreprocessorCheckBox.setChecked(
-                Preferences.getEditor("PascalFoldPreprocessor"))
-            if QSCINTILLA_VERSION() >= 0x020400:
-                self.pascalSmartHighlightingCheckBox.setChecked(
-                    Preferences.getEditor("PascalSmartHighlighting"))
-            else:
-                self.pascalSmartHighlightingCheckBox.setEnabled(False)
-        else:
-            self.pascalGroup.setEnabled(False)
+        self.pascalGroup.setEnabled(True)
+        self.foldPascalCommentCheckBox.setChecked(
+            Preferences.getEditor("PascalFoldComment"))
+        self.foldPascalPreprocessorCheckBox.setChecked(
+            Preferences.getEditor("PascalFoldPreprocessor"))
+        self.pascalSmartHighlightingCheckBox.setChecked(
+            Preferences.getEditor("PascalSmartHighlighting"))
         
         # Perl
         self.foldPerlCommentCheckBox.setChecked(
@@ -140,23 +152,17 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             Preferences.getEditor("PerlFoldPackages"))
         self.foldPerlPODBlocksCheckBox.setChecked(
             Preferences.getEditor("PerlFoldPODBlocks"))
-        if QSCINTILLA_VERSION() >= 0x020600:
-            self.foldPerlAtElseCheckBox.setChecked(
-                Preferences.getEditor("PerlFoldAtElse"))
-        else:
-            self.foldPerlAtElseCheckBox.setEnabled(False)
+        self.foldPerlAtElseCheckBox.setChecked(
+            Preferences.getEditor("PerlFoldAtElse"))
         
         # PostScript
-        if "PostScript" in self.languages:
-            self.postscriptGroup.setEnabled(True)
-            self.psFoldAtElseCheckBox.setChecked(
-                Preferences.getEditor("PostScriptFoldAtElse"))
-            self.psMarkTokensCheckBox.setChecked(
-                Preferences.getEditor("PostScriptTokenize"))
-            self.psLevelSpinBox.setValue(
-                Preferences.getEditor("PostScriptLevel"))
-        else:
-            self.postscriptGroup.setEnabled(False)
+        self.postscriptGroup.setEnabled(True)
+        self.psFoldAtElseCheckBox.setChecked(
+            Preferences.getEditor("PostScriptFoldAtElse"))
+        self.psMarkTokensCheckBox.setChecked(
+            Preferences.getEditor("PostScriptTokenize"))
+        self.psLevelSpinBox.setValue(
+            Preferences.getEditor("PostScriptLevel"))
         
         # Povray
         self.foldPovrayCommentCheckBox.setChecked(
@@ -165,19 +171,23 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             Preferences.getEditor("PovFoldDirectives"))
         
         # Properties
-        if QSCINTILLA_VERSION() >= 0x020500:
-            self.propertiesInitialSpacesCheckBox.setChecked(
-                Preferences.getEditor("PropertiesInitialSpaces"))
-        else:
-            self.propertiesInitialSpacesCheckBox.setEnabled(False)
+        self.propertiesInitialSpacesCheckBox.setChecked(
+            Preferences.getEditor("PropertiesInitialSpaces"))
         
         # Python
+        self.pythonBadIndentationComboBox.addItems([
+            self.tr("No Warning"),
+            self.tr("Inconsistent"),
+            self.tr("Tabs after Spaces"),
+            self.tr("Spaces"),
+            self.tr("Tabs"),
+        ])
+        self.pythonBadIndentationComboBox.setCurrentIndex(
+            Preferences.getEditor("PythonBadIndentation"))
         self.foldPythonCommentCheckBox.setChecked(
             Preferences.getEditor("PythonFoldComment"))
         self.foldPythonStringCheckBox.setChecked(
             Preferences.getEditor("PythonFoldString"))
-        self.pythonBadIndentationCheckBox.setChecked(
-            Preferences.getEditor("PythonBadIndentation"))
         self.pythonAutoindentCheckBox.setChecked(
             Preferences.getEditor("PythonAutoIndent"))
         self.pythonV2UnicodeAllowedCheckBox.setChecked(
@@ -186,69 +196,44 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             Preferences.getEditor("PythonAllowV3Binary"))
         self.pythonV3BytesAllowedCheckBox.setChecked(
             Preferences.getEditor("PythonAllowV3Bytes"))
-        if QSCINTILLA_VERSION() >= 0x020500:
-            self.foldPythonQuotesCheckBox.setChecked(
-                Preferences.getEditor("PythonFoldQuotes"))
-            self.pythonStringsOverNewlineCheckBox.setChecked(
-                Preferences.getEditor("PythonStringsOverNewLineAllowed"))
-        else:
-            self.foldPythonQuotesCheckBox.setEnabled(False)
-            self.pythonStringsOverNewlineCheckBox.setEnabled(False)
-        if QSCINTILLA_VERSION() >= 0x020600:
-            self.pythonHighlightSubidentifierCheckBox.setChecked(
-                Preferences.getEditor("PythonHighlightSubidentifier"))
-        else:
-            self.pythonHighlightSubidentifierCheckBox.setEnabled(False)
+        self.foldPythonQuotesCheckBox.setChecked(
+            Preferences.getEditor("PythonFoldQuotes"))
+        self.pythonStringsOverNewlineCheckBox.setChecked(
+            Preferences.getEditor("PythonStringsOverNewLineAllowed"))
+        self.pythonHighlightSubidentifierCheckBox.setChecked(
+            Preferences.getEditor("PythonHighlightSubidentifier"))
         
         # Ruby
-        if QSCINTILLA_VERSION() >= 0x020500:
-            self.foldRubyCommentCheckBox.setChecked(
-                Preferences.getEditor("RubyFoldComment"))
-        else:
-            self.foldRubyCommentCheckBox.setEnabled(False)
+        self.foldRubyCommentCheckBox.setChecked(
+            Preferences.getEditor("RubyFoldComment"))
         
         # SQL
         self.foldSqlCommentCheckBox.setChecked(
             Preferences.getEditor("SqlFoldComment"))
         self.sqlBackslashEscapesCheckBox.setChecked(
             Preferences.getEditor("SqlBackslashEscapes"))
-        if QSCINTILLA_VERSION() >= 0x020500:
-            self.sqlFoldAtElseCheckBox.setChecked(
-                Preferences.getEditor("SqlFoldAtElse"))
-            self.sqlFoldOnlyBeginCheckBox.setChecked(
-                Preferences.getEditor("SqlFoldOnlyBegin"))
-            self.sqlDottedWordsCheckBox.setChecked(
-                Preferences.getEditor("SqlDottedWords"))
-            self.sqlHashCommentsCheckBox.setChecked(
-                Preferences.getEditor("SqlHashComments"))
-            self.sqlQuotedIdentifiersCheckBox.setChecked(
-                Preferences.getEditor("SqlQuotedIdentifiers"))
-        else:
-            self.sqlFoldAtElseCheckBox.setEnabled(False)
-            self.sqlFoldOnlyBeginCheckBox.setEnabled(False)
-            self.sqlDottedWordsCheckBox.setEnabled(False)
-            self.sqlHashCommentsCheckBox.setEnabled(False)
-            self.sqlQuotedIdentifiersCheckBox.setEnabled(False)
+        self.sqlFoldAtElseCheckBox.setChecked(
+            Preferences.getEditor("SqlFoldAtElse"))
+        self.sqlFoldOnlyBeginCheckBox.setChecked(
+            Preferences.getEditor("SqlFoldOnlyBegin"))
+        self.sqlDottedWordsCheckBox.setChecked(
+            Preferences.getEditor("SqlDottedWords"))
+        self.sqlHashCommentsCheckBox.setChecked(
+            Preferences.getEditor("SqlHashComments"))
+        self.sqlQuotedIdentifiersCheckBox.setChecked(
+            Preferences.getEditor("SqlQuotedIdentifiers"))
         
         # TCL
-        if QSCINTILLA_VERSION() >= 0x020500:
-            self.foldTclCommentCheckBox.setChecked(
-                Preferences.getEditor("TclFoldComment"))
-        else:
-            self.foldTclCommentCheckBox.setEnabled(False)
+        self.foldTclCommentCheckBox.setChecked(
+            Preferences.getEditor("TclFoldComment"))
         
         # TeX
-        if QSCINTILLA_VERSION() >= 0x020500:
-            self.foldTexCommentCheckBox.setChecked(
-                Preferences.getEditor("TexFoldComment"))
-            self.texProcessCommentsCheckBox.setChecked(
-                Preferences.getEditor("TexProcessComments"))
-            self.texProcessIfCheckBox.setChecked(
-                Preferences.getEditor("TexProcessIf"))
-        else:
-            self.foldTexCommentCheckBox.setEnabled(False)
-            self.texProcessCommentsCheckBox.setEnabled(False)
-            self.texProcessIfCheckBox.setEnabled(False)
+        self.foldTexCommentCheckBox.setChecked(
+            Preferences.getEditor("TexFoldComment"))
+        self.texProcessCommentsCheckBox.setChecked(
+            Preferences.getEditor("TexProcessComments"))
+        self.texProcessIfCheckBox.setChecked(
+            Preferences.getEditor("TexProcessIf"))
         
         # VHDL
         self.vhdlFoldCommentCheckBox.setChecked(
@@ -265,12 +250,9 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             Preferences.getEditor("XMLStyleScripts"))
         
         # YAML
-        if "YAML" in self.languages:
-            self.yamlGroup.setEnabled(True)
-            self.foldYamlCommentCheckBox.setChecked(
-                Preferences.getEditor("YAMLFoldComment"))
-        else:
-            self.yamlGroup.setEnabled(False)
+        self.yamlGroup.setEnabled(True)
+        self.foldYamlCommentCheckBox.setChecked(
+            Preferences.getEditor("YAMLFoldComment"))
         
     def save(self):
         """
@@ -313,33 +295,56 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         Preferences.setEditor(
             "CppDollarsAllowed",
             self.cppDollarAllowedCheckBox.isChecked())
-        if QSCINTILLA_VERSION() >= 0x020500:
+        Preferences.setEditor(
+            "CppStylePreprocessor",
+            self.cppStylePreprocessorCheckBox.isChecked())
+        Preferences.setEditor(
+            "CppHighlightTripleQuotedStrings",
+            self.cppHighlightTripleQuotedCheckBox.isChecked())
+        Preferences.setEditor(
+            "CppHighlightHashQuotedStrings",
+            self.cppHighlightHashQuotedCheckBox.isChecked())
+        if QSCINTILLA_VERSION() >= 0x020900:
             Preferences.setEditor(
-                "CppStylePreprocessor",
-                self.cppStylePreprocessorCheckBox.isChecked())
-        if QSCINTILLA_VERSION() >= 0x020600:
+                "CppHighlightBackQuotedStrings",
+                self.cppHighlightBackQuotedCheckBox.isChecked())
             Preferences.setEditor(
-                "CppHighlightTripleQuotedStrings",
-                self.cppHighlightTripleQuotedCheckBox.isChecked())
-        if QSCINTILLA_VERSION() >= 0x020700:
+                "CppHighlightEscapeSequences",
+                self.cppHighlightEsacepSequencesCheckBox.isChecked())
             Preferences.setEditor(
-                "CppHighlightHashQuotedStrings",
-                self.cppHighlightHashQuotedCheckBox.isChecked())
+                "CppVerbatimStringEscapeSequencesAllowed",
+                self.cppVerbatimStringEscapeAllowedCheckBox.isChecked())
+        
+        # CMake
+        Preferences.setEditor(
+            "CMakeFoldAtElse",
+            self.cmakeFoldAtElseCheckBox.isChecked())
+        
+        # CoffeeScript
+        if "CoffeeScript" in self.languages:
+            Preferences.setEditor(
+                "CoffeScriptFoldComment",
+                self.foldCoffeeScriptCommentCheckBox.isChecked())
+            Preferences.setEditor(
+                "CoffeeScriptDollarsAllowed",
+                self.coffeeScriptDollarAllowedCheckBox.isChecked())
+            Preferences.setEditor(
+                "CoffeeScriptStylePreprocessor",
+                self.coffeeScriptStylePreprocessorCheckBox.isChecked())
         
         # CSS
         Preferences.setEditor(
             "CssFoldComment",
             self.foldCssCommentCheckBox.isChecked())
-        if QSCINTILLA_VERSION() >= 0x020700:
-            Preferences.setEditor(
-                "CssHssSupport",
-                self.cssHssCheckBox.isChecked())
-            Preferences.setEditor(
-                "CssLessSupport",
-                self.cssLessCheckBox.isChecked())
-            Preferences.setEditor(
-                "CssSassySupport",
-                self.cssSassyCheckBox.isChecked())
+        Preferences.setEditor(
+            "CssHssSupport",
+            self.cssHssCheckBox.isChecked())
+        Preferences.setEditor(
+            "CssLessSupport",
+            self.cssLessCheckBox.isChecked())
+        Preferences.setEditor(
+            "CssSassySupport",
+            self.cssSassyCheckBox.isChecked())
         
         # D
         Preferences.setEditor(
@@ -355,6 +360,12 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             "DIndentClosingBrace",
             self.dIndentClosingBraceCheckBox.isChecked())
         
+        # Gettext
+        if "Gettext" in self.languages:
+            Preferences.setEditor(
+                "PoFoldComment",
+                self.foldPoCommentCheckBox.isChecked())
+        
         # HTML
         Preferences.setEditor(
             "HtmlFoldPreprocessor",
@@ -368,25 +379,32 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         Preferences.setEditor(
             "HtmlFoldScriptHeredocs",
             self.foldHtmlScriptHereDocsCheckBox.isChecked())
-        if QSCINTILLA_VERSION() >= 0x020500:
+        Preferences.setEditor(
+            "HtmlDjangoTemplates",
+            self.htmlDjangoCheckBox.isChecked())
+        Preferences.setEditor(
+            "HtmlMakoTemplates",
+            self.htmlMakoCheckBox.isChecked())
+        
+        # JSON
+        if "JSON" in self.languages:
             Preferences.setEditor(
-                "HtmlDjangoTemplates",
-                self.htmlDjangoCheckBox.isChecked())
+                "JSONHightlightComments",
+                self.jsonHighlightCommentsCheckBox.isChecked())
             Preferences.setEditor(
-                "HtmlMakoTemplates",
-                self.htmlMakoCheckBox.isChecked())
+                "JSONHighlightEscapeSequences",
+                self.jsonHighlightEscapeCheckBox.isChecked())
         
         # Pascal
-        if "Pascal" in self.languages:
-            Preferences.setEditor(
-                "PascalFoldComment",
-                self.foldPascalCommentCheckBox.isChecked())
-            Preferences.setEditor(
-                "PascalFoldPreprocessor",
-                self.foldPascalPreprocessorCheckBox.isChecked())
-            Preferences.setEditor(
-                "PascalSmartHighlighting",
-                self.pascalSmartHighlightingCheckBox.isChecked())
+        Preferences.setEditor(
+            "PascalFoldComment",
+            self.foldPascalCommentCheckBox.isChecked())
+        Preferences.setEditor(
+            "PascalFoldPreprocessor",
+            self.foldPascalPreprocessorCheckBox.isChecked())
+        Preferences.setEditor(
+            "PascalSmartHighlighting",
+            self.pascalSmartHighlightingCheckBox.isChecked())
         
         # Perl
         Preferences.setEditor(
@@ -398,22 +416,20 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         Preferences.setEditor(
             "PerlFoldPODBlocks",
             self.foldPerlPODBlocksCheckBox.isChecked())
-        if QSCINTILLA_VERSION() >= 0x020600:
-            Preferences.setEditor(
-                "PerlFoldAtElse",
-                self.foldPerlAtElseCheckBox.isChecked())
+        Preferences.setEditor(
+            "PerlFoldAtElse",
+            self.foldPerlAtElseCheckBox.isChecked())
         
         # PostScript
-        if "PostScript" in self.languages:
-            Preferences.setEditor(
-                "PostScriptFoldAtElse",
-                self.psFoldAtElseCheckBox.isChecked())
-            Preferences.setEditor(
-                "PostScriptTokenize",
-                self.psMarkTokensCheckBox.isChecked())
-            Preferences.setEditor(
-                "PostScriptLevel",
-                self.psLevelSpinBox.value())
+        Preferences.setEditor(
+            "PostScriptFoldAtElse",
+            self.psFoldAtElseCheckBox.isChecked())
+        Preferences.setEditor(
+            "PostScriptTokenize",
+            self.psMarkTokensCheckBox.isChecked())
+        Preferences.setEditor(
+            "PostScriptLevel",
+            self.psLevelSpinBox.value())
         
         # Povray
         Preferences.setEditor(
@@ -424,10 +440,9 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             self.foldPovrayDirectivesCheckBox.isChecked())
         
         # Properties
-        if QSCINTILLA_VERSION() >= 0x020500:
-            Preferences.setEditor(
-                "PropertiesInitialSpaces",
-                self.propertiesInitialSpacesCheckBox.isChecked())
+        Preferences.setEditor(
+            "PropertiesInitialSpaces",
+            self.propertiesInitialSpacesCheckBox.isChecked())
         
         # Python
         Preferences.setEditor(
@@ -438,7 +453,7 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             self.foldPythonStringCheckBox.isChecked())
         Preferences.setEditor(
             "PythonBadIndentation",
-            self.pythonBadIndentationCheckBox.isChecked())
+            self.pythonBadIndentationComboBox.currentIndex())
         Preferences.setEditor(
             "PythonAutoIndent",
             self.pythonAutoindentCheckBox.isChecked())
@@ -451,23 +466,20 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         Preferences.setEditor(
             "PythonAllowV3Bytes",
             self.pythonV3BytesAllowedCheckBox.isChecked())
-        if QSCINTILLA_VERSION() >= 0x020500:
-            Preferences.setEditor(
-                "PythonFoldQuotes",
-                self.foldPythonQuotesCheckBox.isChecked())
-            Preferences.setEditor(
-                "PythonStringsOverNewLineAllowed",
-                self.pythonStringsOverNewlineCheckBox.isChecked())
-        if QSCINTILLA_VERSION() >= 0x020600:
-            Preferences.setEditor(
-                "PythonHighlightSubidentifier",
-                self.pythonHighlightSubidentifierCheckBox.isChecked())
+        Preferences.setEditor(
+            "PythonFoldQuotes",
+            self.foldPythonQuotesCheckBox.isChecked())
+        Preferences.setEditor(
+            "PythonStringsOverNewLineAllowed",
+            self.pythonStringsOverNewlineCheckBox.isChecked())
+        Preferences.setEditor(
+            "PythonHighlightSubidentifier",
+            self.pythonHighlightSubidentifierCheckBox.isChecked())
         
         # Ruby
-        if QSCINTILLA_VERSION() >= 0x020500:
-            Preferences.setEditor(
-                "RubyFoldComment",
-                self.foldRubyCommentCheckBox.isChecked())
+        Preferences.setEditor(
+            "RubyFoldComment",
+            self.foldRubyCommentCheckBox.isChecked())
         
         # SQL
         Preferences.setEditor(
@@ -476,40 +488,37 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         Preferences.setEditor(
             "SqlBackslashEscapes",
             self.sqlBackslashEscapesCheckBox.isChecked())
-        if QSCINTILLA_VERSION() >= 0x020500:
-            Preferences.setEditor(
-                "SqlFoldAtElse",
-                self.sqlFoldAtElseCheckBox.isChecked())
-            Preferences.setEditor(
-                "SqlFoldOnlyBegin",
-                self.sqlFoldOnlyBeginCheckBox.isChecked())
-            Preferences.setEditor(
-                "SqlDottedWords",
-                self.sqlDottedWordsCheckBox.isChecked())
-            Preferences.setEditor(
-                "SqlHashComments",
-                self.sqlHashCommentsCheckBox.isChecked())
-            Preferences.setEditor(
-                "SqlQuotedIdentifiers",
-                self.sqlQuotedIdentifiersCheckBox.isChecked())
+        Preferences.setEditor(
+            "SqlFoldAtElse",
+            self.sqlFoldAtElseCheckBox.isChecked())
+        Preferences.setEditor(
+            "SqlFoldOnlyBegin",
+            self.sqlFoldOnlyBeginCheckBox.isChecked())
+        Preferences.setEditor(
+            "SqlDottedWords",
+            self.sqlDottedWordsCheckBox.isChecked())
+        Preferences.setEditor(
+            "SqlHashComments",
+            self.sqlHashCommentsCheckBox.isChecked())
+        Preferences.setEditor(
+            "SqlQuotedIdentifiers",
+            self.sqlQuotedIdentifiersCheckBox.isChecked())
         
         # TCL
-        if QSCINTILLA_VERSION() >= 0x020500:
-            Preferences.setEditor(
-                "TclFoldComment",
-                self.foldTclCommentCheckBox.isChecked())
+        Preferences.setEditor(
+            "TclFoldComment",
+            self.foldTclCommentCheckBox.isChecked())
         
         # TeX
-        if QSCINTILLA_VERSION() >= 0x020500:
-            Preferences.setEditor(
-                "TexFoldComment",
-                self.foldTexCommentCheckBox.isChecked())
-            Preferences.setEditor(
-                "TexProcessComments",
-                self.texProcessCommentsCheckBox.isChecked())
-            Preferences.setEditor(
-                "TexProcessIf",
-                self.texProcessIfCheckBox.isChecked())
+        Preferences.setEditor(
+            "TexFoldComment",
+            self.foldTexCommentCheckBox.isChecked())
+        Preferences.setEditor(
+            "TexProcessComments",
+            self.texProcessCommentsCheckBox.isChecked())
+        Preferences.setEditor(
+            "TexProcessIf",
+            self.texProcessIfCheckBox.isChecked())
         
         # VHDL
         Preferences.setEditor(
@@ -531,10 +540,9 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             self.xmlSyleScriptsCheckBox.isChecked())
         
         # YAML
-        if "YAML" in self.languages:
-            Preferences.setEditor(
-                "YAMLFoldComment",
-                self.foldYamlCommentCheckBox.isChecked())
+        Preferences.setEditor(
+            "YAMLFoldComment",
+            self.foldYamlCommentCheckBox.isChecked())
 
 
 def create(dlg):
