@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -42,7 +42,6 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         self.styleSheetPicker.setFilters(self.tr(
             "Qt Style Sheets (*.qss);;Cascading Style Sheets (*.css);;"
             "All files (*)"))
-        self.styleSheetPicker.setDefaultDirectory(getConfig("ericStylesDir"))
         
         # set initial values
         self.__populateStyleCombo()
@@ -82,37 +81,24 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         else:
             self.brTopButton.setChecked(True)
         
-        layoutType = Preferences.getUI("LayoutType")
-        if layoutType == "Sidebars":
+        layout = Preferences.getUILayout()
+        if layout[0] == "Sidebars":
             index = 0
-        elif layoutType == "Toolboxes":
+        elif layout[0] == "Toolboxes":
             index = 1
         else:
             index = 0   # default for bad values
         self.layoutComboBox.setCurrentIndex(index)
-        
-        # integrated tools activation
-        # left side
-        self.templateViewerCheckBox.setChecked(
-            Preferences.getUI("ShowTemplateViewer"))
-        self.fileBrowserCheckBox.setChecked(
-            Preferences.getUI("ShowFileBrowser"))
-        self.symbolsCheckBox.setChecked(
-            Preferences.getUI("ShowSymbolsViewer"))
-        # right side
-        self.codeDocumentationViewerCheckBox.setChecked(
-            Preferences.getUI("ShowCodeDocumentationViewer"))
-        self.pypiCheckBox.setChecked(
-            Preferences.getUI("ShowPyPIPackageManager"))
-        self.condaCheckBox.setChecked(
-            Preferences.getUI("ShowCondaPackageManager"))
-        self.cooperationCheckBox.setChecked(
-            Preferences.getUI("ShowCooperation"))
-        self.ircCheckBox.setChecked(
-            Preferences.getUI("ShowIrc"))
-        # bottom side
-        self.numbersCheckBox.setChecked(
-            Preferences.getUI("ShowNumbersViewer"))
+        if layout[1] == 0:
+            self.separateShellButton.setChecked(True)
+        else:
+            self.debugEmbeddedShellButton.setChecked(True)
+        if layout[2] == 0:
+            self.separateFileBrowserButton.setChecked(True)
+        elif layout[2] == 1:
+            self.debugEmbeddedFileBrowserButton.setChecked(True)
+        else:
+            self.projectEmbeddedFileBrowserButton.setChecked(True)
         
         self.tabsGroupBox.setEnabled(True)
         self.tabsCloseButtonCheckBox.setChecked(
@@ -180,45 +166,24 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         Preferences.setUILanguage(uiLanguage)
         
         # save the interface layout settings
-        if self.layoutComboBox.currentIndex() == 0:
-            layoutType = "Sidebars"
-        elif self.layoutComboBox.currentIndex() == 1:
-            layoutType = "Toolboxes"
+        if self.separateShellButton.isChecked():
+            layout2 = 0
         else:
-            layoutType = "Sidebars"    # just in case
-        Preferences.setUI("LayoutType", layoutType)
-        
-        # save the integrated tools activation
-        # left side
-        Preferences.setUI(
-            "ShowTemplateViewer",
-            self.templateViewerCheckBox.isChecked())
-        Preferences.setUI(
-            "ShowFileBrowser",
-            self.fileBrowserCheckBox.isChecked())
-        Preferences.setUI(
-            "ShowSymbolsViewer",
-            self.symbolsCheckBox.isChecked())
-        # right side
-        Preferences.setUI(
-            "ShowCodeDocumentationViewer",
-            self.codeDocumentationViewerCheckBox.isChecked())
-        Preferences.setUI(
-            "ShowPyPIPackageManager",
-            self.pypiCheckBox.isChecked())
-        Preferences.setUI(
-            "ShowCondaPackageManager",
-            self.condaCheckBox.isChecked())
-        Preferences.setUI(
-            "ShowCooperation",
-            self.cooperationCheckBox.isChecked())
-        Preferences.setUI(
-            "ShowIrc",
-            self.ircCheckBox.isChecked())
-        # bottom side
-        Preferences.setUI(
-            "ShowNumbersViewer",
-            self.numbersCheckBox.isChecked())
+            layout2 = 1
+        if self.separateFileBrowserButton.isChecked():
+            layout3 = 0
+        elif self.debugEmbeddedFileBrowserButton.isChecked():
+            layout3 = 1
+        else:
+            layout3 = 2
+        if self.layoutComboBox.currentIndex() == 0:
+            layout1 = "Sidebars"
+        elif self.layoutComboBox.currentIndex() == 1:
+            layout1 = "Toolboxes"
+        else:
+            layout1 = "Sidebars"    # just in case
+        layout = (layout1, layout2, layout3)
+        Preferences.setUILayout(layout)
         
         Preferences.setUI(
             "SingleCloseButton",
