@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,37 +9,39 @@ Module implementing the Network configuration page.
 
 from __future__ import unicode_literals
 
-import os
-
 from PyQt5.QtCore import pyqtSlot
 
-from E5Gui.E5Completers import E5DirCompleter
-from E5Gui import E5FileDialog
+from E5Gui.E5PathPicker import E5PathPickerModes
+
 from E5Network.E5Ftp import E5FtpProxyType
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_NetworkPage import Ui_NetworkPage
 
 import Preferences
-import Utilities
-import UI.PixmapCache
 
 
 class NetworkPage(ConfigurationPageBase, Ui_NetworkPage):
     """
     Class implementing the Network configuration page.
     """
-    def __init__(self):
+    def __init__(self, configDialog):
         """
         Constructor
+        
+        @param configDialog reference to the configuration dialog
+            (ConfigurationDialog)
         """
         super(NetworkPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("NetworkPage")
         
-        self.downloadDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.__configDlg = configDialog
+        self.__displayMode = None
+        self.__webEngine = False
+        self.__webKit = False
         
-        self.downloadDirCompleter = E5DirCompleter(self.downloadDirEdit)
+        self.downloadDirPicker.setMode(E5PathPickerModes.DirectoryMode)
         
         self.ftpProxyTypeCombo.addItem(
             self.tr("No FTP Proxy"), E5FtpProxyType.NoProxy)
@@ -63,17 +65,11 @@ class NetworkPage(ConfigurationPageBase, Ui_NetworkPage):
             self.tr("Bluecoat Proxy"), E5FtpProxyType.Bluecoat)
         
         # set initial values
-        self.downloadDirEdit.setText(Preferences.getUI("DownloadPath"))
+        self.dynamicOnlineCheckBox.setChecked(
+            Preferences.getUI("DynamicOnlineCheck"))
+        self.downloadDirPicker.setText(Preferences.getUI("DownloadPath"))
         self.requestFilenameCheckBox.setChecked(
             Preferences.getUI("RequestDownloadFilename"))
-        policy = Preferences.getHelp("DownloadManagerRemovePolicy")
-        from Helpviewer.Download.DownloadManager import DownloadManager
-        if policy == DownloadManager.RemoveNever:
-            self.cleanupNeverButton.setChecked(True)
-        elif policy == DownloadManager.RemoveExit:
-            self.cleanupExitButton.setChecked(True)
-        else:
-            self.cleanupSuccessfulButton.setChecked(True)
         
         # HTTP proxy
         self.httpProxyHostEdit.setText(
@@ -104,35 +100,93 @@ class NetworkPage(ConfigurationPageBase, Ui_NetworkPage):
         
         self.httpProxyForAllCheckBox.setChecked(
             Preferences.getUI("UseHttpProxyForAll"))
-        if Preferences.getUI("UseSystemProxy"):
+        if not Preferences.getUI("UseProxy"):
+            self.noProxyButton.setChecked(True)
+        elif Preferences.getUI("UseSystemProxy"):
             self.systemProxyButton.setChecked(True)
         else:
             self.manualProxyButton.setChecked(True)
-        self.proxyGroup.setChecked(
-            Preferences.getUI("UseProxy"))
+        
+        self.exceptionsEdit.setText(
+            ", ".join(Preferences.getUI("ProxyExceptions").split(",")))
+    
+    def setMode(self, displayMode):
+        """
+        Public method to perform mode dependent setups.
+        
+        @param displayMode mode of the configuration dialog
+            (ConfigurationWidget.DefaultMode,
+             ConfigurationWidget.HelpBrowserMode,
+             ConfigurationWidget.WebBrowserMode)
+        """
+        from ..ConfigurationDialog import ConfigurationWidget
+        assert displayMode in (
+            ConfigurationWidget.DefaultMode,
+            ConfigurationWidget.HelpBrowserMode,
+            ConfigurationWidget.WebBrowserMode
+        )
+        
+        self.__displayMode = displayMode
+        if self.__displayMode == ConfigurationWidget.HelpBrowserMode or \
+                not self.__configDlg.isUsingWebEngine():
+            try:
+                policy = Preferences.getHelp("DownloadManagerRemovePolicy")
+                from Helpviewer.Download.DownloadManager import DownloadManager
+                if policy == DownloadManager.RemoveNever:
+                    self.cleanupNeverButton.setChecked(True)
+                elif policy == DownloadManager.RemoveExit:
+                    self.cleanupExitButton.setChecked(True)
+                else:
+                    self.cleanupSuccessfulButton.setChecked(True)
+                self.__webKit = True
+            except ImportError:
+                self.cleanupGroup.hide()
+        else:
+            policy = Preferences.getWebBrowser("DownloadManagerRemovePolicy")
+            from WebBrowser.Download.DownloadManager import DownloadManager
+            if policy == DownloadManager.RemoveNever:
+                self.cleanupNeverButton.setChecked(True)
+            elif policy == DownloadManager.RemoveExit:
+                self.cleanupExitButton.setChecked(True)
+            else:
+                self.cleanupSuccessfulButton.setChecked(True)
+            self.__webEngine = True
     
     def save(self):
         """
         Public slot to save the Networj configuration.
         """
+        Preferences.setUI(
+            "DynamicOnlineCheck",
+            self.dynamicOnlineCheckBox.isChecked())
         Preferences.setUI(
             "DownloadPath",
-            self.downloadDirEdit.text())
+            self.downloadDirPicker.text())
         Preferences.setUI(
             "RequestDownloadFilename",
             self.requestFilenameCheckBox.isChecked())
-        from Helpviewer.Download.DownloadManager import DownloadManager
-        if self.cleanupNeverButton.isChecked():
-            policy = DownloadManager.RemoveNever
-        elif self.cleanupExitButton.isChecked():
-            policy = DownloadManager.RemoveExit
-        else:
-            policy = DownloadManager.RemoveSuccessFullDownload
-        Preferences.setHelp("DownloadManagerRemovePolicy", policy)
+        if self.__webKit:
+            from Helpviewer.Download.DownloadManager import DownloadManager
+            if self.cleanupNeverButton.isChecked():
+                policy = DownloadManager.RemoveNever
+            elif self.cleanupExitButton.isChecked():
+                policy = DownloadManager.RemoveExit
+            else:
+                policy = DownloadManager.RemoveSuccessFullDownload
+            Preferences.setHelp("DownloadManagerRemovePolicy", policy)
+        elif self.__webEngine:
+            from WebBrowser.Download.DownloadManager import DownloadManager
+            if self.cleanupNeverButton.isChecked():
+                policy = DownloadManager.RemoveNever
+            elif self.cleanupExitButton.isChecked():
+                policy = DownloadManager.RemoveExit
+            else:
+                policy = DownloadManager.RemoveSuccessFullDownload
+            Preferences.setWebBrowser("DownloadManagerRemovePolicy", policy)
         
         Preferences.setUI(
             "UseProxy",
-            self.proxyGroup.isChecked())
+            not self.noProxyButton.isChecked())
         Preferences.setUI(
             "UseSystemProxy",
             self.systemProxyButton.isChecked())
@@ -140,6 +194,11 @@ class NetworkPage(ConfigurationPageBase, Ui_NetworkPage):
             "UseHttpProxyForAll",
             self.httpProxyForAllCheckBox.isChecked())
         
+        Preferences.setUI(
+            "ProxyExceptions",
+            ",".join(
+                [h.strip() for h in self.exceptionsEdit.text().split(",")]))
+        
         # HTTP proxy
         Preferences.setUI(
             "ProxyHost/Http",
@@ -177,23 +236,6 @@ class NetworkPage(ConfigurationPageBase, Ui_NetworkPage):
             "ProxyAccount/Ftp",
             self.ftpProxyAccountEdit.text())
     
-    @pyqtSlot()
-    def on_downloadDirButton_clicked(self):
-        """
-        Private slot to handle the directory selection via dialog.
-        """
-        directory = E5FileDialog.getExistingDirectory(
-            self,
-            self.tr("Select download directory"),
-            self.downloadDirEdit.text(),
-            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
-            
-        if directory:
-            dn = Utilities.toNativeSeparators(directory)
-            while dn.endswith(os.sep):
-                dn = dn[:-1]
-            self.downloadDirEdit.setText(dn)
-    
     @pyqtSlot()
     def on_clearProxyPasswordsButton_clicked(self):
         """
@@ -230,5 +272,5 @@ def create(dlg):
     @param dlg reference to the configuration dialog
     @return reference to the instantiated page (ConfigurationPageBase)
     """
-    page = NetworkPage()
+    page = NetworkPage(dlg)
     return page
