@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to add a new language to the project.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_AddLanguageDialog import Ui_AddLanguageDialog
 
@@ -23,11 +25,14 @@ class AddLanguageDialog(QDialog, Ui_AddLanguageDialog):
         @param parent parent widget of this dialog (QWidget)
         @param name name of this dialog (string)
         """
-        super().__init__(parent)
+        super(AddLanguageDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def getSelectedLanguage(self):
         """
         Public method to retrieve the selected language.
