@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,7 +13,7 @@ import os
 import xml.etree.ElementTree
 
 from PyQt5.QtCore import QMetaObject, QByteArray, QRegExp, Qt, pyqtSlot, \
-    QMetaMethod, qVersion, QSortFilterProxyModel
+    QMetaMethod, QSortFilterProxyModel
 from PyQt5.QtGui import QStandardItemModel, QBrush, QStandardItem
 from PyQt5.QtWidgets import QWidget, QDialog, QDialogButtonBox, QAction
 from PyQt5 import uic
@@ -27,9 +27,15 @@ from .NewDialogClassDialog import NewDialogClassDialog
 
 from eric6config import getConfig
 
+from Globals import qVersionTuple
+
+
 pyqtSignatureRole = Qt.UserRole + 1
 pythonSignatureRole = Qt.UserRole + 2
 rubySignatureRole = Qt.UserRole + 3
+returnTypeRole = Qt.UserRole + 4
+parameterTypesListRole = Qt.UserRole + 5
+parameterNamesListRole = Qt.UserRole + 6
 
 
 class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
@@ -215,7 +221,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             # 1. check for const
             mapped = mapped.replace("const ", "")
             
-            # 2. check fpr *
+            # 2. check for *
             mapped = mapped.replace("*", "")
             
             # 3. replace QString and QStringList
@@ -255,7 +261,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                 for index in range(metaObject.methodCount()):
                     metaMethod = metaObject.method(index)
                     if metaMethod.methodType() == QMetaMethod.Signal:
-                        if qVersion() >= "5.0.0":
+                        if qVersionTuple() >= (5, 0, 0):
                             itm2 = QStandardItem("on_{0}_{1}".format(
                                 name,
                                 bytes(metaMethod.methodSignature()).decode()))
@@ -264,7 +270,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                                 name, metaMethod.signature()))
                         itm.appendRow(itm2)
                         if self.__module is not None:
-                            if qVersion() >= "5.0.0":
+                            if qVersionTuple() >= (5, 0, 0):
                                 method = "on_{0}_{1}".format(
                                     name,
                                     bytes(metaMethod.methodSignature())
@@ -284,9 +290,14 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                                 itm2.setForeground(QBrush(Qt.blue))
                                 continue
                         
-                        pyqtSignature = \
-                            ", ".join([self.__mapType(t)
-                                       for t in metaMethod.parameterTypes()])
+                        returnType = self.__mapType(
+                            metaMethod.typeName().encode())
+                        if returnType == 'void':
+                            returnType = ""
+                        parameterTypesList = [
+                            self.__mapType(t)
+                            for t in metaMethod.parameterTypes()]
+                        pyqtSignature = ", ".join(parameterTypesList)
                         
                         parameterNames = metaMethod.parameterNames()
                         if parameterNames:
@@ -295,12 +306,12 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                                     parameterNames[index] = \
                                         QByteArray("p{0:d}".format(index)
                                                    .encode("utf-8"))
-                        methNamesSig = \
-                            ", ".join(
-                                [bytes(n).decode() for n in parameterNames])
+                        parameterNamesList = [bytes(n).decode()
+                                              for n in parameterNames]
+                        methNamesSig = ", ".join(parameterNamesList)
                         
                         if methNamesSig:
-                            if qVersion() >= "5.0.0":
+                            if qVersionTuple() >= (5, 0, 0):
                                 pythonSignature = \
                                     "on_{0}_{1}(self, {2})".format(
                                         name,
@@ -314,7 +325,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                                         metaMethod.signature().split("(")[0],
                                         methNamesSig)
                         else:
-                            if qVersion() >= "5.0.0":
+                            if qVersionTuple() >= (5, 0, 0):
                                 pythonSignature = "on_{0}_{1}(self)".format(
                                     name,
                                     bytes(metaMethod.methodSignature())
@@ -325,6 +336,11 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                                     metaMethod.signature().split("(")[0])
                         itm2.setData(pyqtSignature, pyqtSignatureRole)
                         itm2.setData(pythonSignature, pythonSignatureRole)
+                        itm2.setData(returnType, returnTypeRole)
+                        itm2.setData(parameterTypesList,
+                                     parameterTypesListRole)
+                        itm2.setData(parameterNamesList,
+                                     parameterNamesListRole)
                         
                         itm2.setFlags(Qt.ItemFlags(
                             Qt.ItemIsUserCheckable |
@@ -495,15 +511,34 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                             child.data(pyqtSignatureRole))))
                     slotsCode.append('{0}def {1}:\n'.format(
                         indentStr, child.data(pythonSignatureRole)))
-                    slotsCode.append('{0}"""\n'.format(indentStr * 2))
+                    indentStr2 = indentStr * 2
+                    slotsCode.append('{0}"""\n'.format(indentStr2))
                     slotsCode.append(
                         '{0}Slot documentation goes here.\n'.format(
-                            indentStr * 2))
-                    slotsCode.append('{0}"""\n'.format(indentStr * 2))
+                            indentStr2))
+                    if child.data(returnTypeRole) or \
+                            child.data(parameterTypesListRole):
+                        slotsCode.append('{0}\n'.format(indentStr2))
+                        if child.data(parameterTypesListRole):
+                            for name, type_ in zip(
+                                child.data(parameterNamesListRole),
+                                    child.data(parameterTypesListRole)):
+                                slotsCode.append(
+                                    '{0}@param {1} DESCRIPTION\n'.format(
+                                        indentStr2, name))
+                                slotsCode.append('{0}@type {1}\n'.format(
+                                    indentStr2, type_))
+                        if child.data(returnTypeRole):
+                            slotsCode.append(
+                                '{0}@returns DESCRIPTION\n'.format(
+                                    indentStr2))
+                            slotsCode.append('{0}@rtype {1}\n'.format(
+                                indentStr2, child.data(returnTypeRole)))
+                    slotsCode.append('{0}"""\n'.format(indentStr2))
                     slotsCode.append('{0}# {1}: not implemented yet\n'.format(
-                        indentStr * 2, "TODO"))
+                        indentStr2, "TODO"))
                     slotsCode.append('{0}raise NotImplementedError\n'.format(
-                        indentStr * 2))
+                        indentStr2))
         
         if appendAtIndex == -1:
             sourceImpl.extend(slotsCode)
