@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,11 +11,13 @@ from __future__ import unicode_literals
 
 import os
 
-from PyQt5.QtCore import Qt, pyqtSlot, qVersion
+from PyQt5.QtCore import Qt, pyqtSlot
 from PyQt5.QtWidgets import QHeaderView, QTreeWidgetItem, QDialog
 
 from .Ui_LexerAssociationDialog import Ui_LexerAssociationDialog
 
+from Globals import qVersionTuple
+
 
 class LexerAssociationDialog(QDialog, Ui_LexerAssociationDialog):
     """
@@ -34,7 +36,7 @@ class LexerAssociationDialog(QDialog, Ui_LexerAssociationDialog):
         self.editorLexerList.headerItem().setText(
             self.editorLexerList.columnCount(), "")
         header = self.editorLexerList.header()
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             header.setSectionResizeMode(QHeaderView.ResizeToContents)
         else:
             header.setResizeMode(QHeaderView.ResizeToContents)
@@ -51,10 +53,13 @@ class LexerAssociationDialog(QDialog, Ui_LexerAssociationDialog):
         languages = [''] + \
             sorted(QScintilla.Lexers.getSupportedLanguages().keys()) + \
             self.extras
-        self.editorLexerCombo.addItems(languages)
+        for lang in languages:
+            self.editorLexerCombo.addItem(
+                QScintilla.Lexers.getLanguageIcon(lang, False),
+                lang)
         
         from pygments.lexers import get_all_lexers
-        pygmentsLexers = [''] + sorted([l[0] for l in get_all_lexers()])
+        pygmentsLexers = [''] + sorted(l[0] for l in get_all_lexers())
         self.pygmentsLexerCombo.addItems(pygmentsLexers)
         
         # set initial values
@@ -84,6 +89,7 @@ class LexerAssociationDialog(QDialog, Ui_LexerAssociationDialog):
             if itmList:
                 index = self.editorLexerList.indexOfTopLevelItem(itmList[0])
                 itm = self.editorLexerList.takeTopLevelItem(index)
+                # __IGNORE_WARNING__
                 del itm
             QTreeWidgetItem(self.editorLexerList, [ext, lexer])
             self.editorFileExtEdit.clear()
@@ -103,6 +109,7 @@ class LexerAssociationDialog(QDialog, Ui_LexerAssociationDialog):
         if itmList:
             index = self.editorLexerList.indexOfTopLevelItem(itmList[0])
             itm = self.editorLexerList.takeTopLevelItem(index)
+            # __IGNORE_WARNING__
             del itm
             
             self.editorLexerList.clearSelection()
