@@ -301,9 +301,12 @@ class ProjectBaseBrowser(Browser):
             DeleteFilesConfirmationDialog
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
-            self.tr("Delete directories"),
-            self.tr("Do you really want to delete these directories from"
-                    " the project?"),
+            QCoreApplication.translate(
+                "ProjectBaseBrowser", "Delete directories"),
+            QCoreApplication.translate(
+                "ProjectBaseBrowser",
+                "Do you really want to delete these directories from"
+                " the project?"),
             dirs)
         
         if dlg.exec_() == QDialog.Accepted:
@@ -482,13 +485,13 @@ class ProjectBaseBrowser(Browser):
         # nothing to do for now
         return
         
-    def _selectEntries(self, local=True, filter=None):
+    def _selectEntries(self, local=True, filterList=None):
         """
         Protected method to select entries based on their VCS status.
         
         @param local flag indicating local (i.e. non VCS controlled)
             file/directory entries should be selected (boolean)
-        @param filter list of classes to check against
+        @param filterList list of classes to check against
         """
         if self.project.vcs is None:
             return
@@ -514,7 +517,7 @@ class ProjectBaseBrowser(Browser):
         index = self.model().index(0, 0)
         while index.isValid():
             itm = self.model().item(index)
-            if self.wantedItem(itm, filter) and \
+            if self.wantedItem(itm, filterList) and \
                compareString == itm.data(1):
                 if startIndex is not None and \
                    startIndex.parent() != index.parent():
@@ -547,13 +550,13 @@ class ProjectBaseBrowser(Browser):
         """
         Public slot to handle the select local files context menu entries.
         """
-        self._selectEntries(local=True, filter=[ProjectBrowserFileItem])
+        self._selectEntries(local=True, filterList=[ProjectBrowserFileItem])
         
     def selectVCSEntries(self):
         """
         Public slot to handle the select VCS files context menu entries.
         """
-        self._selectEntries(local=False, filter=[ProjectBrowserFileItem])
+        self._selectEntries(local=False, filterList=[ProjectBrowserFileItem])
         
     def selectLocalDirEntries(self):
         """
@@ -562,8 +565,8 @@ class ProjectBaseBrowser(Browser):
         """
         self._selectEntries(
             local=True,
-            filter=[ProjectBrowserSimpleDirectoryItem,
-                    ProjectBrowserDirectoryItem])
+            filterList=[ProjectBrowserSimpleDirectoryItem,
+                        ProjectBrowserDirectoryItem])
         
     def selectVCSDirEntries(self):
         """
@@ -571,8 +574,8 @@ class ProjectBaseBrowser(Browser):
         """
         self._selectEntries(
             local=False,
-            filter=[ProjectBrowserSimpleDirectoryItem,
-                    ProjectBrowserDirectoryItem])
+            filterList=[ProjectBrowserSimpleDirectoryItem,
+                        ProjectBrowserDirectoryItem])
         
     def getExpandedItemNames(self):
         """
