@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -43,12 +43,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
     
     @signal appendStderr(str) emitted after something was received from
         a QProcess on stderr
-    @signal sourceFile(str) emitted to open a forms file in an editor
     @signal uipreview(str) emitted to preview a forms file
-    @signal trpreview(list of str) emitted to preview form files in the
-        translations previewer
-    @signal closeSourceWindow(str) emitted after a file has been
-        removed/deleted from the project
     @signal showMenu(str, QMenu) emitted when a menu is about to be shown. The
         name of the menu and a reference to the menu are given.
     @signal menusAboutToBeCreated() emitted when the context menus are about to
@@ -131,7 +126,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         
         self.menu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "PyQt5", "E4Plugin", "E6Plugin", "PySide"]:
+                ["Qt4", "PyQt5", "E6Plugin", "PySide"]:
             self.menu.addAction(
                 self.tr('Compile form'), self.__compileForm)
             self.menu.addAction(
@@ -186,7 +181,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         self.menuActions.append(act)
         self.menu.addSeparator()
         if self.project.getProjectType() in \
-                ["Qt4", "PyQt5", "E4Plugin", "E6Plugin", "PySide"]:
+                ["Qt4", "PyQt5", "E6Plugin", "PySide"]:
             self.menu.addAction(self.tr('New form...'), self.__newForm)
         else:
             if self.hooks["newForm"] is not None:
@@ -209,7 +204,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
 
         self.backMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "PyQt5", "E4Plugin", "E6Plugin", "PySide"] or \
+                ["Qt4", "PyQt5", "E6Plugin", "PySide"] or \
                 self.hooks["compileAllForms"] is not None:
             self.backMenu.addAction(
                 self.tr('Compile all forms'), self.__compileAllForms)
@@ -236,7 +231,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         # create the menu for multiple selected files
         self.multiMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "PyQt5", "E4Plugin", "E6Plugin", "PySide"]:
+                ["Qt4", "PyQt5", "E6Plugin", "PySide"]:
             act = self.multiMenu.addAction(
                 self.tr('Compile forms'), self.__compileSelectedForms)
             self.multiMenu.addSeparator()
@@ -278,7 +273,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
 
         self.dirMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "PyQt5", "E4Plugin", "E6Plugin", "PySide"]:
+                ["Qt4", "PyQt5", "E6Plugin", "PySide"]:
             self.dirMenu.addAction(
                 self.tr('Compile all forms'), self.__compileAllForms)
             self.dirMenu.addSeparator()
@@ -298,7 +293,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         self.dirMenuActions.append(act)
         self.dirMenu.addSeparator()
         if self.project.getProjectType() in \
-                ["Qt4", "PyQt5", "E4Plugin", "E6Plugin", "PySide"]:
+                ["Qt4", "PyQt5", "E6Plugin", "PySide"]:
             self.dirMenu.addAction(self.tr('New form...'), self.__newForm)
         else:
             if self.hooks["newForm"] is not None:
@@ -323,7 +318,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         
         self.dirMultiMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "PyQt5", "E4Plugin", "E6Plugin", "PySide"]:
+                ["Qt4", "PyQt5", "E6Plugin", "PySide"]:
             self.dirMultiMenu.addAction(
                 self.tr('Compile all forms'), self.__compileAllForms)
             self.dirMultiMenu.addSeparator()
@@ -394,7 +389,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except:
+        except Exception:
             pass
         
     def __showContextMenu(self):
@@ -478,7 +473,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                         self.hooks["open"](itm.fileName())
                     else:
                         self.designerFile.emit(itm.fileName())
-            except:
+            except Exception:
                 pass
         
     def __openFileInEditor(self):
@@ -541,7 +536,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             self.hooks["newForm"](path)
         else:
             if self.project.getProjectType() in \
-                    ["Qt4", "PyQt5", "E4Plugin", "E6Plugin", "PySide"]:
+                    ["Qt4", "PyQt5", "E6Plugin", "PySide"]:
                 self.__newUiForm(path)
         
     def __newUiForm(self, path):
@@ -642,7 +637,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
     def __readStdout(self):
         """
         Private slot to handle the readyReadStandardOutput signal of the
-        pyuic/rbuic process.
+        pyuic4/pyuic5/pyside-uic/rbuic4 process.
         """
         if self.compileProc is None:
             return
@@ -655,7 +650,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
     def __readStderr(self):
         """
         Private slot to handle the readyReadStandardError signal of the
-        pyuic/rbuic process.
+        pyuic4/pyuic5/pyside-uic/rbuic4 process.
         """
         if self.compileProc is None:
             return
@@ -747,41 +742,32 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         args = []
         self.buf = ""
         
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
-            if self.project.getProjectType() in ["Qt4", "E4Plugin"]:
-                self.uicompiler = 'pyuic4'
-                if Utilities.isWindowsPlatform():
-                    uic = self.uicompiler + '.bat'
-                else:
-                    uic = self.uicompiler
+            if self.project.getProjectType() in ["Qt4", ]:
+                self.uicompiler = Utilities.generatePyQtToolPath(
+                    'pyuic4', ["py3uic4", "py2uic4"])
             elif self.project.getProjectType() in ["PyQt5"]:
-                self.uicompiler = 'pyuic5'
-                if Utilities.isWindowsPlatform():
-                    uic = self.uicompiler + '.bat'
-                else:
-                    uic = self.uicompiler
+                self.uicompiler = Utilities.generatePyQtToolPath(
+                    'pyuic5', ["py3uic5", "py2uic5"])
             elif self.project.getProjectType() in ["E6Plugin"]:
                 if PYQT_VERSION < 0x050000:
-                    self.uicompiler = 'pyuic4'
+                    self.uicompiler = Utilities.generatePyQtToolPath(
+                        'pyuic4', ["py3uic4", "py2uic4"])
                 else:
-                    self.uicompiler = 'pyuic5'
-                if Utilities.isWindowsPlatform():
-                    uic = self.uicompiler + '.bat'
-                else:
-                    uic = self.uicompiler
+                    self.uicompiler = Utilities.generatePyQtToolPath(
+                        'pyuic5', ["py3uic5", "py2uic5"])
             elif self.project.getProjectType() == "PySide":
-                self.uicompiler = 'pyside-uic'
-                uic = Utilities.generatePySideToolPath(self.uicompiler)
+                self.uicompiler = \
+                    Utilities.generatePySideToolPath('pyside-uic')
             else:
                 return None
-        elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+        elif self.project.getProjectLanguage() == "Ruby":
             if self.project.getProjectType() == "Qt4":
                 self.uicompiler = 'rbuic4'
                 if Utilities.isWindowsPlatform():
-                    uic = self.uicompiler + '.exe'
-                else:
-                    uic = self.uicompiler
+                    self.uicompiler = \
+                        Utilities.getWindowsExecutablePath(self.uicompiler)
             else:
                 return None
         else:
@@ -790,7 +776,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         ofn, ext = os.path.splitext(fn)
         fn = os.path.join(self.project.ppath, fn)
         
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             dirname, filename = os.path.split(ofn)
             self.compiledFile = os.path.join(dirname, "Ui_" + filename + ".py")
@@ -800,7 +786,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 args.append("--indent={0}".format(indentWidth))
             if Preferences.getQt("PyuicFromImports"):
                 args.append("--from-imports")
-        elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+        elif self.project.getProjectLanguage() == "Ruby":
             self.compiledFile = ofn + '.rb'
             args.append('-x')
         
@@ -810,7 +796,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         self.compileProc.readyReadStandardError.connect(self.__readStderr)
         
         self.noDialog = noDialog
-        self.compileProc.start(uic, args)
+        self.compileProc.start(self.uicompiler, args)
         procStarted = self.compileProc.waitForStarted(5000)
         if procStarted:
             self.compileRunning = True
@@ -946,7 +932,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             self.hooks["compileChangedForms"](self.project.pdata["FORMS"])
         else:
             if self.project.getProjectType() not in \
-               ["Qt4", "PyQt5", "E4Plugin", "E6Plugin", "PySide"]:
+               ["Qt4", "PyQt5", "E6Plugin", "PySide"]:
                 # ignore the request for non Qt GUI projects
                 return
             
@@ -965,11 +951,11 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 QApplication.processEvents()
                 
                 ifn = os.path.join(self.project.ppath, fn)
-                if self.project.pdata["PROGLANGUAGE"][0] in \
+                if self.project.getProjectLanguage() in \
                    ["Python", "Python2", "Python3"]:
                     dirname, filename = os.path.split(os.path.splitext(ifn)[0])
                     ofn = os.path.join(dirname, "Ui_" + filename + ".py")
-                elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+                elif self.project.getProjectLanguage() == "Ruby":
                     ofn = os.path.splitext(ifn)[0] + '.rb'
                 if not os.path.exists(ofn) or \
                    os.stat(ifn).st_mtime > os.stat(ofn).st_mtime:
