@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,7 +17,7 @@ from PyQt5.QtWidgets import QDialog, QInputDialog, QMenu
 from E5Gui import E5MessageBox
 
 from UI.BrowserModel import BrowserFileItem, BrowserClassItem, \
-    BrowserMethodItem, BrowserClassAttributeItem
+    BrowserMethodItem, BrowserClassAttributeItem, BrowserImportItem
 
 from .ProjectBrowserModel import ProjectBrowserFileItem, \
     ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem, \
@@ -32,15 +32,8 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
     """
     A class used to display the Sources part of the project.
     
-    @signal closeSourceWindow(str) emitted after a file has been
-        removed/deleted from the project
     @signal showMenu(str, QMenu) emitted when a menu is about to be shown.
         The name of the menu and a reference to the menu are given.
-    @signal sourceFile(str) emitted to open the given file.
-    @signal sourceFile(str, int) emitted to open the given file at the given
-        line.
-    @signal sourceFile(str, int, str) emitted to open the given file as the
-        given type at the given line.
     """
     showMenu = pyqtSignal(str, QMenu)
     
@@ -590,7 +583,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             categories = self.getSelectedItemsCountCategorized(
                 [ProjectBrowserFileItem, BrowserClassItem,
                  BrowserMethodItem, ProjectBrowserSimpleDirectoryItem,
-                 BrowserClassAttributeItem])
+                 BrowserClassAttributeItem, BrowserImportItem])
             cnt = categories["sum"]
             if cnt <= 1:
                 index = self.indexAt(coord)
@@ -599,13 +592,14 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
                     categories = self.getSelectedItemsCountCategorized(
                         [ProjectBrowserFileItem, BrowserClassItem,
                          BrowserMethodItem, ProjectBrowserSimpleDirectoryItem,
-                         BrowserClassAttributeItem])
+                         BrowserClassAttributeItem, BrowserImportItem])
                     cnt = categories["sum"]
             
             bfcnt = categories[str(ProjectBrowserFileItem)]
             cmcnt = categories[str(BrowserClassItem)] + \
                 categories[str(BrowserMethodItem)] + \
-                categories[str(BrowserClassAttributeItem)]
+                categories[str(BrowserClassAttributeItem)] + \
+                categories[str(BrowserImportItem)]
             sdcnt = categories[str(ProjectBrowserSimpleDirectoryItem)]
             if cnt > 1 and cnt == bfcnt:
                 self.multiMenu.popup(self.mapToGlobal(coord))
@@ -656,7 +650,8 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
                                         True)
                             self.sourceMenu.popup(self.mapToGlobal(coord))
                         elif isinstance(itm, BrowserClassItem) or \
-                                isinstance(itm, BrowserMethodItem):
+                            isinstance(itm, BrowserMethodItem) or \
+                                isinstance(itm, BrowserImportItem):
                             self.menu.popup(self.mapToGlobal(coord))
                         elif isinstance(itm, BrowserClassAttributeItem):
                             self.attributeMenu.popup(self.mapToGlobal(coord))
@@ -669,7 +664,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except:
+        except Exception:
             pass
         
     def __showContextMenu(self):
@@ -756,7 +751,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         """
         itmList = self.getSelectedItems(
             [BrowserFileItem, BrowserClassItem, BrowserMethodItem,
-             BrowserClassAttributeItem])
+             BrowserClassAttributeItem, BrowserImportItem])
         
         for itm in itmList:
             if isinstance(itm, BrowserFileItem):
@@ -781,6 +776,9 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             elif isinstance(itm, BrowserClassAttributeItem):
                 self.sourceFile[str, int].emit(
                     itm.fileName(), itm.attributeObject().lineno)
+            elif isinstance(itm, BrowserImportItem):
+                self.sourceFile[str, list].emit(
+                    itm.fileName(), itm.linenos())
         
     def __addNewPackage(self):
         """
