@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -39,17 +39,10 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
     """
     A class used to display the translations part of the project.
     
-    @signal linguistFile(str) emitted to open a translation file with
-        Qt-Linguist
     @signal appendStdout(str) emitted after something was received from
         a QProcess on stdout
     @signal appendStderr(str) emitted after something was received from
         a QProcess on stderr
-    @signal sourceFile(str) emitted to open a translation file in an editor
-    @signal closeSourceWindow(str) emitted after a file has been
-        removed/deleted from the project
-    @signal trpreview(list of str, bool = False) emitted to preview
-        translations in the translations previewer
     @signal showMenu(str, QMenu) emitted when a menu is about to be shown.
         The name of the menu and a reference to the menu are given.
     """
@@ -113,7 +106,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         self.menu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             act = self.menu.addAction(
                 self.tr('Generate translation'), self.__generateSelected)
@@ -240,7 +233,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         self.backMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             act = self.backMenu.addAction(
                 self.tr('Generate all translations'),
@@ -301,7 +294,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         # create the menu for multiple selected files
         self.multiMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             act = self.multiMenu.addAction(
                 self.tr('Generate translations'),
@@ -385,7 +378,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
 
         self.dirMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             act = self.dirMenu.addAction(
                 self.tr('Generate all translations'),
@@ -495,7 +488,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except:
+        except Exception:
             pass
         
     def __showContextMenu(self):
@@ -503,7 +496,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the menu aboutToShow signal.
         """
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             tsFiles = 0
             qmFiles = 0
@@ -545,7 +538,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the multiMenu aboutToShow signal.
         """
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             tsFiles = 0
             qmFiles = 0
@@ -585,7 +578,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the dirMenu aboutToShow signal.
         """
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             if self.pylupdateProcRunning:
                 for act in self.tsprocDirMenuActions:
@@ -605,7 +598,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the backMenu aboutToShow signal.
         """
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             if self.pylupdateProcRunning:
                 for act in self.tsprocBackMenuActions:
@@ -731,7 +724,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
     ##  Methods to support the generation and release commands
     ###########################################################################
     
-    def __writeTempProjectFile(self, langs, filter):
+    def __writeTempProjectFile(self, langs, filterList):
         """
         Private method to write a temporary project file suitable for
         pylupdate and lrelease.
@@ -739,8 +732,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         @param langs list of languages to include in the process. An empty
             list (default) means that all translations should be included.
             (list of ProjectBrowserFileItem)
-        @param filter list of source file extension that should be considered
-            (list of strings)
+        @param filterList list of source file extension that should be
+            considered (list of strings)
         @return flag indicating success
         """
         path, ext = os.path.splitext(self.project.pfile)
@@ -748,7 +741,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         # only consider files satisfying the filter criteria
         _sources = [s for s in self.project.pdata["SOURCES"]
-                    if os.path.splitext(s)[1] in filter]
+                    if os.path.splitext(s)[1] in filterList]
         sources = []
         for s in _sources:
             addIt = True
@@ -775,7 +768,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                      for lang in langs if lang.fileName().endswith('.ts')]
         else:
             try:
-                pattern = self.project.pdata["TRANSLATIONPATTERN"][0]\
+                pattern = self.project.pdata["TRANSLATIONPATTERN"]\
                     .replace("%language%", "*")
                 langs = [lang for lang in self.project.pdata["TRANSLATIONS"]
                          if fnmatch.fnmatch(lang, pattern)]
@@ -808,29 +801,20 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 ("TRANSLATIONS",
                  [prefix + lang for lang in langs]))
             
-            dir, name = os.path.split(pfile)
-            outFile = os.path.join(dir, os.path.dirname(langs[0]), name)
+            directory, name = os.path.split(pfile)
+            outFile = os.path.join(directory, os.path.dirname(langs[0]), name)
             outDir = os.path.dirname(outFile)
             if not os.path.exists(outDir):
                 os.makedirs(outDir)
             try:
                 pf = open(outFile, "w", encoding="utf-8")
-                for key, list in sections:
-                    if len(list) > 0:
+                for key, fileList in sections:
+                    if len(fileList) > 0:
                         pf.write('{0} = '.format(key))
-                        last = len(list) - 1
-                        if last > 0:
-                            pf.write('{0} \\{1}'.format(
-                                list[0].replace(os.sep, '/'), "\n"))
-                            for i in range(1, last):
-                                pf.write('\t{0} \\{1}'.format(
-                                    list[i].replace(os.sep, '/'), "\n"))
-                            pf.write('\t{0} {1}{2}'.format(
-                                list[last].replace(os.sep, '/'), "\n", "\n"))
-                        else:
-                            pf.write('{0} {1}{2}'.format(
-                                list[0].replace(os.sep, '/'), "\n", "\n"))
-                    
+                        pf.write(' \\\n\t'.join(
+                            [f.replace(os.sep, '/') for f in fileList]))
+                        pf.write('\n\n')
+                
                 pf.close()
                 self.__tmpProjects.append(outFile)
             except IOError:
@@ -887,7 +871,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
     def __readStderrLupdate(self):
         """
         Private slot to handle the readyReadStandardError signal of the
-        pylupdate process.
+        pylupdate4/pylupdate5/pyside-lupdate process.
         """
         proc = self.sender()
         if proc is not None:
@@ -985,8 +969,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
     def __generateTSFile(self, noobsolete=False, generateAll=True):
         """
-        Private method used to run pylupdate/pylupdate4 to generate the .ts
-        files.
+        Private method used to run pylupdate4/pylupdate5/pyside-lupdate to
+        generate the .ts files.
         
         @param noobsolete flag indicating whether obsolete entries should be
             kept (boolean)
@@ -1026,7 +1010,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         # generate a minimal temporary projectfile suitable for pylupdate
         self.__tmpProjects = []
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             ok = self.__writeTempProjectFile(langs, [".py"])
         else:
@@ -1034,21 +1018,15 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         if not ok:
             return
         
-        if self.project.getProjectType() in ["Qt4", "Qt4C", "E4Plugin"]:
-            self.pylupdate = 'pylupdate4'
-            if Utilities.isWindowsPlatform():
-                self.pylupdate = self.pylupdate + '.exe'
+        if self.project.getProjectType() in ["Qt4", "Qt4C"]:
+            self.pylupdate = Utilities.generatePyQtToolPath('pylupdate4')
         elif self.project.getProjectType() in ["PyQt5", "PyQt5C"]:
-            self.pylupdate = 'pylupdate5'
-            if Utilities.isWindowsPlatform():
-                self.pylupdate = self.pylupdate + '.exe'
+            self.pylupdate = Utilities.generatePyQtToolPath('pylupdate5')
         elif self.project.getProjectType() in ["E6Plugin"]:
             if PYQT_VERSION < 0x050000:
-                self.pylupdate = 'pylupdate4'
+                self.pylupdate = Utilities.generatePyQtToolPath('pylupdate4')
             else:
-                self.pylupdate = 'pylupdate5'
-            if Utilities.isWindowsPlatform():
-                self.pylupdate = self.pylupdate + '.exe'
+                self.pylupdate = Utilities.generatePyQtToolPath('pylupdate5')
         elif self.project.getProjectType() in ["PySide", "PySideC"]:
             self.pylupdate = Utilities.generatePySideToolPath('pyside-lupdate')
         else:
@@ -1149,11 +1127,10 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                     self.tr("Translation file release"),
                     self.tr("The release of the translation files (*.qm)"
                             " was successful."))
-            if self.project.pdata["TRANSLATIONSBINPATH"] and \
-                    self.project.pdata["TRANSLATIONSBINPATH"][0]:
+            if self.project.pdata["TRANSLATIONSBINPATH"]:
                 target = os.path.join(
                     self.project.ppath,
-                    self.project.pdata["TRANSLATIONSBINPATH"][0])
+                    self.project.pdata["TRANSLATIONSBINPATH"])
                 for langFile in self.project.pdata["TRANSLATIONS"][:]:
                     if langFile.endswith('.ts'):
                         qmFile = os.path.join(self.project.ppath,
@@ -1209,7 +1186,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         # generate a minimal temporary projectfile suitable for lrelease
         self.__tmpProjects = []
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             ok = self.__writeTempProjectFile(langs, [".py"])
         else:
@@ -1218,7 +1195,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             return
         
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
                  "PySide", "PySideC"]:
             lrelease = os.path.join(
                 Utilities.getQtBinariesPath(),
