@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -39,7 +39,7 @@ class UserPropertiesDialog(QDialog, Ui_UserPropertiesDialog):
         
         if self.project.pudata["VCSSTATUSMONITORINTERVAL"]:
             self.vcsStatusMonitorIntervalSpinBox.setValue(
-                self.project.pudata["VCSSTATUSMONITORINTERVAL"][0])
+                self.project.pudata["VCSSTATUSMONITORINTERVAL"])
         else:
             self.vcsStatusMonitorIntervalSpinBox.setValue(
                 Preferences.getVCS("StatusMonitorInterval"))
@@ -51,7 +51,7 @@ class UserPropertiesDialog(QDialog, Ui_UserPropertiesDialog):
                     e5App().getObject("PluginManager")\
                     .getVcsSystemIndicators().items():
                 for vcsSystem, vcsSystemDisplay in vcsData:
-                    if vcsSystem == self.project.pdata["VCS"][0]:
+                    if vcsSystem == self.project.pdata["VCS"]:
                         found = True
                         break
                 
@@ -65,9 +65,9 @@ class UserPropertiesDialog(QDialog, Ui_UserPropertiesDialog):
         
         if self.vcsGroup.isEnabled():
             if self.project.pudata["VCSOVERRIDE"]:
-                vcsSystem = self.project.pudata["VCSOVERRIDE"][0]
+                vcsSystem = self.project.pudata["VCSOVERRIDE"]
             else:
-                vcsSystem = self.project.pdata["VCS"][0]
+                vcsSystem = self.project.pdata["VCS"]
             index = self.vcsInterfaceCombo.findData(vcsSystem)
             if index == -1:
                 index = 0
@@ -84,20 +84,20 @@ class UserPropertiesDialog(QDialog, Ui_UserPropertiesDialog):
         if vcsStatusMonitorInterval != \
                 Preferences.getVCS("StatusMonitorInterval"):
             self.project.pudata["VCSSTATUSMONITORINTERVAL"] = \
-                [vcsStatusMonitorInterval]
+                vcsStatusMonitorInterval
         else:
-            self.project.pudata["VCSSTATUSMONITORINTERVAL"] = []
+            self.project.pudata["VCSSTATUSMONITORINTERVAL"] = 0
         
         if self.vcsGroup.isEnabled():
             vcsSystem = self.vcsInterfaceCombo\
                 .itemData(self.vcsInterfaceCombo.currentIndex())
             if self.vcsInterfaceDefaultCheckBox.isChecked():
-                if vcsSystem != self.project.pdata["VCS"][0]:
-                    self.project.pdata["VCS"] = [vcsSystem]
-                    self.project.pudata["VCSOVERRIDE"] = []
+                if vcsSystem != self.project.pdata["VCS"]:
+                    self.project.pdata["VCS"] = vcsSystem
+                    self.project.pudata["VCSOVERRIDE"] = ""
                     self.project.setDirty(True)
             else:
-                if vcsSystem != self.project.pdata["VCS"][0]:
-                    self.project.pudata["VCSOVERRIDE"] = [vcsSystem]
+                if vcsSystem != self.project.pdata["VCS"]:
+                    self.project.pudata["VCSOVERRIDE"] = vcsSystem
                 else:
-                    self.project.pudata["VCSOVERRIDE"] = []
+                    self.project.pudata["VCSOVERRIDE"] = ""
