@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -74,6 +74,22 @@ class LexerCPP(Lexer, QsciLexerCPP):
                 Preferences.getEditor("CppHighlightHashQuotedStrings"))
         except AttributeError:
             pass
+        try:
+            self.setHighlightBackQuotedStrings(
+                Preferences.getEditor("CppHighlightBackQuotedStrings"))
+        except AttributeError:
+            pass
+        try:
+            self.setHighlightEscapeSequences(
+                Preferences.getEditor("CppHighlightEscapeSequences"))
+        except AttributeError:
+            pass
+        try:
+            self.setVerbatimStringEscapeSequencesAllowed(
+                Preferences.getEditor(
+                    "CppVerbatimStringEscapeSequencesAllowed"))
+        except AttributeError:
+            pass
     
     def autoCompletionWordSeparators(self):
         """
