@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -28,7 +28,7 @@ class LexerFortran(Lexer, QsciLexerFortran):
         QsciLexerFortran.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = "!"
+        self.commentString = "c "
     
     def initProperties(self):
         """
