@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,9 +9,9 @@ Module implementing a compatability interface class to QsciScintilla.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSignal, Qt, QPoint
-from PyQt5.QtGui import QPalette, QColor, QFontMetrics
-from PyQt5.QtWidgets import QApplication, QListWidget
+from PyQt5.QtCore import pyqtSignal, Qt
+from PyQt5.QtGui import QPalette, QColor
+from PyQt5.QtWidgets import QApplication
 from PyQt5.Qsci import QsciScintillaBase, QsciScintilla, \
     QSCINTILLA_VERSION as QSCIQSCINTILLA_VERSION
 
@@ -75,12 +75,6 @@ class QsciScintillaCompat(QsciScintilla):
         
         self.userListActivated.connect(self.__completionListSelected)
         self.modificationChanged.connect(self.__modificationChanged)
-        
-        self.maxLines = 5
-        self.maxChars = 40
-        # Adjust the min. size of the autocomplete list box for short strings.
-        # Otherwise the width of the list box is at least the standard width.
-        self.SendScintilla(QsciScintilla.SCI_AUTOCSETMAXWIDTH, 5)
     
     def __modificationChanged(self, m):
         """
@@ -248,6 +242,14 @@ class QsciScintillaCompat(QsciScintilla):
         """
         self.SendScintilla(QsciScintilla.SCI_SETSTYLING, length, style)
     
+    def setStyleBits(self, bits):
+        """
+        Public method to set the number of bits to be used for styling.
+        
+        @param bits number of style bits (integer)
+        """
+        self.SendScintilla(QsciScintilla.SCI_SETSTYLEBITS, bits)
+    
     def charAt(self, pos):
         """
         Public method to get the character at a position in the text observing
@@ -750,16 +752,6 @@ class QsciScintillaCompat(QsciScintilla):
         except AttributeError:
             pass
     
-    def canPaste(self):
-        """
-        Public method to test, if the paste action is available (i.e. if the
-        clipboard contains some text).
-        
-        @return flag indicating the availability of 'paste'
-        @rtype bool
-        """
-        return self.SendScintilla(QsciScintilla.SCI_CANPASTE)
-    
     ###########################################################################
     ## methods to perform searches in target range
     ###########################################################################
@@ -852,37 +844,25 @@ class QsciScintillaCompat(QsciScintilla):
     
     def findFirstTarget(self, expr_, re_, cs_, wo_,
                         begline=-1, begindex=-1, endline=-1, endindex=-1,
-                        ws_=False, posix=False, cxx11=False):
+                        ws_=False):
         """
         Public method to search in a specified range of text without
         setting the selection.
         
-        @param expr_ search expression
-        @type str
-        @param re_ flag indicating a regular expression
-        @type bool
-        @param cs_ flag indicating a case sensitive search
-        @type bool
-        @param wo_ flag indicating a word only search
-        @type bool
-        @param begline line number to start from (-1 to indicate current
-            position)
-        @type int
-        @param begindex index to start from (-1 to indicate current position)
-        @type int
-        @param endline line number to stop at (-1 to indicate end of document)
-        @type int
-        @param endindex index number to stop at (-1 to indicate end of
-            document)
-        @type int
-        @param ws_ flag indicating a word start search (boolean)
-        @type bool
-        @param posix
-        @type bool
-        @param cxx11
-        @type bool
-        @return flag indicating a successful search
-        @rtype bool
+        @param expr_ search expression (string)
+        @param re_ flag indicating a regular expression (boolean)
+        @param cs_ flag indicating a case sensitive search (boolean)
+        @param wo_ flag indicating a word only search (boolean)
+        @keyparam begline line number to start from (-1 to indicate current
+            position) (integer)
+        @keyparam begindex index to start from (-1 to indicate current
+            position) (integer)
+        @keyparam endline line number to stop at (-1 to indicate end of
+            document) (integer)
+        @keyparam endindex index number to stop at (-1 to indicate end of
+            document) (integer)
+        @keyparam ws_ flag indicating a word start search (boolean)
+        @return flag indicating a successful search (boolean)
         """
         self.__targetSearchFlags = 0
         if re_:
@@ -893,14 +873,6 @@ class QsciScintillaCompat(QsciScintilla):
             self.__targetSearchFlags |= QsciScintilla.SCFIND_WHOLEWORD
         if ws_:
             self.__targetSearchFlags |= QsciScintilla.SCFIND_WORDSTART
-        if posix:
-            self.__targetSearchFlags |= QsciScintilla.SCFIND_POSIX
-        try:
-            if cxx11:
-                self.__targetSearchFlags |= QsciScintilla.SCFIND_CXX11REGEX
-        except AttributeError:
-            # defined for PyQt >= 2.11.0
-            pass
         
         if begline < 0 or begindex < 0:
             self.__targetSearchStart = self.SendScintilla(
@@ -1351,32 +1323,6 @@ class QsciScintillaCompat(QsciScintilla):
         self.SendScintilla(QsciScintilla.SCI_MARKERSETBACK,
                            QsciScintilla.SC_MARKNUM_FOLDEREND, backColor)
     
-    def getVisibleLineFromDocLine(self, docLine):
-        """
-        Public method to convert a document line number to a visible line
-        number (i.e. respect folded lines and annotations).
-        
-        @param docLine document line number to be converted
-        @type int
-        @return visible line number
-        @rtype int
-        """
-        return self.SendScintilla(QsciScintilla.SCI_VISIBLEFROMDOCLINE,
-                                  docLine)
-    
-    def getDocLineFromVisibleLine(self, displayLine):
-        """
-        Public method to convert a visible line number to a document line
-        number (i.e. respect folded lines and annotations).
-        
-        @param displayLine display line number to be converted
-        @type int
-        @return document line number
-        @rtype int
-        """
-        return self.SendScintilla(QsciScintilla.SCI_DOCLINEFROMVISIBLE,
-                                  displayLine)
-    
     ###########################################################################
     ## interface methods to the standard keyboard command set
     ###########################################################################
@@ -1428,7 +1374,7 @@ class QsciScintillaCompat(QsciScintilla):
         Public method to handle events.
         
         Note: We are not interested in the standard QsciScintilla event
-        handling because we do it ourselves.
+        handling because we do it our self.
         
         @param evt event object to handle (QEvent)
         @return result of the event handling (boolean)
@@ -1460,7 +1406,7 @@ class QsciScintillaCompat(QsciScintilla):
                 (Qt.InputMethodQuery)
             @return object containing the requested information
             """
-            return None     # __IGNORE_WARNING_M831__
+            return None
 
     ###########################################################################
     ## interface methods to the mini editor
@@ -1485,120 +1431,28 @@ class QsciScintillaCompat(QsciScintilla):
     ## replacements for buggy methods
     ###########################################################################
     
-    def showUserList(self, listId, lst):
-        """
-        Public method to show a user supplied list.
-        
-        @param listId id of the list (integer)
-        @param lst list to be show (list of strings)
-        """
-        if listId <= 0:
-            return
-        
-        # Setup seperator for user lists
-        self.SendScintilla(
-            QsciScintilla.SCI_AUTOCSETSEPARATOR, ord(self.UserSeparator))
-        self.SendScintilla(
-            QsciScintilla.SCI_USERLISTSHOW, listId,
-            self._encodeString(self.UserSeparator.join(lst)))
-        
-        self.updateUserListSize()
-    
-    def autoCompleteFromDocument(self):
-        """
-        Public method to resize list box after creation.
-        """
-        super(QsciScintillaCompat, self).autoCompleteFromDocument()
-        self.updateUserListSize()
-    
-    def autoCompleteFromAPIs(self):
-        """
-        Public method to resize list box after creation.
-        """
-        super(QsciScintillaCompat, self).autoCompleteFromAPIs()
-        self.updateUserListSize()
-    
-    def autoCompleteFromAll(self):
-        """
-        Public method to resize list box after creation.
-        """
-        super(QsciScintillaCompat, self).autoCompleteFromAll()
-        self.updateUserListSize()
+    if "showUserList" not in QsciScintilla.__dict__:
+        def showUserList(self, listId, lst):
+            """
+            Public method to show a user supplied list.
+            
+            @param listId id of the list (integer)
+            @param lst list to be show (list of strings)
+            """
+            if listId <= 0:
+                return
+            
+            self.SendScintilla(
+                QsciScintilla.SCI_AUTOCSETSEPARATOR,
+                ord(self.UserSeparator))
+            self.SendScintilla(
+                QsciScintilla.SCI_USERLISTSHOW, listId,
+                self._encodeString(self.UserSeparator.join(lst)))
     
     ###########################################################################
     ## work-arounds for buggy behavior
     ###########################################################################
     
-    def updateUserListSize(self):
-        """
-        Public method to resize the completion list to fit with contents.
-        """
-        children = self.findChildren(QListWidget)
-        if children:
-            userListWidget = children[-1]
-            geom = userListWidget.geometry()
-            
-            baseHeight = geom.height()
-            
-            # Workaround for getting all items instead of
-            # userListWidget.items() call with unknown mime types.
-            all_items = userListWidget.findItems('', Qt.MatchStartsWith)
-            if not all_items:
-                return
-            
-            width = 0
-            maxItemHeight = 0
-            for item in all_items:
-                visualRect = userListWidget.visualItemRect(item)
-                itemWidth = visualRect.width()
-                if itemWidth > width:
-                    width = itemWidth
-                itemHeight = visualRect.height()
-                if itemHeight > maxItemHeight:
-                    maxItemHeight = itemHeight
-            
-            height = min(self.maxLines, len(all_items)) * maxItemHeight
-            # Just a fiddling factor: 2 for better readability,
-            # e.g. underscores at the end of the list.
-            height += 2
-            
-            # Borders
-            borders = geom.size() - userListWidget.contentsRect().size()
-            width += borders.width()
-            height += borders.height()
-            
-            font = userListWidget.font()
-            fm = QFontMetrics(font)
-            averageCharWidth = fm.averageCharWidth()
-            maxWidth = averageCharWidth * self.maxChars
-            if width > maxWidth:
-                width = maxWidth
-                height += userListWidget.horizontalScrollBar().sizeHint()\
-                    .height()
-                # List box doesn't honor limited size to show scroll bars, e.g.
-                # Python 2 on Win 10. So just force it.
-                userListWidget.setHorizontalScrollBarPolicy(
-                    Qt.ScrollBarAlwaysOn)
-            
-            if len(all_items) > self.maxLines:
-                width += userListWidget.verticalScrollBar().sizeHint().width()
-            
-            # Special case, where the space below current line where to less
-            yPos = geom.y()
-            charPos = self.SendScintilla(QsciScintilla.SCI_GETCURRENTPOS)
-            currentYPos = self.SendScintilla(
-                QsciScintilla.SCI_POINTYFROMPOSITION, 0, charPos)
-            
-            # X position doesn't matter: set to 0
-            globalPos = self.mapToGlobal(QPoint(0, currentYPos))
-            if yPos < globalPos.y():
-                deltaHeight = baseHeight - height
-                geom.setY(yPos + deltaHeight - 4)
-            
-            geom.setWidth(width)
-            geom.setHeight(height)
-            userListWidget.setGeometry(geom)
-    
     def __completionListSelected(self, listId, txt):
         """
         Private slot to handle the selection from the completion list.
@@ -1641,21 +1495,6 @@ class QsciScintillaCompat(QsciScintilla):
             else:
                 return string.encode("latin-1")
     
-    ###########################################################################
-    ## methods to implement workarounds for broken things
-    ###########################################################################
-    
-    if QSCINTILLA_VERSION() == 0x020B00:
-        def insert(self, txt):
-            """
-            Public method to insert text at the cursor position.
-            
-            @param txt text to be inserted
-            @type str
-            """
-            line, col = self.getCursorPosition()
-            self.insertAt(txt, line, col)
-    
     ###########################################################################
     ## methods below have been added to QScintilla starting with version 2.5
     ###########################################################################
@@ -1672,7 +1511,7 @@ class QsciScintillaCompat(QsciScintilla):
             pos = self.SendScintilla(QsciScintilla.SCI_POSITIONFROMLINE, line)
             
             # Allow for multi-byte characters
-            for _ in range(index):
+            for i in range(index):
                 pos = self.positionAfter(pos)
             
             return pos
@@ -1756,71 +1595,8 @@ class QsciScintillaCompat(QsciScintilla):
             for line in folds:
                 self.foldLine(line)
     
-    #########################################################################
-    ## Method below implements a compatibility variant for the findFirst()
-    ## extended with version 2.11.
-    #########################################################################
-
-    def findFirst(self, expression, regexp, caseSensitive, word, wrap,
-                  forward=True, line=-1, index=-1, show=True, posix=False,
-                  cxx11=False):
-        """
-        Public method to search in the current editor text.
-        
-        @param expression search expression
-        @type str
-        @param regexp flag indicating a regular expression
-        @type bool
-        @param caseSensitive flag indicating a case sensitive search
-        @type bool
-        @param word flag indicating a word only search
-        @type bool
-        @param wrap flag indicating to warp around
-        @type bool
-        @param forward flag indicating the search direction
-        @type bool
-        @param line line to start the search on
-        @type int
-        @param index index to start the search on
-        @type int
-        @param show flag indicating to set the selection to the found
-            expression
-        @type bool
-        @param posix flag indicating the POSIX regular expression search mode
-        @type bool
-        @param cxx11 flag indicating the CXX11 regular expression search mode
-        @type bool
-        @return flag indicating a successful search
-        @rtype bool
-        """
-        if QSCINTILLA_VERSION() >= 0x020B00:
-            return super(QsciScintillaCompat, self).findFirst(
-                expression, regexp, caseSensitive, word, wrap,
-                forward=forward, line=line, index=index, show=show,
-                posix=posix, cxx11=cxx11)
-        else:
-            return super(QsciScintillaCompat, self).findFirst(
-                expression, regexp, caseSensitive, word, wrap,
-                forward=forward, line=line, index=index, show=show,
-                posix=posix)
-    
-    #########################################################################
-    ## Methods below are missing from QScintilla.
-    #########################################################################
-
-    if "setWrapStartIndent" not in QsciScintilla.__dict__:
-        def setWrapStartIndent(self, indent):
-            """
-            Public method to set a the amount of characters wrapped sublines
-            shall be indented.
-            
-            @param indent amount of characters to indent
-            @type int
-            """
-            self.SendScintilla(QsciScintilla.SCI_SETWRAPSTARTINDENT, indent)
-    
 ##    #########################################################################
-##    ## Methods below have been added to QScintilla starting with version 2.x.
+##    # methods below have been added to QScintilla starting with version 2.x
 ##    #########################################################################
 ##
 ##    if "newMethod" not in QsciScintilla.__dict__:
