@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -20,7 +20,7 @@ except ImportError:
 from PyQt5.QtCore import pyqtSignal, QFileInfo, Qt, QEvent
 from PyQt5.QtGui import QClipboard, QPalette, QFont
 from PyQt5.QtWidgets import QDialog, QInputDialog, QApplication, QMenu, \
-    QWidget, QHBoxLayout, QVBoxLayout, QShortcut, QSizePolicy
+    QWidget, QHBoxLayout, QVBoxLayout, QShortcut
 from PyQt5.Qsci import QsciScintilla
 
 from E5Gui.E5Application import e5App
@@ -41,29 +41,21 @@ class ShellAssembly(QWidget):
     """
     Class implementing the containing widget for the shell.
     """
-    def __init__(self, dbs, vm, project, horizontal=True, parent=None):
+    def __init__(self, dbs, vm, horizontal=True, parent=None):
         """
         Constructor
         
         @param dbs reference to the debug server object
-        @type DebugServer
         @param vm reference to the viewmanager object
-        @type ViewManager
-        @param project reference to the project object
-        @type Project
-        @param horizontal flag indicating a horizontal layout
-        @type bool
-        @param parent parent widget
-        @type QWidget
+        @param horizontal flag indicating a horizontal layout (boolean)
+        @param parent parent widget (QWidget)
         """
         super(ShellAssembly, self).__init__(parent)
         
-        self.__shell = Shell(dbs, vm, project, False, self)
+        self.__shell = Shell(dbs, vm, False, self)
         
         from UI.SearchWidget import SearchWidget
         self.__searchWidget = SearchWidget(self.__shell, self, horizontal)
-        self.__searchWidget.setSizePolicy(QSizePolicy.Fixed,
-                                          QSizePolicy.Preferred)
         self.__searchWidget.hide()
         
         if horizontal:
@@ -116,29 +108,19 @@ class Shell(QsciScintillaCompat):
         result
     @signal historyStyleChanged(ShellHistoryStyle) emitted to indicate a
         change of the history style
-    @signal queueText(str) emitted to queue some text for processing
-    @signal virtualEnvironmentChanged(str) emitted to signal the new virtual
-        environment of the shell
     """
     searchStringFound = pyqtSignal(bool)
     historyStyleChanged = pyqtSignal(ShellHistoryStyle)
-    queueText = pyqtSignal(str)
-    virtualEnvironmentChanged = pyqtSignal(str)
     
-    def __init__(self, dbs, vm, project, windowedVariant, parent=None):
+    def __init__(self, dbs, vm, windowedVariant, parent=None):
         """
         Constructor
         
         @param dbs reference to the debug server object
-        @type DebugServer
         @param vm reference to the viewmanager object
-        @type ViewManager
-        @param project reference to the project object
-        @type Project
         @param windowedVariant flag indicating the shell window variant
-        @type bool
-        @param parent parent widget
-        @type QWidget
+            (boolean)
+        @param parent parent widget (QWidget)
         """
         super(Shell, self).__init__(parent)
         self.setUtf8(True)
@@ -147,8 +129,6 @@ class Shell(QsciScintillaCompat):
         self.__mainWindow = parent
         self.__lastSearch = ()
         self.__windowed = windowedVariant
-        self.__currentVenv = ""
-        self.__currentWorkingDirectory = ""
         
         self.linesepRegExp = r"\r\n|\n|\r"
         
@@ -169,18 +149,14 @@ class Shell(QsciScintillaCompat):
                 """ cursor keys on the Shell page of the configuration"""
                 """ dialog. Pressing these keys after some text has been"""
                 """ entered will start an incremental search.</p>"""
-                """<p>The shell has some special commands. 'restart' kills"""
-                """ the shell and starts a new one. 'clear' clears the"""
-                """ display of the shell window. 'start' is used to start a"""
-                """ shell for a virtual environment and should be followed"""
-                """ by a virtual environment name. start' without a virtual"""
-                """ environment name starts the default shell. Available"""
-                """ virtual environments may be listed with the 'envs' or"""
-                """ 'environments' commands. The active virtual environment"""
-                """ can be questioned by the 'which' command. 'quit' or"""
-                """ 'exit' is used to exit the application. These commands"""
-                """ (except environments', 'envs' and 'which') are available"""
-                """ through the window menus as well.</p>"""
+                """<p>The shell has some special commands. 'reset' kills the"""
+                """ shell and starts a new one. 'clear' clears the display"""
+                """ of the shell window. 'start' is used to switch the shell"""
+                """ language and must be followed by a supported language."""
+                """ Supported languages are listed by the 'languages'"""
+                """ command. 'quit' is used to exit the application.These"""
+                """ commands (except 'languages') are available through the"""
+                """ window menus as well.</p>"""
                 """<p>Pressing the Tab key after some text has been entered"""
                 """ will show a list of possible completions. The relevant"""
                 """ entry may be selected from this list. If only one entry"""
@@ -200,17 +176,13 @@ class Shell(QsciScintillaCompat):
                 """ cursor keys on the Shell page of the configuration"""
                 """ dialog. Pressing these keys after some text has been"""
                 """ entered will start an incremental search.</p>"""
-                """<p>The shell has some special commands. 'restart' kills"""
-                """ the shell and starts a new one. 'clear' clears the"""
-                """ display of the shell window. 'start' is used to start a"""
-                """ shell for a virtual environment and should be followed"""
-                """ by a virtual environment name. start' without a virtual"""
-                """ environment name starts the default shell. Available"""
-                """ virtual environments may be listed with the 'envs' or"""
-                """ 'environments' commands. The active virtual environment"""
-                """ can be questioned by the 'which' command. These commands"""
-                """ (except environments' and 'envs') are available through"""
-                """ the context menu as well.</p>"""
+                """<p>The shell has some special commands. 'reset' kills the"""
+                """ shell and starts a new one. 'clear' clears the display"""
+                """ of the shell window. 'start' is used to switch the shell"""
+                """ language and must be followed by a supported language."""
+                """ Supported languages are listed by the 'languages'"""
+                """ command. These commands (except 'languages') are"""
+                """ available through the context menu as well.</p>"""
                 """<p>Pressing the Tab key after some text has been entered"""
                 """ will show a list of possible completions. The relevant"""
                 """ entry may be selected from this list. If only one entry"""
@@ -232,7 +204,7 @@ class Shell(QsciScintillaCompat):
         if self.__showStdOutErr:
             dbs.clientProcessStdout.connect(self.__writeStdOut)
             dbs.clientProcessStderr.connect(self.__writeStdErr)
-        dbs.clientOutput.connect(self.__writeQueued)
+        dbs.clientOutput.connect(self.__write)
         dbs.clientStatement.connect(self.__clientStatement)
         dbs.clientGone.connect(self.__initialise)
         dbs.clientRawInput.connect(self.__raw_input)
@@ -290,7 +262,7 @@ class Shell(QsciScintillaCompat):
         if not self.__windowed:
             # Create a little language context menu
             self.lmenu = QMenu(self.tr('Start'))
-            self.lmenu.aboutToShow.connect(self.__showStartMenu)
+            self.lmenu.aboutToShow.connect(self.__showLanguageMenu)
             self.lmenu.triggered.connect(self.__startDebugClient)
             
             # Create the history context menu
@@ -310,12 +282,11 @@ class Shell(QsciScintillaCompat):
             self.menu.addAction(self.tr('Find'), self.__find)
             self.menu.addSeparator()
             self.menu.addAction(self.tr('Clear'), self.clear)
-            self.menu.addAction(self.tr('Restart'), self.doRestart)
+            self.menu.addAction(self.tr('Reset'), self.__reset)
             self.menu.addAction(
-                self.tr('Restart and Clear'), self.doClearRestart)
+                self.tr('Reset and Clear'), self.__resetAndClear)
             self.menu.addSeparator()
             self.menu.addMenu(self.lmenu)
-            self.menu.addAction(self.tr('Active Name'), self.__showVenvName)
             self.menu.addSeparator()
             self.menu.addAction(self.tr("Configure..."), self.__configure)
         
@@ -351,13 +322,9 @@ class Shell(QsciScintillaCompat):
             QsciScintilla.SCI_VCHOME: self.__QScintillaVCHome,
             QsciScintilla.SCI_LINEEND: self.__QScintillaLineEnd,
             
-            QsciScintilla.SCI_LINEUP: self.__QScintillaCursorCommand,
-            QsciScintilla.SCI_LINEDOWN: self.__QScintillaCursorCommand,
-            QsciScintilla.SCI_LINESCROLLUP: self.__QScintillaCursorCommand,
-            QsciScintilla.SCI_LINESCROLLDOWN: self.__QScintillaCursorCommand,
-            
             QsciScintilla.SCI_PAGEUP: self.__QScintillaAutoCompletionCommand,
             QsciScintilla.SCI_PAGEDOWN: self.__QScintillaAutoCompletionCommand,
+            QsciScintilla.SCI_CANCEL: self.__QScintillaAutoCompletionCommand,
             
             QsciScintilla.SCI_CHARLEFTEXTEND: self.__QScintillaCharLeftExtend,
             QsciScintilla.SCI_CHARRIGHTEXTEND: self.extendSelectionRight,
@@ -368,32 +335,38 @@ class Shell(QsciScintillaCompat):
             
             QsciScintilla.SCI_CANCEL: self.__QScintillaCancel,
         }
-        
-        self.__historyNavigateByCursor = \
-            Preferences.getShell("HistoryNavigateByCursor")
-        
-        self.__queuedText = ''
-        self.__blockTextProcessing = False
-        self.queueText.connect(self.__concatenateText, Qt.QueuedConnection)
-        
-        self.__project = project
-        if self.__project:
-            self.__project.projectOpened.connect(self.__projectOpened)
-            self.__project.projectClosed.connect(self.__projectClosed)
+        self.__setupCursorKeys()
         
         self.grabGesture(Qt.PinchGesture)
     
-    def __showStartMenu(self):
+    def __setupCursorKeys(self):
         """
-        Private slot to prepare the start submenu.
+        Private method to setup the cursor up and down mode.
+        """
+        if Preferences.getShell("HistoryNavigateByCursor"):
+            self.supportedEditorCommands.update({
+                QsciScintilla.SCI_LINEUP: self.__QScintillaHistoryUp,
+                QsciScintilla.SCI_LINEDOWN: self.__QScintillaHistoryDown,
+                QsciScintilla.SCI_LINESCROLLUP: self.__QScintillaLineUp,
+                QsciScintilla.SCI_LINESCROLLDOWN: self.__QScintillaLineDown,
+            })
+        else:
+            self.supportedEditorCommands.update({
+                QsciScintilla.SCI_LINEUP: self.__QScintillaLineUp,
+                QsciScintilla.SCI_LINEDOWN: self.__QScintillaLineDown,
+                QsciScintilla.SCI_LINESCROLLUP: self.__QScintillaHistoryUp,
+                QsciScintilla.SCI_LINESCROLLDOWN: self.__QScintillaHistoryDown,
+            })
+    
+    def __showLanguageMenu(self):
+        """
+        Private slot to prepare the language submenu.
         """
         self.lmenu.clear()
-        venvManager = e5App().getObject("VirtualEnvManager")
-        for venvName in sorted(venvManager.getVirtualenvNames()):
-            self.lmenu.addAction(venvName)
-        if self.__project.isOpen():
-            self.lmenu.addSeparator()
-            self.lmenu.addAction(self.tr("Project"))
+        clientLanguages = self.dbs.getSupportedLanguages(shellOnly=True)
+        for language in sorted(clientLanguages):
+            act = self.lmenu.addAction(language)
+            act.setData(language)
         
     def __resizeLinenoMargin(self):
         """
@@ -437,8 +410,6 @@ class Shell(QsciScintillaCompat):
             self.lexer_.setDefaultFont(font)
         self.setLexer(self.lexer_)
         self.lexer_.readSettings(Preferences.Prefs.settings, "Scintilla")
-        if self.lexer_.hasSubstyles():
-            self.lexer_.readSubstyles(self)
         
         # initialize the lexer APIs settings
         api = self.vm.getAPIsManager().getAPIs(self.language)
@@ -568,9 +539,6 @@ class Shell(QsciScintillaCompat):
         
         self.racEnabled = Preferences.getShell("AutoCompletionEnabled")
         
-        self.maxLines = Preferences.getEditor("AutoCompletionMaxLines")
-        self.maxChars = Preferences.getEditor("AutoCompletionMaxChars")
-        
     def __setCallTips(self, language='Python'):
         """
         Private method to configure the calltips function.
@@ -613,19 +581,14 @@ class Shell(QsciScintillaCompat):
         self.inCommandExecution = False
         self.interruptCommandExecution = False
         
-    def __clientCapabilities(self, cap, clType, venvName):
+    def __clientCapabilities(self, cap, clType):
         """
         Private slot to handle the reporting of the clients capabilities.
         
-        @param cap client capabilities
-        @type int
-        @param clType type of the debug client
-        @type str
-        @param venvName name of the virtual environment
-        @type str
+        @param cap client capabilities (integer)
+        @param clType type of the debug client (string)
         """
         self.clientCapabilities = cap
-        self.__currentVenv = venvName
         if clType != self.clientType:
             self.clientType = clType
             self.__bindLexer(self.clientType)
@@ -642,9 +605,6 @@ class Shell(QsciScintillaCompat):
                 self.loadHistory(self.clientType)
             self.__history = self.__historyLists[self.clientType]
             self.__setHistoryIndex()
-        
-        self.virtualEnvironmentChanged.emit(venvName)
-        Preferences.setShell("LastVirtualEnvironment", venvName)
     
     def __setHistoryIndex(self, index=None):
         """
@@ -805,29 +765,23 @@ class Shell(QsciScintillaCompat):
         debug client side.
         """
         if self.passive:
-            self.__writeBanner('', '', '', '')
+            self.__writeBanner('', '', '')
         else:
             self.dbs.remoteBanner()
         
-    def __writeBanner(self, version, platform, dbgclient, venvName):
+    def __writeBanner(self, version, platform, dbgclient):
         """
         Private method to write a banner with info from the debug client.
         
-        @param version interpreter version string
-        @type str
-        @param platform platform of the remote interpreter
-        @type str
-        @param dbgclient debug client variant used
-        @type str
-        @param venvName name of the virtual environment
-        @type str
+        @param version interpreter version string (string)
+        @param platform platform of the remote interpreter (string)
+        @param dbgclient debug client variant used (string)
         """
         super(Shell, self).clear()
         if self.passive and not self.dbs.isConnected():
             self.__write(self.tr('Passive Debug Mode'))
             self.__write(self.tr('\nNot connected'))
         else:
-            self.__currentVenv = venvName
             version = version.replace("#", self.tr("No."))
             if platform != "" and dbgclient != "":
                 self.__write(
@@ -835,21 +789,19 @@ class Shell(QsciScintillaCompat):
                         .format(version, platform, dbgclient))
             else:
                 self.__write(version)
-            if venvName:
-                self.__write("\n[{0}]".format(venvName))
-            
-            self.virtualEnvironmentChanged.emit(venvName)
-            Preferences.setShell("LastVirtualEnvironment", venvName)
         self.__write('\n')
         
         self.__write(sys.ps1)
         
     def __writePrompt(self):
         """
-        Private method to write the prompt using a write queue.
+        Private method to write the prompt.
         """
-        self.queueText.emit(self.inContinue and sys.ps2 or sys.ps1)
-    
+        self.__write(self.inContinue and sys.ps2 or sys.ps1)
+        # little trick to get the cursor position registered within QScintilla
+        self.SendScintilla(QsciScintilla.SCI_CHARLEFT)
+        self.SendScintilla(QsciScintilla.SCI_CHARRIGHT)
+        
     def __clientStatement(self, more):
         """
         Private method to handle the response from the debugger client.
@@ -860,7 +812,7 @@ class Shell(QsciScintillaCompat):
             self.inContinue = more
             self.__writePrompt()
         self.inCommandExecution = False
-    
+        
     def __clientException(self, exceptionType, exceptionMessage, stackTrace):
         """
         Private method to handle an exception of the client.
@@ -956,45 +908,11 @@ class Shell(QsciScintillaCompat):
         line = self.lines() - 1
         return (line, len(self.text(line)))
         
-    def __writeQueued(self, s):
-        """
-        Private method to display some text using a write queue.
-        
-        @param s text to be displayed (string)
-        """
-        self.queueText.emit(s)
-
-    def __concatenateText(self, text):
-        """
-        Private slot to queue text and process it in one step.
-        
-        @param text text to be appended
-        @type str
-        """
-        self.__queuedText += text
-        if self.__blockTextProcessing:
-            return
-        
-        self.__blockTextProcessing = True
-        # Get all text which is still waiting for output
-        QApplication.processEvents()
-        
-        # Finally process the accumulated text
-        self.__write(self.__queuedText)
-        
-        self.__queuedText = ''
-        self.__blockTextProcessing = False
-        
-        # little trick to get the cursor position registered within QScintilla
-        self.SendScintilla(QsciScintilla.SCI_CHARLEFT)
-        self.SendScintilla(QsciScintilla.SCI_CHARRIGHT)
-
     def __write(self, s):
         """
-        Private method to display some text without queuing.
+        Private method to display some text.
         
-        @param s text to be displayed
-        @type str
+        @param s text to be displayed (string)
         """
         line, col = self.__getEndPos()
         self.setCursorPosition(line, col)
@@ -1026,9 +944,6 @@ class Shell(QsciScintillaCompat):
         @param s prompt to be displayed (string)
         @param echo Flag indicating echoing of the input (boolean)
         """
-        # Get all text which is still waiting for output
-        QApplication.processEvents()
-        
         self.setFocus()
         self.inRawMode = True
         self.echoInput = echo
@@ -1051,35 +966,20 @@ class Shell(QsciScintillaCompat):
         if self.__isCursorOnLastLine():
             line, col = self.getCursorPosition()
             lastLine = self.text(line)
-            if lastLine.startswith(sys.ps1):
-                lastLine = lastLine[len(sys.ps1):]
-                col -= len(sys.ps1)
-                prompt = sys.ps1
-            elif lastLine.startswith(sys.ps2):
-                lastLine = lastLine[len(sys.ps2):]
-                col -= len(sys.ps2)
-                prompt = sys.ps2
-            else:
-                prompt = ""
-            if col < 0:
-                col = 0
-                prompt = ""
             
             # Remove if text is selected
             if self.hasSelectedText():
                 lineFrom, indexFrom, lineTo, indexTo = self.getSelection()
                 if self.text(lineFrom).startswith(sys.ps1):
-                    indexFrom -= len(sys.ps1)
-                    indexTo -= len(sys.ps1)
+                    if indexFrom < len(sys.ps1):
+                        indexFrom = len(sys.ps1)
                 elif self.text(lineFrom).startswith(sys.ps2):
-                    indexFrom -= len(sys.ps2)
-                    indexTo -= len(sys.ps2)
-                if indexFrom < 0:
-                    indexFrom = 0
+                    if indexFrom < len(sys.ps2):
+                        indexFrom = len(sys.ps2)
                 lastLine = lastLine[:indexFrom] + lastLine[indexTo:]
                 col = indexFrom
 
-            self.setCursorPosition(line, len(prompt))
+            self.setCursorPosition(line, 0)
             self.deleteLineRight()
             
             lines = QApplication.clipboard().text()
@@ -1106,19 +1006,7 @@ class Shell(QsciScintillaCompat):
         @param historyIndex history index to be set
         @type int
         """
-        lines = lines.splitlines(True)
-        if not lines:
-            return
-        
-        indentLen = self.__indentLength(lines[0])
-        for line in lines:
-            if line.startswith(sys.ps1):
-                line = line[len(sys.ps1) + indentLen:]
-            elif line.startswith(sys.ps2):
-                line = line[len(sys.ps2) + indentLen:]
-            else:
-                line = line[indentLen:]
-            
+        for line in lines.splitlines(True):
             if line.endswith("\r\n"):
                 fullline = True
                 cmd = line[:-2]
@@ -1132,27 +1020,16 @@ class Shell(QsciScintillaCompat):
             self.__insertTextAtEnd(line)
             if fullline:
                 self.incrementalSearchActive = False
+                if cmd.startswith(sys.ps1):
+                    cmd = cmd[len(sys.ps1):]
+                elif cmd.startswith(sys.ps2):
+                    cmd = cmd[len(sys.ps2):]
                 
                 self.__executeCommand(cmd, historyIndex=historyIndex)
                 if self.interruptCommandExecution:
                     self.__executeCommand("")
                     break
-    
-    def __indentLength(self, line):
-        """
-        Private method to determine the indentation length of the given line.
         
-        @param line line to determine the indentation length for
-        @type str
-        @return indentation length
-        @rtype int
-        """
-        if line.startswith(sys.ps1):
-            line = line[len(sys.ps1):]
-        # If line starts with sys.ps2 or neither don't manipulate the line.
-        indentLen = len(line) - len(line.lstrip())
-        return indentLen
-    
     def __clearCurrentLine(self):
         """
         Private method to clear the line containing the cursor.
@@ -1223,7 +1100,7 @@ class Shell(QsciScintillaCompat):
                 delta = evt.delta()
             if delta < 0:
                 self.zoomOut()
-            elif delta > 0:
+            else:
                 self.zoomIn()
             evt.accept()
             return
@@ -1554,35 +1431,6 @@ class Shell(QsciScintillaCompat):
         elif self.__isCursorOnLastLine():
             self.moveCursorToEOL()
     
-    def __QScintillaCursorCommand(self, cmd):
-        """
-        Private method to handle the cursor commands.
-        
-        @param cmd QScintilla command
-        """
-        if self.isListActive() or self.isCallTipActive():
-            if cmd in (QsciScintilla.SCI_LINEUP, QsciScintilla.SCI_LINEDOWN):
-                self.SendScintilla(cmd)
-        else:
-            if self.__historyNavigateByCursor:
-                if cmd == QsciScintilla.SCI_LINEUP:
-                    self.__QScintillaHistoryUp(cmd)
-                elif cmd == QsciScintilla.SCI_LINEDOWN:
-                    self.__QScintillaHistoryDown(cmd)
-                elif cmd == QsciScintilla.SCI_LINESCROLLUP:
-                    self.__QScintillaLineUp(cmd)
-                elif cmd == QsciScintilla.SCI_LINESCROLLDOWN:
-                    self.__QScintillaLineDown(cmd)
-            else:
-                if cmd == QsciScintilla.SCI_LINEUP:
-                    self.__QScintillaLineUp(cmd)
-                elif cmd == QsciScintilla.SCI_LINEDOWN:
-                    self.__QScintillaLineDown(cmd)
-                elif cmd == QsciScintilla.SCI_LINESCROLLUP:
-                    self.__QScintillaHistoryUp(cmd)
-                elif cmd == QsciScintilla.SCI_LINESCROLLDOWN:
-                    self.__QScintillaHistoryDown(cmd)
-    
     def __QScintillaLineUp(self, cmd):
         """
         Private method to handle the cursor up command.
@@ -1686,12 +1534,9 @@ class Shell(QsciScintillaCompat):
         """
         Private method to handle the ESC command.
         """
-        if self.isListActive() or self.isCallTipActive():
-            self.SendScintilla(QsciScintilla.SCI_CANCEL)
-        else:
-            if self.incrementalSearchActive:
-                self.__resetIncrementalHistorySearch()
-            self.__insertHistory("")
+        if self.incrementalSearchActive:
+            self.__resetIncrementalHistorySearch()
+        self.__insertHistory("")
     
     def __QScintillaCharLeftExtend(self):
         """
@@ -1758,36 +1603,41 @@ class Shell(QsciScintillaCompat):
                     self.__setHistoryIndex(index=-1)
                 elif self.__historyStyle == ShellHistoryStyle.WindowsStyle:
                     if historyIndex is None:
-                        if self.__histidx - 1 > 0 and \
-                           cmd != self.__history[self.__histidx - 1]:
+                        if cmd != self.__history[self.__histidx - 1]:
                             self.__setHistoryIndex(index=-1)
                     else:
                         self.__setHistoryIndex(historyIndex)
             
-            if cmd == 'start' or cmd.startswith('start '):
+            if cmd.startswith('start '):
                 if not self.passive:
                     cmdList = cmd.split(None, 1)
                     if len(cmdList) < 2:
-                        self.dbs.startClient(False)  # start default backend
+                        self.dbs.startClient(False)  # same as reset
                     else:
-                        venvName = cmdList[1]
-                        if venvName == self.tr("Project"):
-                            if self.__project.isOpen():
-                                self.dbs.startClient(
-                                    False, forProject=True,
-                                    workingDir=self.__project.getProjectPath())
-                                self.__currentWorkingDirectory = \
-                                    self.__project.getProjectPath()
-                            else:
-                                self.dbs.startClient(
-                                    False, venvName=self.__currentVenv,
-                                    workingDir=self.__currentWorkingDirectory)
-                                # same as reset
+                        clientLanguages = self.dbs.getSupportedLanguages(
+                            shellOnly=True)
+                        language = cmdList[1]
+                        if language not in clientLanguages:
+                            language = cmdList[1].capitalize()
+                            if language not in clientLanguages:
+                                language = ""
+                        if language:
+                            self.dbs.startClient(False, language)
                         else:
-                            self.dbs.startClient(False, venvName=venvName)
-                            self.__currentWorkingDirectory = ""
-                    self.__getBanner()
-                    return
+                            # language not supported or typo
+                            self.__write(
+                                self.tr(
+                                    'Shell language "{0}" not supported.\n')
+                                .format(cmdList[1]))
+                            self.__clientStatement(False)
+                        return
+                    cmd = ''
+            elif cmd == 'languages':
+                s = '{0}\n'.format(', '.join(sorted(
+                    self.dbs.getSupportedLanguages(shellOnly=True))))
+                self.__write(s)
+                self.__clientStatement(False)
+                return
             elif cmd == 'clear':
                 # Display the banner.
                 self.__getBanner()
@@ -1795,30 +1645,13 @@ class Shell(QsciScintillaCompat):
                     return
                 else:
                     cmd = ''
-            elif cmd in ['reset', 'restart']:
-                self.dbs.startClient(False, venvName=self.__currentVenv,
-                                     workingDir=self.__currentWorkingDirectory)
+            elif cmd == 'reset':
+                self.dbs.startClient(False)
                 if self.passive:
                     return
                 else:
                     cmd = ''
-            elif cmd in ['envs', 'environments']:
-                venvs = e5App().getObject("VirtualEnvManager")\
-                    .getVirtualenvNames()
-                s = self.tr('Available Virtual Environments:\n{0}\n').format(
-                    '\n'.join("- {0}".format(venv) for venv in sorted(venvs))
-                )
-                self.__write(s)
-                self.__clientStatement(False)
-                return
-            elif cmd == 'which':
-                s = self.tr("Current Virtual Environment: '{0}'\n").format(
-                    self.__currentVenv)
-                self.__write(s)
-                self.__clientStatement(False)
-                return
-            elif cmd in ["quit", "quit()", "exit", "exit()"] and \
-                    self.__windowed:
+            elif cmd in ["quit", "quit()"] and self.__windowed:
                 # call main window quit()
                 self.vm.quit()
                 return
@@ -1840,15 +1673,6 @@ class Shell(QsciScintillaCompat):
             
             self.dbs.remoteRawInput(cmd)
     
-    def __showVenvName(self):
-        """
-        Private method to show the name of the active virtual environment.
-        """
-        s = "\n" + self.tr("Current Virtual Environment: '{0}'\n").format(
-            self.__currentVenv)
-        self.__write(s)
-        self.__clientStatement(False)
-    
     def __useHistory(self):
         """
         Private method to display a command from the history.
@@ -1957,19 +1781,18 @@ class Shell(QsciScintillaCompat):
         # Display the banner.
         self.__getBanner()
         
-    def doClearRestart(self):
+    def __resetAndClear(self):
         """
-        Public slot to handle the 'restart and clear' context menu entry.
+        Private slot to handle the 'reset and clear' context menu entry.
         """
-        self.doRestart()
+        self.__reset()
         self.clear()
         
-    def doRestart(self):
+    def __reset(self):
         """
-        Public slot to handle the 'restart' context menu entry.
+        Private slot to handle the 'reset' context menu entry.
         """
-        self.dbs.startClient(False, venvName=self.__currentVenv,
-                             workingDir=self.__currentWorkingDirectory)
+        self.dbs.startClient(False)
         
     def __startDebugClient(self, action):
         """
@@ -1978,16 +1801,8 @@ class Shell(QsciScintillaCompat):
         
         @param action context menu action that was triggered (QAction)
         """
-        venvName = action.text()
-        if venvName == self.tr("Project"):
-            if self.__project.isOpen():
-                self.__currentWorkingDirectory = \
-                    self.__project.getProjectPath()
-            self.dbs.startClient(False, forProject=True,
-                                 workingDir=self.__currentWorkingDirectory)
-        else:
-            self.dbs.startClient(False, venvName=venvName)
-        self.__getBanner()
+        language = action.data()
+        self.dbs.startClient(False, language)
         
     def handlePreferencesChanged(self):
         """
@@ -2015,8 +1830,7 @@ class Shell(QsciScintillaCompat):
         self.__setHistoryIndex()
         if not self.__windowed:
             self.hmenu.menuAction().setEnabled(self.isHistoryEnabled())
-        self.__historyNavigateByCursor = \
-            Preferences.getShell("HistoryNavigateByCursor")
+        self.__setupCursorKeys()
         self.historyStyleChanged.emit(self.__historyStyle)
         
         # do stdout /stderr stuff
@@ -2144,16 +1958,15 @@ class Shell(QsciScintillaCompat):
             self.addActions(self.vm.editorActGrp.actions())
             self.addActions(self.vm.copyActGrp.actions())
             self.addActions(self.vm.viewActGrp.actions())
-            if not self.__windowed:
-                self.__searchShortcut = QShortcut(
-                    self.vm.searchAct.shortcut(), self,
-                    self.__find, self.__find)
-                self.__searchNextShortcut = QShortcut(
-                    self.vm.searchNextAct.shortcut(), self,
-                    self.__searchNext, self.__searchNext)
-                self.__searchPrevShortcut = QShortcut(
-                    self.vm.searchPrevAct.shortcut(), self,
-                    self.__searchPrev, self.__searchPrev)
+            self.__searchShortcut = QShortcut(
+                self.vm.searchAct.shortcut(), self,
+                self.__find, self.__find)
+            self.__searchNextShortcut = QShortcut(
+                self.vm.searchNextAct.shortcut(), self,
+                self.__searchNext, self.__searchNext)
+            self.__searchPrevShortcut = QShortcut(
+                self.vm.searchPrevAct.shortcut(), self,
+                self.__searchPrev, self.__searchPrev)
         
         try:
             self.vm.editActGrp.setEnabled(False)
@@ -2163,10 +1976,9 @@ class Shell(QsciScintillaCompat):
             self.vm.searchActGrp.setEnabled(False)
         except AttributeError:
             pass
-        if not self.__windowed:
-            self.__searchShortcut.setEnabled(True)
-            self.__searchNextShortcut.setEnabled(True)
-            self.__searchPrevShortcut.setEnabled(True)
+        self.__searchShortcut.setEnabled(True)
+        self.__searchNextShortcut.setEnabled(True)
+        self.__searchPrevShortcut.setEnabled(True)
         self.setCaretWidth(self.caretWidth)
         self.setCursorFlashTime(QApplication.cursorFlashTime())
         
@@ -2182,10 +1994,9 @@ class Shell(QsciScintillaCompat):
             self.vm.editorActGrp.setEnabled(False)
         except AttributeError:
             pass
-        if not self.__windowed:
-            self.__searchShortcut.setEnabled(False)
-            self.__searchNextShortcut.setEnabled(False)
-            self.__searchPrevShortcut.setEnabled(False)
+        self.__searchShortcut.setEnabled(False)
+        self.__searchNextShortcut.setEnabled(False)
+        self.__searchPrevShortcut.setEnabled(False)
         self.setCaretWidth(0)
         super(Shell, self).focusOutEvent(event)
         
@@ -2225,27 +2036,19 @@ class Shell(QsciScintillaCompat):
         if self.__lastSearch:
             self.searchNext(*self.__lastSearch)
     
-    def searchNext(self, txt, caseSensitive, wholeWord, regexp):
+    def searchNext(self, txt, caseSensitive, wholeWord):
         """
         Public method to search the next occurrence of the given text.
         
-        @param txt text to search for
-        @type str
+        @param txt text to search for (string)
         @param caseSensitive flag indicating to perform a case sensitive
-            search
-        @type bool
+            search (boolean)
         @param wholeWord flag indicating to search for whole words
-            only
-        @type bool
-        @param regexp flag indicating a regular expression search
-        @type bool
+            only (boolean)
         """
-        self.__lastSearch = (txt, caseSensitive, wholeWord, regexp)
-        posixMode = Preferences.getEditor("SearchRegexpMode") == 0 and regexp
-        cxx11Mode = Preferences.getEditor("SearchRegexpMode") == 1 and regexp
+        self.__lastSearch = (txt, caseSensitive, wholeWord)
         ok = self.findFirst(
-            txt, regexp, caseSensitive, wholeWord, True, forward=True,
-            posix=posixMode, cxx11=cxx11Mode)
+            txt, False, caseSensitive, wholeWord, False, forward=True)
         self.searchStringFound.emit(ok)
     
     def __searchPrev(self):
@@ -2255,32 +2058,24 @@ class Shell(QsciScintillaCompat):
         if self.__lastSearch:
             self.searchPrev(*self.__lastSearch)
     
-    def searchPrev(self, txt, caseSensitive, wholeWord, regexp):
+    def searchPrev(self, txt, caseSensitive, wholeWord):
         """
         Public method to search the previous occurrence of the given text.
         
-        @param txt text to search for
-        @type str
+        @param txt text to search for (string)
         @param caseSensitive flag indicating to perform a case sensitive
-            search
-        @type bool
+            search (boolean)
         @param wholeWord flag indicating to search for whole words
-            only
-        @type bool
-        @param regexp flag indicating a regular expression search
-        @type bool
+            only (boolean)
         """
-        self.__lastSearch = (txt, caseSensitive, wholeWord, regexp)
+        self.__lastSearch = (txt, caseSensitive, wholeWord)
         if self.hasSelectedText():
             line, index = self.getSelection()[:2]
         else:
             line, index = -1, -1
-        posixMode = Preferences.getEditor("SearchRegexpMode") == 0 and regexp
-        cxx11Mode = Preferences.getEditor("SearchRegexpMode") == 1 and regexp
         ok = self.findFirst(
-            txt, regexp, caseSensitive, wholeWord, True,
-            forward=False, line=line, index=index, posix=posixMode,
-            cxx11=cxx11Mode)
+            txt, False, caseSensitive, wholeWord, False,
+            forward=False, line=line, index=index)
         self.searchStringFound.emit(ok)
     
     def historyStyle(self):
@@ -2300,25 +2095,3 @@ class Shell(QsciScintillaCompat):
         @rtype bool
         """
         return self.__historyStyle != ShellHistoryStyle.Disabled
-    
-    #################################################################
-    ## Project Support
-    #################################################################
-    
-    def __projectOpened(self):
-        """
-        Private slot to start the shell for the opened project.
-        """
-        if Preferences.getProject("RestartShellForProject"):
-            self.dbs.startClient(False, forProject=True,
-                                 workingDir=self.__project.getProjectPath())
-            self.__currentWorkingDirectory = self.__project.getProjectPath()
-            self.__getBanner()
-    
-    def __projectClosed(self):
-        """
-        Private slot to restart the default shell when the project is closed.
-        """
-        if Preferences.getProject("RestartShellForProject"):
-            self.dbs.startClient(False)
-            self.__getBanner()
