@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,13 +9,15 @@ Module implementing a grabber widget for a freehand snapshot region.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSignal, Qt, QRect, QPoint, QTimer, qVersion
+from PyQt5.QtCore import pyqtSignal, Qt, QRect, QPoint, QTimer, QLocale
 from PyQt5.QtGui import QPixmap, QColor, QRegion, QPainter, QPalette, \
     QPolygon, QPen, QBrush, QPaintEngine
 from PyQt5.QtWidgets import QWidget, QApplication, QToolTip
 
+from Globals import qVersionTuple
 
-def drawPolygon(painter, polygon, outline, fill=QColor()):
+
+def drawPolygon(painter, polygon, outline, fill=None):
     """
     Module function to draw a polygon with the given parameters.
     
@@ -34,7 +36,7 @@ def drawPolygon(painter, polygon, outline, fill=QColor()):
     painter.drawPolygon(QPolygon(polygon))
     if fill.isValid():
         painter.setClipping(False)
-        painter.setBrush(fill)
+        painter.setBrush(fill or QColor())
         painter.drawPolygon(QPolygon(polygon))
     painter.restore()
 
@@ -64,6 +66,7 @@ class SnapshotFreehandGrabber(QWidget):
         self.__grabbing = False
         self.__dragStartPoint = QPoint()
         self.__selectionBeforeDrag = QPolygon()
+        self.__locale = QLocale()
         
         self.__helpTextRect = QRect()
         self.__helpText = self.tr(
@@ -84,7 +87,7 @@ class SnapshotFreehandGrabber(QWidget):
         self.__desktop = QApplication.desktop()
         x = self.__desktop.x()
         y = self.__desktop.y()
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             self.__pixmap = QApplication.screens()[0].grabWindow(
                 self.__desktop.winId(), x, y,
                 self.__desktop.width(), self.__desktop.height())
@@ -99,6 +102,7 @@ class SnapshotFreehandGrabber(QWidget):
 
         self.grabMouse()
         self.grabKeyboard()
+        self.activateWindow()
     
     def paintEvent(self, evt):
         """
@@ -162,9 +166,12 @@ class SnapshotFreehandGrabber(QWidget):
         # rectangles (border included). This means that there is no 0px
         # selection, since a 0px wide rectangle will always be drawn as a line.
         boundingRect = self.__selection.boundingRect()
-        txt = "{0:n}, {1:n} ({2:n} x {3:n})".format(
-            boundingRect.x(), boundingRect.y(),
-            boundingRect.width(), boundingRect.height())
+        txt = "{0}, {1} ({2} x {3})".format(
+            self.__locale.toString(boundingRect.x()),
+            self.__locale.toString(boundingRect.y()),
+            self.__locale.toString(boundingRect.width()),
+            self.__locale.toString(boundingRect.height())
+        )
         textRect = painter.boundingRect(self.rect(), Qt.AlignLeft, txt)
         boundingRect = textRect.adjusted(-4, 0, 0, 0)
         
