@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,13 +9,15 @@ Module implementing a grabber widget for a rectangular snapshot region.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSignal, Qt, QRect, QPoint, QTimer, qVersion
+from PyQt5.QtCore import pyqtSignal, Qt, QRect, QPoint, QTimer, QLocale
 from PyQt5.QtGui import QPixmap, QColor, QRegion, QPainter, QPalette, \
     QPaintEngine, QPen, QBrush
 from PyQt5.QtWidgets import QWidget, QApplication, QToolTip
 
+from Globals import qVersionTuple
 
-def drawRect(painter, rect, outline, fill=QColor()):
+
+def drawRect(painter, rect, outline, fill=None):
     """
     Module function to draw a rectangle with the given parameters.
     
@@ -32,7 +34,7 @@ def drawRect(painter, rect, outline, fill=QColor()):
     painter.setPen(Qt.NoPen)
     painter.setBrush(outline)
     painter.drawRect(rect)
-    if fill.isValid():
+    if fill is not None and fill.isValid():
         painter.setClipping(False)
         painter.setBrush(fill)
         painter.drawRect(rect.adjusted(1, 1, -1, -1))
@@ -78,6 +80,7 @@ class SnapshotRegionGrabber(QWidget):
         self.__grabbing = False
         self.__dragStartPoint = QPoint()
         self.__selectionBeforeDrag = QRect()
+        self.__locale = QLocale()
         
         # naming conventions for handles
         # T top, B bottom, R Right, L left
@@ -112,7 +115,7 @@ class SnapshotRegionGrabber(QWidget):
         self.__desktop = QApplication.desktop()
         x = self.__desktop.x()
         y = self.__desktop.y()
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             self.__pixmap = QApplication.screens()[0].grabWindow(
                 self.__desktop.winId(), x, y,
                 self.__desktop.width(), self.__desktop.height())
@@ -127,6 +130,7 @@ class SnapshotRegionGrabber(QWidget):
 
         self.grabMouse()
         self.grabKeyboard()
+        self.activateWindow()
     
     def paintEvent(self, evt):
         """
@@ -184,9 +188,12 @@ class SnapshotRegionGrabber(QWidget):
         # The grabbed region is everything which is covered by the drawn
         # rectangles (border included). This means that there is no 0px
         # selection, since a 0px wide rectangle will always be drawn as a line.
-        txt = "{0:n}, {1:n} ({2:n} x {3:n})".format(
-            self.__selection.x(), self.__selection.y(),
-            self.__selection.width(), self.__selection.height())
+        txt = "{0}, {1} ({2} x {3})".format(
+            self.__locale.toString(self.__selection.x()),
+            self.__locale.toString(self.__selection.y()),
+            self.__locale.toString(self.__selection.width()),
+            self.__locale.toString(self.__selection.height())
+        )
         textRect = painter.boundingRect(self.rect(), Qt.AlignLeft, txt)
         boundingRect = textRect.adjusted(-4, 0, 0, 0)
         
@@ -408,8 +415,10 @@ class SnapshotRegionGrabber(QWidget):
         self.__BLHandle.moveBottomLeft(r.bottomLeft())
         self.__BRHandle.moveBottomRight(r.bottomRight())
         
-        self.__LHandle.moveTopLeft(QPoint(r.x(), r.y() + r.height() // 2 - s2))
-        self.__THandle.moveTopLeft(QPoint(r.x() + r.width() // 2 - s2, r.y()))
+        self.__LHandle.moveTopLeft(
+            QPoint(r.x(), r.y() + r.height() // 2 - s2))
+        self.__THandle.moveTopLeft(
+            QPoint(r.x() + r.width() // 2 - s2, r.y()))
         self.__RHandle.moveTopRight(
             QPoint(r.right(), r.y() + r.height() // 2 - s2))
         self.__BHandle.moveBottomLeft(
