@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the connection parameters.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox
-from PyQt4.QtSql import QSqlDatabase
+from __future__ import unicode_literals
 
-from E5Gui.E5Completers import E5FileCompleter
-from E5Gui import E5FileDialog
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
+from PyQt5.QtSql import QSqlDatabase
+
+from E5Gui.E5PathPicker import E5PathPickerModes
 
 from .Ui_SqlConnectionDialog import Ui_SqlConnectionDialog
 
-import Utilities
-
 
 class SqlConnectionDialog(QDialog, Ui_SqlConnectionDialog):
     """
@@ -29,10 +28,10 @@ class SqlConnectionDialog(QDialog, Ui_SqlConnectionDialog):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SqlConnectionDialog, self).__init__(parent)
         self.setupUi(self)
         
-        self.databaseFileCompleter = E5FileCompleter()
+        self.databasePicker.setMode(E5PathPickerModes.OpenFileMode)
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
         
@@ -53,6 +52,9 @@ class SqlConnectionDialog(QDialog, Ui_SqlConnectionDialog):
         self.driverCombo.addItems(drivers)
         
         self.__updateDialog()
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     def __updateDialog(self):
         """
@@ -60,13 +62,11 @@ class SqlConnectionDialog(QDialog, Ui_SqlConnectionDialog):
         """
         driver = self.driverCombo.currentText()
         if driver.startswith("QSQLITE"):
-            self.databaseEdit.setCompleter(self.databaseFileCompleter)
-            self.databaseFileButton.setEnabled(True)
+            self.databasePicker.setPickerEnabled(True)
         else:
-            self.databaseEdit.setCompleter(None)
-            self.databaseFileButton.setEnabled(False)
+            self.databasePicker.setPickerEnabled(False)
         
-        if self.databaseEdit.text() == "" or driver == "":
+        if self.databasePicker.text() == "" or driver == "":
             self.okButton.setEnabled(False)
         else:
             self.okButton.setEnabled(True)
@@ -81,7 +81,7 @@ class SqlConnectionDialog(QDialog, Ui_SqlConnectionDialog):
         self.__updateDialog()
     
     @pyqtSlot(str)
-    def on_databaseEdit_textChanged(self, txt):
+    def on_databasePicker_textChanged(self, txt):
         """
         Private slot handling the change of the database name.
         
@@ -89,21 +89,6 @@ class SqlConnectionDialog(QDialog, Ui_SqlConnectionDialog):
         """
         self.__updateDialog()
     
-    @pyqtSlot()
-    def on_databaseFileButton_clicked(self):
-        """
-        Private slot to open a database file via a file selection dialog.
-        """
-        startdir = self.databaseEdit.text()
-        dbFile = E5FileDialog.getOpenFileName(
-            self,
-            self.trUtf8("Select Database File"),
-            startdir,
-            self.trUtf8("All Files (*)"))
-        
-        if dbFile:
-            self.databaseEdit.setText(Utilities.toNativeSeparators(dbFile))
-    
     def getData(self):
         """
         Public method to retrieve the connection data.
@@ -114,7 +99,7 @@ class SqlConnectionDialog(QDialog, Ui_SqlConnectionDialog):
         """
         return (
             self.driverCombo.currentText(),
-            self.databaseEdit.text(),
+            self.databasePicker.text(),
             self.usernameEdit.text(),
             self.passwordEdit.text(),
             self.hostnameEdit.text(),
