@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -46,29 +46,29 @@ class TaskFilter(object):
         """
         self.active = enabled
     
-    def setSummaryFilter(self, filter):
+    def setSummaryFilter(self, filterStr):
         """
         Public method to set the description filter.
         
-        @param filter a regular expression for the description filter
+        @param filterStr a regular expression for the description filter
             to set (string) or None
         """
-        if not filter:
+        if not filterStr:
             self.summaryFilter = None
         else:
-            self.summaryFilter = QRegExp(filter)
+            self.summaryFilter = QRegExp(filterStr)
     
-    def setFileNameFilter(self, filter):
+    def setFileNameFilter(self, filterStr):
         """
         Public method to set the filename filter.
         
-        @param filter a wildcard expression for the filename filter
+        @param filterStr a wildcard expression for the filename filter
             to set (string) or None
         """
-        if not filter:
+        if not filterStr:
             self.filenameFilter = None
         else:
-            self.filenameFilter = QRegExp(filter)
+            self.filenameFilter = QRegExp(filterStr)
             self.filenameFilter.setPatternSyntax(QRegExp.Wildcard)
     
     def setTypeFilter(self, taskType):
