@@ -1,7 +1,7 @@
 #
 # Jasy - Web Tooling Framework
 # Copyright 2010-2012 Zynga Inc.
-# Copyright 2013 Sebastian Werner
+# Copyright 2013-2014 Sebastian Werner
 #
 
 """
@@ -9,11 +9,11 @@
 
 Jasy is a powerful Python3-based tooling framework. 
 It makes it easy to manage heavy web projects. 
-Its main goal is to offer an API which could be used by developers to write their
-custom build/deployment scripts.
+Its main goal is to offer an API which could be used by developers to write
+their custom build/deployment scripts.
 """
 
 from __future__ import unicode_literals
 
-__version__ = "1.1.0"
+__version__ = "1.5-beta5"
 __author__ = "Sebastian Werner <info@sebastian-werner.net>"
