@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,13 +12,14 @@ from __future__ import unicode_literals
 import os
 import sys
 
-from PyQt5.QtCore import QTranslator, QLocale, QLibraryInfo, QDir, \
-    QTextCodec, qVersion
+from PyQt5.QtCore import Qt, QTranslator, QLocale, QLibraryInfo, QDir, \
+    QTextCodec, QCoreApplication
 from PyQt5.QtWidgets import QApplication
 
 from E5Gui.E5Application import E5Application
 
 import Globals
+from Globals import qVersionTuple
 
 import UI.PixmapCache
 
@@ -60,7 +61,7 @@ def version(appinfo):
           """\n"""
           """{description}\n"""
           """\n"""
-          """Copyright (c) 2002 - 2015 Detlev Offenbach"""
+          """Copyright (c) 2002 - 2017 Detlev Offenbach"""
           """ <detlev@die-offenbachs.de>\n"""
           """This is free software; see LICENSE.GPL3 for copying"""
           """ conditions.\n"""
@@ -104,8 +105,8 @@ def loadTranslatorForLocale(dirs, tn):
         (int, QTranslator)
     """
     trans = QTranslator(None)
-    for dir in dirs:
-        loaded = trans.load(tn, dir)
+    for directory in dirs:
+        loaded = trans.load(tn, directory)
         if loaded:
             return (trans, True)
     
@@ -164,7 +165,7 @@ def loadTranslators(qtTransDir, app, translationFiles=()):
     
     global loaded_translators
     
-    if qVersion() < "5.0.0":
+    if qVersionTuple() < (5, 0, 0):
         # set the default encoding for tr()
         QTextCodec.setCodecForTr(QTextCodec.codecForName("utf-8"))
     
@@ -222,6 +223,10 @@ def simpleAppStartup(argv, appinfo, mwFactory, quitOnLastWindowClosed=True,
     """
     handleArgs(argv, appinfo)
     if app is None:
+        try:
+            QCoreApplication.setAttribute(Qt.AA_ShareOpenGLContexts, True)
+        except AttributeError:
+            pass
         # set the library paths for plugins
         setLibraryPaths()
         app = E5Application(argv)
@@ -233,12 +238,16 @@ def simpleAppStartup(argv, appinfo, mwFactory, quitOnLastWindowClosed=True,
     initializeResourceSearchPath()
     QApplication.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
     
-    qt4TransDir = Preferences.getQt4TranslationsDir()
-    if not qt4TransDir:
-        qt4TransDir = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
-    loadTranslators(qt4TransDir, app)
+    qtTransDir = Preferences.getQtTranslationsDir()
+    if not qtTransDir:
+        qtTransDir = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
+    loadTranslators(qtTransDir, app, ("qscintilla",))
+    # qscintilla needed for web browser
     
     w = mwFactory(argv)
+    if w is None:
+        return 100
+    
     if quitOnLastWindowClosed:
         app.lastWindowClosed.connect(app.quit)
     w.show()
@@ -252,3 +261,6 @@ def simpleAppStartup(argv, appinfo, mwFactory, quitOnLastWindowClosed=True,
         eMsg.setMinimumSize(600, 400)
     
     return app.exec_()
+
+#
+# eflag: noqa = M801
