@@ -163,6 +163,9 @@ class TrayStarter(QSystemTrayIcon):
         self.__menu.addAction(
             UI.PixmapCache.getIcon("ericWeb.png"),
             self.tr("eric6 Web Browser"), self.__startHelpViewer)
+        self.__menu.addAction(
+            UI.PixmapCache.getIcon("shell.png"),
+            self.tr("eric6 Shell Window"), self.__startShell)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
@@ -384,6 +387,12 @@ class TrayStarter(QSystemTrayIcon):
         Private slot to start the eric6 hex editor dialog.
         """
         self.__startProc("eric6_hexeditor.py")
+    
+    def __startShell(self):
+        """
+        Private slot to start the eric6 Shell window.
+        """
+        self.__startProc("eric6_shell.py")
 
     def __showRecentProjectsMenu(self):
         """
@@ -506,9 +515,9 @@ class TrayStarter(QSystemTrayIcon):
         from PyQt5.Qsci import QSCINTILLA_VERSION_STR
         
         try:
-            import sipconfig
-            sip_version_str = sipconfig.Configuration().sip_version_str
-        except ImportError:
+            import sip
+            sip_version_str = sip.SIP_VERSION_STR
+        except (ImportError, AttributeError):
             sip_version_str = "sip version not available"
         
         versionText = self.tr(
