@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,23 +11,26 @@ from __future__ import unicode_literals
 
 import os
 
-from PyQt5.QtCore import QModelIndex, pyqtSignal, QUrl, Qt, qVersion, \
-    QCoreApplication, QItemSelectionModel
+from PyQt5.QtCore import QModelIndex, pyqtSignal, QUrl, Qt, QCoreApplication, \
+    QItemSelectionModel, QElapsedTimer
 from PyQt5.QtGui import QDesktopServices
 from PyQt5.QtWidgets import QTreeView, QApplication, QMenu, QAbstractItemView
 
 from E5Gui.E5Application import e5App
-from E5Gui import E5FileDialog
+from E5Gui import E5FileDialog, E5MessageBox
 
+from Project.ProjectBrowserModel import ProjectBrowserSimpleDirectoryItem
 from .BrowserModel import BrowserModel, BrowserDirectoryItem, \
     BrowserFileItem, BrowserClassItem, BrowserMethodItem, \
-    BrowserClassAttributeItem
+    BrowserClassAttributeItem, BrowserImportItem, BrowserImportsItem, \
+    BrowserSysPathItem, BrowserGlobalsItem
 from .BrowserSortFilterProxyModel import BrowserSortFilterProxyModel
 
 import UI.PixmapCache
 import Preferences
 import Utilities
 import Utilities.MimeTypes
+from Globals import qVersionTuple
 
 
 class Browser(QTreeView):
@@ -38,20 +41,32 @@ class Browser(QTreeView):
     is displayed by a right click the user can select various actions on
     the selected file.
     
-    @signal sourceFile(str, int = 0, str = "") emitted to open a Python file
-        at a line
-    @signal designerFile(str) emitted to open a Qt-Designer file
-    @signal linguistFile(str) emitted to open a Qt-Linguist (*.ts) file
-    @signal trpreview(list of str, bool = False) emitted to preview a
-        Qt-Linguist (*.qm) file
-    @signal projectFile(str) emitted to open an eric4/5 project file
-    @signal multiProjectFile(str) emitted to open an eric4/5 multi project file
-    @signal pixmapFile(str) emitted to open a pixmap file
-    @signal pixmapEditFile(str) emitted to edit a pixmap file
-    @signal svgFile(str) emitted to open a SVG file
-    @signal unittestOpen(str) emitted to open a Python file for a unittest
+    @signal sourceFile(filename) emitted to open a Python file at a line (str)
+    @signal sourceFile(filename, lineno) emitted to open a Python file at a
+        line (str, int)
+    @signal sourceFile(filename, lineno, type) emitted to open a Python file
+        at a line giving an explicit file type (str, int, str)
+    @signal sourceFile(filename, linenos) emitted to open a Python file giving
+        a list of lines(str, list)
+    @signal designerFile(filename) emitted to open a Qt-Designer file (str)
+    @signal linguistFile(filename) emitted to open a Qt-Linguist (*.ts)
+        file (str)
+    @signal trpreview(filenames) emitted to preview Qt-Linguist (*.qm)
+        files (list of str)
+    @signal trpreview(filenames, ignore) emitted to preview Qt-Linguist (*.qm)
+        files indicating whether non-existent files shall be ignored
+        (list of str, bool)
+    @signal projectFile(filename) emitted to open an eric project file (str)
+    @signal multiProjectFile(filename) emitted to open an eric multi project
+        file (str)
+    @signal pixmapFile(filename) emitted to open a pixmap file (str)
+    @signal pixmapEditFile(filename) emitted to edit a pixmap file (str)
+    @signal svgFile(filename) emitted to open a SVG file (str)
+    @signal binaryFile(filename) emitted to open a file as binary (str)
+    @signal unittestOpen(filename) emitted to open a Python file for a
+        unit test (str)
     """
-    sourceFile = pyqtSignal((str, ), (str, int), (str, int, str))
+    sourceFile = pyqtSignal((str, ), (str, int), (str, list), (str, int, str))
     designerFile = pyqtSignal(str)
     linguistFile = pyqtSignal(str)
     trpreview = pyqtSignal((list, ), (list, bool))
@@ -60,6 +75,7 @@ class Browser(QTreeView):
     pixmapFile = pyqtSignal(str)
     pixmapEditFile = pyqtSignal(str)
     svgFile = pyqtSignal(str)
+    binaryFile = pyqtSignal(str)
     unittestOpen = pyqtSignal(str)
     
     def __init__(self, parent=None):
@@ -135,6 +151,10 @@ class Browser(QTreeView):
         
         self._init()    # perform common initialization tasks
         
+        self._keyboardSearchString = ""
+        self._keyboardSearchTimer = QElapsedTimer()
+        self._keyboardSearchTimer.invalidate()
+        
     def _init(self):
         """
         Protected method to perform initialization tasks common to this
@@ -146,7 +166,7 @@ class Browser(QTreeView):
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
         header.setSortIndicatorShown(True)
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             header.setSectionsClickable(True)
         else:
             header.setClickable(True)
@@ -196,6 +216,11 @@ class Browser(QTreeView):
         self.unittestAct = self.sourceMenu.addAction(
             QCoreApplication.translate('Browser', 'Run unittest...'),
             self.handleUnittest)
+        self.sourceMenu.addSeparator()
+        self.mimeTypeAct = self.sourceMenu.addAction(
+            QCoreApplication.translate('Browser', 'Show Mime-Type'),
+            self.__showMimeType)
+        self.sourceMenu.addSeparator()
         self.sourceMenu.addAction(
             QCoreApplication.translate('Browser', 'Copy Path to Clipboard'),
             self._copyToClipboard)
@@ -204,9 +229,17 @@ class Browser(QTreeView):
         self.menu = QMenu(self)
         self.menu.addAction(
             QCoreApplication.translate('Browser', 'Open'), self._openItem)
+        self.menu.addAction(
+            QCoreApplication.translate('Browser', 'Open in Hex Editor'),
+            self._openHexEditor)
         self.editPixmapAct = self.menu.addAction(
             QCoreApplication.translate('Browser', 'Open in Icon Editor'),
             self._editPixmap)
+        self.menu.addSeparator()
+        self.mimeTypeAct = self.menu.addAction(
+            QCoreApplication.translate('Browser', 'Show Mime-Type'),
+            self.__showMimeType)
+        self.menu.addSeparator()
         self.menu.addAction(
             QCoreApplication.translate('Browser', 'Copy Path to Clipboard'),
             self._copyToClipboard)
@@ -259,7 +292,8 @@ class Browser(QTreeView):
                 self.__configure)
         
         # create the attribute menu
-        self.gotoMenu = QMenu(self.tr("Goto"), self)
+        self.gotoMenu = QMenu(QCoreApplication.translate('Browser', "Goto"),
+                              self)
         self.gotoMenu.aboutToShow.connect(self._showGotoMenu)
         self.gotoMenu.triggered.connect(self._gotoAttribute)
         
@@ -297,7 +331,14 @@ class Browser(QTreeView):
         """
         index = self.indexAt(mouseEvent.pos())
         if index.isValid():
-            self._openItem()
+            itm = self.model().item(index)
+            if isinstance(itm, (
+                    BrowserDirectoryItem, BrowserImportsItem,
+                    ProjectBrowserSimpleDirectoryItem, BrowserSysPathItem,
+                    BrowserGlobalsItem)):
+                self.setExpanded(index, not self.isExpanded(index))
+            else:
+                self._openItem()
 
     def _contextMenuRequested(self, coord):
         """
@@ -335,7 +376,9 @@ class Browser(QTreeView):
                         self.editPixmapAct.setVisible(itm.isPixmapFile())
                         self.menu.popup(coord)
                 elif isinstance(itm, BrowserClassItem) or \
-                        isinstance(itm, BrowserMethodItem):
+                    isinstance(itm, BrowserMethodItem) or \
+                        isinstance(itm, BrowserImportItem):
+                    self.editPixmapAct.setVisible(False)
                     self.menu.popup(coord)
                 elif isinstance(itm, BrowserClassAttributeItem):
                     self.attributeMenu.popup(coord)
@@ -364,7 +407,8 @@ class Browser(QTreeView):
         
         for lineno in sorted(linenos):
             act = self.gotoMenu.addAction(
-                self.tr("Line {0}".format(lineno)))
+                QCoreApplication.translate(
+                    'Browser', "Line {0}").format(lineno))
             act.setData([fileName, lineno])
         
     def _gotoAttribute(self, act):
@@ -389,7 +433,8 @@ class Browser(QTreeView):
         """
         itmList = self.getSelectedItems(
             [BrowserFileItem, BrowserClassItem,
-             BrowserMethodItem, BrowserClassAttributeItem])
+             BrowserMethodItem, BrowserClassAttributeItem,
+             BrowserImportItem])
         
         if not self._activating:
             self._activating = True
@@ -438,8 +483,62 @@ class Browser(QTreeView):
                 elif isinstance(itm, BrowserClassAttributeItem):
                     self.sourceFile[str, int].emit(
                         itm.fileName(), itm.attributeObject().lineno)
+                elif isinstance(itm, BrowserImportItem):
+                    self.sourceFile[str, list].emit(
+                        itm.fileName(), itm.linenos())
             self._activating = False
         
+    def __showMimeType(self):
+        """
+        Private slot to show the mime type of the selected entry.
+        """
+        itmList = self.getSelectedItems(
+            [BrowserFileItem, BrowserClassItem,
+             BrowserMethodItem, BrowserClassAttributeItem,
+             BrowserImportItem])
+        if itmList:
+            mimetype = Utilities.MimeTypes.mimeType(itmList[0].fileName())
+            if mimetype is None:
+                E5MessageBox.warning(
+                    self,
+                    QCoreApplication.translate('Browser', "Show Mime-Type"),
+                    QCoreApplication.translate(
+                        'Browser',
+                        """The mime type of the file could not be"""
+                        """ determined."""))
+            elif mimetype.split("/")[0] == "text":
+                E5MessageBox.information(
+                    self,
+                    QCoreApplication.translate('Browser', "Show Mime-Type"),
+                    QCoreApplication.translate(
+                        'Browser',
+                        """The file has the mime type <b>{0}</b>.""")
+                    .format(mimetype))
+            else:
+                textMimeTypesList = Preferences.getUI("TextMimeTypes")
+                if mimetype in textMimeTypesList:
+                    E5MessageBox.information(
+                        self,
+                        QCoreApplication.translate(
+                            'Browser', "Show Mime-Type"),
+                        QCoreApplication.translate(
+                            'Browser',
+                            """The file has the mime type <b>{0}</b>.""")
+                        .format(mimetype))
+                else:
+                    ok = E5MessageBox.yesNo(
+                        self,
+                        QCoreApplication.translate(
+                            'Browser', "Show Mime-Type"),
+                        QCoreApplication.translate(
+                            'Browser',
+                            """The file has the mime type <b>{0}</b>."""
+                            """<br/> Shall it be added to the list of"""
+                            """ text mime types?""").format(mimetype))
+                    if ok:
+                        textMimeTypesList.append(mimetype)
+                        Preferences.setUI("TextMimeTypes", textMimeTypesList)
+        
     def _editPixmap(self):
         """
         Protected slot to handle the open in icon editor popup menu entry.
@@ -451,6 +550,16 @@ class Browser(QTreeView):
                 if itm.isPixmapFile():
                     self.pixmapEditFile.emit(itm.fileName())
         
+    def _openHexEditor(self):
+        """
+        Protected slot to handle the open in hex editor popup menu entry.
+        """
+        itmList = self.getSelectedItems([BrowserFileItem])
+        
+        for itm in itmList:
+            if isinstance(itm, BrowserFileItem):
+                self.binaryFile.emit(itm.fileName())
+        
     def _copyToClipboard(self):
         """
         Protected method to copy the text shown for an entry to the clipboard.
@@ -555,26 +664,26 @@ class Browser(QTreeView):
         """
         self.__model.interpreterChanged(interpreter)
         
-    def wantedItem(self, itm, filter=None):
+    def wantedItem(self, itm, filterList=None):
         """
         Public method to check type of an item.
         
         @param itm the item to check (BrowserItem)
-        @param filter list of classes to check against
+        @param filterList list of classes to check against
         @return flag indicating item is a valid type (boolean)
         """
-        if filter is None:
-            filter = self.selectedItemsFilter
-        for typ in filter:
+        if filterList is None:
+            filterList = self.selectedItemsFilter
+        for typ in filterList:
             if isinstance(itm, typ):
                 return True
         return False
         
-    def getSelectedItems(self, filter=None):
+    def getSelectedItems(self, filterList=None):
         """
         Public method to get the selected items.
         
-        @param filter list of classes to check against
+        @param filterList list of classes to check against
         @return list of selected items (list of BroweserItem)
         """
         selectedItems = []
@@ -582,15 +691,15 @@ class Browser(QTreeView):
         for index in indexes:
             if index.column() == 0:
                 itm = self.model().item(index)
-                if self.wantedItem(itm, filter):
+                if self.wantedItem(itm, filterList):
                     selectedItems.append(itm)
         return selectedItems
         
-    def getSelectedItemsCount(self, filter=None):
+    def getSelectedItemsCount(self, filterList=None):
         """
         Public method to get the count of items selected.
         
-        @param filter list of classes to check against
+        @param filterList list of classes to check against
         @return count of items selected (integer)
         """
         count = 0
@@ -598,15 +707,15 @@ class Browser(QTreeView):
         for index in indexes:
             if index.column() == 0:
                 itm = self.model().item(index)
-                if self.wantedItem(itm, filter):
+                if self.wantedItem(itm, filterList):
                     count += 1
         return count
         
-    def getSelectedItemsCountCategorized(self, filter=None):
+    def getSelectedItemsCountCategorized(self, filterList=None):
         """
         Public method to get a categorized count of selected items.
         
-        @param filter list of classes to check against
+        @param filterList list of classes to check against
         @return a dictionary containing the counts of items belonging
             to the individual filter classes. The keys of the dictionary
             are the string representation of the classes given in the
@@ -614,18 +723,18 @@ class Browser(QTreeView):
             an additional entry with key "sum", that stores the sum of
             all selected entries fulfilling the filter criteria.
         """
-        if filter is None:
-            filter = self.selectedItemsFilter
+        if filterList is None:
+            filterList = self.selectedItemsFilter
         categories = {}
         categories["sum"] = 0
-        for typ in filter:
+        for typ in filterList:
             categories[str(typ)] = 0
         
         indexes = self.selectedIndexes()
         for index in indexes:
             if index.column() == 0:
                 itm = self.model().item(index)
-                for typ in filter:
+                for typ in filterList:
                     if isinstance(itm, typ):
                         categories["sum"] += 1
                         categories[str(typ)] += 1
@@ -648,3 +757,57 @@ class Browser(QTreeView):
         elif self.__embeddedBrowser == 2:
             e5App().getObject("UserInterface")\
                 .showPreferences("projectBrowserPage")
+    
+    def keyboardSearch(self, search):
+        """
+        Public function to search the tree via the keyboard.
+        
+        @param search the character entered via the keyboard
+        @type str
+        """
+        if self.model().rowCount() == 0:
+            return
+        
+        if self.currentIndex().isValid():
+            startIndex = self.currentIndex()
+        else:
+            startIndex = self.model().index(0, 0)
+        
+        keyboardSearchTimeWasValid = self._keyboardSearchTimer.isValid()
+        keyboardSearchTimeElapsed = self._keyboardSearchTimer.restart()
+        if not search or not keyboardSearchTimeWasValid or \
+            keyboardSearchTimeElapsed > \
+                QApplication.keyboardInputInterval():
+            self._keyboardSearchString = search.lower()
+        else:
+            self._keyboardSearchString += search.lower()
+        
+        index = startIndex
+        found = False
+        while True:
+            name = self.model().data(index)
+            if name.lower().startswith(self._keyboardSearchString) and \
+                    self._keyboardSearchType(self.model().item(index)):
+                found = True
+                break
+            
+            index = self.indexBelow(index)
+            if not index.isValid():
+                index = self.model().index(0, 0)
+            if index == startIndex:
+                break
+        
+        if found:
+            self.setCurrentIndex(index)
+    
+    def _keyboardSearchType(self, item):
+        """
+        Protected method to check, if the item is of the correct type.
+        
+        @param item reference to the item
+        @type BrowserItem
+        @return flag indicating a correct type
+        @rtype bool
+        """
+        return isinstance(
+            item, (BrowserDirectoryItem, BrowserFileItem, BrowserSysPathItem))
