@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -87,7 +87,8 @@ class NotificationWidget(QWidget, Ui_NotificationWidget):
         """
         Public method to set the timeout for the notification.
         
-        @param timeout timeout to be used in seconds (integer)
+        @param timeout timeout to be used in seconds (0 = indefinitely)
+        @type int
         """
         self.__timeout = timeout * 1000
     
@@ -101,8 +102,9 @@ class NotificationWidget(QWidget, Ui_NotificationWidget):
         
         if not self.__settingPosition:
             self.__timer.stop()
-            self.__timer.setInterval(self.__timeout)
-            self.__timer.start()
+            if self.__timeout > 0:
+                self.__timer.setInterval(self.__timeout)
+                self.__timer.start()
         
         super(NotificationWidget, self).show()
         
