@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,16 +9,20 @@ Module implementing a widget to select a symbol in various formats.
 
 from __future__ import unicode_literals
 
+try:
+    # Py2
+    str = unicode
+    chr = unichr
+    import htmlentitydefs as html_entities
+except (NameError, ImportError):
+    # Py3
+    import html.entities as html_entities
+
 import sys
 import unicodedata
-try:  # Py3
-    import html.entities as html_entities
-except (ImportError):
-    chr = unichr    # __IGNORE_WARNING__
-    import htmlentitydefs as html_entities    # __IGNORE_WARNING__
 
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, QAbstractTableModel, \
-    QModelIndex, Qt, qVersion, QItemSelectionModel
+    QModelIndex, Qt, QItemSelectionModel, QLocale
 from PyQt5.QtGui import QColor
 from PyQt5.QtWidgets import QWidget, QHeaderView, QAbstractItemView
 
@@ -26,6 +30,7 @@ from .Ui_SymbolsWidget import Ui_SymbolsWidget
 
 import UI.PixmapCache
 import Preferences
+from Globals import qVersionTuple
 
 
 class SymbolsModel(QAbstractTableModel):
@@ -40,6 +45,8 @@ class SymbolsModel(QAbstractTableModel):
         """
         super(SymbolsModel, self).__init__(parent)
         
+        self.__locale = QLocale()
+        
         self.__headerData = [
             self.tr("Code"),
             self.tr("Char"),
@@ -354,28 +361,29 @@ class SymbolsModel(QAbstractTableModel):
         @param role role of the data to retrieve (integer)
         @return requested data
         """
-        id = self.__tables[self.__currentTableIndex][0] + index.row()
+        symbolId = self.__tables[self.__currentTableIndex][0] + index.row()
         
         if role == Qt.DisplayRole:
             col = index.column()
             if col == 0:
-                return str(id)
+                return self.__locale.toString(symbolId)
             elif col == 1:
-                return chr(id)
+                return chr(symbolId)
             elif col == 2:
-                return "0x{0:04x}".format(id)
+                return "0x{0:04x}".format(symbolId)
             elif col == 3:
-                if id in html_entities.codepoint2name:
-                    return "&{0};".format(html_entities.codepoint2name[id])
+                if symbolId in html_entities.codepoint2name:
+                    return "&{0};".format(
+                        html_entities.codepoint2name[symbolId])
             elif col == 4:
-                return unicodedata.name(chr(id), '').title()
+                return unicodedata.name(chr(symbolId), '').title()
         
         if role == Qt.BackgroundColorRole:
             if index.column() == 0:
                 return QColor(Qt.lightGray)
         
         if role == Qt.TextColorRole:
-            char = chr(id)
+            char = chr(symbolId)
             if self.__isDigit(char):
                 return QColor(Qt.darkBlue)
             elif self.__isLetter(char):
@@ -427,7 +435,7 @@ class SymbolsModel(QAbstractTableModel):
         @param char character to test (one character string)
         @return flag indicating a digit (boolean)
         """
-        return unicodedata.category(char) == "Nd"
+        return unicodedata.category(str(char)) == "Nd"
     
     def __isLetter(self, char):
         """
@@ -436,7 +444,8 @@ class SymbolsModel(QAbstractTableModel):
         @param char character to test (one character string)
         @return flag indicating a letter (boolean)
         """
-        return unicodedata.category(char) in ["Lu", "Ll", "Lt", "Lm", "Lo"]
+        return unicodedata.category(str(char)) in ["Lu", "Ll", "Lt", "Lm",
+                                                   "Lo"]
     
     def __isMark(self, char):
         """
@@ -445,7 +454,7 @@ class SymbolsModel(QAbstractTableModel):
         @param char character to test (one character string)
         @return flag indicating a mark character (boolean)
         """
-        return unicodedata.category(char) in ["Mn", "Mc", "Me"]
+        return unicodedata.category(str(char)) in ["Mn", "Mc", "Me"]
     
     def __isSymbol(self, char):
         """
@@ -454,7 +463,7 @@ class SymbolsModel(QAbstractTableModel):
         @param char character to test (one character string)
         @return flag indicating a symbol (boolean)
         """
-        return unicodedata.category(char) in ["Sm", "Sc", "Sk", "So"]
+        return unicodedata.category(str(char)) in ["Sm", "Sc", "Sk", "So"]
     
     def __isPunct(self, char):
         """
@@ -463,8 +472,17 @@ class SymbolsModel(QAbstractTableModel):
         @param char character to test (one character string)
         @return flag indicating a punctuation character (boolean)
         """
-        return unicodedata.category(char) in ["Pc", "Pd", "Ps", "Pe", "Pi",
-                                              "Pf", "Po"]
+        return unicodedata.category(str(char)) in ["Pc", "Pd", "Ps", "Pe",
+                                                   "Pi", "Pf", "Po"]
+    
+    def getLocale(self):
+        """
+        Public method to get the used locale.
+        
+        @return used locale
+        @rtype QLocale
+        """
+        return self.__locale
 
 
 class SymbolsWidget(QWidget, Ui_SymbolsWidget):
@@ -491,7 +509,7 @@ class SymbolsWidget(QWidget, Ui_SymbolsWidget):
         self.symbolsTable.selectionModel().currentRowChanged.connect(
             self.__currentRowChanged)
         
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             self.symbolsTable.horizontalHeader().setSectionResizeMode(
                 QHeaderView.Fixed)
         else:
@@ -536,10 +554,10 @@ class SymbolsWidget(QWidget, Ui_SymbolsWidget):
         """
         Private slot to move the table to the entered symbol id.
         """
-        id = self.symbolSpinBox.value()
+        symbolId = self.symbolSpinBox.value()
         first, last = self.__model.getTableBoundaries(
             self.__model.getTableIndex())
-        row = id - first
+        row = symbolId - first
         self.symbolsTable.selectRow(row)
         self.symbolsTable.scrollTo(
             self.__model.index(row, 0), QAbstractItemView.PositionAtCenter)
@@ -554,6 +572,7 @@ class SymbolsWidget(QWidget, Ui_SymbolsWidget):
         self.symbolsTable.setUpdatesEnabled(False)
         self.__model.selectTable(index)
         self.symbolsTable.setUpdatesEnabled(True)
+        self.symbolsTable.resizeColumnsToContents()
         
         first, last = self.__model.getTableBoundaries(index)
         self.symbolSpinBox.setMinimum(first)
@@ -569,5 +588,5 @@ class SymbolsWidget(QWidget, Ui_SymbolsWidget):
         @param previous previous current index (QModelIndex)
         """
         Preferences.Prefs.settings.setValue("Symbols/Top", current.row())
-        self.symbolSpinBox.setValue(int(
-            self.__model.data(self.__model.index(current.row(), 0))))
+        self.symbolSpinBox.setValue(self.__model.getLocale().toInt(
+            self.__model.data(self.__model.index(current.row(), 0)))[0])
