@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -40,7 +40,7 @@ __extensions = {
 }
 
 
-def readmodule(module, path=[], isPyFile=False):
+def readmodule(module, path=None, isPyFile=False):
     """
     Read a source file and return a dictionary of classes, functions, modules,
     etc. .
@@ -54,32 +54,33 @@ def readmodule(module, path=[], isPyFile=False):
     @return the resulting dictionary
     """
     ext = os.path.splitext(module)[1].lower()
+    path = [] if path is None else path[:]
     
     if ext in __extensions["IDL"]:
         from . import idlclbr
-        dict = idlclbr.readmodule_ex(module, path)
+        dictionary = idlclbr.readmodule_ex(module, path)
         idlclbr._modules.clear()
     elif ext in __extensions["Ruby"]:
         from . import rbclbr
-        dict = rbclbr.readmodule_ex(module, path)
+        dictionary = rbclbr.readmodule_ex(module, path)
         rbclbr._modules.clear()
     elif ext in __extensions["JavaScript"] and sys.version_info[0] == 3:
         from . import jsclbr
-        dict = jsclbr.readmodule_ex(module, path)
+        dictionary = jsclbr.readmodule_ex(module, path)
         jsclbr._modules.clear()
     elif ext in Preferences.getPython("PythonExtensions") or \
         ext in Preferences.getPython("Python3Extensions") or \
             isPyFile:
         from . import pyclbr
-        dict = pyclbr.readmodule_ex(module, path, isPyFile=isPyFile)
+        dictionary = pyclbr.readmodule_ex(module, path, isPyFile=isPyFile)
         pyclbr._modules.clear()
     else:
         # try Python if it is without extension
         from . import pyclbr
-        dict = pyclbr.readmodule_ex(module, path)
+        dictionary = pyclbr.readmodule_ex(module, path)
         pyclbr._modules.clear()
     
-    return dict
+    return dictionary
 
 
 def find_module(name, path, isPyFile=False):
@@ -143,3 +144,6 @@ def find_module(name, path, isPyFile=False):
                 if os.path.exists(pathname):
                     return (open(pathname), pathname, (ext, 'r', PY_SOURCE))
         raise ImportError
+    except SyntaxError:
+        # re-raise as an import error
+        raise ImportError
