@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -25,7 +25,7 @@ from . import ClbrBaseClasses
 SUPPORTED_TYPES = [ClassBrowsers.IDL_SOURCE]
     
 _getnext = re.compile(
-r"""
+    r"""
     (?P<String>
         " [^"\\\n]* (?: \\. [^"\\\n]*)* "
     )
@@ -84,8 +84,8 @@ r"""
 
 |   (?P<End>
         [ \t]* } [ \t]* ;
-    )
-""", re.VERBOSE | re.DOTALL | re.MULTILINE).search      # __IGNORE_WARNING__
+    )""",
+    re.VERBOSE | re.DOTALL | re.MULTILINE).search
 
 # function to replace comments
 _commentsub = re.compile(r"""//[^\n]*\n|//[^\n]*$""").sub
@@ -127,17 +127,19 @@ class Interface(ClbrBaseClasses.Class, VisibilityMixin):
     """
     Class to represent a CORBA IDL interface.
     """
-    def __init__(self, module, name, super, file, lineno):
+    def __init__(self, module, name, superClasses, file, lineno):
         """
         Constructor
         
         @param module name of the module containing this class
         @param name name of this interface
-        @param super list of interface names this interface is inherited from
+        @param superClasses list of interface names this interface is
+            inherited from
         @param file filename containing this interface
         @param lineno linenumber of the interface definition
         """
-        ClbrBaseClasses.Class.__init__(self, module, name, super, file, lineno)
+        ClbrBaseClasses.Class.__init__(self, module, name, superClasses, file,
+                                       lineno)
         VisibilityMixin.__init__(self)
 
 
@@ -179,7 +181,7 @@ class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
         VisibilityMixin.__init__(self)
 
 
-def readmodule_ex(module, path=[]):
+def readmodule_ex(module, path=None):
     """
     Read a CORBA IDL file and return a dictionary of classes, functions and
     modules.
@@ -190,7 +192,7 @@ def readmodule_ex(module, path=[]):
     """
     global _modules
     
-    dict = {}
+    dictionary = {}
     dict_counts = {}
 
     if module in _modules:
@@ -199,24 +201,24 @@ def readmodule_ex(module, path=[]):
 
     # search the path for the file
     f = None
-    fullpath = list(path)
+    fullpath = [] if path is None else path[:]
     f, file, (suff, mode, type) = ClassBrowsers.find_module(module, fullpath)
     if f:
         f.close()
     if type not in SUPPORTED_TYPES:
         # not CORBA IDL source, can't do anything with this module
-        _modules[module] = dict
-        return dict
+        _modules[module] = dictionary
+        return dictionary
 
-    _modules[module] = dict
+    _modules[module] = dictionary
     classstack = []  # stack of (class, indent) pairs
     indent = 0
     try:
         src = Utilities.readEncodedFile(file)[0]
     except (UnicodeError, IOError):
         # can't do anything with this module
-        _modules[module] = dict
-        return dict
+        _modules[module] = dictionary
+        return dictionary
 
     lineno, last_lineno_pos = 1, 0
     lastGlobalEntry = None
@@ -267,7 +269,7 @@ def readmodule_ex(module, path=[]):
                         meth_name, dict_counts[meth_name])
                 else:
                     dict_counts[meth_name] = 0
-                dict[meth_name] = f
+                dictionary[meth_name] = f
             if not classstack:
                 if lastGlobalEntry:
                     lastGlobalEntry.setEndLine(lineno - 1)
@@ -306,7 +308,7 @@ def readmodule_ex(module, path=[]):
             cur_class = Interface(module, class_name, inherit,
                                   file, lineno)
             if not classstack:
-                dict[class_name] = cur_class
+                dictionary[class_name] = cur_class
             else:
                 cls = classstack[-1][0]
                 cls._addclass(class_name, cur_class)
@@ -336,7 +338,7 @@ def readmodule_ex(module, path=[]):
             # remember this module
             cur_class = Module(module, module_name, file, lineno)
             if not classstack:
-                dict[module_name] = cur_class
+                dictionary[module_name] = cur_class
                 if lastGlobalEntry:
                     lastGlobalEntry.setEndLine(lineno - 1)
                 lastGlobalEntry = cur_class
@@ -378,4 +380,4 @@ def readmodule_ex(module, path=[]):
         else:
             assert 0, "regexp _getnext found something unexpected"
 
-    return dict
+    return dictionary
