@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,6 +12,8 @@ and to find out the superclasses of a class as well as its attributes.
 It is based on the Python class browser found in this package.
 """
 
+from __future__ import unicode_literals
+
 import re
 
 import Utilities
@@ -21,7 +23,7 @@ from . import ClbrBaseClasses
 SUPPORTED_TYPES = [ClassBrowsers.RB_SOURCE]
     
 _getnext = re.compile(
-r"""
+    r"""
     (?P<String>
         =begin .*? =end
     
@@ -155,8 +157,8 @@ r"""
         |
             end \b [^_]
         )
-    )
-""", re.VERBOSE | re.DOTALL | re.MULTILINE).search      # __IGNORE_WARNING__
+    )""",
+    re.VERBOSE | re.DOTALL | re.MULTILINE).search
 
 _commentsub = re.compile(r"""#[^\n]*\n|#[^\n]*$""").sub
 
@@ -169,7 +171,7 @@ class VisibilityMixin(ClbrBaseClasses.ClbrVisibilityMixinBase):
     """
     def __init__(self):
         """
-        Method to initialize the visibility.
+        Constructor
         """
         self.setPublic()
 
@@ -178,17 +180,18 @@ class Class(ClbrBaseClasses.Class, VisibilityMixin):
     """
     Class to represent a Ruby class.
     """
-    def __init__(self, module, name, super, file, lineno):
+    def __init__(self, module, name, superClasses, file, lineno):
         """
         Constructor
         
         @param module name of the module containing this class
         @param name name of this class
-        @param super list of class names this class is inherited from
+        @param superClasses list of class names this class is inherited from
         @param file filename containing this class
         @param lineno linenumber of the class definition
         """
-        ClbrBaseClasses.Class.__init__(self, module, name, super, file, lineno)
+        ClbrBaseClasses.Class.__init__(self, module, name, superClasses, file,
+                                       lineno)
         VisibilityMixin.__init__(self)
 
 
@@ -248,7 +251,7 @@ class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
         self.setPrivate()
 
 
-def readmodule_ex(module, path=[]):
+def readmodule_ex(module, path=None):
     """
     Read a Ruby file and return a dictionary of classes, functions and modules.
 
@@ -258,7 +261,7 @@ def readmodule_ex(module, path=[]):
     """
     global _modules
     
-    dict = {}
+    dictionary = {}
     dict_counts = {}
 
     if module in _modules:
@@ -267,16 +270,16 @@ def readmodule_ex(module, path=[]):
 
     # search the path for the file
     f = None
-    fullpath = list(path)
+    fullpath = [] if path is None else path[:]
     f, file, (suff, mode, type) = ClassBrowsers.find_module(module, fullpath)
     if f:
         f.close()
     if type not in SUPPORTED_TYPES:
         # not Ruby source, can't do anything with this module
-        _modules[module] = dict
-        return dict
+        _modules[module] = dictionary
+        return dictionary
 
-    _modules[module] = dict
+    _modules[module] = dictionary
     classstack = []  # stack of (class, indent) pairs
     acstack = []    # stack of (access control, indent) pairs
     indent = 0
@@ -284,8 +287,8 @@ def readmodule_ex(module, path=[]):
         src = Utilities.readEncodedFile(file)[0]
     except (UnicodeError, IOError):
         # can't do anything with this module
-        _modules[module] = dict
-        return dict
+        _modules[module] = dictionary
+        return dictionary
 
     lineno, last_lineno_pos = 1, 0
     cur_obj = None
@@ -354,7 +357,7 @@ def readmodule_ex(module, path=[]):
                         meth_name, dict_counts[meth_name])
                 else:
                     dict_counts[meth_name] = 0
-                dict[meth_name] = f
+                dictionary[meth_name] = f
             if not classstack:
                 if lastGlobalEntry:
                     lastGlobalEntry.setEndLine(lineno - 1)
@@ -396,10 +399,10 @@ def readmodule_ex(module, path=[]):
             cur_class = Class(module, class_name, inherit,
                               file, lineno)
             if not classstack:
-                if class_name in dict:
-                    cur_class = dict[class_name]
+                if class_name in dictionary:
+                    cur_class = dictionary[class_name]
                 else:
-                    dict[class_name] = cur_class
+                    dictionary[class_name] = cur_class
             else:
                 cls = classstack[-1][0]
                 if class_name in cls.classes:
@@ -417,8 +420,8 @@ def readmodule_ex(module, path=[]):
             while acstack and \
                     acstack[-1][1] >= thisindent:
                 del acstack[-1]
-            acstack.append(["public", thisindent])  # default access control
-                                                    # is 'public'
+            acstack.append(["public", thisindent])
+            # default access control is 'public'
 
         elif m.start("Module") >= 0:
             # we found a module definition
@@ -437,10 +440,10 @@ def readmodule_ex(module, path=[]):
             # remember this class
             cur_class = Module(module, module_name, file, lineno)
             if not classstack:
-                if module_name in dict:
-                    cur_class = dict[module_name]
+                if module_name in dictionary:
+                    cur_class = dictionary[module_name]
                 else:
-                    dict[module_name] = cur_class
+                    dictionary[module_name] = cur_class
             else:
                 cls = classstack[-1][0]
                 if module_name in cls.classes:
@@ -458,8 +461,8 @@ def readmodule_ex(module, path=[]):
             while acstack and \
                     acstack[-1][1] >= thisindent:
                 del acstack[-1]
-            acstack.append(["public", thisindent])  # default access control
-                                                    # is 'public'
+            acstack.append(["public", thisindent])
+            # default access control is 'public'
 
         elif m.start("AccessControl") >= 0:
             aclist = m.group("AccessControlList")
@@ -580,11 +583,11 @@ def readmodule_ex(module, path=[]):
             coding = m.group("Coding")
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
-            if "@@Coding@@" not in dict:
-                dict["@@Coding@@"] = ClbrBaseClasses.Coding(
+            if "@@Coding@@" not in dictionary:
+                dictionary["@@Coding@@"] = ClbrBaseClasses.Coding(
                     module, file, lineno, coding)
 
         else:
             assert 0, "regexp _getnext found something unexpected"
 
-    return dict
+    return dictionary
