@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,6 +10,7 @@ Package implementing various functions/classes needed everywhere within eric6.
 from __future__ import unicode_literals
 try:
     str = unicode
+    import locale
     import urllib
 
     def quote(url):
@@ -44,7 +45,7 @@ def __showwarning(message, category, filename, lineno, file=None, line=""):
     @param file file to write the warning message to (ignored)
     @param line line causing the warning (ignored)
     @raise SyntaxError
-    """
+    """     # __IGNORE_WARNING_D252__ __IGNORE_WARNING_D253__
     if category is SyntaxWarning:
         err = SyntaxError(str(message))
         err.filename = filename
@@ -64,14 +65,15 @@ from PyQt5.Qsci import QSCINTILLA_VERSION_STR, QsciScintilla
 from Globals import (  # __IGNORE_WARNING__
     isWindowsPlatform, isLinuxPlatform, isMacPlatform, getConfigDir,
     setConfigDir, getPythonModulesDirectory, getPyQt5ModulesDirectory,
-    getQtBinariesPath)
+    getQtBinariesPath, getPyQtToolsPath, qVersionTuple)
 
 from E5Gui.E5Application import e5App
 
 from UI.Info import Program, Version
 
 import Preferences
-from Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck import (  # __IGNORE_WARNING__
+from Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck import (
+    # __IGNORE_WARNING__
     normalizeCode)
 
 from eric6config import getConfig
@@ -200,10 +202,9 @@ def readEncodedFileWithHash(filename):
     f = open(filename, "rb")
     text = f.read()
     f.close()
-    hash = str(QCryptographicHash.hash(
-               QByteArray(text), QCryptographicHash.Md5).toHex(),
-               encoding="ASCII")
-    return decode(text) + (hash, )
+    hashStr = str(QCryptographicHash.hash(
+        QByteArray(text), QCryptographicHash.Md5).toHex(), encoding="ASCII")
+    return decode(text) + (hashStr, )
 
 
 def decode(text):
@@ -459,16 +460,16 @@ _escape_map = {
 }
 
 
-def escape_entities(m, map=_escape_map):
+def escape_entities(m, escmap=_escape_map):
     """
     Function to encode html entities.
     
     @param m the match object
-    @param map the map of entities to encode
+    @param escmap the map of entities to encode
     @return the converted text (string)
     """
     char = m.group()
-    text = map.get(char)
+    text = escmap.get(char)
     if text is None:
         text = "&#{0:d};".format(ord(char))
     return text
@@ -526,8 +527,8 @@ def unescape_uentities(m):
     @return the converted text (string)
     """
     char = m.group()
-    ord = int(char[2:-1])
-    return chr(ord)
+    ordinal = int(char[2:-1])
+    return chr(ordinal)
 
 
 def html_udecode(text, pattern=_uunescape):
@@ -631,7 +632,11 @@ def extractFlags(text):
             flags[key] = value
         else:
             # treat it as a boolean
-            flags[flag] = True
+            if flag[0] == "-":
+                # false flags start with '-'
+                flags[flag[1:]] = False
+            else:
+                flags[flag] = True
     
     return flags
 
@@ -651,7 +656,7 @@ def extractFlagsFromFile(filename):
     return extractFlags(source)
 
 
-def extractLineFlags(line, startComment="#", endComment=""):
+def extractLineFlags(line, startComment="#", endComment="", flagsLine=False):
     """
     Function to extract flags starting and ending with '__' from a line
     comment.
@@ -659,20 +664,47 @@ def extractLineFlags(line, startComment="#", endComment=""):
     @param line line to extract flags from (string)
     @keyparam startComment string identifying the start of the comment (string)
     @keyparam endComment string identifying the end of a comment (string)
+    @keyparam flagsLine flag indicating to check for a flags only line (bool)
     @return list containing the extracted flags (list of strings)
     """
     flags = []
     
-    pos = line.rfind(startComment)
-    if pos >= 0:
-        comment = line[pos + len(startComment):].strip()
-        if endComment:
-            comment = comment.replace("endComment", "")
-        flags = [f.strip() for f in comment.split()
-                 if (f.startswith("__") and f.endswith("__"))]
+    if not flagsLine or (
+       flagsLine and line.strip().startswith(startComment)):
+        pos = line.rfind(startComment)
+        if pos >= 0:
+            comment = line[pos + len(startComment):].strip()
+            if endComment:
+                endPos = line.rfind(endComment)
+                if endPos >= 0:
+                    comment = comment[:endPos]
+            flags = [f.strip() for f in comment.split()
+                     if (f.startswith("__") and f.endswith("__"))]
     return flags
 
 
+def filterAnsiSequences(txt):
+    """
+    Function to filter out ANSI escape sequences (color only).
+    
+    @param txt text to be filtered
+    @type str
+    @return text without ANSI escape sequences
+    @rtype str
+    """
+    ntxt = txt[:]
+    while True:
+        start = ntxt.find("\33[")    # find escape character
+        if start == -1:
+            break
+        end = ntxt.find("m", start)
+        if end == -1:
+            break
+        ntxt = ntxt[:start] + ntxt[end + 1:]
+    
+    return ntxt
+
+
 def toNativeSeparators(path):
     """
     Function returning a path, that is using native separator characters.
@@ -793,8 +825,8 @@ def isinpath(file):
         return False
     
     dirs = path.split(os.pathsep)
-    for dir in dirs:
-        if os.access(os.path.join(dir, file), os.X_OK):
+    for directory in dirs:
+        if os.access(os.path.join(directory, file), os.X_OK):
             return True
     
     return False
@@ -834,7 +866,10 @@ def relativePath(path, start):
         if path == start:
             return ""
         else:
-            return path[len(start) + 1:]
+            if start.endswith(("/", "\\")):
+                return path[len(start):]
+            else:
+                return path[len(start) + 1:]
     else:
         return path
 
@@ -907,8 +942,8 @@ def getExecutablePath(file):
         return ""
         
     dirs = path.split(os.pathsep)
-    for dir in dirs:
-        exe = os.path.join(dir, file)
+    for directory in dirs:
+        exe = os.path.join(directory, file)
         if os.access(exe, os.X_OK):
             return exe
             
@@ -942,14 +977,58 @@ def getExecutablePaths(file):
     # environment variable not defined
     if path is not None:
         dirs = path.split(os.pathsep)
-        for dir in dirs:
-            exe = os.path.join(dir, file)
+        for directory in dirs:
+            exe = os.path.join(directory, file)
             if os.access(exe, os.X_OK) and exe not in paths:
                 paths.append(exe)
     
     return paths
     
 
+def getWindowsExecutablePath(file):
+    """
+    Function to build the full path of an executable file from the environment
+    on Windows platforms.
+    
+    First an executable with the extension .exe is searched for, thereafter one
+    with the extension .bat and finally the given file name as is. The first
+    match is returned.
+    
+    @param file filename of the executable to check (string)
+    @return full executable name, if the executable file is accessible
+        via the searchpath defined by the PATH environment variable, or an
+        empty string otherwise.
+    """
+    if os.path.isabs(file):
+        if os.access(file, os.X_OK):
+            return file
+        else:
+            return ""
+    
+    filenames = [file + ".exe", file + ".bat", file]
+    
+    for filename in filenames:
+        cur_path = os.path.join(os.curdir, filename)
+        if os.path.exists(cur_path):
+            if os.access(cur_path, os.X_OK):
+                return os.path.abspath(cur_path)
+
+    path = os.getenv('PATH')
+    
+    # environment variable not defined
+    if path is None:
+        return ""
+        
+    dirs = path.split(os.pathsep)
+    for directory in dirs:
+        for filename in filenames:
+            exe = os.path.join(directory, filename)
+            if os.access(exe, os.X_OK):
+                return exe
+    
+    return ""
+    
+
 def isExecutable(exe):
     """
     Function to check, if a file is executable.
@@ -958,6 +1037,24 @@ def isExecutable(exe):
     @return flag indicating executable status (boolean)
     """
     return os.access(exe, os.X_OK)
+
+
+def isDrive(path):
+    """
+    Function to check, if a path is a Windows drive.
+    
+    @param path path name to be checked
+    @type str
+    @return flag indicating a Windows drive
+    @rtype bool
+    """
+    isDrive = False
+    drive, directory = os.path.splitdrive(path)
+    if drive and len(drive) == 2 and drive.endswith(":") and \
+       directory in ["", "\\", "/"]:
+        isDrive = True
+    
+    return isDrive
     
 
 def samepath(f1, f2):
@@ -1341,8 +1438,12 @@ def getUserName():
     """
     user = getpass.getuser()
     
-    if not user and isWindowsPlatform():
-        return win32_GetUserName()
+    if isWindowsPlatform():
+        if not user:
+            return win32_GetUserName()
+        else:
+            if sys.version_info[0] == 2:
+                user = user.decode(locale.getpreferredencoding())
     
     return user
 
@@ -1427,6 +1528,8 @@ def determinePythonVersion(filename, source, editor=None):
 
     pyVer = 0
     if filename:
+        if not source:
+            source = readEncodedFile(filename)[0]
         flags = extractFlags(source)
         ext = os.path.splitext(filename)[1]
         py2Ext = Preferences.getPython("PythonExtensions")
@@ -1490,12 +1593,12 @@ def getEnvironmentEntry(key, default=None):
     @return the requested entry or the default value, if the entry wasn't
         found (string or None)
     """
-    filter = QRegExp("^{0}[ \t]*=".format(key))
+    filterRe = QRegExp("^{0}[ \t]*=".format(key))
     if isWindowsPlatform():
-        filter.setCaseSensitivity(Qt.CaseInsensitive)
+        filterRe.setCaseSensitivity(Qt.CaseInsensitive)
     
     entries = [e for e in QProcess.systemEnvironment()
-               if filter.indexIn(e) != -1]
+               if filterRe.indexIn(e) != -1]
     if not entries:
         return default
     
@@ -1511,12 +1614,12 @@ def hasEnvironmentEntry(key):
     @param key key of the requested environment entry (string)
     @return flag indicating the presence of the requested entry (boolean)
     """
-    filter = QRegExp("^{0}[ \t]*=".format(key))
+    filterRe = QRegExp("^{0}[ \t]*=".format(key))
     if isWindowsPlatform():
-        filter.setCaseSensitivity(Qt.CaseInsensitive)
+        filterRe.setCaseSensitivity(Qt.CaseInsensitive)
     
     entries = [e for e in QProcess.systemEnvironment()
-               if filter.indexIn(e) != -1]
+               if filterRe.indexIn(e) != -1]
     return len(entries) > 0
 
 ###############################################################################
@@ -1586,7 +1689,42 @@ def prepareQtMacBundle(toolname, version, args):
     return ("open", newArgs)
 
 ###############################################################################
-# Qt utility functions below
+# PyQt utility functions below
+###############################################################################
+
+
+def generatePyQtToolPath(toolname, alternatives=None):
+    """
+    Module function to generate the executable path for a PyQt tool.
+    
+    @param toolname base name of the tool
+    @type str
+    @param alternatives list of alternative tool names to try
+    @type list of str
+    @return executable path name of the tool
+    @rtype str
+    """
+    pyqtVariant = int(toolname[-1])
+    pyqtToolsPath = getPyQtToolsPath(pyqtVariant)
+    if pyqtToolsPath:
+        exe = os.path.join(pyqtToolsPath, toolname)
+        if isWindowsPlatform():
+            exe += ".exe"
+    else:
+        if isWindowsPlatform():
+            exe = getWindowsExecutablePath(toolname)
+        else:
+            exe = toolname
+    
+    if not isinpath(exe) and alternatives:
+        ex_ = generatePyQtToolPath(alternatives[0], alternatives[1:])
+        if isinpath(ex_):
+            exe = ex_
+    
+    return exe
+
+###############################################################################
+# PySide utility functions below
 ###############################################################################
 
 
@@ -1594,23 +1732,22 @@ def generatePySideToolPath(toolname):
     """
     Module function to generate the executable path for a PySide tool.
     
-    @param toolname base name of the tool (string or QString)
+    @param toolname base name of the tool (string)
     @return the PySide tool path with extension (string)
     """
     if isWindowsPlatform():
-        try:
-            # step 1: try internal Python variant of PySide
-            import PySide       # __IGNORE_EXCEPTION__
-            del PySide
-            prefix = sys.prefix
-        except ImportError:
-            # step 2: check for a external Python variant
-            if sys.version_info[0] == 2:
-                prefix = os.path.dirname(
-                    Preferences.getDebugger("Python3Interpreter"))
-            else:
-                prefix = os.path.dirname(
-                    Preferences.getDebugger("PythonInterpreter"))
+        pysideInterpreter = checkPyside()
+        interpreter = sys.version_info[0] - 2
+        hasPyside = pysideInterpreter[interpreter]
+        # if it isn't the internal interpreter, it has to be the external one
+        if not hasPyside:
+            interpreter = not interpreter
+        if interpreter:
+            prefix = os.path.dirname(
+                Preferences.getDebugger("Python3Interpreter"))
+        else:
+            prefix = os.path.dirname(
+                Preferences.getDebugger("PythonInterpreter"))
         if toolname == "pyside-uic":
             return os.path.join(prefix, "Scripts", toolname + '.exe')
         else:
@@ -1624,41 +1761,29 @@ def checkPyside():
     """
     Module function to check the presence of PySide.
     
-    @return tuple of two flags indicating the presence of PySide for Python2
+    @return list of two flags indicating the presence of PySide for Python2
         and PySide for Python3 (boolean, boolean)
     """
-    try:
-        # step 1: try internal Python variant of PySide
-        import PySide       # __IGNORE_EXCEPTION__
-        del PySide
-        int_py = True
-    except ImportError:
-        int_py = False
+    pysideInformation = []
+    for interpreterName in ["PythonInterpreter", "Python3Interpreter"]:
+        interpreter = Preferences.getDebugger(interpreterName)
+        if interpreter == "" or not isinpath(interpreter):
+            hasPyside = False
+        else:
+            hasPyside = False
+            checker = os.path.join(getConfig('ericDir'),
+                                   "Utilities", "PySideImporter.py")
+            args = [checker]
+            proc = QProcess()
+            proc.setProcessChannelMode(QProcess.MergedChannels)
+            proc.start(interpreter, args)
+            finished = proc.waitForFinished(30000)
+            if finished:
+                if proc.exitCode() == 0:
+                    hasPyside = True
+        pysideInformation.append(hasPyside)
     
-    # step 2: check for a external Python variant
-    if sys.version_info[0] == 2:
-        interpreter = Preferences.getDebugger("Python3Interpreter")
-    else:
-        interpreter = Preferences.getDebugger("PythonInterpreter")
-    if interpreter == "" or not isinpath(interpreter):
-        ext_py = False
-    else:
-        ext_py = False
-        checker = os.path.join(getConfig('ericDir'),
-                               "Utilities", "PySideImporter.py")
-        args = [checker]
-        proc = QProcess()
-        proc.setProcessChannelMode(QProcess.MergedChannels)
-        proc.start(interpreter, args)
-        finished = proc.waitForFinished(30000)
-        if finished:
-            if proc.exitCode() == 0:
-                ext_py = True
-    
-    if sys.version_info[0] == 2:
-        return int_py, ext_py
-    else:
-        return ext_py, int_py
+    return pysideInformation
 
 ###############################################################################
 # Other utility functions below
@@ -1684,6 +1809,14 @@ def generateVersionInfo(linesep='\n'):
         qVersion(), linesep, PYQT_VERSION_STR, linesep)
     info += "  sip {0}{1}  QScintilla {2}{3}".format(
         sip_version_str, linesep, QSCINTILLA_VERSION_STR, linesep)
+    if qVersionTuple() >= (5, 6, 0):
+        try:
+            from PyQt5 import QtWebEngineWidgets    # __IGNORE_WARNING__
+            from WebBrowser.Tools import WebBrowserTools
+            chromeVersion = WebBrowserTools.getWebEngineVersions()[0]
+            info += "  WebEngine {0}{1}".format(chromeVersion, linesep)
+        except ImportError:
+            pass
     try:
         from PyQt5.QtWebKit import qWebKitVersion
         info += "  WebKit {0}{1}".format(qWebKitVersion(), linesep)
