@@ -11,9 +11,11 @@ from __future__ import unicode_literals
 
 import re
 
-from PyQt5.QtCore import qVersion, Qt, QRegExp
+from PyQt5.QtCore import PYQT_VERSION, Qt, QRegExp
 from PyQt5.QtWebEngineCore import QWebEngineUrlRequestInfo
 
+from Globals import qVersionTuple
+
 
 def toSecondLevelDomain(url):
     """
@@ -42,11 +44,11 @@ class AdBlockRule(object):
     """
     Class implementing the AdBlock rule.
     """
-    def __init__(self, filter="", subscription=None):
+    def __init__(self, filterRule="", subscription=None):
         """
         Constructor
         
-        @param filter filter string of the rule (string)
+        @param filterRule filter string of the rule (string)
         @param subscription reference to the subscription object
             (AdBlockSubscription)
         """
@@ -86,7 +88,7 @@ class AdBlockRule(object):
         self.__objectSubrequestException = False
         self.__stringMatchRule = False
         
-        self.setFilter(filter)
+        self.setFilter(filterRule)
     
     def subscription(self):
         """
@@ -104,13 +106,13 @@ class AdBlockRule(object):
         """
         return self.__filter
     
-    def setFilter(self, filter):
+    def setFilter(self, filterRule):
         """
         Public method to set the rule filter string.
         
-        @param filter rule filter string (string)
+        @param filterRule rule filter string (string)
         """
-        self.__filter = filter
+        self.__filter = filterRule
         self.__parseFilter()
     
     def __parseFilter(self):
@@ -532,7 +534,7 @@ class AdBlockRule(object):
         match = (
             req.resourceType() ==
             QWebEngineUrlRequestInfo.ResourceTypeSubResource)
-        if qVersion() >= "5.7.0":
+        if qVersionTuple() >= (5, 7, 0) and PYQT_VERSION >= 0x50700:
             match = match or (
                 req.resourceType() ==
                 QWebEngineUrlRequestInfo.ResourceTypePluginResource)
