@@ -16,9 +16,9 @@ except NameError:
 
 import os
 
-from PyQt5.QtCore import pyqtSignal, QUrl, QFileInfo, Qt, QTimer, QEvent, \
-    QPoint, QPointF, QDateTime, QStandardPaths, QByteArray, QIODevice, \
-    QDataStream
+from PyQt5.QtCore import pyqtSignal, PYQT_VERSION, Qt, QUrl, QFileInfo, \
+    QTimer, QEvent, QPoint, QPointF, QDateTime, QStandardPaths, QByteArray, \
+    QIODevice, QDataStream
 from PyQt5.QtGui import QDesktopServices, QClipboard, QIcon, \
     QContextMenuEvent, QPixmap
 from PyQt5.QtWidgets import qApp, QStyle, QMenu, QApplication
@@ -53,6 +53,10 @@ class WebBrowserView(QWebEngineView):
     @signal search(QUrl) emitted, when a search is requested
     @signal zoomValueChanged(int) emitted to signal a change of the zoom value
     @signal faviconChanged() emitted to signal a changed web site icon
+    @signal safeBrowsingAbort() emitted to indicate an abort due to a safe
+        browsing event
+    @signal safeBrowsingBad(threatType, threatMessages) emitted to indicate a
+        malicious web site as determined by safe browsing
     """
     sourceChanged = pyqtSignal(QUrl)
     forwardAvailable = pyqtSignal(bool)
@@ -61,6 +65,8 @@ class WebBrowserView(QWebEngineView):
     search = pyqtSignal(QUrl)
     zoomValueChanged = pyqtSignal(int)
     faviconChanged = pyqtSignal()
+    safeBrowsingAbort = pyqtSignal()
+    safeBrowsingBad = pyqtSignal(str, str)
     
     ZoomLevels = [
         30, 40, 50, 67, 80, 90,
@@ -85,8 +91,8 @@ class WebBrowserView(QWebEngineView):
         
         self.__speedDial = WebBrowserWindow.speedDial()
         
-        self.__page = WebBrowserPage(self)
-        self.setPage(self.__page)
+        self.__page = None
+        self.__createNewPage()
         
         self.__mw = mainWindow
         self.__isLoading = False
@@ -137,6 +143,16 @@ class WebBrowserView(QWebEngineView):
         
         self.grabGesture(Qt.PinchGesture)
     
+    def __createNewPage(self):
+        """
+        Private method to create a new page object.
+        """
+        self.__page = WebBrowserPage(self)
+        self.setPage(self.__page)
+        
+        self.__page.safeBrowsingAbort.connect(self.safeBrowsingAbort)
+        self.__page.safeBrowsingBad.connect(self.safeBrowsingBad)
+    
     def __setRwhvqt(self):
         """
         Private slot to set widget that receives input events.
@@ -346,9 +362,10 @@ class WebBrowserView(QWebEngineView):
         """
         Public slot to clear the current selection.
         """
-        if qVersionTuple() >= (5, 7, 0):
+        try:
             self.triggerPageAction(QWebEnginePage.Unselect)
-        else:
+        except AttributeError:
+            # prior to 5.7.0
             self.page().runJavaScript(
                 "window.getSelection().empty()",
                 WebBrowserPage.SafeJsWorld)
@@ -529,11 +546,11 @@ class WebBrowserView(QWebEngineView):
         @type WebHitTestResult
         """
         spellCheckActionCount = 0
-        if qVersionTuple() >= (5, 7, 0):
+        if qVersionTuple() >= (5, 7, 0) and PYQT_VERSION >= 0x50700:
             contextMenuData = self.page().contextMenuData()
             hitTest.updateWithContextMenuData(contextMenuData)
             
-            if qVersionTuple() >= (5, 8, 0) and \
+            if qVersionTuple() >= (5, 8, 0) and PYQT_VERSION >= 0x50800 and \
                bool(contextMenuData.misspelledWord()):
                 boldFont = menu.font()
                 boldFont.setBold(True)
@@ -544,7 +561,7 @@ class WebBrowserView(QWebEngineView):
                         self.__replaceMisspelledWord)
                     act.setFont(boldFont)
                 
-                if bool(menu.actions()):
+                if not bool(menu.actions()):
                     menu.addAction(self.tr("No suggestions")).setEnabled(False)
                 
                 menu.addSeparator()
@@ -785,7 +802,7 @@ class WebBrowserView(QWebEngineView):
             language = languages[0]
             langCode = language.split("[")[1][:2]
             googleTranslatorUrl = QUrl(
-                "http://translate.google.com/#auto|{0}|{1}".format(
+                "http://translate.google.com/#auto/{0}/{1}".format(
                     langCode, self.selectedText()))
             menu.addAction(
                 UI.PixmapCache.getIcon("translate.png"),
@@ -1579,8 +1596,7 @@ class WebBrowserView(QWebEngineView):
         @type QWebEnginePage.RenderProcessTerminationStatus
         """
         self.page().deleteLater()
-        self.__page = WebBrowserPage(self)
-        self.setPage(self.__page)
+        self.__createNewPage()
         
         html = readAllFileContents(":/html/tabCrashPage.html")
         html = html.replace("@IMAGE@", pixmapToDataUrl(
@@ -1708,7 +1724,7 @@ class WebBrowserView(QWebEngineView):
         if url.isEmpty():
             return
         
-        if qVersionTuple() >= (5, 8, 0):
+        if qVersionTuple() >= (5, 8, 0) and PYQT_VERSION >= 0x50800:
             # since Qt 5.8.0
             fileName, savePageFormat = self.__getSavePageFileNameAndFormat()
             if fileName:
@@ -2049,3 +2065,19 @@ class WebBrowserView(QWebEngineView):
                 QUrl.fromUserInput(urlStr))
         
         return title, urlStr, icon
+    
+    ###########################################################################
+    ## Methods below implement safe browsing related functions
+    ###########################################################################
+    
+    def getSafeBrowsingStatus(self):
+        """
+        Public method to get the safe browsing status of the current page.
+        
+        @return flag indicating a safe site
+        @rtype bool
+        """
+        if self.__page:
+            return self.__page.getSafeBrowsingStatus()
+        else:
+            return True
