@@ -27,11 +27,9 @@ try:  # Only for Py2
     import Globals.compatibility_fixes     # __IGNORE_WARNING__
     import StringIO as io   # __IGNORE_EXCEPTION__
     import locale
-    coverage = 'Python'
 except ImportError:
     import io       # __IGNORE_WARNING__
     basestring = str
-    coverage = 'Python3'
 
 try:
     import sip
@@ -97,7 +95,7 @@ sys.path.insert(2, os.path.join(os.path.dirname(__file__),
 sys.path.insert(2, os.path.join(os.path.dirname(__file__),
                                 "ThirdParty", "Jasy"))
 sys.path.insert(2, os.path.join(os.path.dirname(__file__),
-                                "DebugClients", coverage))
+                                "DebugClients", "Python"))
 
 from E5Gui.E5Application import E5Application
 
@@ -133,7 +131,8 @@ def handleSingleApplication(ddindex):
             client.processArgs(sys.argv[1:])
         sys.exit(0)
     elif res < 0:
-        print("eric6: {0}".format(client.errstr()))     # __IGNORE_WARNING__
+        print("eric6: {0}".format(client.errstr()))
+        # __IGNORE_WARNING_M801__
         sys.exit(res)
 
 
@@ -145,7 +144,6 @@ def excepthook(excType, excValue, tracebackobj):
     @param excValue exception value
     @param tracebackobj traceback object
     """
-    import xml.sax.saxutils
     from UI.Info import BugAddress
     import Utilities
     import Globals
@@ -194,11 +192,14 @@ def excepthook(excType, excValue, tracebackobj):
             msg = msg.encode(sys.stdout.encoding, 'replace')
             versionInfo = versionInfo.encode(sys.stdout.encoding, 'replace')
         warning = notice + msg + versionInfo
-        print(warning)                          # __IGNORE_WARNING__
+        print(warning)                          # __IGNORE_WARNING_M801__
     else:
         warning = notice + msg + versionInfo
         # Escape &<> otherwise it's not visible in the error dialog
-        warning = xml.sax.saxutils.escape(warning)
+        warning = warning\
+            .replace("&", "&amp;")\
+            .replace(">", "&gt;")\
+            .replace("<", "&lt;")
         if sys.version_info[0] == 2:
             warning = warning.encode('utf-8', 'replace')
         qWarning(warning)
@@ -310,7 +311,7 @@ def main():
     pluginFile = None
     noopen = False
     nocrash = False
-    disablecrash=False
+    disablecrash = False
     if "--no-open" in sys.argv and sys.argv.index("--no-open") < ddindex:
         del sys.argv[sys.argv.index("--no-open")]
         noopen = True
