@@ -54,7 +54,9 @@ def createMainWidget(argv):
     from UI.CompareDialog import CompareWindow
     if len(argv) >= 6:
         # assume last two entries are the files to compare
-        return CompareWindow([(argv[-5], argv[-2]), (argv[-3], argv[-1])])
+        file1 = (argv[-4], argv[-2])
+        file2 = (argv[-3], argv[-1])
+        return CompareWindow([file1, file2])
     elif len(argv) >= 2:
         return CompareWindow([("", argv[-2]), ("", argv[-1])])
     else:
