@@ -269,7 +269,6 @@ def main():
             qtHelpTitle == ""):
         usage()
     
-    input = output = 0
     basename = ""
 
     if outputDir:
@@ -385,8 +384,6 @@ def main():
                     sys.stderr.write("{0} error: {1}\n".format(file, v))
                     continue
                 
-                input = input + 1
-                
                 f = Utilities.joinext(os.path.join(
                     outputDir, moduleDocument.name()), ".html")
                 
@@ -410,8 +407,7 @@ def main():
                     sys.stderr.write("{0} error: {1}\n".format(file, v[1]))
                 else:
                     sys.stdout.write("{0} ok\n".format(f))
-                
-                output = output + 1
+    
     sys.stdout.flush()
     sys.stderr.flush()
 
