@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002-2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric6.
 
@@ -9,8 +9,7 @@
 Installation script for the eric6 IDE and all eric6 related tools.
 """
 
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import unicode_literals, print_function
 try:
     import cStringIO as io
     import sip
@@ -31,6 +30,7 @@ import fnmatch
 import distutils.sysconfig
 import codecs
 import subprocess
+import time
 
 # Define the globals.
 progName = None
@@ -38,6 +38,7 @@ currDir = os.getcwd()
 modDir = None
 pyModDir = None
 platBinDir = None
+platBinDirOld = None
 distDir = None
 apisDir = None
 installApis = True
@@ -174,7 +175,10 @@ def usage(rcode=2):
     print("    -y         add the Python variant to the executable names")
     print("    -z         don't compile the installed python files")
     print("    --pyqt=version version of PyQt to be used (one of 4 or 5)")
-    print("                   (default: {0})".format(pyqtVariant[-1]))
+    if pyqtVariant:
+        print("                   (default: {0})".format(pyqtVariant[-1]))
+    else:
+        print("                   (no PyQt variant found)")
     print()
     print("The file given to the -f option must be valid Python code"
           " defining a")
@@ -223,12 +227,16 @@ def initGlobals():
     Module function to set the values of globals that need more than a
     simple assignment.
     """
-    global platBinDir, modDir, pyModDir, apisDir, pyqtVariant
+    global platBinDir, modDir, pyModDir, apisDir, pyqtVariant, platBinDirOld
 
     if sys.platform.startswith("win"):
         platBinDir = sys.exec_prefix
         if platBinDir.endswith("\\"):
             platBinDir = platBinDir[:-1]
+        platBinDirOld = platBinDir
+        platBinDir = os.path.join(platBinDir, "Scripts")
+        if not os.path.exists(platBinDir):
+            platBinDir = platBinDirOld
     else:
         platBinDir = "/usr/local/bin"
 
@@ -299,6 +307,43 @@ def copyDesktopFile(src, dst, marker):
     os.chmod(dst, 0o644)
 
 
+def copyAppStreamFile(src, dst, marker):
+    """
+    Modify an appstream file and write it to its destination.
+    
+    @param src source file name (string)
+    @param dst destination file name (string)
+    @param marker marker to be used (string)
+    """
+    if os.path.exists(os.path.join("eric", "UI", "Info.py")):
+        # Installing from archive
+        from eric.UI.Info import Version
+    elif os.path.exists(os.path.join("UI", "Info.py")):
+        # Installing from source tree
+        from UI.Info import Version
+    else:
+        Version = "Unknown"
+    
+    if sys.version_info[0] == 2:
+        f = codecs.open(src, "r", "utf-8")
+    else:
+        f = open(src, "r", encoding="utf-8")
+    text = f.read()
+    f.close()
+    
+    text = text.replace("@MARKER@", marker)\
+        .replace("@VERSION@", Version.split(None, 1)[0])\
+        .replace("@DATE@", time.strftime("%Y-%m-%d"))
+    
+    if sys.version_info[0] == 2:
+        f = codecs.open(dst, "w", "utf-8")
+    else:
+        f = open(dst, "w", encoding="utf-8")
+    f.write(text)
+    f.close()
+    os.chmod(dst, 0o644)
+
+
 def wrapperName(dname, wfile):
     """
     Create the platform specific name for the wrapper script.
@@ -380,7 +425,7 @@ def createPyWrapper(pydir, wfile, isGuiScript=True):
     return wname
 
 
-def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
+def copyTree(src, dst, filters, excludeDirs=None, excludePatterns=None):
     """
     Copy Python, translation, documentation, wizards configuration,
     designer template files and DTDs of a directory tree.
@@ -392,6 +437,10 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
     @keyparam excludePatterns list of filter pattern determining the files to
         be skipped
     """
+    if excludeDirs is None:
+        excludeDirs = []
+    if excludePatterns is None:
+        excludePatterns = []
     try:
         names = os.listdir(src)
     except OSError:
@@ -407,8 +456,8 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
         if not skipIt:
             srcname = os.path.join(src, name)
             dstname = os.path.join(dst, name)
-            for filter in filters:
-                if fnmatch.fnmatch(srcname, filter):
+            for fileFilter in filters:
+                if fnmatch.fnmatch(srcname, fileFilter):
                     if not os.path.isdir(dst):
                         os.makedirs(dst)
                     shutil.copy2(srcname, dstname)
@@ -433,7 +482,7 @@ def createGlobalPluginsDir():
             os.mkdir(pdir, 0o755)
         f = open(fname, "w")
         f.write(
-'''# -*- coding: utf-8 -*-
+            '''# -*- coding: utf-8 -*-
 
 """
 Package containing the global plugins.
@@ -462,10 +511,11 @@ def cleanupSource(dirName):
             if os.path.exists(os.path.join(dirName, sourceName + "c")):
                 os.remove(os.path.join(dirName, sourceName + "c"))
     
-    # step 2: delete the __pycache__ directory and all *.pyc files
+    # step 2: delete the __pycache__ directory and all remaining *.pyc files
     if os.path.exists(os.path.join(dirName, "__pycache__")):
         shutil.rmtree(os.path.join(dirName, "__pycache__"))
-    for name in [f for f in dirListing if fnmatch.fnmatch(f, "*.pyc")]:
+    for name in [f for f in os.listdir(dirName)
+                 if fnmatch.fnmatch(f, "*.pyc")]:
         os.remove(os.path.join(dirName, name))
     
     # step 3: descent into subdirectories and delete them if empty
@@ -481,7 +531,7 @@ def cleanUp():
     """
     Uninstall the old eric files.
     """
-    global platBinDir, includePythonVariant
+    global platBinDir, platBinDirOld, includePythonVariant
     
     try:
         from eric6config import getConfig
@@ -503,8 +553,12 @@ def cleanUp():
             marker = ""
         for name in ["/usr/share/applications/eric6" + marker + ".desktop",
                      "/usr/share/appdata/eric6" + marker + ".appdata.xml",
+                     "/usr/share/metainfo/eric6" + marker + ".appdata.xml",
                      "/usr/share/applications/eric6_webbrowser" + marker +
-                     ".desktop"]:
+                     ".desktop",
+                     "/usr/share/applications/eric6_browser" + marker +
+                     ".desktop",
+                     ]:
             if os.path.exists(name):
                 os.remove(name)
     
@@ -520,15 +574,19 @@ def cleanUp():
         "eric6_plugininstall", "eric6_pluginuninstall",
         "eric6_pluginrepository", "eric6_sqlbrowser",
         "eric6_webbrowser", "eric6_iconeditor",
-        "eric6_snap",
+        "eric6_snap", "eric6_hexeditor", "eric6_browser",
+        "eric6_shell",
     ]
     if includePythonVariant:
         marker = PythonMarkers[sys.version_info.major]
         rem_wnames = [n + marker for n in rem_wnames]
     
     try:
+        dirs = [platBinDir, getConfig('bindir')]
+        if platBinDirOld:
+            dirs.append(platBinDirOld)
         for rem_wname in rem_wnames:
-            for d in [platBinDir, getConfig('bindir')]:
+            for d in dirs:
                 rwname = wrapperName(d, rem_wname)
                 if os.path.exists(rwname):
                     os.remove(rwname)
@@ -621,12 +679,13 @@ def installEric():
     for name in ["eric6_api", "eric6_doc"]:
         wnames.append(createPyWrapper(cfg['ericDir'], name, False))
     for name in ["eric6_compare", "eric6_configure", "eric6_diff",
-                 "eric6_editor", "eric6_iconeditor", "eric6_plugininstall",
-                 "eric6_pluginrepository", "eric6_pluginuninstall",
-                 "eric6_qregexp", "eric6_qregularexpression", "eric6_re",
-                 "eric6_snap", "eric6_sqlbrowser", "eric6_tray",
-                 "eric6_trpreviewer", "eric6_uipreviewer", "eric6_unittest",
-                 "eric6_webbrowser", "eric6"]:
+                 "eric6_editor", "eric6_hexeditor", "eric6_iconeditor",
+                 "eric6_plugininstall", "eric6_pluginrepository",
+                 "eric6_pluginuninstall", "eric6_qregexp",
+                 "eric6_qregularexpression", "eric6_re", "eric6_snap",
+                 "eric6_sqlbrowser", "eric6_tray", "eric6_trpreviewer",
+                 "eric6_uipreviewer", "eric6_unittest", "eric6_webbrowser",
+                 "eric6_browser", "eric6_shell", "eric6"]:
         wnames.append(createPyWrapper(cfg['ericDir'], name))
     
     # set install prefix, if not None
@@ -727,7 +786,7 @@ def installEric():
         try:
             shutilCopy(name, cfg['ericDocDir'])
         except EnvironmentError:
-            print("Could not install '{1}'.".format(name))
+            print("Could not install '{0}'.".format(name))
    
     # copy some more stuff
     for name in ['default.e4k', 'default_Mac.e4k']:
@@ -803,11 +862,15 @@ def installEric():
                 os.path.join(sourceDir, "eric6_webbrowser.desktop"),
                 os.path.join(dst, "eric6_webbrowser" + marker + ".desktop"),
                 marker)
+            copyDesktopFile(
+                os.path.join(sourceDir, "eric6_browser.desktop"),
+                os.path.join(dst, "eric6_browser" + marker + ".desktop"),
+                marker)
             dst = os.path.normpath(
-                os.path.join(distDir, "usr/share/appdata"))
+                os.path.join(distDir, "usr/share/metainfo"))
             if not os.path.exists(dst):
                 os.makedirs(dst)
-            copyDesktopFile(
+            copyAppStreamFile(
                 os.path.join(sourceDir, "eric6.appdata.xml"),
                 os.path.join(dst, "eric6" + marker + ".appdata.xml"),
                 marker)
@@ -819,8 +882,13 @@ def installEric():
                 os.path.join(sourceDir, "eric6.desktop"),
                 "/usr/share/applications/eric6" + marker + ".desktop",
                 marker)
-            if os.path.exists("/usr/share/appdata"):
-                copyDesktopFile(
+            if os.path.exists("/usr/share/metainfo"):
+                copyAppStreamFile(
+                    os.path.join(sourceDir, "eric6.appdata.xml"),
+                    "/usr/share/metainfo/eric6" + marker + ".appdata.xml",
+                    marker)
+            elif os.path.exists("/usr/share/appdata"):
+                copyAppStreamFile(
                     os.path.join(sourceDir, "eric6.appdata.xml"),
                     "/usr/share/appdata/eric6" + marker + ".appdata.xml",
                     marker)
@@ -832,6 +900,11 @@ def installEric():
                 "/usr/share/applications/eric6_webbrowser" + marker +
                 ".desktop",
                 marker)
+            copyDesktopFile(
+                os.path.join(sourceDir, "eric6_browser.desktop"),
+                "/usr/share/applications/eric6_browser" + marker +
+                ".desktop",
+                marker)
     
     # Create a Mac application bundle
     if sys.platform == "darwin":
@@ -847,7 +920,8 @@ def createMacAppBundle(pydir):
     @param pydir the name of the directory where the Python script will
         eventually be installed (string)
     """
-    global cfg, sourceDir, macAppBundleName, macPythonExe, macAppBundlePath
+    global cfg, sourceDir, macAppBundleName, macPythonExe, macAppBundlePath, \
+        pyqtVariant
     
     dirs = {
         "contents": "{0}/{1}/Contents/".format(
@@ -868,23 +942,39 @@ def createMacAppBundle(pydir):
         starter = "python{0}".format(sys.version_info.major)
     
     wname = os.path.join(dirs["exe"], "eric6")
+    
+    # determine entry for DYLD_FRAMEWORK_PATH
+    dyldLine = ""
+    try:
+        if pyqtVariant == "PyQt4":
+            from PyQt4.QtCore import QLibraryInfo
+        else:
+            from PyQt5.QtCore import QLibraryInfo
+        qtLibraryDir = QLibraryInfo.location(QLibraryInfo.LibrariesPath)
+    except ImportError:
+        qtLibraryDir = ""
+    if qtLibraryDir:
+        dyldLine = "DYLD_FRAMEWORK_PATH={0}\n".format(qtLibraryDir)
+    
+    # determine entry for PATH
+    pathLine = ""
     path = os.getenv("PATH", "")
     if path:
         pybin = os.path.join(sys.exec_prefix, "bin")
         pathlist = path.split(os.pathsep)
-        if pybin not in pathlist:
-            pathlist.insert(0, pybin)
-        path = os.pathsep.join(pathlist)
-        wrapper = ('''#!/bin/sh\n'''
-                   '''\n'''
-                   '''PATH={0}\n'''
-                   '''exec "{1}" "{2}/{3}.py" "$@"\n'''
-                   .format(path, starter, pydir, "eric6"))
-    else:
-        wrapper = ('''#!/bin/sh\n'''
-                   '''\n'''
-                   '''exec "{0}" "{1}/{2}.py" "$@"\n'''
-                   .format(starter, pydir, "eric6"))
+        pathlist_n = [pybin]
+        for path_ in pathlist:
+            if path_ and path_ not in pathlist_n:
+                pathlist_n.append(path_)
+        pathLine = "PATH={0}\n".format(os.pathsep.join(pathlist_n))
+    
+    # create the wrapper script
+    wrapper = ('''#!/bin/sh\n'''
+               '''\n'''
+               '''{0}'''
+               '''{1}'''
+               '''exec "{2}" "{3}/{4}.py" "$@"\n'''
+               .format(pathLine, dyldLine, starter, pydir, "eric6"))
     copyToFile(wname, wrapper)
     os.chmod(wname, 0o755)
     
@@ -962,13 +1052,13 @@ def createConfig():
     apis = []
     if installApis:
         for progLanguage in progLanguages:
-            for apiName in glob.glob(
-                    os.path.join(sourceDir, "APIs", progLanguage, "*.api")):
+            for apiName in sorted(glob.glob(
+                    os.path.join(sourceDir, "APIs", progLanguage, "*.api"))):
                 apis.append(os.path.basename(apiName))
             if progLanguage == "Python":
                 # treat Python3 API files the same as Python API files
-                for apiName in glob.glob(
-                        os.path.join(sourceDir, "APIs", "Python3", "*.api")):
+                for apiName in sorted(glob.glob(
+                        os.path.join(sourceDir, "APIs", "Python3", "*.api"))):
                     apis.append(os.path.basename(apiName))
     
     fn = 'eric6config.py'
@@ -1004,15 +1094,19 @@ def createConfig():
         """    '''\n"""
         """    Module function to get a configuration value.\n"""
         """\n"""
-        """    @param name name of the configuration value (string)\n"""
+        """    @param name name of the configuration value"""
+        """    @type str\n"""
+        """    @exception AttributeError raised to indicate an invalid"""
+        """ config entry\n"""
         """    '''\n"""
         """    try:\n"""
         """        return _pkg_config[name]\n"""
         """    except KeyError:\n"""
         """        pass\n"""
         """\n"""
-        """    raise AttributeError('"{{0}}" is not a valid configuration"""
-        """ value'.format(name))\n"""
+        """    raise AttributeError(\n"""
+        """        '"{{0}}" is not a valid configuration value'"""
+        """.format(name))\n"""
     ).format(
         cfg['ericDir'], cfg['ericPixDir'], cfg['ericIconDir'],
         cfg['ericDTDDir'], cfg['ericCSSDir'],
@@ -1021,7 +1115,7 @@ def createConfig():
         cfg['ericTemplatesDir'],
         cfg['ericCodeTemplatesDir'], cfg['ericOthersDir'],
         cfg['bindir'], cfg['mdir'],
-        cfg['apidir'], apis,
+        cfg['apidir'], sorted(apis),
         macAppBundlePath, macAppBundleName,
     )
     copyToFile(fn, config)
@@ -1035,12 +1129,12 @@ def doDependancyChecks():
     
     # perform dependency checks
     print("Python Version: {0:d}.{1:d}.{2:d}".format(*sys.version_info[:3]))
-    if sys.version_info < (2, 7, 0):
-        print('Sorry, you must have Python 2.7.0 or higher or '
-              'Python 3.1.0 or higher.')
+    if sys.version_info < (2, 7, 10):
+        print('Sorry, you must have Python 2.7.10 or higher or '
+              'Python 3.4.0 or higher.')
         exit(5)
-    elif sys.version_info < (3, 1, 0) and sys.version_info[0] == 3:
-        print('Sorry, you must have Python 3.1.0 or higher.')
+    elif sys.version_info < (3, 4, 0) and sys.version_info[0] == 3:
+        print('Sorry, you must have Python 3.4.0 or higher.')
         exit(5)
     if sys.version_info > (3, 9, 9):
         print('Sorry, eric6 requires Python 3 or Python 2 for running.')
@@ -1070,6 +1164,19 @@ def doDependancyChecks():
             exit(1)
         print("Found PyQt5")
     
+    try:
+        if pyqtVariant == "PyQt4":
+            pyuic = "pyuic4"
+            from PyQt4 import uic      # __IGNORE_WARNING__
+        else:
+            pyuic = "pyuic5"
+            from PyQt5 import uic      # __IGNORE_WARNING__
+    except ImportError as msg:
+        print("Sorry, {0} is not installed.".format(pyuic))
+        print('Error: {0}'.format(msg))
+        exit(1)
+    print("Found {0}".format(pyuic))
+    
     try:
         if pyqtVariant == "PyQt4":
             from PyQt4 import Qsci      # __IGNORE_WARNING__
@@ -1085,13 +1192,12 @@ def doDependancyChecks():
     if pyqtVariant == "PyQt4":
         impModulesList = [
             "PyQt4.QtGui", "PyQt4.QtNetwork", "PyQt4.QtSql",
-            "PyQt4.QtSvg", "PyQt4.QtWebKit",
+            "PyQt4.QtSvg",
         ]
     else:
         impModulesList = [
             "PyQt5.QtGui", "PyQt5.QtNetwork", "PyQt5.QtPrintSupport",
-            "PyQt5.QtSql", "PyQt5.QtSvg", "PyQt5.QtWebKit",
-            "PyQt5.QtWebKitWidgets", "PyQt5.QtWidgets",
+            "PyQt5.QtSql", "PyQt5.QtSvg", "PyQt5.QtWidgets",
         ]
     modulesOK = True
     for impModule in impModulesList:
@@ -1130,16 +1236,16 @@ def doDependancyChecks():
         import sip
         sipVersion = sip.SIP_VERSION_STR
         print("sip Version:", sipVersion.strip())
-        # always assume, that snapshots are new enough
-        if "snapshot" not in sipVersion:
+        # always assume, that snapshots or dev versions are new enough
+        if "snapshot" not in sipVersion and "dev" not in sipVersion:
             while sipVersion.count('.') < 2:
                 sipVersion += '.0'
-            (maj, min, pat) = sipVersion.split('.')
-            maj = int(maj)
-            min = int(min)
+            (major, minor, pat) = sipVersion.split('.')
+            major = int(major)
+            minor = int(minor)
             pat = int(pat)
-            if maj < 4 or (maj == 4 and min < 14) or \
-                    (maj == 4 and min == 14 and pat < 2):
+            if major < 4 or (major == 4 and minor < 14) or \
+                    (major == 4 and minor == 14 and pat < 2):
                 print('Sorry, you must have sip 4.14.2 or higher or'
                       ' a recent snapshot release.')
                 exit(3)
@@ -1161,17 +1267,17 @@ def doDependancyChecks():
         from PyQt5.QtCore import PYQT_VERSION_STR
     pyqtVersion = PYQT_VERSION_STR
     print("PyQt Version:", pyqtVersion.strip())
-    # always assume, that snapshots are new enough
-    if "snapshot" not in pyqtVersion:
+    # always assume, that snapshots or dev versions are new enough
+    if "snapshot" not in pyqtVersion and "dev" not in pyqtVersion:
         while pyqtVersion.count('.') < 2:
             pyqtVersion += '.0'
-        (maj, min, pat) = pyqtVersion.split('.')
-        maj = int(maj)
-        min = int(min)
+        (major, minor, pat) = pyqtVersion.split('.')
+        major = int(major)
+        minor = int(minor)
         pat = int(pat)
-        if maj < 4 or \
-            (maj == 4 and min < 10) or \
-                (maj == 5 and min < 3):
+        if major < 4 or \
+            (major == 4 and minor < 10) or \
+                (major == 5 and minor < 3):
             print('Sorry, you must have PyQt 4.10.0 or better or')
             print('PyQt 5.3.0 or better or'
                   ' a recent snapshot release.')
@@ -1191,15 +1297,15 @@ def doDependancyChecks():
         from PyQt5.Qsci import QSCINTILLA_VERSION_STR
     scintillaVersion = QSCINTILLA_VERSION_STR
     print("QScintilla Version:", QSCINTILLA_VERSION_STR.strip())
-    # always assume, that snapshots are new enough
-    if "snapshot" not in scintillaVersion:
+    # always assume, that snapshots or dev versions are new enough
+    if "snapshot" not in scintillaVersion and "dev" not in scintillaVersion:
         while scintillaVersion.count('.') < 2:
             scintillaVersion += '.0'
-        (maj, min, pat) = scintillaVersion.split('.')
-        maj = int(maj)
-        min = int(min)
+        (major, minor, pat) = scintillaVersion.split('.')
+        major = int(major)
+        minor = int(minor)
         pat = int(pat)
-        if maj < 2 or (maj == 2 and min < 8):
+        if major < 2 or (major == 2 and minor < 8):
             print('Sorry, you must have QScintilla 2.8.0 or higher or'
                   ' a recent snapshot release.')
             exit(5)
@@ -1217,101 +1323,28 @@ def doDependancyChecks():
     print()
 
 
+def __pyName(py_dir, py_file):
+    """
+    Local function to create the Python source file name for the compiled
+    .ui file.
+    
+    @param py_dir suggested name of the directory (string)
+    @param py_file suggested name for the compile source file (string)
+    @return tuple of directory name (string) and source file name (string)
+    """
+    return py_dir, "Ui_{0}".format(py_file)
+
+
 def compileUiFiles():
     """
     Compile the .ui files to Python sources.
-    """                                                 # __IGNORE_WARNING__
+    """
     global sourceDir
-    try:
-        if pyqtVariant == "PyQt4":
-            from PyQt4.uic import compileUiDir
-        else:
-            from PyQt5.uic import compileUiDir
-    except ImportError:
-        if pyqtVariant == "PyQt4":
-            from PyQt4.uic import compileUi
-        else:
-            from PyQt5.uic import compileUi
-        
-        def compileUiDir(dir, recurse=False,            # __IGNORE_WARNING__
-                         map=None, **compileUi_args):
-            """
-            Creates Python modules from Qt Designer .ui files in a directory or
-            directory tree.
-            
-            Note: This function is a modified version of the one found in
-            PyQt5.
-
-            @param dir Name of the directory to scan for files whose name ends
-                with '.ui'. By default the generated Python module is created
-                in the same directory ending with '.py'.
-            @param recurse flag indicating that any sub-directories should be
-                scanned.
-            @param map an optional callable that is passed the name of the
-                directory containing the '.ui' file and the name of the Python
-                module that will be created. The callable should return a
-                tuple of the name of the directory in which the Python module
-                will be created and the (possibly modified) name of the module.
-            @param compileUi_args any additional keyword arguments that are
-                passed to the compileUi() function that is called to create
-                each Python module.
-            """
-            def compile_ui(ui_dir, ui_file):
-                """
-                Local function to compile a single .ui file.
-                
-                @param ui_dir directory containing the .ui file (string)
-                @param ui_file file name of the .ui file (string)
-                """
-                # Ignore if it doesn't seem to be a .ui file.
-                if ui_file.endswith('.ui'):
-                    py_dir = ui_dir
-                    py_file = ui_file[:-3] + '.py'
-
-                    # Allow the caller to change the name of the .py file or
-                    # generate it in a different directory.
-                    if map is not None:
-                        py_dir, py_file = list(map(py_dir, py_file))
-
-                    # Make sure the destination directory exists.
-                    try:
-                        os.makedirs(py_dir)
-                    except:
-                        pass
-
-                    ui_path = os.path.join(ui_dir, ui_file)
-                    py_path = os.path.join(py_dir, py_file)
-
-                    ui_file = open(ui_path, 'r')
-                    py_file = open(py_path, 'w')
-
-                    try:
-                        compileUi(ui_file, py_file, **compileUi_args)
-                    finally:
-                        ui_file.close()
-                        py_file.close()
-
-            if recurse:
-                for root, _, files in os.walk(dir):
-                    for ui in files:
-                        compile_ui(root, ui)
-            else:
-                for ui in os.listdir(dir):
-                    if os.path.isfile(os.path.join(dir, ui)):
-                        compile_ui(dir, ui)
-    
-    def pyName(py_dir, py_file):
-        """
-        Local function to create the Python source file name for the compiled
-        .ui file.
-        
-        @param py_dir suggested name of the directory (string)
-        @param py_file suggested name for the compile source file (string)
-        @return tuple of directory name (string) and source file name (string)
-        """
-        return py_dir, "Ui_{0}".format(py_file)
-    
-    compileUiDir(sourceDir, True, pyName)
+    if pyqtVariant == "PyQt4":
+        from PyQt4.uic import compileUiDir
+    else:
+        from PyQt5.uic import compileUiDir
+    compileUiDir(sourceDir, True, __pyName)
 
 
 def prepareInfoFile(fileName):
@@ -1331,7 +1364,7 @@ def prepareInfoFile(fileName):
         hgOut = subprocess.check_output(["hg", "identify", "-i"])
         if sys.version_info[0] == 3:
             hgOut = hgOut.decode()
-    except (FileNotFoundError, subprocess.CalledProcessError):
+    except (OSError, subprocess.CalledProcessError):
         hgOut = ""
     if hgOut:
         hgOut = hgOut.strip()
@@ -1421,7 +1454,7 @@ def main(argv):
                     print("The configuration dictionary in '{0}' is incorrect."
                           " Aborting".format(arg))
                     exit(6)
-            except:
+            except Exception:
                 cfg = {}
         elif opt == "-m":
             macAppBundleName = arg
@@ -1499,12 +1532,13 @@ def main(argv):
     if doCompile:
         print("\nCompiling source files ...")
         # Hide compile errors (mainly because of Py2/Py3 differences)
+        skipRe = re.compile(r"DebugClients[\\/]Python[\\/]")
         sys.stdout = io.StringIO()
         if distDir:
             compileall.compile_dir(
                 sourceDir,
                 ddir=os.path.join(distDir, modDir, cfg['ericDir']),
-                rx=re.compile(r"DebugClients[\\/]Python[\\/]"),
+                rx=skipRe,
                 quiet=True)
             py_compile.compile(
                 configName,
@@ -1513,7 +1547,7 @@ def main(argv):
             compileall.compile_dir(
                 sourceDir,
                 ddir=os.path.join(modDir, cfg['ericDir']),
-                rx=re.compile(r"DebugClients[\\/]Python[\\/]"),
+                rx=skipRe,
                 quiet=True)
             py_compile.compile(configName,
                                dfile=os.path.join(modDir, "eric6config.py"))
@@ -1552,8 +1586,11 @@ if __name__ == "__main__":
         main(sys.argv)
     except SystemExit:
         raise
-    except:
+    except Exception:
         print("""An internal error occured.  Please report all the output"""
               """ of the program,\nincluding the following traceback, to"""
               """ eric-bugs@eric-ide.python-projects.org.\n""")
         raise
+
+#
+# eflag: noqa = M801
