@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is a  script to patch mod_python for eric6.
 
@@ -8,6 +8,8 @@
 Script to patch mod_python for usage with the eric6 IDE.
 """
 
+from __future__ import unicode_literals
+
 import sys
 import os
 import shutil
@@ -82,40 +84,41 @@ def main(argv):
     
     try:
         filename = os.path.join(modDir, "apache.py")
-        with open(filename, "r", encoding="utf-8") as f:
-            lines = f.readlines()
-    except OSError:
+        f = open(filename, "r", encoding="utf-8")
+    except EnvironmentError:
         print("The file {0} does not exist. Aborting.".format(filename))
         sys.exit(1)
     
+    lines = f.readlines()
+    f.close()
+    
     pdbFound = False
     ericFound = False
     
     sn = "apache.py"
-    with open(sn, "w", encoding="utf-8") as s:
-        for line in lines:
-            if not pdbFound and line.startswith("import pdb"):
-                s.write("import eric6.DebugClients.Python.eric6dbgstub as"
-                        " pdb\n")
-                pdbFound = True
-            else:
-                s.write(line)
-                if line.startswith("import eric6"):
-                    ericFound = True
-        
-        if not ericFound:
-            s.write("\n")
-            s.write('def initDebugger(name):\n')
-            s.write('    """\n')
-            s.write('    Initialize the debugger and set the script name to be'
-                    ' reported \n')
-            s.write('    by the debugger. This is a patch for eric6.\n')
-            s.write('    """\n')
-            s.write('    if not pdb.initDebugger("standard"):\n')
-            s.write('        raise ImportError("Could not initialize'
-                    ' debugger")\n')
-            s.write('    pdb.setScriptname(name)\n')
-            s.write("\n")
+    s = open(sn, "w", encoding="utf-8")
+    for line in lines:
+        if not pdbFound and line.startswith("import pdb"):
+            s.write("import eric6.DebugClients.Python.eric6dbgstub as pdb\n")
+            pdbFound = True
+        else:
+            s.write(line)
+            if line.startswith("import eric6"):
+                ericFound = True
+    
+    if not ericFound:
+        s.write("\n")
+        s.write('def initDebugger(name):\n')
+        s.write('    """\n')
+        s.write('    Initialize the debugger and set the script name to be'
+                ' reported \n')
+        s.write('    by the debugger. This is a patch for eric6.\n')
+        s.write('    """\n')
+        s.write('    if not pdb.initDebugger("standard"):\n')
+        s.write('        raise ImportError("Could not initialize debugger")\n')
+        s.write('    pdb.setScriptname(name)\n')
+        s.write("\n")
+    s.close()
     
     if ericFound:
         print("Mod_python is already patched for eric6.")
